{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "---\n",
    "title: 'Week 07 - Student Notebook'\n",
    "subtitle: Dimensionality reduction using PCA and UMAP\n",
    "author: MY NAME (MY CANDIDATE NUMBER)\n",
    "date: 03 March 2025\n",
    "---\n",
    "\n",
    "Let's start by loading the required packages!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "c:\\Users\\User\\AppData\\Local\\Programs\\Python\\Python313\\Lib\\site-packages\\tqdm\\auto.py:21: TqdmWarning: IProgress not found. Please update jupyter and ipywidgets. See https://ipywidgets.readthedocs.io/en/stable/user_install.html\n",
      "  from .autonotebook import tqdm as notebook_tqdm\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "\n",
       "            <div id=\"qR8iPH\"></div>\n",
       "            <script type=\"text/javascript\" data-lets-plot-script=\"library\">\n",
       "                if(!window.letsPlotCallQueue) {\n",
       "                    window.letsPlotCallQueue = [];\n",
       "                }; \n",
       "                window.letsPlotCall = function(f) {\n",
       "                    window.letsPlotCallQueue.push(f);\n",
       "                };\n",
       "                (function() {\n",
       "                    var script = document.createElement(\"script\");\n",
       "                    script.type = \"text/javascript\";\n",
       "                    script.src = \"https://cdn.jsdelivr.net/gh/JetBrains/lets-plot@v4.5.1/js-package/distr/lets-plot.min.js\";\n",
       "                    script.onload = function() {\n",
       "                        window.letsPlotCall = function(f) {f();};\n",
       "                        window.letsPlotCallQueue.forEach(function(f) {f();});\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        \n",
       "                    };\n",
       "                    script.onerror = function(event) {\n",
       "                        window.letsPlotCall = function(f) {};    // noop\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        var div = document.createElement(\"div\");\n",
       "                        div.style.color = 'darkred';\n",
       "                        div.textContent = 'Error loading Lets-Plot JS';\n",
       "                        document.getElementById(\"qR8iPH\").appendChild(div);\n",
       "                    };\n",
       "                    var e = document.getElementById(\"qR8iPH\");\n",
       "                    e.appendChild(script);\n",
       "                })()\n",
       "            </script>\n",
       "            "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import numpy as np\n",
    "import pandas as pd\n",
    "from sklearn.decomposition import PCA\n",
    "from sklearn.pipeline import Pipeline\n",
    "from sklearn.preprocessing import StandardScaler\n",
    "from umap import UMAP\n",
    "import plotly.express as px\n",
    "from lets_plot import *\n",
    "LetsPlot.setup_html()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Exploring ethical values and norms in the World Values Survey (15 minutes)\n",
    "\n",
    "The WVS provides information on 19 such issues which respondents can rate from 0 (never justifiable) to 10 (always justifiable), including:\n",
    "\n",
    "-   `Q177`: Claiming government benefits to which you are not entitled \n",
    "-   `Q178`: Avoiding a fare on public transport\n",
    "-   `Q179`: Stealing property \n",
    "-   `Q180`: Cheating on taxes if you have a chance \n",
    "-   `Q181`: Someone accepting a bribe in the course of their duties \n",
    "-   `Q182`: Homosexuality\n",
    "-   `Q183`: Prostitution\n",
    "-   `Q184`: Abortion\n",
    "-   `Q185`: Divorce\n",
    "-   `Q186`: Sex before marriage\n",
    "-   `Q187`: Suicide\n",
    "-   `Q188`: Euthanasia\n",
    "-   `Q189`: For a man to beat his wife\n",
    "-   `Q190`: Parents beating children\n",
    "-   `Q191`: Violence against other people\n",
    "-   `Q192`: Terrorism as a political, ideological or religious mean\n",
    "-   `Q193`: Having casual sex\n",
    "-   `Q194`: Political violence\n",
    "-   `Q195`: Death penalty\n",
    "\n",
    "🗣️ **CLASSROOM DISCUSSION:** How could we explore relationships between these features?\n",
    "\n",
    "🎯 **ACTION POINT:** Read the data set into Python (set `low_memory = False`)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "wvs = pd.read_csv(\"../data/wvs-wave-7-ethical-norms.csv\", low_memory=False)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🎯 **ACTION POINT:** Rename the variables to better reflect the ethical value / norm"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a list of columns to keep\n",
    "\n",
    "\n",
    "# Create a list of descriptive labels for the columns\n",
    "\n",
    "\n",
    "# Create a dictionary to rename the columns in the data frame, adapt the below code:\n",
    "# vars_renamed = dict(zip(list of columns to keep, list of descriptive labels))\n",
    "\n",
    "# Employ the changes to data frame\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Principle Component Analysis with the World Values Survey (45 minutes)\n",
    "\n",
    "Besides making data exploration and visualization difficult, high dimensional data comes with other challenges too, in particular with regards to supervised learning.\n",
    "\n",
    "::: callout-tip\n",
    "## Pay Attention\n",
    "\n",
    "🧑‍🏫 **TEACHING MOMENT:**\n",
    "\n",
    "### The Curse of Dimensionality 🪄\n",
    "\n",
    "No, that's not a Harry Potter spell but it refers to the problems that often arise when dealing with high dimensional data (ie lots of variables).\n",
    "\n",
    "Machine learning models tend to perform badly with too many features - there is a higher chance for overfitting, plus there is also a much bigger computational cost associated to training models with many variables.\n",
    "\n",
    "### Dimensionality Reduction to the Rescue 🧑‍⚕️\n",
    "\n",
    "We want to reduce the number of variables. Intuitively, this could work because there are often strong correlations between many of the individual variables. In other words, there is redundancy in the data.\n",
    "\n",
    "Dimensionality reduction refers to a collection of methods that can help reduce the number of variables while preserving most of the information. PCA is one such method.\n",
    "\n",
    "### Principal Component Analysis (PCA) 💡\n",
    "\n",
    "However, rather than deciding which variables to keep and which ones to throw out (that would fall under \"*variable selection*\"), we want to compress our high dimensional data into a low dimensional set of variables while retaining as much information from the original data as possible.\n",
    "\n",
    ":::\n",
    "\n",
    "To implement PCA, we must first normalise our variables.  Up until now, we have employed a user-based function.  However, because we have only numeric features, we can actually perform the data transformation and PCA in one step using pipelines!  `Pipeline` consists of a list of tuples, `(user defined step name, model instantiation)` that can be seen as a series of steps to be run in order to apply a model.\n",
    "\n",
    "🎯 **ACTION POINT:** Use `Pipeline` to combine `StandardScaler()` and `PCA()` and fit the pipeline to the cleaned data."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a pipeline whereby all features are scaled\n",
    "\n",
    "\n",
    "# Fit the pipeline to the full data set\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🎯 **ACTION POINT:** With pipelines, accessing the attributes of each step may seem tricky at first.  Luckily, however, any pipeline has a `named_steps` attribute, which can allow you to explore all the attributes that pertain to a specific step.  Try this with the `explained_variance_ratio_` attribute which gives us the proportion of variance explained by each principle component between all features.  **Ideally, we would like to see a graph showing the cumulative proportion of variance explained over the first 10 principle components.**"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Code here"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🗣️ **CLASSROOM DISCUSSION:** Do we notice anything in particular?"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🎯 **ACTION POINT:** Use `fit_transform` on the cleaned data to create an array.  Use `pd.DataFrame()` to transform this output into a singular data frame.  Try using list comprehension to create a series of variable names such as pc1, ..., pc19"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Employ fit_transform to create an array\n",
    "\n",
    "\n",
    "# Convert the array to a data frame and rename the columns\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🎯 **ACTION POINT:** Plot the first two principle components."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Code here"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "👨🏻‍🏫 **TEACHING MOMENT:**  Why is there no correlation between the first and second principle components?\n",
    "\n",
    "We can further elaborate on each principle component by understanding the role each feature plays in influencing its loadings.  We assess two aspects of the loadings.\n",
    "-   **Magnitude:** larger absolute loadings show that a given feature will have a greater influence on the principle component.\n",
    "-   **Sign:** positive / negative loadings indicate that a feature will contribute positively / negatively to the principle component."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a list of data frames for each loading\n",
    "\n",
    "\n",
    "# Concatenate the list of data frames to create a singular data frame\n",
    "\n",
    "\n",
    "# Create a new column showing the absolute value of the loading\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🎯 **ACTION POINT:** Plot the loadings of the first 4 principle components using a bar graph.  Add `facet_wrap(facets=\"component\")` to the plot to see the loading for each principle component in isolation."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Code here"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🗣️ **CLASSROOM DISCUSSION:**  How can we describe each principle component? \n",
    "\n",
    "-   **PC1:** There are none that stand out - in fact, it looks like the principle component indicates moderate positions on all values / norms.\n",
    "-   **PC2:** Interestingly, we see that issues such as sex before marriage, abortion tend to positively influence the principle component and issues such as the use of violence tend to negatively influence the principle component.\n",
    "-   **PC3:** We see almost the flip side of PC2, although avoiding transport fairs and the death penalty influence the principle component the most.\n",
    "-   **PC4:** This is the most interesting.  On the one hand, we see strong positive influence of the death penalty, yet political violence and terrorism strongly / negatively influence the principle component. \n",
    "\n",
    "## Part II: Using UMAP on the Varieties of Democracy Data Set (30 mins)\n",
    "\n",
    "To round off our exploration of dimensionality reduction, we will look at UMAP (Uniform Manifold Approximation and Projection). UMAP, in essence, takes data that has a high number of dimensions and compresses it to a 2-dimensional feature space.\n",
    "\n",
    "👉 **NOTE:** Andy Coenen and Adam Pearce of Google PAIR have put together an excellent tutorial on UMAP (click [here](https://pair-code.github.io/understanding-umap/))."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {},
   "outputs": [],
   "source": [
    "vdem = pd.read_csv(\"../data/vdem-data-subset.csv\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "To explore this in the context of social science data, we will be looking at the Varieties of Democracy data set (2010-2023). Specifically, we will be looking at four different variables\n",
    "\n",
    "-   `v2x_polyarchy`: Index of free and fair elections.\n",
    "-   `v2x_libdem`: Index of liberal democracy (protection of individuals / minorities from the tyranny of the state/majority).\n",
    "-   `v2x_partip`: Index of participatory democracy (participation of citizens in all political processes).\n",
    "-   `regime`: Four-fold typology of political regimes, namely, closed autocracy, electoral autocracy, electoral democracy, liberal democracy.\n",
    "\n",
    "We will represent the three indices using a 3-d scatter plot, using colour to distinguish between regime type:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "hovertemplate": "regime=Electoral Democracy<br>v2x_polyarchy=%{x}<br>v2x_libdem=%{y}<br>v2x_partipdem=%{z}<extra></extra>",
         "legendgroup": "Electoral Democracy",
         "marker": {
          "color": "#636efa",
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Electoral Democracy",
         "scene": "scene",
         "showlegend": true,
         "type": "scatter3d",
         "x": [
          0.514565574365911,
          0.5184384291422404,
          0.5068198648132521,
          0.3906342215233703,
          0.3983799310760291,
          0.45647275272097,
          0.4642184622736288,
          0.45647275272097,
          0.5997683794451577,
          0.6075140889978164,
          0.5184384291422404,
          0.3673970928653939,
          0.2047371922595592,
          0.061441565535372,
          0.940579599762144,
          0.9095967615515088,
          0.9095967615515088,
          0.9212153258804971,
          0.9212153258804971,
          0.9328338902094854,
          0.9560710188674616,
          0.9212153258804971,
          0.9018510519988502,
          0.8669953590118856,
          0.9134696163278384,
          0.8979781972225208,
          0.9947995666307556,
          0.8553767946828974,
          0.8205211016959328,
          0.8669953590118856,
          0.870868213788215,
          0.8011568278142859,
          0.7895382634852977,
          0.5532941221292049,
          0.5649126864581931,
          0.5532941221292049,
          0.9328338902094854,
          0.8941053424461913,
          0.8941053424461913,
          0.8824867781172032,
          0.8437582303539092,
          0.8437582303539092,
          0.7469368609456744,
          0.7585554252746625,
          0.7972839730379565,
          0.7469368609456744,
          0.6539883463137692,
          0.1272800967329717,
          0.1272800967329717,
          0.1117886776276541,
          0.022713017772078,
          0.0343315821010662,
          0.0343315821010662,
          0.042077291653725,
          0.0846786941933484,
          0.0343315821010662,
          -0.0043969656622277,
          0.0691872750880308,
          0.0459501464300544,
          0.0188401629957486,
          -0.0315069490965334,
          0.4022527858523584,
          0.5455484125765462,
          0.5378027030238873,
          0.5687855412345225,
          0.6075140889978164,
          0.642369781984781,
          0.6152597985504753,
          0.6113869437741458,
          0.5765312507871813,
          0.5068198648132521,
          0.4719641718262876,
          0.495201300484264,
          0.6810983297480746,
          0.7198268775113685,
          0.812775392143274,
          0.665606910642757,
          0.6578612010900982,
          0.642369781984781,
          0.3673970928653939,
          0.2667028686808296,
          0.2357200304701944,
          0.270575723457159,
          1.3511022060530598,
          1.3704664799347066,
          1.3665936251583772,
          1.393703608592683,
          1.3898307538163537,
          1.3549750608293891,
          1.0064181309597438,
          0.9870538570780968,
          0.890232487669862,
          0.6694797654190864,
          0.6888440393007333,
          0.6075140889978164,
          0.6733526201954158,
          1.0296552596177202,
          1.265899400973813,
          0.3867613667470408,
          0.3867613667470408,
          0.4099984954050172,
          0.4216170597340054,
          0.5687855412345225,
          0.5455484125765462,
          0.5687855412345225,
          0.5958955246688283,
          0.4835827361552758,
          0.3170499807731117,
          0.0149673082194192,
          0.6539883463137692,
          0.6346240724321223,
          0.6346240724321223,
          0.5649126864581931,
          0.5184384291422404,
          0.379015657194382,
          0.4254899145103348,
          0.3983799310760291,
          0.3093042712204529,
          0.3402871094310881,
          0.2976857068914648,
          0.2628300139045002,
          0.0730601298643602,
          0.061441565535372,
          0.3325413998784293,
          0.3441599642074175,
          0.1040429680749953,
          0.1001701132986659,
          0.1001701132986659,
          0.0459501464300544,
          1.1226037742496258,
          1.1380951933549432,
          1.1845694506708957,
          1.176823741118237,
          1.1652051767892486,
          1.15745946723659,
          1.045146678723038,
          1.0528923882756966,
          1.1303494838022845,
          1.1109852099206377,
          1.1613323220129192,
          0.9715624379727792,
          0.8824867781172032,
          0.7004626036297216,
          0.6268783628794634,
          0.6268783628794634,
          0.6810983297480746,
          0.7856654087089683,
          0.7895382634852977,
          0.7895382634852977,
          0.7856654087089683,
          0.7043354584060509,
          0.7004626036297216,
          0.8011568278142859,
          0.8592496494592268,
          0.8050296825906152,
          0.6578612010900982,
          0.3828885119707115,
          0.928961035433156,
          0.940579599762144,
          0.979308147525438,
          1.0102909857360731,
          1.0412738239467083,
          0.979308147525438,
          0.9250881806568264,
          0.9095967615515088,
          1.0490195334993673,
          1.0490195334993673,
          1.1380951933549432,
          1.1226037742496258,
          1.227170853210519,
          1.246535127092166,
          0.623005508103134,
          0.623005508103134,
          0.6113869437741458,
          0.5416755578002167,
          0.3983799310760291,
          0.1311529515093011,
          0.0575687107590426,
          0.003348743890431,
          0.0536958559827132,
          0.0536958559827132,
          0.0653144203117014,
          0.1079158228513247,
          0.1776272088252534,
          0.042077291653725,
          -0.0315069490965334,
          -0.0082698204385571,
          0.2667028686808296,
          0.4874555909316052,
          0.4797098813789464,
          0.2086100470358886,
          0.5261841386948991,
          0.6036412342214871,
          0.5532941221292049,
          0.5726583960108519,
          0.6075140889978164,
          0.6036412342214871,
          -0.0160155299912158,
          0.042077291653725,
          0.0691872750880308,
          0.1853729183779122,
          0.1698814992725951,
          0.1737543540489241,
          0.1466443706146187,
          0.0265858725484074,
          0.0188401629957486,
          0.0343315821010662,
          0.1195343871803129,
          0.1195343871803129,
          0.1195343871803129,
          0.1195343871803129,
          0.1272800967329717,
          -0.0005241108858983132,
          -0.0508712229781804,
          0.5029470100369228,
          0.3364142546547587,
          0.3131771259967824,
          0.3402871094310881,
          0.3480328189837469,
          0.5532941221292049,
          0.7546825704983331,
          0.7391911513930155,
          0.3867613667470408,
          0.3519056737600763,
          0.3519056737600763,
          0.3441599642074175,
          0.2357200304701944,
          0.2202286113648768,
          0.2395928852465238,
          0.1853729183779122,
          0.2163557565885474,
          0.2473385947991826,
          0.3209228355494411,
          0.3015585616677941,
          0.1621357897199363,
          0.2008643374832298,
          0.2047371922595592,
          0.3170499807731117,
          0.2086100470358886,
          0.665606910642757,
          0.6694797654190864,
          0.6113869437741458,
          0.5532941221292049,
          0.5455484125765462,
          0.417744204957676,
          0.6888440393007333,
          0.6888440393007333,
          0.6888440393007333,
          0.6268783628794634,
          0.5842769603398401,
          0.5416755578002167,
          0.4874555909316052,
          0.437108478839323,
          0.3286685451020999,
          0.3209228355494411,
          0.2241014661412062,
          0.1543900801672775,
          0.1815000636015828,
          0.0885515489696778,
          0.1195343871803129,
          0.1272800967329717,
          0.4216170597340054,
          0.4913284457079346,
          0.5571669769055343,
          0.5610398316818637,
          0.45647275272097,
          0.3209228355494411,
          0.3093042712204529,
          0.3519056737600763,
          0.4448541883919818,
          0.6307512176557929,
          0.1350258062856305,
          0.4216170597340054,
          0.4409813336156524,
          0.4293627692866642,
          0.3983799310760291,
          0.2357200304701944,
          0.1195343871803129,
          0.0769329846406896,
          0.061441565535372,
          0.1117886776276541,
          0.0072215986667604,
          -0.0353798038728628,
          -0.0392526586491922,
          -0.0586169325308392,
          -0.0547440777545098,
          0.0149673082194192,
          0.042077291653725,
          0.042077291653725,
          0.0924244037460072,
          0.0885515489696778,
          0.061441565535372,
          1.3162465130660952,
          1.3046279487371069,
          0.2821942877861472,
          0.2163557565885474,
          0.1543900801672775,
          1.0219095500650617,
          1.056765243052026,
          1.0606380978283554,
          1.099366645591649,
          1.099366645591649,
          1.0838752264863318,
          1.099366645591649,
          1.0838752264863318,
          1.018036695288732,
          1.037400969170379,
          1.0722566621573435,
          0.998672421407085,
          0.9134696163278384,
          0.9134696163278384,
          1.2116794341052015,
          1.2194251436578605,
          0.4138713501813466,
          0.4138713501813466,
          0.4874555909316052,
          0.4680913170499582,
          0.4293627692866642,
          0.4409813336156524,
          0.3596513833127351,
          0.5223112839185697,
          0.6152597985504753,
          0.665606910642757,
          0.5804041055635107,
          0.6307512176557929,
          0.665606910642757,
          0.6965897488533922,
          0.2860671425624765,
          0.2667028686808296,
          0.2860671425624765,
          0.0885515489696778,
          0.0769329846406896,
          0.0962972585223365,
          0.1079158228513247,
          0.1543900801672775,
          0.5300569934712286,
          0.4022527858523584,
          0.4099984954050172,
          0.4099984954050172,
          0.5687855412345225,
          0.495201300484264,
          0.2821942877861472,
          0.2821942877861472,
          0.2473385947991826,
          0.2473385947991826,
          0.2589571591281708,
          0.3209228355494411,
          0.4254899145103348,
          0.417744204957676,
          0.3209228355494411,
          0.3441599642074175,
          0.2976857068914648,
          0.1388986610619599,
          -0.0431255134255216,
          -0.0508712229781804,
          1.238789417539507,
          1.2581536914211542,
          0.212482901812218,
          0.251211449575512,
          0.2589571591281708,
          0.4293627692866642,
          0.4293627692866642,
          0.3015585616677941,
          0.2241014661412062,
          -0.0586169325308392,
          0.3015585616677941,
          0.4216170597340054,
          0.4525998979446406,
          0.4061256406286879,
          0.495201300484264,
          0.4874555909316052,
          0.533929848247558,
          0.514565574365911,
          0.4797098813789464,
          0.379015657194382,
          0.3635242380890645,
          0.3596513833127351,
          0.3751428024180527,
          0.4099984954050172,
          0.4138713501813466,
          0.4061256406286879,
          0.4719641718262876,
          0.4332356240629936,
          0.4487270431683112,
          0.4680913170499582,
          0.003348743890431,
          0.0110944534430898,
          0.0769329846406896,
          0.1543900801672775,
          0.0924244037460072,
          0.0691872750880308,
          0.0691872750880308,
          0.0962972585223365,
          0.0343315821010662,
          0.1040429680749953,
          0.3364142546547587,
          0.3596513833127351,
          0.2395928852465238,
          0.3247956903257705,
          0.3325413998784293,
          0.1001701132986659,
          0.212482901812218,
          0.2357200304701944,
          0.2434657400228532,
          0.270575723457159,
          0.3131771259967824,
          0.6152597985504753,
          0.642369781984781,
          0.6694797654190864,
          0.6694797654190864,
          0.6733526201954158,
          0.6075140889978164,
          0.6113869437741458,
          0.5765312507871813,
          0.533929848247558,
          0.5455484125765462,
          0.45647275272097,
          0.3596513833127351,
          0.2086100470358886,
          0.0343315821010662,
          0.890232487669862,
          0.890232487669862,
          0.890232487669862,
          0.9212153258804971,
          0.8863596328935326,
          0.9173424711041678,
          0.9173424711041678,
          0.8592496494592268,
          0.8321396660249211,
          0.8398853755775798,
          0.8398853755775798,
          0.8747410685645444,
          0.8282668112485916,
          0.8205211016959328,
          -0.0160155299912158,
          -0.0160155299912158,
          -0.0547440777545098,
          -0.0547440777545098,
          -0.0547440777545098,
          -0.0547440777545098,
          -0.0586169325308392,
          0.0769329846406896,
          0.0924244037460072,
          0.1079158228513247,
          0.1117886776276541,
          0.1698814992725951,
          0.9715624379727792,
          0.928961035433156,
          0.8979781972225208,
          0.8089025373669446,
          0.8205211016959328,
          0.8321396660249211,
          0.8360125208012504,
          0.7972839730379565,
          0.7391911513930155,
          0.0653144203117014,
          0.042077291653725,
          0.0110944534430898,
          -0.0237612395438746,
          0.022713017772078,
          0.1079158228513247,
          0.0575687107590426,
          0.042077291653725,
          1.0916209360389906,
          1.0296552596177202,
          0.8166482469196035,
          0.514565574365911,
          0.4487270431683112,
          0.3945070762996996,
          0.3712699476417233,
          0.3247956903257705,
          0.3015585616677941,
          0.3015585616677941,
          0.2434657400228532,
          0.1466443706146187,
          0.1001701132986659,
          0.1311529515093011,
          0.1195343871803129,
          0.495201300484264,
          0.6578612010900982,
          0.6462426367611104,
          0.6462426367611104,
          -0.0624897873071686,
          0.0730601298643602,
          0.0149673082194192,
          -0.046998368201851,
          0.4099984954050172,
          0.475837026602617,
          -0.066362642083498,
          -0.0586169325308392,
          -0.0160155299912158,
          0.3983799310760291,
          0.6036412342214871,
          0.5997683794451577,
          0.6772254749717451,
          0.665606910642757,
          0.6113869437741458,
          0.4525998979446406,
          0.4293627692866642,
          0.4525998979446406,
          0.4448541883919818,
          0.3325413998784293,
          -0.0315069490965334,
          0.0304587273247368,
          0.0653144203117014,
          0.0691872750880308,
          1.018036695288732,
          0.9909267118544264,
          1.0528923882756966,
          1.0916209360389906,
          1.0916209360389906,
          1.0916209360389906,
          1.114858064696967,
          1.1535866124602605,
          1.134222338578614,
          1.134222338578614,
          1.114858064696967,
          1.099366645591649,
          1.0838752264863318,
          0.0846786941933484,
          -0.066362642083498,
          0.3247956903257705,
          0.5881498151161695,
          0.5455484125765462,
          0.4332356240629936,
          0.3867613667470408,
          0.1737543540489241,
          0.0459501464300544,
          -0.0508712229781804,
          -0.066362642083498,
          0.2550843043518414,
          0.5261841386948991,
          0.928961035433156,
          0.948325309314803,
          0.7546825704983331,
          0.4874555909316052,
          0.5068198648132521,
          0.5068198648132521,
          0.5455484125765462,
          0.5610398316818637,
          0.7779196991563094,
          0.7895382634852977,
          0.7740468443799801,
          0.6733526201954158,
          0.5455484125765462,
          0.495201300484264,
          0.4603456074972994,
          0.4913284457079346,
          0.495201300484264,
          0.1388986610619599,
          0.3093042712204529,
          0.2783214330098177,
          0.3751428024180527,
          0.1815000636015828,
          0.2163557565885474,
          0.2279743209175356,
          0.3325413998784293,
          0.2395928852465238,
          0.9599438736437912,
          0.9095967615515088,
          0.9095967615515088,
          1.2891365296317894,
          1.2310437079868484,
          1.2620265461974836,
          1.0141638405124027,
          1.0141638405124027,
          1.0141638405124027,
          1.0025452761834144,
          0.998672421407085,
          0.212482901812218,
          0.2163557565885474,
          0.212482901812218,
          0.1698814992725951,
          0.1660086444962657,
          0.1156615324039835,
          0.1234072419566423,
          0.1001701132986659,
          0.003348743890431,
          0.0110944534430898,
          0.0188401629957486,
          -0.0237612395438746,
          0.0072215986667604,
          -0.0237612395438746,
          0.6268783628794634,
          0.6075140889978164,
          0.5881498151161695,
          0.5494212673528756,
          0.6152597985504753,
          0.5881498151161695,
          0.5920226698924989,
          0.4293627692866642,
          0.3828885119707115,
          0.3596513833127351,
          0.3480328189837469,
          0.5958955246688283,
          0.6733526201954158,
          0.5726583960108519,
          -0.046998368201851,
          -0.046998368201851,
          1.2736451105264717,
          1.3046279487371069,
          1.3046279487371069,
          1.2194251436578605,
          1.2155522888815309,
          1.1613323220129192,
          0.9521981640911324,
          0.8398853755775798,
          0.8398853755775798,
          0.8669953590118856,
          0.96768958319645,
          0.9212153258804971,
          0.8437582303539092,
          0.8321396660249211,
          0.9909267118544264,
          1.169078031565578,
          1.0800023717100025,
          -0.0547440777545098,
          0.979308147525438,
          0.9018510519988502,
          0.251211449575512,
          0.251211449575512,
          0.2550843043518414,
          0.3673970928653939,
          0.3751428024180527,
          0.514565574365911,
          0.5649126864581931,
          0.5804041055635107,
          0.5842769603398401,
          0.5106927195895815,
          0.1892457731542416,
          0.0498230012063838,
          -0.0005241108858983132,
          -0.0237612395438746,
          0.793411118261627,
          1.1845694506708957,
          1.114858064696967,
          1.15745946723659,
          1.169078031565578,
          1.1303494838022845,
          1.0916209360389906,
          1.0916209360389906,
          1.0838752264863318,
          0.0188401629957486,
          0.1195343871803129,
          0.2241014661412062,
          0.3286685451020999,
          0.2976857068914648,
          0.2589571591281708,
          0.1505172253909481,
          0.1621357897199363,
          -0.046998368201851,
          1.176823741118237,
          1.176823741118237,
          1.176823741118237,
          1.0722566621573435,
          1.0141638405124027,
          1.0141638405124027,
          1.0064181309597438,
          0.9638167284201204,
          0.9367067449858149,
          0.9638167284201204,
          0.9638167284201204,
          0.9947995666307556,
          1.0102909857360731,
          1.0102909857360731,
          0.8166482469196035,
          0.8786139233408737,
          0.8631225042355561,
          0.8592496494592268,
          0.8786139233408737,
          0.6888440393007333,
          0.1117886776276541,
          0.0382044368773956,
          -0.0547440777545098,
          -0.0353798038728628,
          -0.0547440777545098,
          0.2434657400228532,
          0.475837026602617,
          0.437108478839323,
          0.3286685451020999,
          0.2628300139045002,
          0.3093042712204529,
          0.2744485782334884,
          0.251211449575512,
          0.2821942877861472,
          0.2550843043518414,
          0.2667028686808296,
          0.251211449575512,
          0.251211449575512,
          0.251211449575512,
          0.2357200304701944,
          0.6307512176557929,
          0.6384969272084516,
          0.5958955246688283,
          0.5842769603398401,
          0.6036412342214871,
          0.7469368609456744,
          0.8282668112485916,
          0.684971184524404,
          0.665606910642757,
          0.8786139233408737,
          1.09549379081532,
          0.9754352927491088,
          0.6617340558664276,
          0.5842769603398401,
          0.6307512176557929,
          0.6384969272084516,
          0.6191326533268047,
          0.6191326533268047,
          0.6346240724321223,
          0.684971184524404,
          0.6346240724321223,
          0.5920226698924989,
          0.6036412342214871,
          0.7159540227350392,
          0.6772254749717451,
          0.665606910642757,
          0.623005508103134,
          0.6075140889978164,
          -0.066362642083498,
          1.2697722557501423,
          1.2891365296317894,
          1.2891365296317894,
          1.2542808366448248,
          1.1806965958945663,
          0.7663011348273213,
          0.928961035433156,
          0.1079158228513247,
          0.1466443706146187,
          0.1466443706146187,
          0.1350258062856305,
          0.1505172253909481,
          0.1853729183779122,
          0.2241014661412062,
          0.2744485782334884,
          0.289939997338806,
          0.3906342215233703,
          0.3712699476417233,
          0.3712699476417233,
          0.3712699476417233,
          0.3906342215233703,
          0.7663011348273213,
          0.7663011348273213,
          0.7663011348273213,
          0.7817925539326389,
          0.7817925539326389,
          0.7701739896036507,
          0.9173424711041678,
          0.9715624379727792,
          0.948325309314803,
          0.9095967615515088,
          0.8631225042355561,
          0.9715624379727792,
          0.9870538570780968,
          1.076129516933673,
          1.1226037742496258,
          1.0257824048413908,
          0.9870538570780968,
          0.8321396660249211,
          0.5842769603398401,
          0.4061256406286879,
          0.3673970928653939,
          0.1660086444962657
         ],
         "y": [
          0.2403892734364615,
          0.2403892734364615,
          0.2178084117149527,
          0.0710328105251454,
          0.0747962874787302,
          0.1011406261538239,
          0.1049041031074087,
          0.1500658265504263,
          0.1764101652255199,
          0.1161945339681631,
          0.0145806562213734,
          -0.1321949449684336,
          -0.2902609770189951,
          -0.3918748547657848,
          0.8914707864066318,
          0.8688899246851229,
          0.8463090629636142,
          0.8613629707779533,
          0.8613629707779533,
          0.8726534016387077,
          0.8463090629636142,
          0.8425455860100294,
          0.7785664777990877,
          0.6656621691915436,
          0.8651264477315381,
          0.8575994938243685,
          0.9366325098496494,
          0.8538360168707838,
          0.7898569086598421,
          0.8575994938243685,
          0.8538360168707838,
          0.7973838625670118,
          0.7860934317062573,
          0.5791021992590936,
          0.6129734918413564,
          0.5979195840270176,
          0.887707309453047,
          0.8613629707779533,
          0.8914707864066318,
          0.8764168785922926,
          0.8237282012421053,
          0.831255155149275,
          0.7672760469383333,
          0.7446951852168245,
          0.7748030008455029,
          0.7559856160775789,
          0.6807160770058829,
          0.1688832113183503,
          0.1726466882719351,
          0.1726466882719351,
          0.1237214878753327,
          0.1463023495968415,
          0.1463023495968415,
          0.1500658265504263,
          0.1425388726432567,
          0.1086675800609935,
          0.1086675800609935,
          0.1651197343647655,
          0.1350119187360871,
          0.1124310570145783,
          -0.0042367285465503,
          0.3532935820440054,
          0.5075961371409824,
          0.5038326601873976,
          0.5000691832338128,
          0.5377039527696608,
          0.5565213375375848,
          0.5452309066768304,
          0.5414674297232456,
          0.5038326601873976,
          0.3909283515798534,
          0.3307127203224966,
          0.323185766415327,
          0.5791021992590936,
          0.6092100148877716,
          0.7409317082632397,
          0.5113596140945672,
          0.4323265980692863,
          0.3909283515798534,
          0.1726466882719351,
          0.0823232413858998,
          0.0672693335715606,
          0.1538293035040111,
          1.410830606001334,
          1.4371749446764277,
          1.4258845138156733,
          1.4559923294443518,
          1.452228852490767,
          1.4145940829549188,
          0.9629768485247432,
          0.906524694220971,
          0.7860934317062573,
          0.5000691832338128,
          0.5113596140945672,
          0.4699613676051343,
          0.5264135219089063,
          1.087171587993041,
          1.3092167282545444,
          0.0973771492002391,
          0.0973771492002391,
          0.1237214878753327,
          0.1575927804575959,
          0.2592066582043854,
          0.2441527503900463,
          0.2554431812508005,
          0.2554431812508005,
          0.1575927804575959,
          -0.0080002055001351,
          -0.3166053156940888,
          0.0183441331749582,
          0.0108171792677888,
          0.007053702314204,
          0.0032902253606192,
          -0.0230541133144743,
          -0.1020871293397552,
          -0.0832697445718312,
          -0.124667991061264,
          -0.2187549149008841,
          -0.1698297145042816,
          -0.2262818688080535,
          -0.1886470992722057,
          -0.0644523598039072,
          -0.0343445441752287,
          0.0032902253606192,
          0.007053702314204,
          -0.2864975000654103,
          -0.1999375301329601,
          -0.1999375301329601,
          -0.2864975000654103,
          0.9629768485247432,
          0.9855577102462518,
          1.0909350649466258,
          1.0796446340858714,
          1.0758811571322866,
          1.0796446340858714,
          1.0194290028285151,
          1.0382463875964392,
          1.1172794036217195,
          1.105988972760965,
          1.1586776501111524,
          0.9705038024319126,
          0.8688899246851229,
          0.6506082613772044,
          0.4774883215123039,
          0.4774883215123039,
          0.5188865680017367,
          0.6769526000522981,
          0.6731891230987133,
          0.6882430309130525,
          0.6618986922379588,
          0.5715752453519239,
          0.5565213375375848,
          0.63931783051645,
          0.63931783051645,
          0.6242639227021108,
          0.4925422293266431,
          0.2102814578077831,
          0.6995334617738068,
          0.6844795539594677,
          0.6920065078666372,
          0.7334047543560701,
          0.7597490930311637,
          0.7334047543560701,
          0.8162012473349357,
          0.793620385613427,
          0.8952342633602166,
          0.8575994938243685,
          0.944159463756819,
          0.9516864176639886,
          0.9629768485247432,
          1.0796446340858714,
          0.5226500449553215,
          0.5188865680017367,
          0.5113596140945672,
          0.4737248445587191,
          0.342003151183251,
          0.0973771492002391,
          0.022107610128543,
          0.0258710870821278,
          0.0672693335715606,
          0.0672693335715606,
          0.0710328105251454,
          0.1726466882719351,
          0.1989910269470287,
          -0.0606888828503224,
          -0.0757427906646616,
          -0.1510123297363576,
          0.0258710870821278,
          0.1651197343647655,
          0.1613562574111807,
          -0.0230541133144743,
          0.2366257964828768,
          0.3344761972760814,
          0.304368381647403,
          0.3194222894617422,
          0.3946918285334382,
          0.342003151183251,
          -0.1397218988756032,
          -0.068215836757492,
          -0.0493984519895679,
          0.0258710870821278,
          -0.0192906363608895,
          -0.0305810672216439,
          -0.0268175902680591,
          -0.1547758066899424,
          -0.1735931914578664,
          0.022107610128543,
          0.0936136722466542,
          0.0936136722466542,
          0.0936136722466542,
          0.0860867183394846,
          0.0973771492002391,
          -0.1510123297363576,
          -0.2112279609937145,
          0.4699613676051343,
          0.3457666281368358,
          0.3269492433689118,
          0.323185766415327,
          0.3194222894617422,
          0.4925422293266431,
          0.6920065078666372,
          0.7221143234953157,
          0.3081318586009878,
          0.4247996441621167,
          0.4285631211157015,
          0.4247996441621167,
          0.3156588125081574,
          0.3006049046938182,
          0.3081318586009878,
          0.2704970890651398,
          0.2968414277402334,
          0.3532935820440054,
          0.4586709367443799,
          0.4210361672085319,
          -0.1698297145042816,
          -0.1585392836435272,
          -0.1472488527827728,
          0.0145806562213734,
          0.0710328105251454,
          0.4022187824406079,
          0.4323265980692863,
          0.3457666281368358,
          0.2968414277402334,
          0.3081318586009878,
          0.1952275499934439,
          0.5452309066768304,
          0.5377039527696608,
          0.533940475816076,
          0.4774883215123039,
          0.4436170289300407,
          0.4135092133013623,
          0.3721109668119294,
          0.3156588125081574,
          0.2328623195292919,
          0.2215718886685375,
          0.0484519488036366,
          0.0145806562213734,
          -0.0343445441752287,
          -0.162302760597112,
          0.2253353656221223,
          0.2441527503900463,
          0.3683474898583446,
          0.5038326601873976,
          0.5753387223055088,
          0.5828656762126784,
          0.4511439828372103,
          0.2817875199258942,
          0.2704970890651398,
          0.3194222894617422,
          0.3721109668119294,
          0.4511439828372103,
          -0.0305810672216439,
          0.2930779507866486,
          0.3382396742296662,
          0.3269492433689118,
          0.3006049046938182,
          0.1952275499934439,
          0.078559764432315,
          0.007053702314204,
          -0.0155271594073047,
          -0.0117636824537199,
          -0.0268175902680591,
          -0.068215836757492,
          0.0522154257572214,
          0.0522154257572214,
          0.059742379664391,
          0.1124310570145783,
          0.078559764432315,
          -0.1773566684114512,
          -0.2149914379472993,
          -0.2074644840401296,
          -0.2752070692046559,
          1.3468514977903925,
          1.3393245438832229,
          0.2968414277402334,
          0.2253353656221223,
          0.1161945339681631,
          1.105988972760965,
          1.1323333114360588,
          1.1360967883896436,
          1.1737315579254914,
          1.1737315579254914,
          1.1624411270647372,
          1.1774950348790765,
          1.1436237422968132,
          1.1172794036217195,
          1.1323333114360588,
          1.1323333114360588,
          1.042009864550024,
          0.9366325098496494,
          0.9215786020353102,
          1.3694323595119011,
          1.3619054056047315,
          0.2893144738330638,
          0.2893144738330638,
          0.3495301050904206,
          0.323185766415327,
          0.2516797042972158,
          0.2215718886685375,
          0.1801736421791047,
          0.2930779507866486,
          0.3495301050904206,
          0.4135092133013623,
          0.3118953355545726,
          0.323185766415327,
          0.3683474898583446,
          0.3909283515798534,
          -0.3166053156940888,
          -0.3316592235084279,
          -0.3278957465548431,
          -0.4934887325125742,
          -0.516069594234083,
          -0.5123061172804982,
          -0.497252209466159,
          -0.2187549149008841,
          0.2554431812508005,
          0.1877005960862743,
          0.2742605660187246,
          0.2102814578077831,
          0.3946918285334382,
          0.2403892734364615,
          0.0183441331749582,
          0.0032902253606192,
          -0.0268175902680591,
          0.0446884718500518,
          0.0747962874787302,
          0.1350119187360871,
          0.2065179808541983,
          0.2027545039006135,
          0.0710328105251454,
          0.0823232413858998,
          0.040924994896467,
          -0.1359584219220184,
          -0.3316592235084279,
          -0.3542400852299368,
          1.316743682161714,
          1.3242706360688836,
          0.1049041031074087,
          0.1350119187360871,
          0.2027545039006135,
          0.304368381647403,
          0.304368381647403,
          0.1726466882719351,
          0.0898501952930694,
          -0.1171410371540944,
          0.1237214878753327,
          0.323185766415327,
          0.3834013976726839,
          0.3721109668119294,
          0.3758744437655142,
          0.3758744437655142,
          0.3382396742296662,
          0.3307127203224966,
          0.2968414277402334,
          0.1952275499934439,
          0.1952275499934439,
          0.1839371191326895,
          0.1952275499934439,
          0.2215718886685375,
          0.1049041031074087,
          0.0333980409892974,
          0.0936136722466542,
          0.0747962874787302,
          0.0823232413858998,
          0.1237214878753327,
          0.0258710870821278,
          0.0258710870821278,
          0.078559764432315,
          0.1425388726432567,
          0.1274849648289175,
          0.1538293035040111,
          0.1387753956896719,
          0.1914640730398591,
          0.1575927804575959,
          0.2403892734364615,
          0.4473805058836255,
          0.3946918285334382,
          0.3081318586009878,
          -0.0117636824537199,
          -0.0004732515929655609,
          -0.2450992535759775,
          0.0333980409892974,
          0.1124310570145783,
          0.0710328105251454,
          0.1124310570145783,
          0.1877005960862743,
          0.5753387223055088,
          0.601683060980602,
          0.6242639227021108,
          0.5753387223055088,
          0.5640482914447544,
          0.5264135219089063,
          0.5264135219089063,
          0.4925422293266431,
          0.4812517984658887,
          0.5188865680017367,
          0.4247996441621167,
          0.3081318586009878,
          0.1764101652255199,
          0.007053702314204,
          0.5979195840270176,
          0.5979195840270176,
          0.5979195840270176,
          0.5866291531662632,
          0.5602848144911696,
          0.5866291531662632,
          0.5866291531662632,
          0.5791021992590936,
          0.5264135219089063,
          0.5188865680017367,
          0.5678117683983392,
          0.5828656762126784,
          0.6129734918413564,
          0.6317908766092805,
          -0.2977879309261647,
          -0.2977879309261647,
          -0.3429496543691824,
          -0.3429496543691824,
          -0.3429496543691824,
          -0.3580035621835216,
          -0.2639166383439015,
          -0.0945601754325856,
          -0.0795062676182464,
          0.0446884718500518,
          0.0747962874787302,
          0.1161945339681631,
          0.9027612172673862,
          0.8688899246851229,
          0.8801803555458774,
          0.8425455860100294,
          0.8387821090564446,
          0.906524694220971,
          0.8914707864066318,
          0.8575994938243685,
          0.8199647242885205,
          0.2441527503900463,
          -0.1209045141076792,
          -0.1547758066899424,
          -0.181120145365036,
          -0.3241322696012583,
          -0.3053148848333343,
          -0.3090783617869191,
          0.0183441331749582,
          0.8575994938243685,
          0.6807160770058829,
          0.5188865680017367,
          0.1613562574111807,
          0.0710328105251454,
          -0.2037010070865449,
          -0.2450992535759775,
          -0.2639166383439015,
          -0.2977879309261647,
          -0.3053148848333343,
          -0.3354227004620128,
          -0.3805844239050304,
          -0.4219826703944632,
          -0.3918748547657848,
          -0.3881113778122,
          0.0296345640357126,
          0.2065179808541983,
          0.1877005960862743,
          0.1312484417825023,
          -0.0268175902680591,
          0.078559764432315,
          0.0710328105251454,
          0.0635058566179758,
          0.3796379207190991,
          0.4285631211157015,
          -0.2225183918544689,
          -0.2225183918544689,
          -0.1773566684114512,
          0.2065179808541983,
          0.3683474898583446,
          0.4097457363477775,
          0.4661978906515495,
          0.4323265980692863,
          0.4925422293266431,
          0.3495301050904206,
          0.3156588125081574,
          0.304368381647403,
          0.3194222894617422,
          0.2629701351579702,
          -0.312841838740504,
          -0.2601531613903167,
          -0.2338088227152231,
          -0.2639166383439015,
          0.981794233292667,
          0.9592133715711584,
          1.000611618060591,
          1.0457733415036088,
          1.0457733415036088,
          1.0457733415036088,
          1.0721176801787018,
          1.1323333114360588,
          1.087171587993041,
          1.1248063575288891,
          1.0984620188537957,
          1.1022254958073805,
          1.0344829106428544,
          -0.3881113778122,
          -0.5537043637699312,
          0.3909283515798534,
          0.5979195840270176,
          0.5715752453519239,
          0.4661978906515495,
          0.4059822593941927,
          0.2592066582043854,
          0.1086675800609935,
          -0.0117636824537199,
          -0.0456349750359831,
          0.1500658265504263,
          0.4549074597907951,
          0.8387821090564446,
          0.9291055559424798,
          0.7710395238919181,
          0.4850152754194735,
          0.5000691832338128,
          0.5000691832338128,
          0.5151230910481519,
          0.5301769988624911,
          0.7108238926345612,
          0.7108238926345612,
          0.658135215284374,
          0.6054465379341868,
          0.4360900750228711,
          0.4586709367443799,
          0.4247996441621167,
          0.4059822593941927,
          0.4360900750228711,
          -0.0080002055001351,
          0.1764101652255199,
          0.1538293035040111,
          0.2968414277402334,
          0.1161945339681631,
          -0.124667991061264,
          -0.0305810672216439,
          0.1425388726432567,
          0.0672693335715606,
          0.9102881711745558,
          0.8726534016387077,
          0.8726534016387077,
          1.429647990769258,
          1.3317975899760532,
          1.39201322123341,
          0.9855577102462518,
          0.9855577102462518,
          0.9855577102462518,
          0.9629768485247432,
          0.9629768485247432,
          -0.0719793137110768,
          -0.068215836757492,
          -0.0644523598039072,
          -0.1096140832469248,
          -0.1096140832469248,
          -0.1321949449684336,
          -0.1284314680148488,
          -0.1359584219220184,
          -0.2074644840401296,
          -0.1999375301329601,
          -0.2262818688080535,
          -0.2375722996688079,
          -0.1999375301329601,
          -0.2149914379472993,
          0.6506082613772044,
          0.6317908766092805,
          0.620500445748526,
          0.5565213375375848,
          0.6242639227021108,
          0.6317908766092805,
          0.6167369687949412,
          0.4774883215123039,
          0.4285631211157015,
          0.4022187824406079,
          0.3721109668119294,
          0.5715752453519239,
          0.8011473395205965,
          0.695769984820222,
          -0.3994018086729544,
          -0.3881113778122,
          1.241474143090018,
          1.2828723895794507,
          1.2866358665330355,
          1.1699680809719069,
          1.1549141731575676,
          1.1248063575288891,
          0.9366325098496494,
          0.8274916781956901,
          0.8124377703813509,
          0.8274916781956901,
          0.9516864176639886,
          0.9178151250817254,
          0.925342078988895,
          0.887707309453047,
          0.8764168785922926,
          1.1963124196470003,
          1.1549141731575676,
          0.0258710870821278,
          0.7635125699847485,
          0.6731891230987133,
          -0.1096140832469248,
          -0.1020871293397552,
          -0.0832697445718312,
          -0.0381080211288135,
          -0.0192906363608895,
          0.1914640730398591,
          0.2366257964828768,
          0.2441527503900463,
          0.2102814578077831,
          0.1500658265504263,
          -0.0080002055001351,
          -0.1472488527827728,
          -0.1773566684114512,
          -0.2676801152974863,
          0.8688899246851229,
          1.376959313419071,
          1.3054532513009596,
          1.3205071591152988,
          1.3242706360688836,
          1.3242706360688836,
          1.2640550048115269,
          1.2715819587186965,
          1.2490010969971876,
          -0.1171410371540944,
          -0.068215836757492,
          -0.0456349750359831,
          0.0484519488036366,
          0.007053702314204,
          -0.0418714980823983,
          -0.1209045141076792,
          -0.1660662375506968,
          -0.1660662375506968,
          0.8839438324994622,
          0.8839438324994622,
          0.8726534016387077,
          0.7785664777990877,
          0.7183508465417309,
          0.7032969387273916,
          0.6844795539594677,
          0.6167369687949412,
          0.590392630119848,
          0.6656621691915436,
          0.8387821090564446,
          0.8651264477315381,
          0.8801803555458774,
          0.8914707864066318,
          0.8049108164741813,
          0.8613629707779533,
          0.8575994938243685,
          0.8463090629636142,
          0.8575994938243685,
          0.7145873695881461,
          0.1538293035040111,
          0.0635058566179758,
          -0.1020871293397552,
          0.0446884718500518,
          0.007053702314204,
          0.2403892734364615,
          0.4022187824406079,
          0.3758744437655142,
          0.2780240429723094,
          0.0145806562213734,
          0.040924994896467,
          0.0446884718500518,
          0.0446884718500518,
          0.059742379664391,
          0.0484519488036366,
          0.0747962874787302,
          0.0747962874787302,
          0.1049041031074087,
          0.1086675800609935,
          0.0860867183394846,
          0.533940475816076,
          0.5414674297232456,
          0.4963057062802279,
          0.5753387223055088,
          0.6092100148877716,
          0.7371682313096549,
          0.8237282012421053,
          0.4812517984658887,
          0.3156588125081574,
          0.5678117683983392,
          0.9780307563390822,
          0.7823299547526725,
          0.5188865680017367,
          0.3683474898583446,
          0.5828656762126784,
          0.590392630119848,
          0.5715752453519239,
          0.6054465379341868,
          0.6280273996556957,
          0.6618986922379588,
          0.6242639227021108,
          0.5753387223055088,
          0.5489943836304152,
          0.6769526000522981,
          0.6807160770058829,
          0.6731891230987133,
          0.6129734918413564,
          0.601683060980602,
          -0.0042367285465503,
          1.2903993434866203,
          1.3656688825583163,
          1.3656688825583163,
          1.3656688825583163,
          1.2640550048115269,
          0.8387821090564446,
          0.9403959868032342,
          0.0747962874787302,
          0.0973771492002391,
          0.0973771492002391,
          0.0898501952930694,
          0.0973771492002391,
          0.1237214878753327,
          0.1613562574111807,
          0.2065179808541983,
          0.2253353656221223,
          0.2817875199258942,
          0.2140449347613679,
          0.2366257964828768,
          0.2592066582043854,
          0.2930779507866486,
          0.752222139123994,
          0.752222139123994,
          0.7559856160775789,
          0.7748030008455029,
          0.7748030008455029,
          0.8124377703813509,
          0.9403959868032342,
          0.9893211871998366,
          0.9780307563390822,
          0.8989977403138014,
          0.850072539917199,
          0.9178151250817254,
          0.9629768485247432,
          1.0834081110394562,
          1.0231924797821,
          0.8952342633602166,
          0.8124377703813509,
          0.6430813074700348,
          0.4436170289300407,
          0.3081318586009878,
          0.266733612111555,
          0.1350119187360871
         ],
         "z": [
          0.3719693206446288,
          0.3719693206446288,
          0.3570341858196906,
          0.1927477027453704,
          0.1877693244703909,
          0.3072504030698968,
          0.3022720247949174,
          0.36201256409467,
          0.4566017513192788,
          0.3819260771945876,
          0.3271639161698144,
          0.2823585116949997,
          0.3072504030698968,
          0.2076828375703086,
          0.7453476912680843,
          0.7254341781681667,
          0.7254341781681667,
          0.6955639085182902,
          0.6955639085182902,
          0.7055206650682491,
          0.7403693129931049,
          0.6955639085182902,
          0.6856071519683314,
          0.6557368823184552,
          0.6856071519683314,
          0.7204557998931873,
          0.8100666088428167,
          0.1678558113704733,
          0.1529206765455351,
          0.2325747289452056,
          0.2275963506702262,
          0.1081152720707204,
          0.0882017589708027,
          -0.0611495892785792,
          -0.0661279675535586,
          -0.0760847241035174,
          0.8299801219427343,
          0.7951314740178784,
          0.7951314740178784,
          0.7801963391929402,
          0.7503260695430637,
          0.7453476912680843,
          0.6308449909435582,
          0.6009747212936817,
          0.6258666126685788,
          0.5760828299187847,
          0.4914503992441347,
          0.0732666241458645,
          0.0682882458708851,
          0.0533531110459469,
          -0.0760847241035174,
          -0.0611495892785792,
          -0.0661279675535586,
          -0.0611495892785792,
          -0.0412360761786615,
          -0.0810631023784968,
          -0.1059549937533939,
          -0.0163441848037645,
          -0.0263009413537233,
          -0.0611495892785792,
          -0.0959982372034351,
          0.4366882382193612,
          0.5661260733688258,
          0.5362558037189494,
          0.5462125602689082,
          0.5711044516438053,
          0.6059530995686612,
          0.7553044478180432,
          0.7204557998931873,
          0.6905855302433108,
          0.5760828299187847,
          0.5163422906190317,
          0.5362558037189494,
          0.7403693129931049,
          0.7453476912680843,
          0.7453476912680843,
          0.5910179647437229,
          0.5711044516438053,
          0.556169316818867,
          0.2873368899699792,
          0.1578990548205145,
          0.103136893795741,
          0.1529206765455351,
          1.5568233500897275,
          1.5518449718147482,
          1.526953080439851,
          1.5070395673399335,
          1.477169297690057,
          1.4224071366652835,
          0.934526065717302,
          0.8548720133176313,
          0.7204557998931873,
          0.5063855340690729,
          0.5611476950938464,
          0.471536886144217,
          0.5312774254439699,
          1.0490287660418285,
          1.1834449794662718,
          0.2524882420451233,
          0.2624449985950821,
          0.2823585116949997,
          0.2773801334200203,
          0.3918828337445465,
          0.3719693206446288,
          0.3819260771945876,
          0.4018395902945053,
          0.3520558075447115,
          0.0882017589708027,
          -0.1656955330531468,
          1.093834170516643,
          1.0639639008667665,
          1.0191584963919518,
          0.9295476874423224,
          0.839936878492693,
          0.6457801257684964,
          0.6457801257684964,
          0.6159098561186199,
          0.5163422906190317,
          0.4615801295942582,
          0.4068179685694847,
          0.3122287813448762,
          0.0334395979460295,
          -0.046214454453641,
          0.3172071596198556,
          0.3122287813448762,
          -0.0312793196287027,
          -0.0362576979036821,
          -0.0362576979036821,
          -0.0760847241035174,
          1.1934017360162306,
          1.2929693015158188,
          1.3377747059906335,
          1.248163897041004,
          1.2531422753159835,
          1.2133152491161483,
          1.0739206574167253,
          1.0788990356917048,
          1.36764497564051,
          1.248163897041004,
          1.3228395711656953,
          1.03409363121689,
          0.8897206612424872,
          0.6756503954183726,
          0.3968612120195259,
          0.3918828337445465,
          0.44664499476932,
          0.5362558037189494,
          0.5362558037189494,
          0.5262990471689906,
          0.5959963430187023,
          0.5959963430187023,
          0.6009747212936817,
          0.680628773693352,
          0.7005422867932696,
          0.6408017474935169,
          0.5362558037189494,
          0.2823585116949997,
          0.8498936350426519,
          0.8747855264175489,
          0.9146125526173844,
          0.9395044439922812,
          0.9693747136421578,
          0.9046557960674254,
          0.839936878492693,
          0.8299801219427343,
          0.9544395788172196,
          0.94946120054224,
          1.0739206574167253,
          1.0540071443168078,
          1.163531466366354,
          1.173488222916313,
          0.5661260733688258,
          0.5661260733688258,
          0.5511909385438876,
          0.4814936426941759,
          0.2674233768700615,
          0.0135260848461119,
          -0.0511928327286204,
          0.1529206765455351,
          0.2027044592953292,
          0.1977260810203498,
          0.1977260810203498,
          0.1778125679204321,
          0.1827909461954115,
          -0.1706739113281262,
          -0.2403712071778379,
          -0.2204576940779203,
          -0.0263009413537233,
          0.1330071634456174,
          0.2027044592953292,
          0.0334395979460295,
          0.2724017551450409,
          0.3520558075447115,
          0.3122287813448762,
          0.322185537894835,
          0.3371206727197732,
          0.3420990509947527,
          0.0483747327709675,
          0.103136893795741,
          0.1230504068956586,
          0.2176395941202674,
          0.2027044592953292,
          0.2076828375703086,
          0.1927477027453704,
          0.0882017589708027,
          0.0782450024208439,
          0.1379855417205968,
          0.1927477027453704,
          0.1927477027453704,
          0.2027044592953292,
          0.2027044592953292,
          0.2076828375703086,
          0.0732666241458645,
          0.0284612196710501,
          0.4267314816694024,
          0.2773801334200203,
          0.2624449985950821,
          0.2674233768700615,
          0.2773801334200203,
          0.4964287775191141,
          0.7304125564431461,
          0.7104990433432284,
          0.3321422944447939,
          0.1927477027453704,
          0.212661215845288,
          0.2076828375703086,
          0.1529206765455351,
          0.1429639199955762,
          0.1529206765455351,
          0.1081152720707204,
          0.1529206765455351,
          0.1479422982705557,
          0.2275963506702262,
          0.2275963506702262,
          -0.046214454453641,
          -0.0113658065287851,
          0.0135260848461119,
          0.0832233806958233,
          0.0234828413960707,
          0.4068179685694847,
          0.4217531033944229,
          0.3719693206446288,
          0.3122287813448762,
          0.3022720247949174,
          0.0931801372457822,
          0.6208882343935993,
          0.6208882343935993,
          0.6208882343935993,
          0.6109314778436405,
          0.5810612081937641,
          0.5462125602689082,
          0.4964287775191141,
          0.4317098599443817,
          0.3321422944447939,
          0.3122287813448762,
          0.2176395941202674,
          0.1479422982705557,
          0.2027044592953292,
          0.0882017589708027,
          -0.3698090423273023,
          -0.3598522857773435,
          -0.1358252634032703,
          0.0981585155207616,
          0.1827909461954115,
          0.5511909385438876,
          0.44664499476932,
          0.3022720247949174,
          0.2823585116949997,
          0.2773801334200203,
          0.4416666164943406,
          0.5810612081937641,
          0.3669909423696494,
          0.556169316818867,
          0.6109314778436405,
          0.5959963430187023,
          0.556169316818867,
          0.1578990548205145,
          0.043396354495988,
          -0.1159117503033527,
          0.0135260848461119,
          0.1230504068956586,
          0.0085477065711325,
          -0.0362576979036821,
          -0.0611495892785792,
          -0.0810631023784968,
          -0.0760847241035174,
          0.1479422982705557,
          0.1728341896454527,
          0.0981585155207616,
          0.1778125679204321,
          0.1678558113704733,
          0.1429639199955762,
          1.357688219090551,
          1.3477314625405925,
          0.3022720247949174,
          0.1927477027453704,
          -0.2105009375279615,
          0.6706720171433932,
          0.7104990433432284,
          0.7104990433432284,
          0.7553044478180432,
          0.7553044478180432,
          0.7453476912680843,
          0.7254341781681667,
          0.7353909347181254,
          0.6656936388684137,
          0.7851747174679196,
          0.8200233653927754,
          0.7503260695430637,
          0.6358233692185375,
          0.6358233692185375,
          1.1336611967164778,
          1.3029260580657775,
          0.0583314893209263,
          0.0334395979460295,
          0.0931801372457822,
          0.0732666241458645,
          0.043396354495988,
          0.0483747327709675,
          0.0981585155207616,
          0.2524882420451233,
          0.3570341858196906,
          0.36201256409467,
          0.297293646519938,
          0.3072504030698968,
          0.4566017513192788,
          0.4864720209691552,
          0.4068179685694847,
          0.3918828337445465,
          0.4068179685694847,
          0.1827909461954115,
          0.1628774330954939,
          0.1728341896454527,
          0.1728341896454527,
          0.2425314854951644,
          0.5860395864687434,
          0.4814936426941759,
          0.5163422906190317,
          0.4814936426941759,
          0.6706720171433932,
          0.815044987117796,
          0.0633098675959057,
          0.0483747327709675,
          0.0284612196710501,
          0.0284612196710501,
          0.0334395979460295,
          0.0931801372457822,
          0.1778125679204321,
          0.1479422982705557,
          0.0682882458708851,
          0.0981585155207616,
          0.1230504068956586,
          -0.0014090499788263,
          -0.2154793158029409,
          -0.2304144506278791,
          1.6663476721392745,
          1.5717584849146655,
          0.0234828413960707,
          0.0483747327709675,
          0.0633098675959057,
          0.212661215845288,
          0.212661215845288,
          0.1180720286206792,
          0.0583314893209263,
          -0.0760847241035174,
          0.2027044592953292,
          0.2724017551450409,
          0.297293646519938,
          0.2773801334200203,
          0.3371206727197732,
          0.2574666203201027,
          0.1081152720707204,
          0.1529206765455351,
          0.1230504068956586,
          0.0483747327709675,
          0.0334395979460295,
          0.0334395979460295,
          0.0384179762210089,
          0.0533531110459469,
          0.0384179762210089,
          0.0135260848461119,
          0.0832233806958233,
          0.0583314893209263,
          0.0682882458708851,
          0.0882017589708027,
          -0.3698090423273023,
          -0.3747874206022817,
          -0.3299820161274671,
          -0.2503279637277968,
          0.0483747327709675,
          0.0284612196710501,
          0.0185044631210913,
          0.0832233806958233,
          0.0085477065711325,
          0.1529206765455351,
          0.3420990509947527,
          0.2624449985950821,
          0.1330071634456174,
          -0.1308468851282909,
          0.3271639161698144,
          0.0882017589708027,
          -0.0213225630787439,
          -0.0362576979036821,
          -0.0412360761786615,
          -0.0063874282538057,
          0.0234828413960707,
          0.3022720247949174,
          0.322185537894835,
          0.3271639161698144,
          0.3271639161698144,
          0.3371206727197732,
          0.212661215845288,
          0.1728341896454527,
          0.1778125679204321,
          0.1230504068956586,
          0.1180720286206792,
          -0.0113658065287851,
          -0.1009766154784145,
          -0.2503279637277968,
          -0.3648306640523229,
          0.7453476912680843,
          0.7403693129931049,
          0.7304125564431461,
          0.7553044478180432,
          0.7055206650682491,
          0.7304125564431461,
          0.7204557998931873,
          0.6756503954183726,
          0.5860395864687434,
          0.5511909385438876,
          0.5810612081937641,
          0.5810612081937641,
          0.5163422906190317,
          0.4964287775191141,
          0.0384179762210089,
          0.0384179762210089,
          0.0135260848461119,
          0.0135260848461119,
          0.0135260848461119,
          0.0135260848461119,
          0.0135260848461119,
          0.1379855417205968,
          0.1529206765455351,
          0.1628774330954939,
          0.1728341896454527,
          0.1330071634456174,
          0.5711044516438053,
          0.5312774254439699,
          0.4566017513192788,
          0.3570341858196906,
          0.3769476989196083,
          0.3769476989196083,
          0.7951314740178784,
          0.7453476912680843,
          0.6756503954183726,
          0.0882017589708027,
          0.1379855417205968,
          0.1081152720707204,
          0.0832233806958233,
          -0.046214454453641,
          0.0483747327709675,
          -0.0263009413537233,
          0.0782450024208439,
          1.1436179532664366,
          0.8946990395174665,
          0.6308449909435582,
          0.3819260771945876,
          0.0135260848461119,
          0.3321422944447939,
          0.3122287813448762,
          0.2823585116949997,
          0.2325747289452056,
          0.2325747289452056,
          0.1379855417205968,
          0.0682882458708851,
          0.0284612196710501,
          0.0682882458708851,
          0.128028785170638,
          0.4615801295942582,
          0.6308449909435582,
          0.6159098561186199,
          0.5462125602689082,
          -0.1308468851282909,
          0.0583314893209263,
          0.003569328296153,
          -0.0412360761786615,
          0.3122287813448762,
          0.3869044554695671,
          -0.0511928327286204,
          -0.0611495892785792,
          -0.0063874282538057,
          0.3321422944447939,
          0.5163422906190317,
          0.5063855340690729,
          0.5860395864687434,
          0.5661260733688258,
          0.5312774254439699,
          0.3669909423696494,
          0.3072504030698968,
          0.2923152682449585,
          0.2724017551450409,
          0.1578990548205145,
          -0.4892901209268082,
          -0.4743549861018699,
          -0.4544414730019523,
          -0.4494630947269729,
          0.8648287698675902,
          0.8847422829675078,
          0.934526065717302,
          1.009201739841993,
          1.0241368746669313,
          1.0241368746669313,
          1.058985522591787,
          1.1087693053415812,
          1.0838774139666842,
          1.068942279141746,
          0.9793314701921164,
          0.9992449832920342,
          0.924569309167343,
          -0.1109333720283733,
          -0.1756522896031056,
          0.3122287813448762,
          0.5412341819939288,
          0.4914503992441347,
          0.4167747251194435,
          0.3719693206446288,
          0.1529206765455351,
          0.0782450024208439,
          -0.0511928327286204,
          -0.0611495892785792,
          0.2425314854951644,
          0.5711044516438053,
          1.0042233615670135,
          1.0241368746669313,
          0.839936878492693,
          0.347077429269732,
          0.3520558075447115,
          0.347077429269732,
          0.4018395902945053,
          0.4217531033944229,
          0.6159098561186199,
          0.5760828299187847,
          0.5213206688940112,
          0.44664499476932,
          0.2823585116949997,
          0.2624449985950821,
          0.2475098637701439,
          0.2823585116949997,
          0.1479422982705557,
          0.1130936503456998,
          0.237553107220185,
          0.2226179723952468,
          0.2425314854951644,
          0.0384179762210089,
          -0.0014090499788263,
          0.043396354495988,
          0.1130936503456998,
          0.0981585155207616,
          0.7602828260930226,
          0.7403693129931049,
          0.7403693129931049,
          1.36764497564051,
          1.2929693015158188,
          1.2929693015158188,
          0.0185044631210913,
          0.0185044631210913,
          0.0185044631210913,
          0.003569328296153,
          -0.0014090499788263,
          0.0085477065711325,
          0.003569328296153,
          0.003569328296153,
          -0.0213225630787439,
          -0.0263009413537233,
          -0.0611495892785792,
          -0.046214454453641,
          -0.0860414806534762,
          -0.1656955330531468,
          -0.1308468851282909,
          -0.1059549937533939,
          -0.1358252634032703,
          -0.1109333720283733,
          -0.1408036416782498,
          0.5014071557940936,
          0.5213206688940112,
          0.5213206688940112,
          0.6557368823184552,
          0.7204557998931873,
          0.6457801257684964,
          0.8100666088428167,
          0.6258666126685788,
          0.5959963430187023,
          0.5661260733688258,
          0.5661260733688258,
          0.7602828260930226,
          0.7652612043680019,
          0.6607152605934347,
          -0.0362576979036821,
          -0.0412360761786615,
          1.173488222916313,
          1.2282503839410863,
          1.307904436340757,
          1.3975152452903865,
          1.3975152452903865,
          1.3128828146157363,
          1.0241368746669313,
          0.9195909308923635,
          0.9395044439922812,
          0.9295476874423224,
          0.9942666050170548,
          0.9195909308923635,
          0.839936878492693,
          0.8100666088428167,
          0.8050882305678372,
          1.0191584963919518,
          0.9395044439922812,
          -0.3648306640523229,
          1.0042233615670135,
          0.9096341743424048,
          0.0832233806958233,
          0.0882017589708027,
          0.0981585155207616,
          0.2076828375703086,
          0.212661215845288,
          0.322185537894835,
          0.3769476989196083,
          0.3819260771945876,
          0.3719693206446288,
          0.2823585116949997,
          0.0284612196710501,
          -0.071106345828538,
          -0.1408036416782498,
          -0.1607171547781674,
          0.7104990433432284,
          1.392536867015407,
          1.332796327715654,
          1.3875584887404275,
          1.4672125411400982,
          1.3776017321904688,
          1.28301254496586,
          1.28301254496586,
          1.2431855187660248,
          0.0732666241458645,
          0.1479422982705557,
          0.3072504030698968,
          0.3819260771945876,
          0.3520558075447115,
          0.322185537894835,
          0.1827909461954115,
          0.1778125679204321,
          -0.1408036416782498,
          1.1685098446413336,
          1.2033584925661895,
          1.19838011429121,
          1.0540071443168078,
          0.9942666050170548,
          1.2182936273911276,
          1.2083368708411688,
          1.1585530880913748,
          1.11872606189154,
          1.148596331541416,
          1.0888557922416635,
          1.1037909270666018,
          1.0988125487916225,
          1.0639639008667665,
          0.6258666126685788,
          0.680628773693352,
          0.6706720171433932,
          0.6955639085182902,
          0.6856071519683314,
          0.5412341819939288,
          0.0533531110459469,
          -0.0014090499788263,
          -0.0760847241035174,
          -0.1358252634032703,
          -0.1656955330531468,
          0.1379855417205968,
          0.3570341858196906,
          0.4217531033944229,
          0.3022720247949174,
          0.1678558113704733,
          0.1977260810203498,
          0.2027044592953292,
          0.1778125679204321,
          0.1628774330954939,
          0.1529206765455351,
          0.1529206765455351,
          0.1081152720707204,
          0.103136893795741,
          0.0832233806958233,
          0.0732666241458645,
          0.6856071519683314,
          0.6955639085182902,
          0.6656936388684137,
          0.6557368823184552,
          0.6607152605934347,
          0.8100666088428167,
          0.8449152567676725,
          0.5959963430187023,
          0.7055206650682491,
          1.093834170516643,
          1.3477314625405925,
          1.2282503839410863,
          0.8200233653927754,
          0.6607152605934347,
          0.4217531033944229,
          0.4317098599443817,
          0.4018395902945053,
          0.4068179685694847,
          0.4167747251194435,
          0.4516233730442994,
          0.4167747251194435,
          0.4018395902945053,
          0.4217531033944229,
          0.5362558037189494,
          0.4914503992441347,
          0.4864720209691552,
          0.4416666164943406,
          0.4217531033944229,
          -0.0014090499788263,
          1.4472990280401803,
          1.442320649765201,
          1.4024936235653658,
          1.3477314625405925,
          1.3228395711656953,
          0.8698071481425695,
          1.138639574991457,
          -0.1507603982282086,
          -0.1109333720283733,
          -0.1109333720283733,
          -0.1059549937533939,
          -0.0860414806534762,
          -0.0760847241035174,
          -0.0611495892785792,
          -0.0063874282538057,
          0.0185044631210913,
          0.1529206765455351,
          0.1130936503456998,
          0.1081152720707204,
          0.1130936503456998,
          0.1230504068956586,
          0.5213206688940112,
          0.5213206688940112,
          0.5262990471689906,
          0.5462125602689082,
          0.5462125602689082,
          0.5312774254439699,
          0.6557368823184552,
          0.680628773693352,
          0.6607152605934347,
          0.6258666126685788,
          0.6308449909435582,
          0.7154774216182078,
          0.7304125564431461,
          0.8250017436677549,
          1.2083368708411688,
          1.093834170516643,
          1.0540071443168078,
          0.8001098522928578,
          0.5213206688940112,
          0.3669909423696494,
          0.4117963468444641,
          0.237553107220185
         ]
        },
        {
         "hovertemplate": "regime=Liberal Democracy<br>v2x_polyarchy=%{x}<br>v2x_libdem=%{y}<br>v2x_partipdem=%{z}<extra></extra>",
         "legendgroup": "Liberal Democracy",
         "marker": {
          "color": "#EF553B",
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Liberal Democracy",
         "scene": "scene",
         "showlegend": true,
         "type": "scatter3d",
         "x": [
          0.9095967615515088,
          1.5369992353168709,
          1.5447449448695294,
          1.5524906544221884,
          1.5447449448695294,
          1.5408720900932,
          1.5369992353168709,
          1.5331263805405413,
          1.5331263805405413,
          1.5137621066588944,
          1.4827792684482592,
          1.4827792684482592,
          1.4827792684482592,
          1.4634149945666122,
          1.4169407372506595,
          1.471160704119271,
          1.47890641367193,
          1.4982706875535767,
          1.4982706875535767,
          1.4982706875535767,
          1.4943978327772474,
          1.4982706875535767,
          1.5098892518825648,
          1.5098892518825648,
          1.5060163971062357,
          1.4827792684482592,
          1.4672878493429415,
          1.4672878493429415,
          1.4401778659086355,
          0.948325309314803,
          0.948325309314803,
          0.9715624379727792,
          0.9250881806568264,
          0.8786139233408737,
          0.979308147525438,
          0.9638167284201204,
          0.9831810023017676,
          1.28526367485546,
          1.28526367485546,
          1.2736451105264717,
          1.1729508863419074,
          1.1729508863419074,
          1.169078031565578,
          1.169078031565578,
          1.1613323220129192,
          1.2194251436578605,
          1.2116794341052015,
          1.227170853210519,
          1.1613323220129192,
          1.15745946723659,
          1.1613323220129192,
          1.4363050111323064,
          1.444050720684965,
          1.447923575461295,
          1.451796430237624,
          1.4208135920269889,
          1.382085044263695,
          1.4982706875535767,
          1.4827792684482592,
          1.4827792684482592,
          1.490524978000918,
          1.4943978327772474,
          1.4982706875535767,
          1.444050720684965,
          1.2194251436578605,
          1.176823741118237,
          1.1380951933549432,
          1.134222338578614,
          1.188442305447225,
          1.2232979984341896,
          1.2775179653028013,
          1.471160704119271,
          1.4285593015796476,
          1.432432156355977,
          1.4169407372506595,
          1.4169407372506595,
          1.4363050111323064,
          1.4363050111323064,
          1.471160704119271,
          1.4750335588956005,
          1.41306788247433,
          1.4246864468033182,
          1.4401778659086355,
          1.2620265461974836,
          0.9754352927491088,
          0.9754352927491088,
          0.9057239067751796,
          0.7817925539326389,
          0.7508097157220037,
          0.7585554252746625,
          0.8050296825906152,
          1.3278650773950833,
          1.3472293512767304,
          1.2736451105264717,
          1.3085008035134362,
          1.3085008035134362,
          1.1458409029076018,
          0.7159540227350392,
          1.107112355144308,
          1.107112355144308,
          1.1226037742496258,
          1.114858064696967,
          1.1264766290259551,
          1.1264766290259551,
          1.2426622723158367,
          1.265899400973813,
          1.265899400973813,
          1.227170853210519,
          1.1652051767892486,
          1.1652051767892486,
          1.1845694506708957,
          1.1806965958945663,
          0.2047371922595592,
          0.1350258062856305,
          0.0343315821010662,
          1.227170853210519,
          1.1380951933549432,
          1.1187309194732964,
          1.1535866124602605,
          1.1419680481312724,
          1.1535866124602605,
          1.2581536914211542,
          1.2736451105264717,
          1.2736451105264717,
          1.335610786947742,
          1.296882239184448,
          1.3085008035134362,
          1.4672878493429415,
          1.4866521232245886,
          1.4866521232245886,
          1.323992222618754,
          1.28526367485546,
          1.3472293512767304,
          1.3665936251583772,
          1.362720770382048,
          1.3278650773950833,
          1.188442305447225,
          1.2504079818684954,
          1.2039337245525426,
          1.2891365296317894,
          1.3007550939607777,
          0.7585554252746625,
          0.7546825704983331,
          0.7546825704983331,
          0.7508097157220037,
          0.7353182966166861,
          0.6617340558664276,
          0.6539883463137692,
          0.623005508103134,
          0.6307512176557929,
          0.5378027030238873,
          0.2976857068914648,
          1.4401778659086355,
          1.444050720684965,
          1.4556692850139534,
          1.4672878493429415,
          1.447923575461295,
          1.447923575461295,
          1.447923575461295,
          1.4595421397902828,
          1.374339334711036,
          1.2542808366448248,
          1.227170853210519,
          1.238789417539507,
          1.5176349614352238,
          1.5176349614352238,
          1.5137621066588944,
          1.5060163971062357,
          1.5060163971062357,
          1.5060163971062357,
          1.490524978000918,
          1.4750335588956005,
          1.444050720684965,
          1.4556692850139534,
          1.4672878493429415,
          1.4595421397902828,
          1.3278650773950833,
          1.3549750608293891,
          1.4363050111323064,
          1.4401778659086355,
          1.451796430237624,
          1.4556692850139534,
          1.4595421397902828,
          1.4595421397902828,
          1.4595421397902828,
          1.447923575461295,
          1.41306788247433,
          1.3782121894873656,
          1.3704664799347066,
          1.382085044263695,
          1.3975764633690124,
          1.3898307538163537,
          1.47890641367193,
          1.4943978327772474,
          1.490524978000918,
          1.4750335588956005,
          1.447923575461295,
          1.4401778659086355,
          1.4363050111323064,
          1.451796430237624,
          1.41306788247433,
          1.41306788247433,
          1.374339334711036,
          1.3472293512767304,
          1.3085008035134362,
          1.3085008035134362,
          1.47890641367193,
          1.4750335588956005,
          1.4750335588956005,
          1.4750335588956005,
          1.4750335588956005,
          1.4750335588956005,
          1.447923575461295,
          1.447923575461295,
          1.451796430237624,
          1.447923575461295,
          1.451796430237624,
          1.4750335588956005,
          1.447923575461295,
          1.4634149945666122,
          1.296882239184448,
          1.3278650773950833,
          1.362720770382048,
          1.331737932171413,
          1.331737932171413,
          1.331737932171413,
          1.3588479156057185,
          1.3511022060530598,
          1.3549750608293891,
          1.3123736582897658,
          1.3123736582897658,
          1.3123736582897658,
          1.28526367485546,
          1.2349165627631775,
          1.0877480812626612,
          1.176823741118237,
          1.1845694506708957,
          1.2504079818684954,
          1.2736451105264717,
          1.2349165627631775,
          1.227170853210519,
          1.2232979984341896,
          1.1923151602235544,
          1.2232979984341896,
          1.2116794341052015,
          1.2930093844081187,
          1.3859578990400243,
          1.393703608592683,
          1.3859578990400243,
          1.4014493181453418,
          1.4091950276980003,
          1.4091950276980003,
          1.4091950276980003,
          1.3975764633690124,
          1.4053221729216712,
          1.3511022060530598,
          1.343356496500401,
          1.3394836417240714,
          1.3046279487371069,
          1.3007550939607777,
          1.444050720684965,
          1.451796430237624,
          1.444050720684965,
          1.3782121894873656,
          1.374339334711036,
          1.3162465130660952,
          1.2891365296317894,
          1.246535127092166,
          1.3046279487371069,
          1.3782121894873656,
          1.3898307538163537,
          1.2891365296317894,
          1.3472293512767304,
          1.2581536914211542,
          1.3511022060530598,
          1.3511022060530598,
          1.3549750608293891,
          1.3511022060530598,
          1.3472293512767304,
          1.3123736582897658,
          1.3085008035134362,
          1.3394836417240714,
          1.382085044263695,
          1.3123736582897658,
          1.3782121894873656,
          1.3394836417240714,
          1.2581536914211542,
          1.2930093844081187,
          1.5331263805405413,
          1.5331263805405413,
          1.5331263805405413,
          1.5215078162115532,
          1.5176349614352238,
          1.4750335588956005,
          1.4750335588956005,
          1.4556692850139534,
          1.47890641367193,
          1.4750335588956005,
          1.362720770382048,
          1.3201193678424246,
          1.1845694506708957,
          1.265899400973813,
          1.1380951933549432,
          0.979308147525438,
          1.0064181309597438,
          1.0064181309597438,
          0.8669953590118856,
          0.8669953590118856,
          0.9521981640911324,
          0.9328338902094854,
          0.8979781972225208,
          0.8824867781172032,
          0.8786139233408737,
          0.9212153258804971,
          1.374339334711036,
          1.382085044263695,
          1.382085044263695,
          1.382085044263695,
          1.374339334711036,
          1.374339334711036,
          1.2891365296317894,
          1.296882239184448,
          1.296882239184448,
          1.331737932171413,
          1.3201193678424246,
          0.998672421407085,
          0.998672421407085,
          0.9909267118544264,
          0.9947995666307556,
          1.0412738239467083,
          1.0916209360389906,
          1.0490195334993673,
          1.0722566621573435,
          1.076129516933673,
          1.471160704119271,
          1.471160704119271,
          1.471160704119271,
          1.4943978327772474,
          1.490524978000918,
          1.4866521232245886,
          1.4866521232245886,
          1.4827792684482592,
          1.4827792684482592,
          1.47890641367193,
          1.4556692850139534,
          1.4595421397902828,
          1.4595421397902828,
          1.4595421397902828,
          1.2813908200791306,
          1.28526367485546,
          1.265899400973813,
          1.2891365296317894,
          1.2697722557501423,
          1.3007550939607777,
          1.2891365296317894,
          1.238789417539507,
          1.2194251436578605,
          1.238789417539507,
          1.107112355144308,
          1.0838752264863318,
          1.0141638405124027,
          1.432432156355977,
          1.4672878493429415,
          1.4672878493429415,
          1.374339334711036,
          1.323992222618754,
          1.323992222618754,
          1.323992222618754,
          1.2426622723158367,
          1.169078031565578,
          1.1264766290259551,
          1.3123736582897658,
          1.3665936251583772,
          1.5524906544221884,
          1.5524906544221884,
          1.5641092187511765,
          1.5641092187511765,
          1.5641092187511765,
          1.560236363974847,
          1.548617799645859,
          1.548617799645859,
          1.548617799645859,
          1.5331263805405413,
          1.5369992353168709,
          1.5369992353168709,
          1.5369992353168709,
          1.5369992353168709,
          1.4169407372506595,
          1.4208135920269889,
          1.4208135920269889,
          1.41306788247433,
          1.432432156355977,
          1.4595421397902828,
          1.5060163971062357,
          1.502143542329906,
          1.502143542329906,
          1.4595421397902828,
          1.4634149945666122,
          1.4672878493429415,
          1.4595421397902828,
          1.4595421397902828,
          1.4169407372506595,
          1.4208135920269889,
          1.4208135920269889,
          1.4208135920269889,
          1.4208135920269889,
          1.3472293512767304,
          1.335610786947742,
          1.3472293512767304,
          1.3898307538163537,
          1.3859578990400243,
          1.3782121894873656,
          1.3665936251583772,
          1.362720770382048,
          1.323992222618754,
          1.5060163971062357,
          1.5098892518825648,
          1.4827792684482592,
          1.4401778659086355,
          1.444050720684965,
          1.4014493181453418,
          1.3898307538163537,
          1.382085044263695,
          1.3472293512767304,
          1.3549750608293891,
          1.1264766290259551,
          0.979308147525438,
          1.41306788247433,
          1.41306788247433,
          1.393703608592683,
          1.343356496500401,
          1.343356496500401,
          1.3588479156057185,
          1.343356496500401,
          1.343356496500401,
          1.4014493181453418,
          1.3085008035134362,
          1.3123736582897658,
          1.2310437079868484,
          1.176823741118237,
          1.2232979984341896,
          0.9018510519988502,
          0.9018510519988502,
          0.9018510519988502,
          0.8631225042355561,
          0.8631225042355561,
          0.851503939906568,
          0.8321396660249211,
          0.7779196991563094,
          0.7236997322876979,
          0.7546825704983331,
          0.8166482469196035,
          0.8553767946828974,
          0.8089025373669446,
          1.2775179653028013,
          1.2620265461974836,
          1.246535127092166,
          1.2039337245525426,
          1.2155522888815309,
          1.238789417539507,
          1.4053221729216712,
          1.4053221729216712,
          1.4053221729216712,
          1.4014493181453418,
          1.393703608592683,
          1.393703608592683,
          1.393703608592683,
          1.393703608592683,
          1.3975764633690124,
          1.4014493181453418,
          1.4014493181453418,
          1.4014493181453418,
          1.4014493181453418,
          1.393703608592683,
          0.9057239067751796,
          0.9018510519988502,
          0.9018510519988502,
          0.8824867781172032,
          1.4827792684482592,
          1.4672878493429415,
          1.4595421397902828,
          1.4363050111323064,
          1.4285593015796476,
          1.4363050111323064,
          1.4363050111323064,
          1.4246864468033182,
          1.4672878493429415,
          1.4556692850139534,
          1.4401778659086355,
          1.41306788247433,
          1.4208135920269889,
          1.4246864468033182,
          1.4750335588956005,
          1.4672878493429415,
          1.4672878493429415,
          1.4208135920269889,
          1.432432156355977,
          1.4595421397902828,
          1.4595421397902828,
          1.444050720684965,
          1.4169407372506595,
          1.4363050111323064,
          1.4014493181453418,
          1.4246864468033182,
          1.4246864468033182,
          1.4246864468033182,
          0.3635242380890645,
          0.3751428024180527,
          0.2976857068914648,
          -0.0005241108858983132,
          0.2860671425624765,
          0.3519056737600763,
          0.3596513833127351,
          0.4061256406286879,
          0.5804041055635107,
          0.7508097157220037,
          0.9328338902094854,
          0.870868213788215,
          1.3007550939607777,
          1.3123736582897658,
          1.2930093844081187,
          1.2349165627631775,
          1.246535127092166,
          1.265899400973813,
          1.2504079818684954,
          1.2504079818684954,
          1.169078031565578,
          1.3704664799347066,
          1.3472293512767304,
          1.2891365296317894,
          1.3278650773950833,
          1.3549750608293891,
          1.3782121894873656,
          1.331737932171413,
          1.2581536914211542,
          1.2155522888815309,
          1.134222338578614,
          0.940579599762144,
          1.1380951933549432
         ],
         "y": [
          0.8575994938243685,
          1.805995686127738,
          1.8097591630813228,
          1.8210495939420768,
          1.8210495939420768,
          1.813522640034908,
          1.8097591630813228,
          1.7984687322205684,
          1.7984687322205684,
          1.787178301359814,
          1.7608339626847205,
          1.764597439638305,
          1.7533070087775506,
          1.745780054870381,
          1.689327900566609,
          1.693091377520194,
          1.7006183314273635,
          1.7156722392417028,
          1.7194357161952876,
          1.7194357161952876,
          1.7231991931488724,
          1.7231991931488724,
          1.7495435318239658,
          1.7495435318239658,
          1.7420165779167962,
          1.7006183314273635,
          1.6855644236130245,
          1.6855644236130245,
          1.6592200849379306,
          0.9742672793854974,
          0.9742672793854974,
          0.9592133715711584,
          0.8952342633602166,
          0.8575994938243685,
          0.9629768485247432,
          0.9479229407104038,
          0.9592133715711584,
          1.39201322123341,
          1.39201322123341,
          1.3807227903726558,
          1.2866358665330355,
          1.279108912625866,
          1.275345435672281,
          1.275345435672281,
          1.2678184817651117,
          1.335561066929638,
          1.3242706360688836,
          1.2903993434866203,
          1.2264202352756788,
          1.222656758322094,
          1.2339471891828484,
          1.595240976726989,
          1.599004453680574,
          1.6065314075877437,
          1.599004453680574,
          1.5688966380518954,
          1.410830606001334,
          1.6968548544737787,
          1.6780374697058549,
          1.6780374697058549,
          1.693091377520194,
          1.693091377520194,
          1.6968548544737787,
          1.6366392232164215,
          1.316743682161714,
          1.2678184817651117,
          1.2565280509043573,
          1.2264202352756788,
          1.3280341130224684,
          1.3619054056047315,
          1.3882497442798254,
          1.6667470388451002,
          1.625348792355667,
          1.632875746262837,
          1.602767930634159,
          1.602767930634159,
          1.614058361494913,
          1.614058361494913,
          1.6742739927522698,
          1.6780374697058549,
          1.5688966380518954,
          1.523734914608878,
          1.557606207191141,
          1.3280341130224684,
          1.004375095014176,
          1.004375095014176,
          0.944159463756819,
          0.7898569086598421,
          0.7597490930311637,
          0.7710395238919181,
          0.8387821090564446,
          1.4861001450730302,
          1.489863622026615,
          1.429647990769258,
          1.4559923294443518,
          1.4221210368620885,
          1.2339471891828484,
          0.7559856160775789,
          1.0119020489213455,
          1.0119020489213455,
          1.0307194336892695,
          1.0495368184571934,
          1.0533002954107782,
          1.057063772364363,
          1.2301837122292636,
          1.2565280509043573,
          1.2527645739507725,
          1.20383937355417,
          1.1624411270647372,
          1.128569834482474,
          1.2000758966005851,
          1.2000758966005851,
          0.3006049046938182,
          0.2328623195292919,
          0.1575927804575959,
          1.3656688825583163,
          1.275345435672281,
          1.2565280509043573,
          1.2903993434866203,
          1.2715819587186965,
          1.2866358665330355,
          1.3957766981869948,
          1.4070671290477492,
          1.39201322123341,
          1.4221210368620885,
          1.3656688825583163,
          1.3242706360688836,
          1.7194357161952876,
          1.7382531009632114,
          1.7382531009632114,
          1.5613696841447258,
          1.5312618685160475,
          1.5877140228198194,
          1.614058361494913,
          1.595240976726989,
          1.557606207191141,
          1.4183575599085037,
          1.4748097142122758,
          1.4221210368620885,
          1.4936270989802,
          1.5086810067945389,
          0.8274916781956901,
          0.8162012473349357,
          0.7823299547526725,
          0.7823299547526725,
          0.7823299547526725,
          0.7070604156809764,
          0.6882430309130525,
          0.6355543535628653,
          0.6694256461451285,
          0.5941561070734328,
          0.323185766415327,
          1.6479296540771762,
          1.651693131030761,
          1.6592200849379306,
          1.693091377520194,
          1.6780374697058549,
          1.6592200849379306,
          1.6592200849379306,
          1.6855644236130245,
          1.5312618685160475,
          1.4258845138156733,
          1.429647990769258,
          1.4409384216300123,
          1.711908762288118,
          1.711908762288118,
          1.7156722392417028,
          1.6968548544737787,
          1.7043818083809483,
          1.7043818083809483,
          1.7006183314273635,
          1.689327900566609,
          1.632875746262837,
          1.6592200849379306,
          1.670510515798685,
          1.6667470388451002,
          1.527498391562463,
          1.553842730237556,
          1.557606207191141,
          1.5613696841447258,
          1.576423591959065,
          1.576423591959065,
          1.576423591959065,
          1.576423591959065,
          1.576423591959065,
          1.5688966380518954,
          1.5124444837481237,
          1.4936270989802,
          1.471046237258691,
          1.4748097142122758,
          1.523734914608878,
          1.5312618685160475,
          1.7382531009632114,
          1.7533070087775506,
          1.7533070087775506,
          1.7156722392417028,
          1.689327900566609,
          1.689327900566609,
          1.6855644236130245,
          1.670510515798685,
          1.629112269309252,
          1.632875746262837,
          1.595240976726989,
          1.557606207191141,
          1.523734914608878,
          1.5387888224232174,
          1.595240976726989,
          1.5877140228198194,
          1.5914774997734042,
          1.6065314075877437,
          1.6065314075877437,
          1.6065314075877437,
          1.5801870689126498,
          1.5914774997734042,
          1.599004453680574,
          1.5877140228198194,
          1.5914774997734042,
          1.6215853154020827,
          1.595240976726989,
          1.6102948845413283,
          1.3807227903726558,
          1.429647990769258,
          1.4672827603051062,
          1.429647990769258,
          1.429647990769258,
          1.429647990769258,
          1.4635192833515214,
          1.4672827603051062,
          1.4559923294443518,
          1.4221210368620885,
          1.3957766981869948,
          1.3995401751405796,
          1.376959313419071,
          1.3317975899760532,
          1.1323333114360588,
          1.222656758322094,
          1.241474143090018,
          1.335561066929638,
          1.358141928651147,
          1.3054532513009596,
          1.3129802052081292,
          1.3016897743473748,
          1.2866358665330355,
          1.2828723895794507,
          1.275345435672281,
          1.3731958364654862,
          1.6102948845413283,
          1.614058361494913,
          1.6065314075877437,
          1.614058361494913,
          1.625348792355667,
          1.625348792355667,
          1.625348792355667,
          1.6215853154020827,
          1.6215853154020827,
          1.5726601150054802,
          1.5425522993768015,
          1.5387888224232174,
          1.5011540528873693,
          1.4936270989802,
          1.5801870689126498,
          1.5801870689126498,
          1.5011540528873693,
          1.4183575599085037,
          1.4258845138156733,
          1.3656688825583163,
          1.3882497442798254,
          1.3468514977903925,
          1.4145940829549188,
          1.5199714376552933,
          1.4635192833515214,
          1.4033036520941644,
          1.429647990769258,
          1.3317975899760532,
          1.504917529840954,
          1.504917529840954,
          1.5124444837481237,
          1.489863622026615,
          1.4861001450730302,
          1.452228852490767,
          1.448465375537182,
          1.4936270989802,
          1.5350253454696323,
          1.4559923294443518,
          1.5086810067945389,
          1.4409384216300123,
          1.358141928651147,
          1.3882497442798254,
          1.693091377520194,
          1.6855644236130245,
          1.6855644236130245,
          1.670510515798685,
          1.6667470388451002,
          1.625348792355667,
          1.625348792355667,
          1.629112269309252,
          1.6479296540771762,
          1.6441661771235914,
          1.5387888224232174,
          1.4785731911658606,
          1.3205071591152988,
          1.3807227903726558,
          1.1398602653432284,
          0.9554498946175736,
          0.9780307563390822,
          0.9780307563390822,
          0.8726534016387077,
          0.8651264477315381,
          0.9366325098496494,
          0.9215786020353102,
          0.8989977403138014,
          0.8688899246851229,
          0.8952342633602166,
          0.887707309453047,
          1.5086810067945389,
          1.5162079607017085,
          1.5162079607017085,
          1.523734914608878,
          1.5199714376552933,
          1.5124444837481237,
          1.433411467722843,
          1.4409384216300123,
          1.4145940829549188,
          1.4635192833515214,
          1.452228852490767,
          0.981794233292667,
          0.981794233292667,
          0.9554498946175736,
          0.9403959868032342,
          0.9855577102462518,
          1.0382463875964392,
          1.008138571967761,
          1.0307194336892695,
          1.0344829106428544,
          1.629112269309252,
          1.625348792355667,
          1.625348792355667,
          1.651693131030761,
          1.651693131030761,
          1.6479296540771762,
          1.6441661771235914,
          1.6366392232164215,
          1.6366392232164215,
          1.6404027001700066,
          1.5877140228198194,
          1.5914774997734042,
          1.6215853154020827,
          1.5463157763303863,
          1.2640550048115269,
          1.2640550048115269,
          1.2452376200436028,
          1.260291527857942,
          1.2527645739507725,
          1.275345435672281,
          1.2715819587186965,
          1.2339471891828484,
          1.2113663274613395,
          1.1737315579254914,
          1.0946985419002109,
          0.9366325098496494,
          0.9027612172673862,
          1.5425522993768015,
          1.5500792532839711,
          1.5801870689126498,
          1.4597558063979366,
          1.3995401751405796,
          1.4033036520941644,
          1.39201322123341,
          1.2565280509043573,
          1.188785465739831,
          1.1624411270647372,
          1.452228852490767,
          1.5124444837481237,
          1.8473939326171709,
          1.8473939326171709,
          1.858684363477925,
          1.8549208865243405,
          1.8549208865243405,
          1.8511574095707557,
          1.8398669787100013,
          1.8285765478492468,
          1.8285765478492468,
          1.8097591630813228,
          1.805995686127738,
          1.8022322091741527,
          1.8210495939420768,
          1.805995686127738,
          1.6065314075877437,
          1.614058361494913,
          1.614058361494913,
          1.617821838448498,
          1.6404027001700066,
          1.6667470388451002,
          1.7156722392417028,
          1.7156722392417028,
          1.7231991931488724,
          1.6629835618915154,
          1.651693131030761,
          1.6742739927522698,
          1.6855644236130245,
          1.6629835618915154,
          1.6629835618915154,
          1.6592200849379306,
          1.6592200849379306,
          1.6855644236130245,
          1.6855644236130245,
          1.5839505458662346,
          1.5726601150054802,
          1.602767930634159,
          1.6554566079843458,
          1.6404027001700066,
          1.6366392232164215,
          1.6215853154020827,
          1.614058361494913,
          1.5688966380518954,
          1.5651331610983106,
          1.5688966380518954,
          1.5463157763303863,
          1.5011540528873693,
          1.5199714376552933,
          1.444701898583597,
          1.433411467722843,
          1.4221210368620885,
          1.3995401751405796,
          1.3807227903726558,
          1.0909350649466258,
          0.906524694220971,
          1.489863622026615,
          1.489863622026615,
          1.4748097142122758,
          1.4258845138156733,
          1.4221210368620885,
          1.4371749446764277,
          1.4183575599085037,
          1.429647990769258,
          1.4861001450730302,
          1.4145940829549188,
          1.4070671290477492,
          1.2828723895794507,
          1.241474143090018,
          1.2828723895794507,
          1.0231924797821,
          1.0231924797821,
          1.0231924797821,
          0.9742672793854974,
          0.9742672793854974,
          0.9629768485247432,
          0.9366325098496494,
          0.8839438324994622,
          0.8425455860100294,
          0.8425455860100294,
          0.9102881711745558,
          0.9554498946175736,
          0.9516864176639886,
          1.4672827603051062,
          1.4559923294443518,
          1.433411467722843,
          1.3957766981869948,
          1.3995401751405796,
          1.4258845138156733,
          1.4861001450730302,
          1.4861001450730302,
          1.4861001450730302,
          1.4823366681194454,
          1.4748097142122758,
          1.4748097142122758,
          1.4748097142122758,
          1.4748097142122758,
          1.4823366681194454,
          1.4861001450730302,
          1.4597558063979366,
          1.4559923294443518,
          1.471046237258691,
          1.4861001450730302,
          0.9667403254783278,
          0.9629768485247432,
          0.9629768485247432,
          0.9178151250817254,
          1.670510515798685,
          1.6592200849379306,
          1.651693131030761,
          1.629112269309252,
          1.617821838448498,
          1.632875746262837,
          1.632875746262837,
          1.617821838448498,
          1.6592200849379306,
          1.651693131030761,
          1.629112269309252,
          1.5877140228198194,
          1.602767930634159,
          1.6102948845413283,
          1.7533070087775506,
          1.745780054870381,
          1.745780054870381,
          1.689327900566609,
          1.7043818083809483,
          1.7344896240096266,
          1.7344896240096266,
          1.7194357161952876,
          1.6780374697058549,
          1.689327900566609,
          1.6102948845413283,
          1.629112269309252,
          1.625348792355667,
          1.629112269309252,
          0.3946918285334382,
          0.4059822593941927,
          0.3156588125081574,
          0.0973771492002391,
          0.3570570589975902,
          0.4323265980692863,
          0.4737248445587191,
          0.5038326601873976,
          0.6618986922379588,
          0.8914707864066318,
          1.0119020489213455,
          0.9629768485247432,
          1.3280341130224684,
          1.3280341130224684,
          1.3016897743473748,
          1.2264202352756788,
          1.2339471891828484,
          1.2490010969971876,
          1.2377106661364332,
          1.2301837122292636,
          1.147387219250398,
          1.4785731911658606,
          1.4597558063979366,
          1.39201322123341,
          1.444701898583597,
          1.4823366681194454,
          1.5086810067945389,
          1.4748097142122758,
          1.3957766981869948,
          1.3468514977903925,
          1.279108912625866,
          1.0119020489213455,
          1.2264202352756788
         ],
         "z": [
          0.7154774216182078,
          1.7111530766140892,
          1.7011963200641305,
          1.6912395635141717,
          1.671326050414254,
          1.6265206459394392,
          1.6066071328395215,
          1.6016287545645422,
          1.5916719980145837,
          1.5916719980145837,
          1.561801728364707,
          1.5568233500897275,
          1.561801728364707,
          1.53690983698981,
          1.4721909194150775,
          2.323493604436556,
          2.328471982711536,
          2.348385495811453,
          2.348385495811453,
          2.348385495811453,
          2.343407117536474,
          2.348385495811453,
          2.3633206306363914,
          2.3633206306363914,
          2.338428739261494,
          2.2936233347866795,
          2.3085584696116177,
          2.3085584696116177,
          2.273709821686762,
          0.3022720247949174,
          0.2823585116949997,
          0.3072504030698968,
          0.2275963506702262,
          0.1977260810203498,
          0.899677417792446,
          0.8897206612424872,
          0.899677417792446,
          1.1237044401665195,
          1.1237044401665195,
          1.1237044401665195,
          0.9992449832920342,
          0.9992449832920342,
          0.9693747136421578,
          0.9693747136421578,
          0.9942666050170548,
          1.0291152529419108,
          1.0141801181169725,
          1.0291152529419108,
          0.934526065717302,
          0.924569309167343,
          0.9395044439922812,
          1.5916719980145837,
          1.5667801066396865,
          1.5319314587148305,
          1.5070395673399335,
          1.4572557845901393,
          1.4074720018403453,
          1.6066071328395215,
          1.586693619739604,
          1.586693619739604,
          1.5966503762895627,
          1.6016287545645422,
          1.6016287545645422,
          1.5518449718147482,
          1.307904436340757,
          1.2531422753159835,
          1.2182936273911276,
          1.2033584925661895,
          1.258120653590963,
          1.3029260580657775,
          1.3477314625405925,
          1.62154226766446,
          1.5817152414646245,
          1.5767368631896452,
          1.4970828107899743,
          1.5070395673399335,
          1.5120179456149128,
          1.5070395673399335,
          1.5219747021648715,
          1.4970828107899743,
          1.4124503801153248,
          1.3726233539154893,
          1.4024936235653658,
          1.2133152491161483,
          0.9295476874423224,
          0.9295476874423224,
          0.8598503915926108,
          0.7005422867932696,
          0.6656936388684137,
          0.6557368823184552,
          0.6905855302433108,
          1.3278179494406748,
          1.3377747059906335,
          1.2182936273911276,
          1.2680774101409218,
          1.2730557884159013,
          1.058985522591787,
          0.6507585040434758,
          1.4572557845901393,
          1.4472990280401803,
          1.442320649765201,
          1.3825801104654485,
          1.3626665973655303,
          1.3278179494406748,
          1.477169297690057,
          1.4672125411400982,
          1.6613692938642952,
          1.5518449718147482,
          1.45227740631516,
          1.4472990280401803,
          1.5667801066396865,
          1.53690983698981,
          0.1628774330954939,
          0.0682882458708851,
          -0.0163441848037645,
          1.2083368708411688,
          1.1237044401665195,
          1.0988125487916225,
          1.11872606189154,
          1.1087693053415812,
          1.138639574991457,
          1.2680774101409218,
          1.2979476797907985,
          1.307904436340757,
          1.3776017321904688,
          1.3377747059906335,
          1.342753084265613,
          1.526953080439851,
          1.5319314587148305,
          1.5319314587148305,
          1.3128828146157363,
          1.2680774101409218,
          1.332796327715654,
          1.3527098408155718,
          1.4921044325149952,
          1.45227740631516,
          1.2730557884159013,
          1.357688219090551,
          1.3029260580657775,
          1.36764497564051,
          1.5070395673399335,
          0.6507585040434758,
          0.6408017474935169,
          0.6358233692185375,
          0.6258666126685788,
          0.6059530995686612,
          0.5362558037189494,
          0.5262990471689906,
          0.3819260771945876,
          0.4366882382193612,
          0.297293646519938,
          0.1429639199955762,
          1.2182936273911276,
          1.223272005666107,
          1.2282503839410863,
          1.2332287622160658,
          1.28301254496586,
          1.3029260580657775,
          1.28301254496586,
          1.3029260580657775,
          1.2282503839410863,
          1.2929693015158188,
          1.307904436340757,
          1.3128828146157363,
          1.8107206421136768,
          1.8107206421136768,
          1.7957855072887383,
          1.7659152376388625,
          1.7509801028139245,
          1.721109833164048,
          1.6912395635141717,
          1.6514125373143362,
          1.6265206459394392,
          1.5817152414646245,
          1.5817152414646245,
          1.561801728364707,
          1.417428758390304,
          1.3975152452903865,
          1.6265206459394392,
          1.611585511114501,
          1.6016287545645422,
          1.5817152414646245,
          1.561801728364707,
          1.5120179456149128,
          1.4871260542400158,
          1.4622341628651188,
          1.3875584887404275,
          1.3726233539154893,
          1.3726233539154893,
          1.4124503801153248,
          1.36764497564051,
          1.3825801104654485,
          1.586693619739604,
          1.6016287545645422,
          1.5966503762895627,
          1.5817152414646245,
          1.5568233500897275,
          1.5418882152647893,
          1.5418882152647893,
          1.561801728364707,
          1.5120179456149128,
          1.5169963238898925,
          1.477169297690057,
          1.442320649765201,
          1.4024936235653658,
          1.4024936235653658,
          1.5518449718147482,
          1.5418882152647893,
          1.5468665935397687,
          1.5468665935397687,
          1.5468665935397687,
          1.5468665935397687,
          1.5219747021648715,
          1.5169963238898925,
          1.526953080439851,
          1.4871260542400158,
          1.5319314587148305,
          1.4970828107899743,
          1.4572557845901393,
          1.4672125411400982,
          1.6763044286892337,
          1.731066589714007,
          1.7509801028139245,
          1.696217941789151,
          1.6763044286892337,
          1.6663476721392745,
          1.7659152376388625,
          1.7559584810889033,
          1.696217941789151,
          1.6862611852391922,
          1.7011963200641305,
          1.696217941789151,
          1.6563909155893155,
          1.5817152414646245,
          1.3527098408155718,
          1.611585511114501,
          1.6016287545645422,
          1.6514125373143362,
          1.6514125373143362,
          1.4921044325149952,
          1.3975152452903865,
          1.3377747059906335,
          1.3626665973655303,
          1.3527098408155718,
          1.3178611928907158,
          1.4024936235653658,
          1.3726233539154893,
          1.357688219090551,
          1.392536867015407,
          1.3726233539154893,
          1.3626665973655303,
          1.36764497564051,
          1.5169963238898925,
          1.4871260542400158,
          1.477169297690057,
          1.2630990318659423,
          1.248163897041004,
          1.248163897041004,
          1.223272005666107,
          1.2531422753159835,
          1.5817152414646245,
          1.5916719980145837,
          1.5319314587148305,
          1.4572557845901393,
          1.45227740631516,
          1.3975152452903865,
          1.3626665973655303,
          1.28301254496586,
          1.332796327715654,
          1.4373422714902218,
          1.45227740631516,
          1.3278179494406748,
          1.36764497564051,
          1.2879909232408393,
          1.36764497564051,
          1.4970828107899743,
          1.5219747021648715,
          1.5120179456149128,
          1.5169963238898925,
          1.4821476759650365,
          1.477169297690057,
          1.5070395673399335,
          1.5468665935397687,
          1.45227740631516,
          1.5468665935397687,
          1.4821476759650365,
          1.3228395711656953,
          1.3626665973655303,
          2.179120634462153,
          2.159207121362236,
          2.1392936082623177,
          2.1940557692870915,
          2.1691638779121942,
          2.069596312412606,
          2.0496827993126887,
          2.0148341513878325,
          1.989942260012936,
          1.994920638287915,
          1.820677398663636,
          1.7111530766140892,
          1.6016287545645422,
          1.671326050414254,
          1.0639639008667665,
          0.7702395826429813,
          0.790153095742899,
          0.790153095742899,
          0.6905855302433108,
          0.6905855302433108,
          0.7652612043680019,
          0.7453476912680843,
          0.7254341781681667,
          0.7104990433432284,
          0.7005422867932696,
          0.7055206650682491,
          1.477169297690057,
          1.4672125411400982,
          1.4622341628651188,
          1.636477402489398,
          1.62154226766446,
          1.62154226766446,
          1.526953080439851,
          1.53690983698981,
          1.5120179456149128,
          1.4721909194150775,
          1.4721909194150775,
          0.003569328296153,
          0.003569328296153,
          0.0085477065711325,
          0.0085477065711325,
          0.0234828413960707,
          0.0832233806958233,
          0.0583314893209263,
          0.0483747327709675,
          0.0483747327709675,
          1.5568233500897275,
          1.5518449718147482,
          1.5518449718147482,
          1.5717584849146655,
          1.5667801066396865,
          1.5667801066396865,
          1.5518449718147482,
          1.5468665935397687,
          1.5468665935397687,
          1.53690983698981,
          1.5070395673399335,
          1.5120179456149128,
          1.5169963238898925,
          1.5169963238898925,
          1.2133152491161483,
          1.223272005666107,
          1.2033584925661895,
          1.2282503839410863,
          1.2133152491161483,
          1.2133152491161483,
          1.2182936273911276,
          1.148596331541416,
          1.1286828184414988,
          1.148596331541416,
          0.9693747136421578,
          0.9295476874423224,
          0.8299801219427343,
          1.3776017321904688,
          1.4124503801153248,
          1.4024936235653658,
          1.3029260580657775,
          1.2382071404910453,
          1.2282503839410863,
          1.2182936273911276,
          1.1585530880913748,
          1.044050387766849,
          0.984309848467096,
          1.153574709816395,
          1.2083368708411688,
          1.9003314510633065,
          1.8903746945133475,
          1.8903746945133475,
          1.8804179379633883,
          1.8804179379633883,
          1.8704611814134295,
          1.8555260465884915,
          1.8555260465884915,
          1.8555260465884915,
          1.825655776938615,
          1.820677398663636,
          1.7957855072887383,
          1.835612533488574,
          1.835612533488574,
          1.5169963238898925,
          1.5070395673399335,
          1.4970828107899743,
          1.4821476759650365,
          1.4572557845901393,
          1.4721909194150775,
          1.561801728364707,
          1.5468665935397687,
          1.5717584849146655,
          1.5120179456149128,
          1.4921044325149952,
          1.4921044325149952,
          1.4721909194150775,
          1.477169297690057,
          1.4572557845901393,
          1.45227740631516,
          1.442320649765201,
          1.442320649765201,
          1.442320649765201,
          1.3626665973655303,
          1.3477314625405925,
          1.36764497564051,
          1.4124503801153248,
          1.4323638932152425,
          1.4224071366652835,
          1.4074720018403453,
          1.4124503801153248,
          1.3278179494406748,
          1.4273855149402628,
          1.442320649765201,
          1.4224071366652835,
          1.3825801104654485,
          1.3776017321904688,
          1.53690983698981,
          1.5219747021648715,
          1.5169963238898925,
          1.4672125411400982,
          1.4871260542400158,
          1.2133152491161483,
          1.0241368746669313,
          1.6165638893894805,
          1.6165638893894805,
          1.5966503762895627,
          1.53690983698981,
          1.5319314587148305,
          1.5568233500897275,
          1.53690983698981,
          1.526953080439851,
          1.5966503762895627,
          1.4921044325149952,
          1.4921044325149952,
          1.392536867015407,
          1.3178611928907158,
          1.2879909232408393,
          0.7503260695430637,
          0.7503260695430637,
          0.7453476912680843,
          0.7005422867932696,
          0.7104990433432284,
          0.7055206650682491,
          0.6856071519683314,
          0.6308449909435582,
          0.5910179647437229,
          0.6308449909435582,
          0.6457801257684964,
          0.7702395826429813,
          0.7055206650682491,
          1.3875584887404275,
          1.36764497564051,
          1.342753084265613,
          1.2780341666908803,
          1.4472990280401803,
          1.4572557845901393,
          1.5468665935397687,
          1.5319314587148305,
          1.5169963238898925,
          1.502061189064954,
          1.4821476759650365,
          1.526953080439851,
          1.526953080439851,
          1.526953080439851,
          1.4921044325149952,
          1.5219747021648715,
          1.4572557845901393,
          1.45227740631516,
          1.248163897041004,
          1.2182936273911276,
          0.7304125564431461,
          0.7304125564431461,
          0.7304125564431461,
          0.7154774216182078,
          1.721109833164048,
          1.8156990203886565,
          1.7908071290137593,
          1.7659152376388625,
          1.7559584810889033,
          1.7708936159138415,
          1.7708936159138415,
          1.8057422638386973,
          1.820677398663636,
          1.7858287507387798,
          1.7509801028139245,
          1.7011963200641305,
          1.6613692938642952,
          1.6514125373143362,
          1.5717584849146655,
          1.5667801066396865,
          1.5667801066396865,
          1.502061189064954,
          1.5169963238898925,
          1.5468665935397687,
          1.5468665935397687,
          1.53690983698981,
          1.502061189064954,
          1.502061189064954,
          1.4871260542400158,
          1.5070395673399335,
          1.502061189064954,
          1.502061189064954,
          0.3918828337445465,
          0.3968612120195259,
          0.3072504030698968,
          -0.6286847126262315,
          -0.4743549861018699,
          -0.4345279599020347,
          -0.4345279599020347,
          -0.3498955292273847,
          -0.3150468813025288,
          -0.180630667878085,
          -0.0661279675535586,
          -0.1059549937533939,
          1.6066071328395215,
          1.6314990242144187,
          1.62154226766446,
          1.5468665935397687,
          1.5468665935397687,
          1.5418882152647893,
          1.502061189064954,
          1.45227740631516,
          1.3477314625405925,
          2.089509825512524,
          2.0247909079377915,
          1.9799855034629767,
          1.7957855072887383,
          1.7957855072887383,
          1.8057422638386973,
          1.646434159039357,
          1.4970828107899743,
          1.4273855149402628,
          1.342753084265613,
          1.0540071443168078,
          1.2680774101409218
         ]
        },
        {
         "hovertemplate": "regime=Closed Autocracy<br>v2x_polyarchy=%{x}<br>v2x_libdem=%{y}<br>v2x_partipdem=%{z}<extra></extra>",
         "legendgroup": "Closed Autocracy",
         "marker": {
          "color": "#00cc96",
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Closed Autocracy",
         "scene": "scene",
         "showlegend": true,
         "type": "scatter3d",
         "x": [
          -1.5496660214176556,
          -1.5883945691809496,
          -1.654233100378549,
          -1.692961648141843,
          -1.2863118966272569,
          -1.5612845857466435,
          -1.5690302952993025,
          -1.5651574405229731,
          -1.545793166641326,
          -1.5612845857466435,
          -1.553538876193985,
          -1.5225560379833498,
          -1.5031917641017027,
          -1.1662533985610457,
          -1.1778719628900338,
          -1.0655591743764814,
          -1.104287722139775,
          -1.119779141245093,
          -1.228219074982316,
          -1.228219074982316,
          -1.3289132991668802,
          -1.3560232826011858,
          -1.3444047182721974,
          -1.3753875564828326,
          -1.387006120811821,
          -1.398624685140809,
          -1.3715147017065032,
          -1.336659008719539,
          -1.4993189093253734,
          -1.5109374736543617,
          -1.4528446520094207,
          -1.367641846930174,
          -1.4063703946934678,
          -1.3908789755881503,
          -1.483827490220056,
          -1.4257346685751149,
          -1.4296075233514445,
          -1.4334803781277736,
          -1.4412260876804324,
          -1.4412260876804324,
          -1.4412260876804324,
          -1.4257346685751149,
          -1.417988959022456,
          -1.3753875564828326,
          -1.1856176724426928,
          -1.1894905272190222,
          -1.348277573048527,
          -1.4102432494697972,
          -1.4296075233514445,
          -1.7007073576945018,
          -1.7161987767998192,
          -1.6735973742601962,
          -1.6735973742601962,
          -1.6735973742601962,
          -1.6735973742601962,
          -1.677470229036525,
          -1.677470229036525,
          -1.677470229036525,
          -1.677470229036525,
          -1.677470229036525,
          -1.677470229036525,
          -1.681343083812855,
          -1.681343083812855,
          -1.677470229036525,
          -1.681343083812855,
          -1.4063703946934678,
          -1.4296075233514445,
          -1.4141161042461268,
          -1.437353232904103,
          -1.3637689921538445,
          -1.2127276558769984,
          -1.2630747679692804,
          -1.2359647845349746,
          -1.208854801100669,
          -1.2127276558769984,
          -0.9764835145209052,
          -1.2863118966272569,
          -1.309549025285233,
          -1.3908789755881503,
          -1.4296075233514445,
          -1.4024975399171384,
          -1.07330488392914,
          -1.050067755271164,
          -1.050067755271164,
          -1.022957771836858,
          -1.0268306266131877,
          -1.022957771836858,
          -1.0849234482581285,
          -0.9997206431788817,
          -0.9997206431788817,
          -0.9997206431788817,
          -1.01133920750787,
          -1.0268306266131877,
          -1.01133920750787,
          -1.0152120622841994,
          -1.0074663527315404,
          -0.9881020788498937,
          -0.9803563692972348,
          -0.972610659744576,
          -0.9687378049682466,
          -0.9881020788498937,
          -0.9764835145209052,
          -0.9958477884025524,
          -0.9919749336262228,
          -1.003593497955211,
          -1.0190849170605287,
          -0.9881020788498937,
          -0.9881020788498937,
          -0.9881020788498937,
          -1.8478758391950187,
          -1.8440029844186892,
          -1.84013012964236,
          -1.84013012964236,
          -1.8440029844186892,
          -1.8440029844186892,
          -1.8478758391950187,
          -1.8478758391950187,
          -1.8440029844186892,
          -1.851748693971348,
          -1.8556215487476777,
          -1.661978809931208,
          -1.6697245194838668,
          -1.6697245194838668,
          -1.476081780667397,
          -1.4683360711147382,
          -1.4722089258910676,
          -1.476081780667397,
          -1.4722089258910676,
          -1.476081780667397,
          -1.4722089258910676,
          -1.4683360711147382,
          -1.4722089258910676,
          -1.4722089258910676,
          -1.4412260876804324,
          -1.4412260876804324,
          -1.4334803781277736,
          -1.642614536049561,
          -1.642614536049561,
          -1.642614536049561,
          -1.6697245194838668,
          -1.681343083812855,
          -1.692961648141843,
          -1.6968345029181724,
          -1.7045802124708311,
          -1.7084530672471605,
          -1.7161987767998192,
          -1.71232592202349,
          -1.7084530672471605,
          -1.7161987767998192,
          -1.7200716315761488,
          -1.743308760234125,
          -1.743308760234125,
          -1.743308760234125,
          -1.7355630506814663,
          -1.7355630506814663,
          -1.7355630506814663,
          -1.7394359054577957,
          -1.743308760234125,
          -1.7394359054577957,
          -1.7355630506814663,
          -1.7394359054577957,
          -1.7278173411288076,
          -1.7278173411288076,
          -1.743308760234125,
          -0.8874078546653295,
          -1.6503602456022195,
          -1.654233100378549,
          -1.658105955154879,
          -1.658105955154879,
          -1.658105955154879,
          -1.658105955154879,
          -1.6464873908258904,
          -1.5225560379833498,
          -1.5186831832070204,
          -1.5109374736543617,
          -1.5148103284306909,
          -1.4877003449963853,
          -1.4915731997727146,
          -1.495446054549044,
          -1.7278173411288076,
          -1.3134218800615625,
          -0.9222635476522938,
          -0.8990264189943176,
          -0.8990264189943176,
          -0.9416278215339408,
          -0.972610659744576,
          -0.984229224073564,
          -0.9764835145209052,
          -1.170126253337375,
          -1.2011090915480105,
          -1.2553290584166217,
          -1.1313977055740811,
          -1.1313977055740811,
          -1.1275248507977518,
          -1.2553290584166217,
          -1.2359647845349746,
          -1.3211675896142214,
          -1.348277573048527,
          -1.348277573048527,
          -1.348277573048527,
          -1.3521504278248564,
          -1.3289132991668802,
          -1.3947518303644797,
          -1.417988959022456,
          -1.387006120811821,
          -1.3598961373775151,
          -1.3753875564828326,
          -1.3405318634958685,
          -1.5264288927596792,
          -1.5264288927596792,
          -1.5264288927596792,
          -1.5031917641017027,
          -1.5031917641017027,
          -1.5031917641017027,
          -1.5031917641017027,
          -1.495446054549044,
          -1.5031917641017027,
          -1.4877003449963853,
          -1.495446054549044,
          -1.545793166641326,
          -1.5496660214176556,
          -1.5264288927596792,
          -1.4450989424567615,
          -1.448971797233091,
          -1.4450989424567615,
          -1.4450989424567615,
          -1.448971797233091,
          -1.448971797233091,
          -1.448971797233091,
          -1.4334803781277736,
          -1.4334803781277736,
          -1.4257346685751149,
          -1.4102432494697972,
          -1.4141161042461268,
          -1.4063703946934678,
          -1.4799546354437263,
          -1.476081780667397,
          -1.5186831832070204,
          -1.5264288927596792,
          -1.5225560379833498,
          -1.553538876193985,
          -1.541920311864997,
          -1.495446054549044,
          -1.4993189093253734,
          -1.483827490220056,
          -1.4799546354437263,
          -1.3598961373775151,
          -1.3560232826011858,
          -1.3521504278248564,
          -1.2630747679692804,
          -1.2746933322982683,
          -1.2127276558769984,
          -1.1739991081137044,
          -1.1739991081137044,
          -1.1507619794557282,
          -1.3444047182721974,
          -1.367641846930174,
          -1.3753875564828326,
          -1.3831332660354916,
          -1.4683360711147382,
          -1.4877003449963853,
          -1.5225560379833498,
          -1.545793166641326,
          -1.5380474570886673,
          -1.534174602312338,
          -1.5225560379833498,
          -1.5225560379833498,
          -1.507064618878032,
          -1.3598961373775151,
          -1.3598961373775151,
          -1.3598961373775151,
          -1.3521504278248564,
          -1.3521504278248564,
          -1.3521504278248564,
          -1.348277573048527,
          -1.348277573048527,
          -1.317294734837892,
          -1.3056761705089035,
          -1.3134218800615625,
          -1.3134218800615625,
          -1.3134218800615625,
          -1.3250404443905508,
          -1.4915731997727146,
          -1.4915731997727146,
          -1.4722089258910676,
          -1.4528446520094207,
          -0.5659609082299898,
          -0.5698337630063192,
          -0.5969437464406249,
          -0.6163080203222719,
          -0.6240537298749307,
          -0.6627822776382246,
          -0.7092565349541772,
          -0.7441122279411417,
          -0.7673493565991182,
          -0.8370607425730473,
          -0.9609920954155876,
          -1.1817448176663634,
          -1.3637689921538445,
          -1.4102432494697972,
          -0.7324936636121535,
          -0.7324936636121535,
          -0.7789679209281063,
          -0.7712222113754476,
          -0.7596036470464593,
          -0.7789679209281063,
          -0.7750950661517769,
          -0.7286208088358241,
          -0.7596036470464593,
          -0.7324936636121535,
          -0.7479850827174711,
          -0.7944593400334239,
          -0.7983321948097533,
          -0.717002244506836,
          -1.3947518303644797,
          -1.3598961373775151,
          -1.3444047182721974,
          -1.3444047182721974,
          -1.3444047182721974,
          -1.3444047182721974,
          -1.3289132991668802,
          -1.3289132991668802,
          -1.3211675896142214,
          -1.3250404443905508,
          -1.336659008719539,
          -1.336659008719539,
          -1.3560232826011858,
          -1.348277573048527,
          -1.929205789497936,
          -1.9330786442742651,
          -1.9330786442742651,
          -1.9369514990505947,
          -1.940824353826924,
          -1.9446972086032532,
          -1.9485700633795828,
          -1.9524429181559124,
          -1.9485700633795828,
          -1.9485700633795828,
          -1.9524429181559124,
          -1.9485700633795828,
          -1.9485700633795828,
          -1.9485700633795828,
          -1.7355630506814663,
          -1.692961648141843,
          -1.661978809931208,
          -1.661978809931208,
          -1.6697245194838668,
          -1.642614536049561,
          -1.6309959717205729,
          -1.6464873908258904,
          -1.6464873908258904,
          -1.6193774073915848,
          -1.6155045526152552,
          -1.623250262167914,
          -1.6116316978389258,
          -1.6116316978389258
         ],
         "y": [
          -1.396723201372926,
          -1.434357970908774,
          -1.453175355676698,
          -1.4569388326302828,
          -1.1483337224363297,
          -1.3741423396514174,
          -1.381669293558587,
          -1.3779058166050022,
          -1.3666153857442478,
          -1.3854327705121716,
          -1.3891962474657564,
          -1.3553249548834934,
          -1.3365075701155693,
          -0.9752137825714284,
          -1.268764984951043,
          -0.9225251052212414,
          -0.9526329208499198,
          -0.9601598747570892,
          -1.1295163376684054,
          -1.1295163376684054,
          -1.2424206462759493,
          -1.268764984951043,
          -1.2762919388582126,
          -1.3327440931619845,
          -1.3026362775333062,
          -1.3327440931619845,
          -1.2838188927653822,
          -1.265001507997458,
          -1.310163231440476,
          -1.2913458466725518,
          -1.2725284619046278,
          -1.287582369718967,
          -1.313926708394061,
          -1.310163231440476,
          -1.344034524022739,
          -1.0918815681325575,
          -1.095645045086142,
          -1.095645045086142,
          -1.0730641833646335,
          -1.0730641833646335,
          -1.0730641833646335,
          -1.0580102755502945,
          -1.069300706411049,
          -1.0805911372718031,
          -1.061773752503879,
          -1.1069354759468966,
          -1.1031719989933118,
          -1.1069354759468966,
          -1.0881180911789727,
          -1.4117771091872653,
          -1.4042501552800957,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.4607023095838676,
          -1.084354614225388,
          -1.137043291575575,
          -1.1332798146219902,
          -1.14080676852916,
          -1.1069354759468966,
          -0.8209112274744519,
          -0.8510190431031303,
          -0.8472555661495454,
          -0.8171477505208671,
          -0.8322016583352063,
          -0.8171477505208671,
          -1.178441538065008,
          -1.1859684919721776,
          -1.1746780611114231,
          -1.2236032615080252,
          -1.208549353693686,
          -0.7230608266812472,
          -0.7042434419133231,
          -0.6929530110525687,
          -0.6816625801918142,
          -0.6854260571453991,
          -0.6816625801918142,
          -0.7832764579386038,
          -0.6327373797952119,
          -0.6063930411201184,
          -0.6176834719808727,
          -0.6101565180737032,
          -0.5838121793986095,
          -0.5838121793986095,
          -0.5649947946306855,
          -0.6440278106559663,
          -0.6327373797952119,
          -0.6289739028416271,
          -0.6477912876095511,
          -0.6440278106559663,
          -0.6477912876095511,
          -0.6402643337023814,
          -0.6101565180737032,
          -0.6063930411201184,
          -0.6139199950272879,
          -0.6440278106559663,
          -0.6289739028416271,
          -0.5913391333057791,
          -0.5800487024450247,
          -1.1445702454827449,
          -1.1445702454827449,
          -1.1445702454827449,
          -1.1746780611114231,
          -1.1709145841578383,
          -1.1709145841578383,
          -1.1746780611114231,
          -1.1859684919721776,
          -1.178441538065008,
          -1.2010223997865166,
          -1.1934954458793472,
          -1.2010223997865166,
          -1.2010223997865166,
          -1.1972589228329318,
          -1.4230675400480195,
          -1.4230675400480195,
          -1.4230675400480195,
          -1.419304063094435,
          -1.41554058614085,
          -1.41554058614085,
          -1.41554058614085,
          -1.3929597244193412,
          -1.381669293558587,
          -1.3891962474657564,
          -1.313926708394061,
          -1.3703788626978326,
          -1.340271047069154,
          -1.306399754486891,
          -1.310163231440476,
          -1.310163231440476,
          -1.3176901853476457,
          -1.3176901853476457,
          -1.32145366230123,
          -1.3176901853476457,
          -1.3289806162083997,
          -1.3327440931619845,
          -1.3365075701155693,
          -1.3553249548834934,
          -1.3515614779299086,
          -1.3553249548834934,
          -1.3779058166050022,
          -1.4983370791197157,
          -1.4983370791197157,
          -1.4983370791197157,
          -1.4945736021661309,
          -1.490810125212546,
          -1.4945736021661309,
          -1.4945736021661309,
          -1.490810125212546,
          -1.490810125212546,
          -1.4832831713053765,
          -1.4795196943517916,
          -1.4757562173982068,
          -1.471992740444622,
          -1.4795196943517916,
          -0.7305877805884167,
          -1.2236032615080252,
          -1.2236032615080252,
          -1.2236032615080252,
          -1.2198397845544404,
          -1.2236032615080252,
          -1.2236032615080252,
          -1.2198397845544404,
          -1.1859684919721776,
          -1.1934954458793472,
          -1.137043291575575,
          -1.2010223997865166,
          -1.1520971993899145,
          -1.1219893837612358,
          -1.159624153297084,
          -1.3515614779299086,
          -1.287582369718967,
          -0.8623094739638847,
          -0.8660729509174695,
          -0.8698364278710543,
          -0.8886538126389782,
          -0.9451059669427502,
          -0.9601598747570892,
          -0.9714503056178436,
          -1.042956367735955,
          -1.1106989529004814,
          -1.1295163376684054,
          -1.208549353693686,
          -1.1295163376684054,
          -1.1295163376684054,
          -1.1219893837612358,
          -1.1144624298540662,
          -1.1069354759468966,
          -1.065537229457464,
          -1.065537229457464,
          -1.0504833216431246,
          -1.099408522039727,
          -1.0542467985967094,
          -1.1219893837612358,
          -1.137043291575575,
          -1.1257528607148206,
          -1.099408522039727,
          -1.084354614225388,
          -1.005321598200107,
          -1.155860676343499,
          -1.159624153297084,
          -1.159624153297084,
          -1.1445702454827449,
          -1.1483337224363297,
          -1.1483337224363297,
          -1.1483337224363297,
          -1.137043291575575,
          -1.0881180911789727,
          -1.095645045086142,
          -1.0918815681325575,
          -1.1633876302506687,
          -1.1671511072042535,
          -1.1633876302506687,
          -1.4268310170016043,
          -1.4305944939551891,
          -1.4305944939551891,
          -1.4230675400480195,
          -1.419304063094435,
          -1.419304063094435,
          -1.419304063094435,
          -1.4117771091872653,
          -1.3891962474657564,
          -1.381669293558587,
          -1.1295163376684054,
          -1.137043291575575,
          -1.1332798146219902,
          -1.2537110771367037,
          -1.249947600183119,
          -1.2800554158117974,
          -1.2725284619046278,
          -1.2913458466725518,
          -1.3703788626978326,
          -1.2424206462759493,
          -1.3289806162083997,
          -1.313926708394061,
          -1.2913458466725518,
          -1.2537110771367037,
          -1.381669293558587,
          -1.381669293558587,
          -1.3779058166050022,
          -1.32145366230123,
          -1.2762919388582126,
          -1.2198397845544404,
          -1.2160763076008556,
          -1.2123128306472708,
          -1.2010223997865166,
          -1.3477980009763235,
          -1.3515614779299086,
          -1.3515614779299086,
          -1.3477980009763235,
          -1.3515614779299086,
          -1.3515614779299086,
          -1.3590884318370782,
          -1.3515614779299086,
          -1.32145366230123,
          -1.32145366230123,
          -1.313926708394061,
          -1.310163231440476,
          -1.313926708394061,
          -1.32145366230123,
          -1.3176901853476457,
          -1.3176901853476457,
          -1.2951093236261366,
          -1.2951093236261366,
          -1.2988728005797214,
          -1.2988728005797214,
          -1.2913458466725518,
          -1.2838188927653822,
          -1.2800554158117974,
          -1.287582369718967,
          -1.2988728005797214,
          -1.2988728005797214,
          -1.2988728005797214,
          -1.118225906807651,
          -1.118225906807651,
          -1.1144624298540662,
          -1.084354614225388,
          -0.3053148848333343,
          -0.3053148848333343,
          -0.3203687926476735,
          -0.3429496543691824,
          -0.3504766082763519,
          -0.3843479008586152,
          -0.4144557164872936,
          -0.4370365782088024,
          -0.4746713477446502,
          -0.516069594234083,
          -0.7343512575420015,
          -0.9037077204533174,
          -1.005321598200107,
          -1.0504833216431246,
          -0.406928762580124,
          -0.406928762580124,
          -0.4332731012552176,
          -0.4332731012552176,
          -0.425746147348048,
          -0.4370365782088024,
          -0.4295096243016328,
          -0.3994018086729544,
          -0.4144557164872936,
          -0.4031652856265392,
          -0.4219826703944632,
          -0.4483270090695568,
          -0.4031652856265392,
          -0.3391861774155976,
          -1.042956367735955,
          -1.005321598200107,
          -0.9977946442929374,
          -0.9977946442929374,
          -0.9940311673393526,
          -0.9940311673393526,
          -0.9940311673393526,
          -0.9940311673393526,
          -0.9902676903857678,
          -0.9902676903857678,
          -1.005321598200107,
          -0.9977946442929374,
          -1.001558121246522,
          -1.001558121246522,
          -1.340271047069154,
          -1.340271047069154,
          -1.340271047069154,
          -1.3365075701155693,
          -1.3365075701155693,
          -1.3365075701155693,
          -1.344034524022739,
          -1.344034524022739,
          -1.3477980009763235,
          -1.340271047069154,
          -1.344034524022739,
          -1.344034524022739,
          -1.344034524022739,
          -1.344034524022739,
          -1.208549353693686,
          -1.2160763076008556,
          -1.1934954458793472,
          -1.1897319689257624,
          -1.1859684919721776,
          -1.178441538065008,
          -1.1746780611114231,
          -1.1709145841578383,
          -1.1633876302506687,
          -1.1709145841578383,
          -1.178441538065008,
          -1.208549353693686,
          -1.1934954458793472,
          -1.2236032615080252
         ],
         "z": [
          -1.2310684838987396,
          -1.166349566324007,
          -1.201198214248863,
          -1.2410252404486983,
          -1.300765779748451,
          -1.335614427673307,
          -1.335614427673307,
          -1.3306360493983276,
          -1.3405928059482863,
          -1.360506319048204,
          -1.350549562498245,
          -1.335614427673307,
          -1.325657671123348,
          -1.1812847011489451,
          -1.1812847011489451,
          -0.7879928174255725,
          -0.8029279522505107,
          -0.6834468736510049,
          -1.2360468621737188,
          -1.250981996998657,
          -1.2858306449235128,
          -1.2908090231984923,
          -1.2111549707988218,
          -1.3405928059482863,
          -1.3804198321481216,
          -1.3804198321481216,
          -1.3455711842232658,
          -1.201198214248863,
          -1.3903765886980806,
          -1.410290101797998,
          -1.2957874014734718,
          -1.1414576749491103,
          -1.2559603752736364,
          -1.1464360532240898,
          -1.2360468621737188,
          -0.8178630870754489,
          -0.8128847088004696,
          -0.8278198436254076,
          -0.8427549784503459,
          -0.8377766001753665,
          -0.8377766001753665,
          -0.832798221900387,
          -0.8278198436254076,
          -0.8079063305254901,
          -0.7282522781258196,
          -0.758122547775696,
          -0.8178630870754489,
          -0.8726252481002224,
          -0.8427549784503459,
          -1.594490097972236,
          -1.6094252327971743,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.450117127997833,
          -1.445138749722854,
          -1.445138749722854,
          -1.445138749722854,
          -1.2808522666485336,
          -1.265917131823595,
          -1.2310684838987396,
          -1.151414431499069,
          -1.126522540124172,
          -1.0717603790993986,
          -1.0966522704742956,
          -1.0219765963496044,
          -1.0369117311745426,
          -0.9622360570498516,
          -0.5789009298764374,
          -0.832798221900387,
          -0.9871279484247486,
          -1.4849657759226893,
          -1.4999009107476275,
          -1.4899441541976688,
          -1.201198214248863,
          -1.1812847011489451,
          -1.1414576749491103,
          -1.1215441618491926,
          -1.1215441618491926,
          -1.1066090270242543,
          -1.1215441618491926,
          -1.066782000824419,
          -1.076738757374378,
          -1.0618036225494398,
          -1.0866955139243368,
          -1.091673892199316,
          -1.0817171356493571,
          -1.0866955139243368,
          -0.9970847049747076,
          -0.8377766001753665,
          -0.8228414653504282,
          -0.832798221900387,
          -0.832798221900387,
          -0.7879928174255725,
          -0.7929711957005519,
          -0.8477333567253252,
          -0.8427549784503459,
          -0.8527117350003047,
          -0.8576901132752841,
          -0.8676468698252429,
          -0.8726252481002224,
          -0.8825820046501811,
          -1.5098576672975863,
          -1.5247928021225243,
          -1.5297711803975036,
          -1.5447063152224418,
          -1.549684693497421,
          -1.5546630717724008,
          -1.55964145004738,
          -1.569598206597339,
          -1.5745765848723183,
          -1.569598206597339,
          -1.5845333414222773,
          -1.5646198283223596,
          -1.5845333414222773,
          -1.5895117196972566,
          -1.4252252366229363,
          -1.4302036148979158,
          -1.4351819931728953,
          -1.4351819931728953,
          -1.4401603714478746,
          -1.385398210423101,
          -1.4252252366229363,
          -1.4351819931728953,
          -1.4351819931728953,
          -1.4351819931728953,
          -1.4252252366229363,
          -1.22609010562376,
          -1.1464360532240898,
          -1.410290101797998,
          -1.410290101797998,
          -1.4252252366229363,
          -1.445138749722854,
          -1.445138749722854,
          -1.4650522628227716,
          -1.4650522628227716,
          -1.470030641097751,
          -1.4799873976477098,
          -1.4750090193727303,
          -1.4750090193727303,
          -1.4799873976477098,
          -1.470030641097751,
          -1.4899441541976688,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6243603676221126,
          -1.6144036110721536,
          -1.619381989347133,
          -1.619381989347133,
          -1.6144036110721536,
          -0.9622360570498516,
          -1.1563928097740486,
          -1.1563928097740486,
          -1.1563928097740486,
          -1.176306322873966,
          -1.176306322873966,
          -1.176306322873966,
          -1.176306322873966,
          -1.1464360532240898,
          -1.116565783574213,
          -1.1613711880490278,
          -1.1066090270242543,
          -1.0518468659994809,
          -1.0866955139243368,
          -1.0866955139243368,
          -1.450117127997833,
          -1.166349566324007,
          -0.7780360608756137,
          -0.7730576826006342,
          -0.7780360608756137,
          -0.8427549784503459,
          -0.8527117350003047,
          -0.8576901132752841,
          -0.8527117350003047,
          -0.8825820046501811,
          -0.9024955177500988,
          -0.9323657873999752,
          -0.9373441656749546,
          -0.9373441656749546,
          -0.9323657873999752,
          -1.2111549707988218,
          -1.1962198359738836,
          -1.22609010562376,
          -1.2310684838987396,
          -1.2310684838987396,
          -1.2310684838987396,
          -1.216133349073801,
          -1.201198214248863,
          -1.265917131823595,
          -1.2808522666485336,
          -1.2410252404486983,
          -1.2310684838987396,
          -1.2310684838987396,
          -1.2410252404486983,
          -1.0269549746245838,
          -1.0319333528995631,
          -1.0319333528995631,
          -1.0568252442744603,
          -1.0518468659994809,
          -1.0518468659994809,
          -1.0518468659994809,
          -1.0468684877245016,
          -1.0717603790993986,
          -1.091673892199316,
          -1.1115874052992338,
          -1.126522540124172,
          -1.2808522666485336,
          -1.2858306449235128,
          -1.4650522628227716,
          -1.470030641097751,
          -1.4750090193727303,
          -1.5148360455725658,
          -1.5148360455725658,
          -1.5148360455725658,
          -1.5148360455725658,
          -1.5148360455725658,
          -1.5098576672975863,
          -1.519814423847545,
          -1.0518468659994809,
          -1.041890109449522,
          -1.0219765963496044,
          -1.076738757374378,
          -1.076738757374378,
          -1.126522540124172,
          -1.126522540124172,
          -1.1066090270242543,
          -1.201198214248863,
          -1.1464360532240898,
          -1.1563928097740486,
          -1.116565783574213,
          -1.076738757374378,
          -1.1364792966741308,
          -1.470030641097751,
          -1.4750090193727303,
          -1.4799873976477098,
          -1.4351819931728953,
          -1.3804198321481216,
          -1.3555279407732246,
          -1.3654846973231836,
          -1.3057441580234306,
          -1.151414431499069,
          -1.3555279407732246,
          -1.4302036148979158,
          -1.4550955062728128,
          -1.4600738845477923,
          -1.4849657759226893,
          -1.494922532472648,
          -1.504879289022607,
          -1.519814423847545,
          -1.494922532472648,
          -1.4999009107476275,
          -1.4999009107476275,
          -1.4600738845477923,
          -1.4550955062728128,
          -1.2908090231984923,
          -1.3107225362984098,
          -1.3107225362984098,
          -1.3206792928483688,
          -1.3206792928483688,
          -1.3206792928483688,
          -1.3206792928483688,
          -1.3206792928483688,
          -1.300765779748451,
          -1.2460036187236776,
          -1.2460036187236776,
          -1.2460036187236776,
          -1.2460036187236776,
          -1.2609387535486158,
          -1.2559603752736364,
          -1.2559603752736364,
          -1.250981996998657,
          -1.2310684838987396,
          -0.9473009222249136,
          -0.942322543949934,
          -0.9672144353248312,
          -0.9771711918747896,
          -0.9821495701497692,
          -1.0219765963496044,
          -1.0369117311745426,
          -1.0568252442744603,
          -1.076738757374378,
          -1.1066090270242543,
          -1.201198214248863,
          -1.3306360493983276,
          -1.400333345248039,
          -1.420246858347957,
          -1.1364792966741308,
          -1.1364792966741308,
          -1.1464360532240898,
          -1.1215441618491926,
          -1.1115874052992338,
          -1.1215441618491926,
          -1.116565783574213,
          -1.151414431499069,
          -1.201198214248863,
          -1.1613711880490278,
          -1.166349566324007,
          -1.216133349073801,
          -1.166349566324007,
          -1.1364792966741308,
          -1.300765779748451,
          -1.126522540124172,
          -1.0618036225494398,
          -1.0618036225494398,
          -1.066782000824419,
          -1.0618036225494398,
          -1.0568252442744603,
          -1.0568252442744603,
          -1.0568252442744603,
          -1.041890109449522,
          -1.0618036225494398,
          -1.0568252442744603,
          -1.076738757374378,
          -1.0568252442744603,
          -1.5546630717724008,
          -1.5447063152224418,
          -1.5546630717724008,
          -1.55964145004738,
          -1.5546630717724008,
          -1.5297711803975036,
          -1.5397279369474626,
          -1.5397279369474626,
          -1.5397279369474626,
          -1.55964145004738,
          -1.5646198283223596,
          -1.5646198283223596,
          -1.5447063152224418,
          -1.55964145004738,
          -1.5646198283223596,
          -1.55964145004738,
          -1.534749558672483,
          -1.534749558672483,
          -1.519814423847545,
          -1.5148360455725658,
          -1.5148360455725658,
          -1.5247928021225243,
          -1.5247928021225243,
          -1.5247928021225243,
          -1.470030641097751,
          -1.5148360455725658,
          -1.5098576672975863,
          -1.5098576672975863
         ]
        },
        {
         "hovertemplate": "regime=Electoral Autocracy<br>v2x_polyarchy=%{x}<br>v2x_libdem=%{y}<br>v2x_partipdem=%{z}<extra></extra>",
         "legendgroup": "Electoral Autocracy",
         "marker": {
          "color": "#ab63fa",
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Electoral Autocracy",
         "scene": "scene",
         "showlegend": true,
         "type": "scatter3d",
         "x": [
          -1.1546348342320576,
          -0.8370607425730473,
          -0.6395451489802483,
          -0.6240537298749307,
          -0.5891980368879661,
          -0.4497752649401078,
          -0.4381567006111196,
          -0.480758103150743,
          -0.3606996050845319,
          -0.3723181694135201,
          -0.8331878877967178,
          -0.8602978712310236,
          -0.933882111981282,
          -0.9416278215339408,
          -0.984229224073564,
          -0.984229224073564,
          -0.9997206431788817,
          -0.9958477884025524,
          -0.9881020788498937,
          -0.9997206431788817,
          -1.0074663527315404,
          -1.061686319600152,
          -1.2011090915480105,
          -1.2708204775219392,
          -1.1778719628900338,
          -1.2127276558769984,
          -0.8564250164546943,
          -1.476081780667397,
          -1.4024975399171384,
          -1.3134218800615625,
          -1.3134218800615625,
          -1.317294734837892,
          -1.3250404443905508,
          -1.3250404443905508,
          -1.297930460956245,
          -1.2901847514035862,
          -1.2746933322982683,
          -0.883534999889,
          -0.7828407757044357,
          -0.6046894559932837,
          -0.697637970625189,
          -0.8176964686914003,
          -1.2863118966272569,
          -0.4342838458347902,
          -0.4962495222560606,
          -0.5039952318087194,
          -0.3413353312028849,
          -0.3800638789661789,
          -0.4149195719531435,
          -0.5620880534536603,
          -0.8796621451126706,
          -0.9222635476522938,
          -0.9261364024286232,
          -0.9493735310865996,
          -0.9997206431788817,
          -1.0268306266131877,
          -1.01133920750787,
          -1.0307034813895168,
          -0.9919749336262228,
          -1.0268306266131877,
          -0.1593111567154035,
          -0.7208750992831654,
          -0.2909882191106028,
          -0.3839367337425083,
          -0.3413353312028849,
          -0.3645724598608613,
          -0.3645724598608613,
          -0.4265381362821316,
          -0.4730123935980842,
          -0.442029555387449,
          -0.4187924267294729,
          -0.4575209744927666,
          -0.5504694891246722,
          -0.7712222113754476,
          -0.4187924267294729,
          -0.3761910241898495,
          -0.3800638789661789,
          -0.3878095885188377,
          -0.3142253477685792,
          -0.3297167668738968,
          -0.3374624764265556,
          -0.4033010076241553,
          -0.5853251821116368,
          -0.5620880534536603,
          -0.5504694891246722,
          -0.4768852483744136,
          -0.6434180037565776,
          -0.7402393731648124,
          -0.0121426752148865,
          -0.027634094320204,
          -0.5659609082299898,
          -0.1902939949260387,
          -0.1902939949260387,
          -0.1980397044786973,
          -0.1709297210443917,
          -0.1593111567154035,
          -0.2793696547816146,
          -0.3335896216502261,
          -0.3568267503082025,
          -0.4497752649401078,
          -0.538850924795684,
          -0.5078680865850488,
          -0.4497752649401078,
          -0.4846309579270724,
          -0.6744008419672128,
          -1.1275248507977518,
          -1.1275248507977518,
          -1.1430162699030693,
          -1.1546348342320576,
          -1.1507619794557282,
          -1.0926691578107872,
          -1.0887963030344578,
          -1.0539406100474933,
          -1.0539406100474933,
          -1.2049819463243396,
          -0.5427237795720133,
          -0.5233595056903664,
          -0.519486650914037,
          -0.5233595056903664,
          -0.5311052152430251,
          -0.5543423439010016,
          -0.6434180037565776,
          -0.6240537298749307,
          -0.6356722942039189,
          -0.6279265846512601,
          -0.6085623107696131,
          -1.398624685140809,
          -1.119779141245093,
          -1.13914341512674,
          -1.1352705603504103,
          -1.1352705603504103,
          -1.1313977055740811,
          -1.119779141245093,
          -1.119779141245093,
          -1.1236519960214224,
          -0.9493735310865996,
          -0.717002244506836,
          -0.75573079227013,
          -0.8719164355600119,
          -0.844806452125706,
          -0.9106449833233058,
          -0.105091189846792,
          -0.1399468828337566,
          -0.3297167668738968,
          -0.480758103150743,
          -0.4652666840454254,
          -0.5156137961377076,
          -0.5465966343483427,
          -0.3684453146371907,
          -0.3606996050845319,
          -0.3413353312028849,
          -0.027634094320204,
          -0.0895997707414744,
          -0.0895997707414744,
          -0.0741083516361568,
          -0.0353798038728628,
          -0.0702354968598274,
          -0.1709297210443917,
          -0.105091189846792,
          -0.1167097541757802,
          -0.0895997707414744,
          -0.0895997707414744,
          -0.1167097541757802,
          -0.1322011732810978,
          -0.1554383019390741,
          -0.2754968000052852,
          -0.321971057321238,
          -0.3103524929922498,
          -0.302606783439591,
          -0.4226652815058023,
          -0.5969437464406249,
          -0.3335896216502261,
          -0.0818540611888156,
          -0.1631840114917329,
          -0.1167097541757802,
          -0.105091189846792,
          -0.1360740280574272,
          -0.2600053808999676,
          -0.3568267503082025,
          -0.3413353312028849,
          -0.3568267503082025,
          -0.3413353312028849,
          -0.1593111567154035,
          -0.1360740280574272,
          -0.1322011732810978,
          -0.1515654471627447,
          -0.1631840114917329,
          -0.2135311235840148,
          -0.3994281528478259,
          -0.4187924267294729,
          -0.4768852483744136,
          -0.4923766674797312,
          -0.50012237703239,
          -0.5620880534536603,
          -0.4497752649401078,
          -0.321971057321238,
          -0.3955552980714965,
          -0.2212768331366736,
          -0.0741083516361568,
          -0.321971057321238,
          -0.8912807094416588,
          -0.7286208088358241,
          -0.7286208088358241,
          -0.7402393731648124,
          -0.7634765018227887,
          -0.7828407757044357,
          -0.8022050495860827,
          -0.8525521616783649,
          -0.8525521616783649,
          -0.8719164355600119,
          -0.8757892903363412,
          -0.864170726007353,
          -0.9067721285469764,
          -0.9300092572049524,
          -0.9222635476522938,
          -0.3684453146371907,
          -0.4033010076241553,
          -0.4536481197164372,
          -0.736366518388483,
          -0.7944593400334239,
          -0.8331878877967178,
          -0.8796621451126706,
          -1.0965420125871166,
          -1.1778719628900338,
          -1.2049819463243396,
          -1.2049819463243396,
          -1.1507619794557282,
          -1.1856176724426928,
          -1.1894905272190222,
          -0.2019125592550267,
          -0.3994281528478259,
          -0.4691395388217548,
          -0.3180982025449086,
          -0.0779812064124862,
          -0.5543423439010016,
          -0.8602978712310236,
          -0.8060779043624121,
          -0.8060779043624121,
          -0.8254421782440591,
          -0.8680435807836824,
          -0.8602978712310236,
          -0.8680435807836824,
          -0.933882111981282,
          -1.0887963030344578,
          -1.1778719628900338,
          -1.247583348863963,
          -1.2553290584166217,
          -1.247583348863963,
          -1.2127276558769984,
          -1.239837639311304,
          -0.3297167668738968,
          -0.3297167668738968,
          -0.3297167668738968,
          -0.321971057321238,
          -0.3297167668738968,
          -0.283242509557944,
          -0.3258439120975674,
          -0.4226652815058023,
          -0.4536481197164372,
          -0.4846309579270724,
          -0.5930708916642955,
          -0.5930708916642955,
          -0.6008166012169543,
          -0.6395451489802483,
          -0.50012237703239,
          -0.9261364024286232,
          -0.3103524929922498,
          -0.3568267503082025,
          -0.5620880534536603,
          -0.7596036470464593,
          -0.7634765018227887,
          -0.7634765018227887,
          -0.8060779043624121,
          -0.902899273770647,
          -1.1430162699030693,
          -1.158507689008387,
          -1.1546348342320576,
          -1.239837639311304,
          -1.3444047182721974,
          -1.348277573048527,
          -0.50012237703239,
          -0.1322011732810978,
          -0.1593111567154035,
          -0.2600053808999676,
          -0.5039952318087194,
          -0.697637970625189,
          -0.6744008419672128,
          -0.7092565349541772,
          -0.7324936636121535,
          -0.4381567006111196,
          -1.003593497955211,
          -0.9997206431788817,
          -0.9997206431788817,
          -0.9145178380996352,
          -0.8719164355600119,
          -0.8796621451126706,
          -0.8874078546653295,
          -0.8796621451126706,
          -0.8525521616783649,
          -0.8912807094416588,
          -0.8951535642179882,
          -0.8990264189943176,
          -0.9145178380996352,
          -0.8912807094416588,
          -1.100414867363446,
          -0.7944593400334239,
          -0.7867136304807651,
          -0.7789679209281063,
          -0.5775794725589779,
          -0.5814523273353073,
          -0.5698337630063192,
          -0.6046894559932837,
          -0.6046894559932837,
          -0.6434180037565776,
          -0.8486793069020354,
          -1.0074663527315404,
          -0.2793696547816146,
          -0.3490810407555437,
          -0.1864211401497093,
          -0.2057854140313561,
          -0.1980397044786973,
          -0.1554383019390741,
          -0.0315069490965334,
          -0.2909882191106028,
          -0.24451396179465,
          -0.2483868165709794,
          -0.1825482853733799,
          -0.1825482853733799,
          -0.1786754305970505,
          -0.3955552980714965,
          -0.3645724598608613,
          -0.3374624764265556,
          -0.3374624764265556,
          -0.5117409413613782,
          -0.4923766674797312,
          -0.4381567006111196,
          -0.4923766674797312,
          -0.480758103150743,
          -0.4730123935980842,
          -0.6008166012169543,
          -0.7673493565991182,
          -0.883534999889,
          -0.883534999889,
          -0.9261364024286232,
          -0.9571192406392584,
          -1.2359647845349746,
          -1.3598961373775151,
          -1.398624685140809,
          -1.3908789755881503,
          -1.3831332660354916,
          -1.348277573048527,
          -1.2940576061799156,
          -1.2630747679692804,
          -1.278566187074598,
          -0.6898922610725302,
          -0.7828407757044357,
          -0.7867136304807651,
          -0.953246385862929,
          -0.9067721285469764,
          -0.9106449833233058,
          -0.4846309579270724,
          -0.4652666840454254,
          -0.4226652815058023,
          -0.5156137961377076,
          -0.5543423439010016,
          -0.678273696743542,
          -0.7479850827174711,
          -0.8370607425730473,
          -1.4450989424567615,
          -1.4450989424567615,
          -1.3947518303644797,
          -1.3250404443905508,
          -1.2940576061799156,
          -1.2824390418509275,
          -1.2824390418509275,
          -1.2824390418509275,
          -1.297930460956245,
          -1.297930460956245,
          -1.367641846930174,
          -0.3606996050845319,
          -0.3606996050845319,
          -0.3723181694135201,
          -0.3955552980714965,
          -0.4265381362821316,
          -0.461393829269096,
          -0.4497752649401078,
          -0.5349780700193546,
          -0.4381567006111196,
          -0.4768852483744136,
          -0.5582151986773309,
          -0.5543423439010016,
          -0.5311052152430251,
          -0.5853251821116368,
          -0.1554383019390741,
          -0.263878235676297,
          -0.4265381362821316,
          -0.5272323604666957,
          -0.5775794725589779,
          -0.6240537298749307,
          -0.4923766674797312,
          -0.2019125592550267,
          -0.2096582688076854,
          -0.2677510904526264,
          -0.3064796382159204,
          -0.2948610738869322,
          -0.3142253477685792,
          -0.3142253477685792,
          -0.3064796382159204,
          -0.263878235676297,
          -0.2522596713473088,
          -0.24451396179465,
          -0.24451396179465,
          -0.1902939949260387,
          -0.1670568662680623,
          -0.0702354968598274,
          -0.0818540611888156,
          -1.4412260876804324,
          -1.4412260876804324,
          -1.4412260876804324,
          -1.2630747679692804,
          -0.7441122279411417,
          -0.9106449833233058,
          -0.1786754305970505,
          -0.1980397044786973,
          -0.3684453146371907,
          -0.5117409413613782,
          -0.8254421782440591,
          -0.8796621451126706,
          -0.8680435807836824,
          -0.883534999889,
          -0.8874078546653295,
          -0.8912807094416588,
          -0.9067721285469764,
          -0.8951535642179882,
          -0.105091189846792,
          -0.1515654471627447,
          -0.1631840114917329,
          -0.2290225426893324,
          -0.4187924267294729,
          -0.3916824432951671,
          -0.3568267503082025,
          -0.3761910241898495,
          -0.3606996050845319,
          -0.4187924267294729,
          -0.3994281528478259,
          -0.7441122279411417,
          -0.7441122279411417,
          -0.7402393731648124,
          -0.736366518388483,
          -0.7441122279411417,
          -0.736366518388483,
          -0.8138236139150709,
          -0.8176964686914003,
          -0.8099507591387415,
          -0.8757892903363412,
          -0.9261364024286232,
          -0.9183906928759644,
          -0.9609920954155876,
          -0.9609920954155876,
          -1.1352705603504103,
          -0.8022050495860827,
          -0.8138236139150709,
          -0.8099507591387415,
          -0.8099507591387415,
          -0.8099507591387415,
          -0.8099507591387415,
          -0.75573079227013,
          -0.5659609082299898,
          -0.5891980368879661,
          -0.6356722942039189,
          -0.678273696743542,
          -0.6821465515198714,
          -0.6550365680855659,
          -0.7208750992831654,
          -0.7053836801778478,
          -0.6279265846512601,
          -0.6356722942039189,
          -0.6589094228618952,
          -0.6511637133092365,
          -0.6279265846512601,
          -0.5117409413613782,
          -1.1817448176663634,
          -1.2011090915480105,
          -1.208854801100669,
          -1.2204733654296571,
          -1.247583348863963,
          -1.2514562036402923,
          -1.2359647845349746,
          -1.2320919297586452,
          -1.259201913192951,
          -1.2553290584166217,
          -1.259201913192951,
          -1.259201913192951,
          -1.2863118966272569,
          -1.278566187074598,
          -1.1313977055740811,
          -1.158507689008387,
          -1.1430162699030693,
          -1.0655591743764814,
          -1.0655591743764814,
          -1.0384491909421756,
          -1.0074663527315404,
          -1.0190849170605287,
          -1.0190849170605287,
          -1.003593497955211,
          -1.1933633819953515,
          -1.3327861539432095,
          -1.3327861539432095,
          -1.398624685140809,
          -0.7596036470464593,
          -0.7596036470464593,
          -0.7441122279411417,
          -0.7634765018227887,
          -0.7286208088358241,
          -0.7402393731648124,
          -0.8022050495860827,
          -0.8370607425730473,
          -0.8602978712310236,
          -0.8951535642179882,
          -0.8796621451126706,
          -0.8757892903363412,
          -0.8486793069020354,
          -0.8525521616783649,
          -0.9067721285469764,
          -0.902899273770647,
          -0.9145178380996352,
          -0.9222635476522938,
          -0.933882111981282,
          -0.9183906928759644,
          -0.9183906928759644,
          -0.9648649501919172,
          -0.9687378049682466,
          -0.9493735310865996,
          -0.9571192406392584,
          -1.3598961373775151,
          -0.6124351655459425,
          -0.6356722942039189,
          -0.736366518388483,
          -0.7479850827174711,
          -0.736366518388483,
          -0.7712222113754476,
          -0.7944593400334239,
          -0.7905864852570945,
          -0.7828407757044357,
          -0.6550365680855659,
          -0.6356722942039189,
          -0.6627822776382246,
          -0.7092565349541772,
          -0.7789679209281063,
          -1.01133920750787,
          -1.01133920750787,
          -1.0190849170605287,
          -1.0384491909421756,
          -1.0384491909421756,
          -1.0384491909421756,
          -1.0578134648238229,
          -1.050067755271164,
          -1.0307034813895168,
          -1.0771777387054695,
          -1.042322045718505,
          -1.050067755271164,
          -1.0926691578107872,
          -1.0578134648238229,
          -1.061686319600152,
          -1.0539406100474933,
          -1.0539406100474933,
          -1.061686319600152,
          -1.061686319600152,
          -1.061686319600152,
          -1.0578134648238229,
          -1.0461949004948343,
          -1.0152120622841994,
          -1.0190849170605287,
          -1.0268306266131877,
          -1.0268306266131877,
          -1.0268306266131877,
          -1.0268306266131877,
          -0.5659609082299898,
          -0.5659609082299898,
          -0.5698337630063192,
          -0.5582151986773309,
          -0.5582151986773309,
          -0.5582151986773309,
          -0.538850924795684,
          -0.4768852483744136,
          -0.5039952318087194,
          -0.5117409413613782,
          -0.5504694891246722,
          -0.5504694891246722,
          -0.5737066177826485,
          -0.8719164355600119,
          -1.0655591743764814,
          -1.0655591743764814,
          -1.0539406100474933,
          -1.07330488392914,
          -1.0655591743764814,
          -1.0655591743764814,
          -1.0461949004948343,
          -0.085726915965145,
          -0.263878235676297,
          -0.2754968000052852,
          -0.7324936636121535,
          -0.2909882191106028,
          -0.0741083516361568,
          -0.0702354968598274,
          -0.0818540611888156,
          -0.5465966343483427,
          -0.3761910241898495,
          -1.081050593481799,
          -1.100414867363446,
          -1.100414867363446,
          -1.100414867363446,
          -1.104287722139775,
          -1.0926691578107872,
          -1.061686319600152,
          -1.100414867363446,
          -1.0926691578107872,
          -1.081050593481799,
          -1.0655591743764814,
          -1.0190849170605287,
          -0.9493735310865996,
          -0.9067721285469764,
          -0.519486650914037,
          -0.1554383019390741,
          -0.1980397044786973,
          -0.263878235676297,
          -0.2871153643342734,
          -0.2367682522419912,
          -0.2600053808999676,
          -0.2522596713473088,
          -0.1902939949260387,
          -0.283242509557944,
          -0.5078680865850488,
          -0.3955552980714965,
          -0.5272323604666957,
          -0.6201808750986013,
          -0.7286208088358241,
          -1.0307034813895168,
          -0.2600053808999676,
          -0.1748025758207211,
          -0.1515654471627447,
          -0.1631840114917329,
          -0.0779812064124862,
          -0.0895997707414744,
          -0.0818540611888156,
          -0.0818540611888156,
          -0.1709297210443917,
          -0.9997206431788817,
          -1.01133920750787,
          -1.0074663527315404,
          -0.9881020788498937,
          -0.972610659744576,
          -1.01133920750787,
          -1.0190849170605287,
          -0.9881020788498937,
          -0.9493735310865996,
          -0.9222635476522938,
          -0.9997206431788817,
          -1.01133920750787,
          -1.022957771836858,
          -1.022957771836858,
          -1.170126253337375,
          -1.1739991081137044,
          -1.158507689008387,
          -1.1507619794557282,
          -1.1352705603504103,
          -1.1275248507977518,
          -1.1352705603504103,
          -1.1430162699030693,
          -1.13914341512674,
          -1.1236519960214224,
          -1.1236519960214224,
          -1.1275248507977518,
          -1.1546348342320576,
          -1.1778719628900338,
          -0.4846309579270724,
          -0.4923766674797312,
          -0.4730123935980842,
          -0.3645724598608613,
          -0.3839367337425083,
          -1.13914341512674,
          -1.1352705603504103,
          -1.1468891246793989,
          -1.2049819463243396,
          -1.2320919297586452,
          -1.297930460956245,
          -1.336659008719539,
          -1.348277573048527,
          -1.367641846930174,
          -1.367641846930174,
          -1.3405318634958685,
          -1.3250404443905508,
          -1.3637689921538445,
          -1.3560232826011858,
          -0.3645724598608613,
          -0.3684453146371907,
          -0.3606996050845319,
          -0.2716239452289558,
          -0.1438197376100859,
          -0.1476925923864153,
          -0.1128368993994508,
          -0.2174039783603442,
          -0.2522596713473088,
          -0.4110467171768141,
          -0.2367682522419912,
          -0.3684453146371907,
          -0.3645724598608613,
          -0.3955552980714965,
          -1.4296075233514445,
          -1.4257346685751149,
          -1.4218618137987855,
          -1.4257346685751149,
          -0.3568267503082025,
          -0.2754968000052852,
          -0.2754968000052852,
          -0.4304109910584611,
          -0.4304109910584611,
          -0.4304109910584611,
          -0.4342838458347902,
          -0.3839367337425083,
          -0.480758103150743,
          -0.4923766674797312,
          -0.480758103150743,
          -0.4342838458347902,
          -0.4071738624004847,
          -0.442029555387449,
          -1.3753875564828326,
          -1.3753875564828326,
          -1.3753875564828326,
          -1.3598961373775151,
          -1.216600510653328,
          -1.216600510653328,
          -0.283242509557944,
          -0.1476925923864153,
          -0.1476925923864153,
          -0.3839367337425083,
          -0.4304109910584611,
          -0.4691395388217548,
          -0.538850924795684,
          -0.7673493565991182,
          -0.8874078546653295,
          -0.883534999889,
          -0.9145178380996352,
          -0.9416278215339408,
          -1.309549025285233,
          -1.3134218800615625,
          -1.3134218800615625,
          -1.3056761705089035,
          -1.3018033157325744,
          -1.3056761705089035,
          -1.3056761705089035,
          -1.3250404443905508,
          -1.3211675896142214,
          -1.3134218800615625,
          -1.3250404443905508,
          -1.3327861539432095,
          -1.3327861539432095,
          -1.297930460956245,
          -1.2437104940876331,
          -0.4730123935980842,
          -0.442029555387449,
          -0.4342838458347902,
          -0.4187924267294729,
          -0.461393829269096,
          -0.4226652815058023,
          -0.4575209744927666,
          -0.461393829269096,
          -0.1631840114917329,
          -0.2522596713473088,
          -0.302606783439591,
          -0.2716239452289558,
          -0.2948610738869322,
          -0.2677510904526264,
          -0.7131293897305065,
          -0.7286208088358241,
          -0.7286208088358241,
          -0.7441122279411417,
          -0.7286208088358241,
          -0.7286208088358241,
          -0.7324936636121535,
          -0.7092565349541772,
          -0.2987339286632616,
          -0.1670568662680623,
          -0.3606996050845319,
          -0.3568267503082025,
          -0.2406411070183206,
          -0.1515654471627447,
          -0.0818540611888156,
          -0.0818540611888156,
          -0.0818540611888156,
          -0.1554383019390741,
          -0.1902939949260387,
          -0.1902939949260387,
          -0.2019125592550267,
          -0.2290225426893324,
          -0.2019125592550267,
          -0.2290225426893324,
          -0.1438197376100859,
          -0.2677510904526264,
          -0.3529538955318732,
          -0.3955552980714965,
          -0.5427237795720133,
          -0.6163080203222719,
          -0.5814523273353073,
          -0.6356722942039189,
          -0.6898922610725302,
          -0.6124351655459425,
          -0.5969437464406249,
          -0.1515654471627447,
          -0.1283283185047684,
          -0.1360740280574272,
          -0.0934726255178038,
          -0.0818540611888156,
          -0.4691395388217548,
          -0.4304109910584611,
          -0.3490810407555437,
          -0.3800638789661789,
          -0.3800638789661789,
          -0.3645724598608613,
          -0.3335896216502261,
          -0.3490810407555437,
          -0.3994281528478259,
          -0.4149195719531435,
          -0.4536481197164372,
          -0.4497752649401078,
          -0.4652666840454254,
          -0.4459024101637784,
          -0.1399468828337566,
          -0.1786754305970505,
          -0.2057854140313561,
          -0.2406411070183206,
          -0.2677510904526264,
          -0.302606783439591,
          -0.8022050495860827,
          -0.7286208088358241,
          -0.7208750992831654,
          -0.717002244506836,
          -0.7402393731648124,
          -0.8370607425730473,
          -0.9648649501919172,
          -0.9764835145209052,
          -0.972610659744576,
          -0.9803563692972348,
          -0.9919749336262228,
          -0.9493735310865996,
          -0.9067721285469764,
          -0.8874078546653295
         ],
         "y": [
          -1.1069354759468966,
          -1.0128485521072763,
          -0.9074711974069022,
          -0.8886538126389782,
          -0.8322016583352063,
          -0.6402643337023814,
          -0.6289739028416271,
          -0.6101565180737032,
          -0.5386504559555919,
          -0.5311235020484223,
          -1.0090850751536915,
          -1.0128485521072763,
          -1.061773752503879,
          -1.0730641833646335,
          -1.095645045086142,
          -1.1031719989933118,
          -1.1106989529004814,
          -1.1069354759468966,
          -1.1069354759468966,
          -1.1219893837612358,
          -1.1445702454827449,
          -1.159624153297084,
          -1.2537110771367037,
          -1.2838188927653822,
          -0.9262885821748262,
          -1.0467198446895398,
          -0.9149981513140718,
          -1.1934954458793472,
          -1.159624153297084,
          -1.0580102755502945,
          -1.084354614225388,
          -1.0881180911789727,
          -1.069300706411049,
          -1.061773752503879,
          -1.065537229457464,
          -1.0316659368752006,
          -1.0316659368752006,
          -0.930052059128411,
          -0.9676868286642588,
          -0.8848903356853934,
          -0.9375790130355808,
          -1.0467198446895398,
          -1.2574745540902883,
          -0.9037077204533174,
          -1.0504833216431246,
          -1.099408522039727,
          -0.8623094739638847,
          -0.8848903356853934,
          -0.8924172895925631,
          -0.9752137825714284,
          -1.1031719989933118,
          -1.099408522039727,
          -1.099408522039727,
          -1.1106989529004814,
          -1.1295163376684054,
          -1.155860676343499,
          -1.155860676343499,
          -1.1633876302506687,
          -1.155860676343499,
          -1.155860676343499,
          -0.5649947946306855,
          -0.6440278106559663,
          -0.5198330711876679,
          -0.5612313176771007,
          -0.5424139329091767,
          -0.5687582715842703,
          -0.5687582715842703,
          -0.6477912876095511,
          -0.6026295641665336,
          -0.6176834719808727,
          -0.6026295641665336,
          -0.6402643337023814,
          -0.6891895340989839,
          -0.7832764579386038,
          -0.6026295641665336,
          -0.5612313176771007,
          -0.5988660872129488,
          -0.5424139329091767,
          -0.4859617786054047,
          -0.5875756563521943,
          -0.5424139329091767,
          -0.5800487024450247,
          -0.6214469489344575,
          -0.6365008567487966,
          -0.6252104258880423,
          -0.5838121793986095,
          -0.6440278106559663,
          -0.7870399348921886,
          -0.3580035621835216,
          -0.312841838740504,
          -0.6365008567487966,
          -0.4370365782088024,
          -0.4408000551623872,
          -0.4520904860231416,
          -0.425746147348048,
          -0.4332731012552176,
          -0.5085426403269134,
          -0.5386504559555919,
          -0.5461774098627615,
          -0.5574678407235159,
          -0.6176834719808727,
          -0.5461774098627615,
          -0.5649947946306855,
          -0.6365008567487966,
          -0.7192973497276623,
          -1.265001507997458,
          -1.2988728005797214,
          -1.287582369718967,
          -1.2800554158117974,
          -1.2838188927653822,
          -1.2725284619046278,
          -1.268764984951043,
          -1.2311302154151949,
          -1.2537110771367037,
          -1.2311302154151949,
          -0.6778991032382294,
          -0.6741356262846446,
          -0.6666086723774751,
          -0.6590817184703055,
          -0.6590817184703055,
          -0.6703721493310598,
          -0.7343512575420015,
          -0.7305877805884167,
          -0.7682225501242647,
          -0.8246747044280367,
          -0.798330365752943,
          -1.3891962474657564,
          -1.1069354759468966,
          -1.1106989529004814,
          -1.1144624298540662,
          -1.1257528607148206,
          -1.1257528607148206,
          -1.1332798146219902,
          -1.1445702454827449,
          -1.1483337224363297,
          -1.0203755060144462,
          -0.9187616282676566,
          -0.948869443896335,
          -1.005321598200107,
          -1.0128485521072763,
          -1.1031719989933118,
          -0.124667991061264,
          -0.1472488527827728,
          -0.2940244539725799,
          -0.4106922395337088,
          -0.3617670391371064,
          -0.425746147348048,
          -0.4821983016518198,
          -0.1735931914578664,
          -0.1660662375506968,
          -0.1698297145042816,
          0.0145806562213734,
          -0.0418714980823983,
          -0.0305810672216439,
          -0.0117636824537199,
          0.0860867183394846,
          -0.1020871293397552,
          -0.4709078707910654,
          -0.4332731012552176,
          -0.4144557164872936,
          -0.3580035621835216,
          -0.3580035621835216,
          -0.3956383317193696,
          -0.3956383317193696,
          -0.3881113778122,
          -0.4483270090695568,
          -0.4821983016518198,
          -0.4859617786054047,
          -0.497252209466159,
          -0.5649947946306855,
          -0.6252104258880423,
          -0.3203687926476735,
          -0.1698297145042816,
          -0.3015514078797495,
          -0.3053148848333343,
          -0.2864975000654103,
          -0.3354227004620128,
          -0.4031652856265392,
          -0.4483270090695568,
          -0.459617439930311,
          -0.4483270090695568,
          -0.4370365782088024,
          0.0032902253606192,
          0.0258710870821278,
          0.0183441331749582,
          -0.0042367285465503,
          -0.0080002055001351,
          -0.0192906363608895,
          -0.1735931914578664,
          -0.1961740531793752,
          -0.2450992535759775,
          -0.2488627305295623,
          -0.2187549149008841,
          -0.2450992535759775,
          -0.1547758066899424,
          -0.0493984519895679,
          -0.2639166383439015,
          -0.1020871293397552,
          0.0108171792677888,
          -0.2037010070865449,
          -0.6590817184703055,
          -0.5574678407235159,
          -0.5537043637699312,
          -0.5725217485378551,
          -0.5649947946306855,
          -0.5800487024450247,
          -0.5988660872129488,
          -0.6628451954238903,
          -0.7117703958204927,
          -0.7192973497276623,
          -0.7155338727740775,
          -0.7004799649597383,
          -0.7494051653563407,
          -0.7192973497276623,
          -0.7004799649597383,
          -0.9262885821748262,
          -0.9451059669427502,
          -0.963923351710674,
          -1.099408522039727,
          -1.14080676852916,
          -1.1257528607148206,
          -1.084354614225388,
          -1.1972589228329318,
          -1.2913458466725518,
          -1.2951093236261366,
          -1.3026362775333062,
          -1.2913458466725518,
          -1.306399754486891,
          -1.310163231440476,
          -0.2338088227152231,
          -0.4370365782088024,
          -0.4821983016518198,
          -0.4106922395337088,
          -0.2940244539725799,
          -0.3504766082763519,
          -0.6289739028416271,
          -1.069300706411049,
          -1.069300706411049,
          -1.069300706411049,
          -1.0918815681325575,
          -1.0881180911789727,
          -1.0881180911789727,
          -1.1332798146219902,
          -1.2198397845544404,
          -1.246184123229534,
          -1.2725284619046278,
          -1.2725284619046278,
          -1.268764984951043,
          -1.2762919388582126,
          -1.3026362775333062,
          -0.3956383317193696,
          -0.3956383317193696,
          -0.3918748547657848,
          -0.3918748547657848,
          -0.3730574699978607,
          -0.369293993044276,
          -0.4182191934408784,
          -0.4821983016518198,
          -0.5047791633733286,
          -0.5612313176771007,
          -0.6365008567487966,
          -0.6365008567487966,
          -0.6252104258880423,
          -0.6854260571453991,
          -0.3504766082763519,
          -0.798330365752943,
          -0.7908034118457734,
          -0.8020938427065278,
          -0.9187616282676566,
          -1.0391928907823702,
          -1.0354294138287854,
          -1.042956367735955,
          -1.0580102755502945,
          -1.1219893837612358,
          -1.3252171392548149,
          -1.340271047069154,
          -1.3477980009763235,
          -1.3854327705121716,
          -1.4004866783265109,
          -1.41554058614085,
          -0.4558539629767264,
          -0.0945601754325856,
          -0.0983236523861704,
          -0.1698297145042816,
          -0.3504766082763519,
          -0.5311235020484223,
          -0.5424139329091767,
          -0.4709078707910654,
          -0.5273600250948375,
          -0.3467131313227671,
          -0.7795129809850191,
          -0.7757495040314343,
          -0.7757495040314343,
          -0.7494051653563407,
          -0.7381147344955863,
          -0.7381147344955863,
          -0.760695596217095,
          -0.6816625801918142,
          -0.7305877805884167,
          -0.7832764579386038,
          -0.8133842735672823,
          -0.8058573196601126,
          -0.8284381813816215,
          -0.8623094739638847,
          -1.1709145841578383,
          -1.0881180911789727,
          -1.0881180911789727,
          -1.0881180911789727,
          -0.930052059128411,
          -0.8999442434997326,
          -0.8924172895925631,
          -0.9074711974069022,
          -0.9149981513140718,
          -0.9714503056178436,
          -1.065537229457464,
          -1.1257528607148206,
          -0.3805844239050304,
          -0.3918748547657848,
          -0.2789705461582407,
          -0.3203687926476735,
          -0.3015514078797495,
          -0.2789705461582407,
          -0.5010156864197439,
          -0.5988660872129488,
          -0.5913391333057791,
          -0.5649947946306855,
          -0.6590817184703055,
          -0.6553182415167207,
          -0.6553182415167207,
          -0.8585459970102999,
          -0.8472555661495454,
          -0.8359651352887911,
          -0.8359651352887911,
          -0.9187616282676566,
          -0.8660729509174695,
          -0.8133842735672823,
          -0.7418782114491711,
          -0.7757495040314343,
          -0.7795129809850191,
          -0.8246747044280367,
          -0.963923351710674,
          -0.9977946442929374,
          -1.005321598200107,
          -1.1106989529004814,
          -1.14080676852916,
          -1.287582369718967,
          -1.3477980009763235,
          -1.340271047069154,
          -1.3515614779299086,
          -1.313926708394061,
          -1.32145366230123,
          -1.246184123229534,
          -1.2123128306472708,
          -1.2951093236261366,
          -0.7832764579386038,
          -0.8284381813816215,
          -0.8284381813816215,
          -0.948869443896335,
          -0.8698364278710543,
          -0.8359651352887911,
          -0.6440278106559663,
          -0.6440278106559663,
          -0.5800487024450247,
          -0.6891895340989839,
          -0.7682225501242647,
          -0.8510190431031303,
          -0.8811268587318086,
          -1.14080676852916,
          -1.1069354759468966,
          -1.1031719989933118,
          -1.0918815681325575,
          -1.0504833216431246,
          -1.042956367735955,
          -1.0279024599216158,
          -1.0203755060144462,
          -1.0354294138287854,
          -1.0391928907823702,
          -1.0542467985967094,
          -1.084354614225388,
          -0.5499408868163463,
          -0.5574678407235159,
          -0.5612313176771007,
          -0.6176834719808727,
          -0.6139199950272879,
          -0.6214469489344575,
          -0.5875756563521943,
          -0.6289739028416271,
          -0.6063930411201184,
          -0.6553182415167207,
          -0.7268243036348319,
          -0.6967164880061535,
          -0.7531686423099254,
          -0.7268243036348319,
          0.0333980409892974,
          -0.6176834719808727,
          -0.7155338727740775,
          -0.798330365752943,
          -0.8209112274744519,
          -0.8434920891959606,
          -0.7757495040314343,
          -0.1359584219220184,
          -0.1585392836435272,
          -0.1999375301329601,
          -0.2225183918544689,
          -0.2149914379472993,
          -0.2300453457616383,
          -0.2225183918544689,
          -0.2300453457616383,
          -0.1961740531793752,
          -0.2074644840401296,
          -0.1848836223186208,
          -0.1924105762257905,
          -0.1171410371540944,
          -0.0757427906646616,
          -0.3316592235084279,
          -0.0719793137110768,
          -1.3252171392548149,
          -1.362851908790663,
          -1.3929597244193412,
          -1.1106989529004814,
          -0.5875756563521943,
          -0.7719860270778495,
          -0.3843479008586152,
          -0.3881113778122,
          -0.5461774098627615,
          -0.6289739028416271,
          -0.963923351710674,
          -1.1219893837612358,
          -1.1106989529004814,
          -1.0918815681325575,
          -1.069300706411049,
          -1.069300706411049,
          -1.0881180911789727,
          -1.0918815681325575,
          -0.5123061172804982,
          -0.5311235020484223,
          -0.5424139329091767,
          -0.5762852254914399,
          -0.7155338727740775,
          -0.6666086723774751,
          -0.6252104258880423,
          -0.6176834719808727,
          -0.6063930411201184,
          -0.5988660872129488,
          -0.5800487024450247,
          -0.9074711974069022,
          -0.9074711974069022,
          -0.8961807665461479,
          -0.8848903356853934,
          -0.8848903356853934,
          -0.873599904824639,
          -0.9037077204533174,
          -0.9225251052212414,
          -0.9074711974069022,
          -0.9601598747570892,
          -0.9563963978035044,
          -1.001558121246522,
          -1.065537229457464,
          -1.061773752503879,
          -1.118225906807651,
          -1.0203755060144462,
          -1.024138982968031,
          -1.0128485521072763,
          -1.0128485521072763,
          -1.0128485521072763,
          -1.0128485521072763,
          -0.9526329208499198,
          -0.8510190431031303,
          -0.8246747044280367,
          -0.8322016583352063,
          -0.8811268587318086,
          -0.8585459970102999,
          -0.8660729509174695,
          -0.798330365752943,
          -0.7908034118457734,
          -0.7494051653563407,
          -0.7230608266812472,
          -0.7418782114491711,
          -0.7381147344955863,
          -0.7305877805884167,
          -0.6741356262846446,
          -1.249947600183119,
          -1.261238031043873,
          -1.261238031043873,
          -1.261238031043873,
          -1.2725284619046278,
          -1.2725284619046278,
          -1.2838188927653822,
          -1.261238031043873,
          -1.2951093236261366,
          -1.2725284619046278,
          -1.2725284619046278,
          -1.268764984951043,
          -1.2800554158117974,
          -1.2762919388582126,
          -1.155860676343499,
          -1.159624153297084,
          -1.159624153297084,
          -1.14080676852916,
          -1.14080676852916,
          -1.1332798146219902,
          -1.1069354759468966,
          -1.1031719989933118,
          -1.095645045086142,
          -1.095645045086142,
          -1.340271047069154,
          -1.381669293558587,
          -1.3741423396514174,
          -1.381669293558587,
          -0.9225251052212414,
          -0.9187616282676566,
          -0.8999442434997326,
          -0.9413424899891654,
          -0.9262885821748262,
          -0.9375790130355808,
          -0.9789772595250134,
          -1.001558121246522,
          -1.0391928907823702,
          -1.0580102755502945,
          -1.0279024599216158,
          -1.0316659368752006,
          -0.9789772595250134,
          -1.024138982968031,
          -1.14080676852916,
          -1.14080676852916,
          -1.1445702454827449,
          -1.1633876302506687,
          -1.1746780611114231,
          -1.1671511072042535,
          -1.1709145841578383,
          -1.1934954458793472,
          -1.2160763076008556,
          -1.1822050150185928,
          -1.1897319689257624,
          -1.3327440931619845,
          -0.930052059128411,
          -0.9375790130355808,
          -0.9714503056178436,
          -1.0128485521072763,
          -1.0090850751536915,
          -1.0354294138287854,
          -1.042956367735955,
          -1.065537229457464,
          -1.0467198446895398,
          -0.9714503056178436,
          -0.933815536081996,
          -0.963923351710674,
          -0.9413424899891654,
          -1.0580102755502945,
          -1.1671511072042535,
          -1.1671511072042535,
          -1.1709145841578383,
          -1.14080676852916,
          -1.14080676852916,
          -1.1445702454827449,
          -1.1520971993899145,
          -1.1483337224363297,
          -1.118225906807651,
          -1.159624153297084,
          -1.0881180911789727,
          -1.099408522039727,
          -1.099408522039727,
          -1.069300706411049,
          -1.084354614225388,
          -1.0805911372718031,
          -1.0805911372718031,
          -1.084354614225388,
          -1.084354614225388,
          -1.084354614225388,
          -1.0805911372718031,
          -1.095645045086142,
          -1.0805911372718031,
          -1.061773752503879,
          -1.061773752503879,
          -1.0580102755502945,
          -1.0580102755502945,
          -1.0580102755502945,
          -0.7343512575420015,
          -0.7343512575420015,
          -0.6929530110525687,
          -0.6590817184703055,
          -0.6590817184703055,
          -0.6590817184703055,
          -0.6515547645631359,
          -0.6289739028416271,
          -0.7042434419133231,
          -0.7381147344955863,
          -0.7569321192635102,
          -0.7531686423099254,
          -0.7418782114491711,
          -0.8585459970102999,
          -1.0881180911789727,
          -1.0881180911789727,
          -1.0881180911789727,
          -1.1144624298540662,
          -1.1144624298540662,
          -1.1144624298540662,
          -1.1069354759468966,
          0.0296345640357126,
          -0.4821983016518198,
          -0.4897252555589894,
          -0.8359651352887911,
          -0.4520904860231416,
          -0.3617670391371064,
          -0.369293993044276,
          -0.3504766082763519,
          -0.9601598747570892,
          -0.6402643337023814,
          -1.0504833216431246,
          -1.061773752503879,
          -1.0881180911789727,
          -1.0918815681325575,
          -1.095645045086142,
          -1.0918815681325575,
          -1.0768276603182183,
          -1.0918815681325575,
          -1.099408522039727,
          -1.0881180911789727,
          -1.0730641833646335,
          -1.0467198446895398,
          -1.001558121246522,
          -0.9752137825714284,
          -0.5725217485378551,
          -0.2676801152974863,
          -0.3053148848333343,
          -0.3354227004620128,
          -0.3391861774155976,
          -0.3354227004620128,
          -0.3580035621835216,
          -0.3542400852299368,
          -0.2526262074831471,
          -0.3090783617869191,
          -0.5499408868163463,
          -0.5010156864197439,
          -0.6063930411201184,
          -0.7682225501242647,
          -0.7305877805884167,
          -1.0354294138287854,
          -0.6778991032382294,
          -0.5725217485378551,
          -0.5725217485378551,
          -0.5687582715842703,
          -0.4483270090695568,
          -0.5461774098627615,
          -0.5800487024450247,
          -0.5800487024450247,
          -0.6101565180737032,
          -0.9601598747570892,
          -0.9601598747570892,
          -0.963923351710674,
          -0.8660729509174695,
          -0.8623094739638847,
          -0.8698364278710543,
          -0.873599904824639,
          -0.8434920891959606,
          -0.8246747044280367,
          -0.7719860270778495,
          -0.9149981513140718,
          -0.9789772595250134,
          -1.001558121246522,
          -0.9977946442929374,
          -1.0203755060144462,
          -1.0166120290608611,
          -1.0090850751536915,
          -1.0166120290608611,
          -1.005321598200107,
          -1.005321598200107,
          -1.0391928907823702,
          -1.0805911372718031,
          -1.065537229457464,
          -1.065537229457464,
          -1.0768276603182183,
          -1.1031719989933118,
          -1.1069354759468966,
          -1.155860676343499,
          -0.595102610259364,
          -0.595102610259364,
          -0.5762852254914399,
          -0.497252209466159,
          -0.5010156864197439,
          -1.261238031043873,
          -1.2574745540902883,
          -1.268764984951043,
          -1.310163231440476,
          -1.3176901853476457,
          -1.3515614779299086,
          -1.362851908790663,
          -1.3515614779299086,
          -1.3327440931619845,
          -1.3553249548834934,
          -1.3515614779299086,
          -1.3590884318370782,
          -1.362851908790663,
          -1.362851908790663,
          -0.595102610259364,
          -0.5838121793986095,
          -0.5875756563521943,
          -0.5649947946306855,
          -0.5010156864197439,
          -0.4897252555589894,
          -0.4709078707910654,
          -0.5612313176771007,
          -0.6402643337023814,
          -0.7117703958204927,
          -0.5537043637699312,
          -0.6365008567487966,
          -0.6327373797952119,
          -0.7080069188669079,
          -1.4004866783265109,
          -1.3779058166050022,
          -1.3891962474657564,
          -1.381669293558587,
          -0.5687582715842703,
          -0.5273600250948375,
          -0.5235965481412527,
          -0.6063930411201184,
          -0.6026295641665336,
          -0.6026295641665336,
          -0.5988660872129488,
          -0.5687582715842703,
          -0.6176834719808727,
          -0.6365008567487966,
          -0.6477912876095511,
          -0.5988660872129488,
          -0.6063930411201184,
          -0.5875756563521943,
          -1.3891962474657564,
          -1.381669293558587,
          -1.381669293558587,
          -1.3779058166050022,
          -1.22736673846161,
          -1.2010223997865166,
          -0.5687582715842703,
          -0.5047791633733286,
          -0.5047791633733286,
          -0.5762852254914399,
          -0.595102610259364,
          -0.798330365752943,
          -0.8848903356853934,
          -1.084354614225388,
          -1.1069354759468966,
          -1.1106989529004814,
          -1.1106989529004814,
          -1.118225906807651,
          -1.3176901853476457,
          -1.3176901853476457,
          -1.3176901853476457,
          -1.306399754486891,
          -1.306399754486891,
          -1.313926708394061,
          -1.313926708394061,
          -1.3176901853476457,
          -1.306399754486891,
          -1.306399754486891,
          -1.3176901853476457,
          -1.313926708394061,
          -1.32145366230123,
          -1.3026362775333062,
          -0.9714503056178436,
          -0.4821983016518198,
          -0.4633809168838958,
          -0.4408000551623872,
          -0.4408000551623872,
          -0.5010156864197439,
          -0.4934887325125742,
          -0.497252209466159,
          -0.516069594234083,
          -0.2338088227152231,
          -0.3278957465548431,
          -0.4408000551623872,
          -0.478434824698235,
          -0.5085426403269134,
          -0.4746713477446502,
          -0.6929530110525687,
          -0.7042434419133231,
          -0.6929530110525687,
          -0.7268243036348319,
          -0.7192973497276623,
          -0.7381147344955863,
          -0.7456416884027559,
          -0.7456416884027559,
          -0.3278957465548431,
          -0.2413357766223927,
          -0.369293993044276,
          -0.3918748547657848,
          -0.3278957465548431,
          -0.162302760597112,
          -0.0155271594073047,
          -0.0155271594073047,
          -0.0155271594073047,
          -0.087033221525416,
          -0.10585060629334,
          -0.1171410371540944,
          -0.124667991061264,
          -0.1472488527827728,
          -0.1510123297363576,
          -0.1735931914578664,
          -0.0795062676182464,
          -0.1698297145042816,
          -0.2225183918544689,
          -0.2864975000654103,
          -0.4031652856265392,
          -0.4408000551623872,
          -0.4370365782088024,
          -0.5875756563521943,
          -0.6176834719808727,
          -0.5311235020484223,
          -0.5649947946306855,
          -0.0907966984790008,
          -0.0757427906646616,
          -0.087033221525416,
          -0.0230541133144743,
          -0.0004732515929655609,
          -0.3278957465548431,
          -0.2977879309261647,
          -0.2563896844367319,
          -0.2676801152974863,
          -0.2676801152974863,
          -0.2639166383439015,
          -0.2488627305295623,
          -0.2225183918544689,
          -0.2488627305295623,
          -0.2639166383439015,
          -0.2864975000654103,
          -0.2752070692046559,
          -0.2977879309261647,
          -0.2714435922510711,
          -0.1020871293397552,
          -0.1321949449684336,
          -0.1773566684114512,
          -0.1999375301329601,
          -0.2488627305295623,
          -0.2940244539725799,
          -0.6327373797952119,
          -0.5913391333057791,
          -0.5875756563521943,
          -0.5800487024450247,
          -0.5875756563521943,
          -0.6402643337023814,
          -0.7155338727740775,
          -0.7117703958204927,
          -0.6967164880061535,
          -0.7230608266812472,
          -0.7381147344955863,
          -0.6891895340989839,
          -0.6553182415167207,
          -0.6515547645631359
         ],
         "z": [
          -1.0269549746245838,
          -0.8825820046501811,
          -0.633663090901211,
          -0.6037928212513345,
          -0.5789009298764374,
          -0.4444847164519935,
          -0.4295495816270552,
          -0.414614446802117,
          -0.3449171509524053,
          -0.3498955292273847,
          -0.7680793043256549,
          -0.7780360608756137,
          -0.8377766001753665,
          -0.8527117350003047,
          -0.8875603829251606,
          -0.917430652575037,
          -0.9273874091249958,
          -0.9273874091249958,
          -0.9124522743000576,
          -0.9124522743000576,
          -0.7929711957005519,
          -0.8975171394751194,
          -0.9871279484247486,
          -1.041890109449522,
          -1.2808522666485336,
          -1.1912414576989043,
          -1.0817171356493571,
          -1.4053117235230188,
          -1.400333345248039,
          -1.3804198321481216,
          -1.3654846973231836,
          -1.360506319048204,
          -1.2908090231984923,
          -1.3107225362984098,
          -1.3057441580234306,
          -1.275873888373554,
          -1.275873888373554,
          -0.9473009222249136,
          -0.8228414653504282,
          -0.8676468698252429,
          -0.9224090308500164,
          -1.0269549746245838,
          -1.2310684838987396,
          -0.499246877476767,
          -0.5540090385015404,
          -0.549030660226561,
          -0.6635333605510872,
          -0.6784684953760255,
          -0.7431874129507579,
          -0.8576901132752841,
          -1.0120198397996456,
          -0.992106326699728,
          -1.0020630832496868,
          -0.992106326699728,
          -1.0618036225494398,
          -1.076738757374378,
          -1.0717603790993986,
          -1.091673892199316,
          -1.0618036225494398,
          -1.0618036225494398,
          0.0782450024208439,
          -0.3548739075023641,
          -0.3996793119771788,
          -0.4544414730019523,
          -0.4295495816270552,
          -0.439506338177014,
          -0.439506338177014,
          -0.4843117426518288,
          -0.5092036340267256,
          -0.4892901209268082,
          -0.4594198512769317,
          -0.5938360647013756,
          -0.9273874091249958,
          -0.7631009260506755,
          -0.3548739075023641,
          -0.3150468813025288,
          -0.3200252595775082,
          -0.3001117464775906,
          -0.2602847202777556,
          -0.2752198551026936,
          -0.2702414768277141,
          -0.3200252595775082,
          -0.4345279599020347,
          -0.4096360685271376,
          -0.414614446802117,
          -0.3449171509524053,
          -0.3648306640523229,
          -0.5390739036766021,
          -0.1308468851282909,
          -0.1308468851282909,
          -0.4942684992017876,
          -0.1308468851282909,
          -0.1358252634032703,
          -0.1457820199532292,
          -0.1756522896031056,
          -0.1607171547781674,
          -0.2951333682026112,
          -0.3399387726774259,
          -0.3548739075023641,
          -0.3747874206022817,
          -0.4544414730019523,
          -0.3996793119771788,
          -0.3996793119771788,
          -0.4046576902521582,
          -0.5191603905766845,
          -1.1115874052992338,
          -1.1414576749491103,
          -1.1315009183991516,
          -1.2410252404486983,
          -1.250981996998657,
          -1.2360468621737188,
          -1.2310684838987396,
          -1.201198214248863,
          -1.2111549707988218,
          -1.0817171356493571,
          -0.9273874091249958,
          -0.917430652575037,
          -0.9124522743000576,
          -0.8776036263752017,
          -0.8776036263752017,
          -0.8676468698252429,
          -0.917430652575037,
          -0.9473009222249136,
          -0.832798221900387,
          -0.9871279484247486,
          -0.9622360570498516,
          -1.4550955062728128,
          -1.216133349073801,
          -1.2061765925238426,
          -1.2111549707988218,
          -1.1862630794239248,
          -1.1862630794239248,
          -1.1812847011489451,
          -1.2111549707988218,
          -1.1962198359738836,
          -1.0966522704742956,
          -0.8278198436254076,
          -0.8427549784503459,
          -0.8427549784503459,
          -0.8228414653504282,
          -0.89253876120014,
          -0.1756522896031056,
          -0.180630667878085,
          -0.3200252595775082,
          -0.4046576902521582,
          -0.4046576902521582,
          -0.4096360685271376,
          -0.5042252557517463,
          -0.2055225592529821,
          -0.1905874244280438,
          -0.180630667878085,
          0.128028785170638,
          0.0384179762210089,
          0.0085477065711325,
          0.0633098675959057,
          0.0384179762210089,
          -0.2503279637277968,
          -0.4096360685271376,
          -0.3648306640523229,
          -0.3797657988772612,
          -0.3200252595775082,
          -0.3349603944024464,
          -0.3498955292273847,
          -0.3200252595775082,
          -0.3250036378524876,
          -0.3947009337021994,
          -0.4892901209268082,
          -0.4693766078268905,
          -0.4793333643768493,
          -0.5241387688516639,
          -0.5888576864263962,
          -0.1856090461530644,
          0.003569328296153,
          -0.0760847241035174,
          -0.046214454453641,
          -0.0263009413537233,
          -0.071106345828538,
          -0.1109333720283733,
          -0.2403712071778379,
          -0.2254360723528997,
          -0.2453495854528173,
          -0.265263098552735,
          -0.155738776503188,
          -0.1358252634032703,
          -0.1258685068533115,
          -0.1408036416782498,
          -0.1507603982282086,
          -0.1955658027030233,
          -0.3150468813025288,
          -0.3349603944024464,
          -0.3498955292273847,
          -0.3747874206022817,
          -0.3797657988772612,
          -0.38972255542722,
          -0.3498955292273847,
          -0.3250036378524876,
          -0.5340955254016228,
          -0.4195928250770964,
          -0.3449171509524053,
          -0.499246877476767,
          -0.8676468698252429,
          -0.4594198512769317,
          -0.4693766078268905,
          -0.4793333643768493,
          -0.5241387688516639,
          -0.5390739036766021,
          -0.5440522819515815,
          -0.5988144429763551,
          -0.5838793081514169,
          -0.5988144429763551,
          -0.6386414691761904,
          -0.6884252519259842,
          -0.8128847088004696,
          -0.8278198436254076,
          -0.8825820046501811,
          -0.1856090461530644,
          -0.2055225592529821,
          -0.2702414768277141,
          -0.5141820123017051,
          -0.5589874167765198,
          -0.6037928212513345,
          -0.6386414691761904,
          -0.7979495739755313,
          -0.8726252481002224,
          -0.8825820046501811,
          -0.8975171394751194,
          -0.8726252481002224,
          -0.942322543949934,
          -0.8576901132752841,
          -0.2503279637277968,
          -0.4295495816270552,
          -0.4544414730019523,
          -0.3847441771522406,
          -0.2553063420027762,
          -0.499246877476767,
          -0.7382090346757784,
          -0.758122547775696,
          -0.758122547775696,
          -0.758122547775696,
          -0.7879928174255725,
          -0.7830144391505931,
          -0.8079063305254901,
          -0.8576901132752841,
          -0.9024955177500988,
          -0.9970847049747076,
          -1.016998218074625,
          -0.9871279484247486,
          -1.0219765963496044,
          -1.0269549746245838,
          -1.0369117311745426,
          -0.3299820161274671,
          -0.3250036378524876,
          -0.3250036378524876,
          -0.3200252595775082,
          -0.3150468813025288,
          -0.2901549899276318,
          -0.2951333682026112,
          -0.3498955292273847,
          -0.3847441771522406,
          -0.4494630947269729,
          -0.5340955254016228,
          -0.4345279599020347,
          -0.5141820123017051,
          -0.499246877476767,
          -0.6934036302009637,
          -0.8975171394751194,
          -0.3648306640523229,
          -0.38972255542722,
          -0.5141820123017051,
          -0.6983820084759431,
          -0.7232738998508401,
          -0.7232738998508401,
          -0.7730576826006342,
          -0.8427549784503459,
          -1.016998218074625,
          -1.0269549746245838,
          -1.0518468659994809,
          -1.126522540124172,
          -1.1713279445989866,
          -1.201198214248863,
          -0.2951333682026112,
          -0.1308468851282909,
          -0.1457820199532292,
          -0.2154793158029409,
          -0.4046576902521582,
          -0.6137495778012932,
          -0.4345279599020347,
          -0.4693766078268905,
          -0.5789009298764374,
          -0.2702414768277141,
          -0.6485982257261491,
          -0.6535766040011286,
          -0.6585549822761079,
          -0.5291171471266434,
          -0.5141820123017051,
          -0.5141820123017051,
          -0.5191603905766845,
          -0.499246877476767,
          -0.4643982295519111,
          -0.5042252557517463,
          -0.5589874167765198,
          -0.5639657950514992,
          -0.5789009298764374,
          -0.6485982257261491,
          -0.7033603867509225,
          -0.5540090385015404,
          -0.5589874167765198,
          -0.5589874167765198,
          -0.4494630947269729,
          -0.4444847164519935,
          -0.4594198512769317,
          -0.5191603905766845,
          -0.5141820123017051,
          -0.5540090385015404,
          -0.6286847126262315,
          -0.7033603867509225,
          -0.2105009375279615,
          -0.2453495854528173,
          -0.1308468851282909,
          -0.1408036416782498,
          -0.1358252634032703,
          -0.1258685068533115,
          0.0633098675959057,
          -0.1258685068533115,
          -0.1258685068533115,
          -0.1208901285783321,
          -0.7979495739755313,
          -0.8079063305254901,
          -0.8079063305254901,
          -0.7879928174255725,
          -0.7730576826006342,
          -0.7780360608756137,
          -0.7830144391505931,
          -0.8278198436254076,
          -0.5888576864263962,
          -0.38972255542722,
          -0.4544414730019523,
          -0.4345279599020347,
          -0.4295495816270552,
          -0.5042252557517463,
          -0.5838793081514169,
          -0.6535766040011286,
          -0.6585549822761079,
          -0.6685117388260666,
          -0.6983820084759431,
          -0.8228414653504282,
          -0.9771711918747896,
          -0.9821495701497692,
          -0.9323657873999752,
          -0.9373441656749546,
          -1.250981996998657,
          -1.2808522666485336,
          -1.3107225362984098,
          -1.3206792928483688,
          -0.8676468698252429,
          -0.917430652575037,
          -0.9273874091249958,
          -1.1115874052992338,
          -1.076738757374378,
          -1.0269549746245838,
          -0.7431874129507579,
          -0.7830144391505931,
          -0.7730576826006342,
          -0.8626684915502635,
          -0.89253876120014,
          -0.9522793004998928,
          -1.0070414615246663,
          -0.9771711918747896,
          -1.4899441541976688,
          -1.4899441541976688,
          -1.470030641097751,
          -1.4550955062728128,
          -1.4401603714478746,
          -1.4252252366229363,
          -1.420246858347957,
          -1.4302036148979158,
          -1.4351819931728953,
          -1.450117127997833,
          -1.4650522628227716,
          -0.3299820161274671,
          -0.3349603944024464,
          -0.3349603944024464,
          -0.3349603944024464,
          -0.3847441771522406,
          -0.4195928250770964,
          -0.4345279599020347,
          -0.4942684992017876,
          -0.3996793119771788,
          -0.4046576902521582,
          -0.5191603905766845,
          -0.6137495778012932,
          -0.6137495778012932,
          -0.6037928212513345,
          -0.1258685068533115,
          -0.2304144506278791,
          -0.3698090423273023,
          -0.4892901209268082,
          -0.5540090385015404,
          -0.5440522819515815,
          -0.4743549861018699,
          -0.2403712071778379,
          -0.2403712071778379,
          -0.2951333682026112,
          -0.3200252595775082,
          -0.3001117464775906,
          -0.3200252595775082,
          -0.3200252595775082,
          -0.3150468813025288,
          -0.2951333682026112,
          -0.2851766116526524,
          -0.2851766116526524,
          -0.2851766116526524,
          -0.2453495854528173,
          -0.2304144506278791,
          -0.0014090499788263,
          -0.0611495892785792,
          -1.4252252366229363,
          -1.410290101797998,
          -1.420246858347957,
          -0.992106326699728,
          -0.6734901171010461,
          -0.6286847126262315,
          -0.1856090461530644,
          -0.1109333720283733,
          -0.2353928289028585,
          -0.3399387726774259,
          -0.6436198474511697,
          -0.6934036302009637,
          -0.6983820084759431,
          -0.7182955215758607,
          -0.7481657912257372,
          -0.7979495739755313,
          -0.8228414653504282,
          -0.832798221900387,
          -0.2254360723528997,
          -0.2851766116526524,
          -0.3100685030275494,
          -0.2702414768277141,
          -0.265263098552735,
          -0.2105009375279615,
          -0.2403712071778379,
          -0.2951333682026112,
          -0.3150468813025288,
          -0.3200252595775082,
          -0.2851766116526524,
          -0.9572576787748724,
          -0.9672144353248312,
          -0.9771711918747896,
          -1.0319333528995631,
          -1.0618036225494398,
          -1.0717603790993986,
          -1.116565783574213,
          -1.1315009183991516,
          -1.0866955139243368,
          -1.1464360532240898,
          -1.1115874052992338,
          -1.1215441618491926,
          -1.1464360532240898,
          -1.151414431499069,
          -1.335614427673307,
          -1.2310684838987396,
          -1.2360468621737188,
          -1.300765779748451,
          -1.300765779748451,
          -1.300765779748451,
          -1.2957874014734718,
          -1.2808522666485336,
          -1.1563928097740486,
          -1.1613711880490278,
          -1.1713279445989866,
          -1.2211117273487808,
          -1.1364792966741308,
          -1.1215441618491926,
          -0.733230656400799,
          -0.7282522781258196,
          -0.6934036302009637,
          -0.7232738998508401,
          -0.633663090901211,
          -0.7033603867509225,
          -0.5440522819515815,
          -0.3947009337021994,
          -1.2957874014734718,
          -1.300765779748451,
          -1.300765779748451,
          -1.2957874014734718,
          -1.360506319048204,
          -1.3704630755981628,
          -1.325657671123348,
          -1.3107225362984098,
          -1.3754414538731423,
          -1.3654846973231836,
          -1.3704630755981628,
          -1.3804198321481216,
          -1.3953549669730598,
          -1.410290101797998,
          -1.250981996998657,
          -1.2609387535486158,
          -1.2609387535486158,
          -1.2460036187236776,
          -1.250981996998657,
          -1.2111549707988218,
          -1.1812847011489451,
          -1.166349566324007,
          -1.1713279445989866,
          -1.176306322873966,
          -1.2460036187236776,
          -1.3654846973231836,
          -1.360506319048204,
          -1.3804198321481216,
          -0.8228414653504282,
          -0.7979495739755313,
          -0.7929711957005519,
          -0.8029279522505107,
          -0.7830144391505931,
          -0.7879928174255725,
          -1.0369117311745426,
          -1.1066090270242543,
          -1.1066090270242543,
          -1.1215441618491926,
          -1.1066090270242543,
          -1.0866955139243368,
          -1.041890109449522,
          -1.0817171356493571,
          -0.9821495701497692,
          -0.9871279484247486,
          -1.0020630832496868,
          -1.0219765963496044,
          -1.041890109449522,
          -1.0468684877245016,
          -1.0468684877245016,
          -1.0269549746245838,
          -1.0269549746245838,
          -1.0269549746245838,
          -1.0319333528995631,
          -1.126522540124172,
          -0.4942684992017876,
          -0.5141820123017051,
          -0.573922551601458,
          -0.6137495778012932,
          -0.6087711995263139,
          -0.633663090901211,
          -0.6286847126262315,
          -0.633663090901211,
          -0.6386414691761904,
          -0.5938360647013756,
          -0.5938360647013756,
          -0.6784684953760255,
          -0.7531441695007166,
          -0.8128847088004696,
          -1.0219765963496044,
          -1.0319333528995631,
          -1.0518468659994809,
          -1.0568252442744603,
          -1.0618036225494398,
          -1.0319333528995631,
          -1.0369117311745426,
          -0.7730576826006342,
          -0.733230656400799,
          -0.758122547775696,
          -0.6983820084759431,
          -0.7033603867509225,
          -0.7282522781258196,
          -0.708338765025902,
          -0.9871279484247486,
          -0.992106326699728,
          -0.9871279484247486,
          -0.9871279484247486,
          -0.9871279484247486,
          -0.9871279484247486,
          -0.9821495701497692,
          -0.9821495701497692,
          -0.9771711918747896,
          -0.9821495701497692,
          -0.9871279484247486,
          -0.9821495701497692,
          -0.9224090308500164,
          -0.9224090308500164,
          -0.3947009337021994,
          -0.3996793119771788,
          -0.3498955292273847,
          -0.3449171509524053,
          -0.3498955292273847,
          -0.3498955292273847,
          -0.3250036378524876,
          -0.2851766116526524,
          -0.3200252595775082,
          -0.3250036378524876,
          -0.3498955292273847,
          -0.38972255542722,
          -0.4195928250770964,
          -0.5938360647013756,
          -0.9522793004998928,
          -0.9572576787748724,
          -0.9572576787748724,
          -0.9771711918747896,
          -0.9721928135998104,
          -0.9771711918747896,
          -0.9522793004998928,
          -0.0910198589284556,
          -0.6585549822761079,
          -0.6635333605510872,
          -0.8825820046501811,
          -0.6784684953760255,
          -0.5689441733264786,
          -0.5639657950514992,
          -0.573922551601458,
          -0.7780360608756137,
          -0.6884252519259842,
          -1.275873888373554,
          -1.2908090231984923,
          -1.2908090231984923,
          -1.2908090231984923,
          -1.2957874014734718,
          -1.2908090231984923,
          -1.2858306449235128,
          -1.3206792928483688,
          -1.2858306449235128,
          -1.2858306449235128,
          -1.2808522666485336,
          -1.2111549707988218,
          -1.1066090270242543,
          -1.0269549746245838,
          -0.4643982295519111,
          -0.2204576940779203,
          -0.1955658027030233,
          -0.2951333682026112,
          -0.3150468813025288,
          -0.2951333682026112,
          -0.3001117464775906,
          -0.2951333682026112,
          -0.2901549899276318,
          -0.3797657988772612,
          -0.5440522819515815,
          -0.499246877476767,
          -0.6734901171010461,
          -0.7431874129507579,
          -0.5689441733264786,
          -0.7531441695007166,
          -0.2254360723528997,
          -0.155738776503188,
          -0.1457820199532292,
          -0.155738776503188,
          -0.1159117503033527,
          -0.1856090461530644,
          -0.1955658027030233,
          -0.2005441809780027,
          -0.2851766116526524,
          -0.7481657912257372,
          -0.7531441695007166,
          -0.758122547775696,
          -0.7879928174255725,
          -0.7830144391505931,
          -0.8079063305254901,
          -0.8128847088004696,
          -0.8029279522505107,
          -0.7631009260506755,
          -0.7182955215758607,
          -0.7431874129507579,
          -0.8228414653504282,
          -0.8228414653504282,
          -0.8825820046501811,
          -0.708338765025902,
          -0.708338765025902,
          -0.708338765025902,
          -0.733230656400799,
          -0.733230656400799,
          -0.6734901171010461,
          -0.6884252519259842,
          -0.6934036302009637,
          -0.6934036302009637,
          -0.7382090346757784,
          -0.7879928174255725,
          -0.8427549784503459,
          -0.8377766001753665,
          -0.9473009222249136,
          -0.573922551601458,
          -0.573922551601458,
          -0.5639657950514992,
          -0.4544414730019523,
          -0.4643982295519111,
          -1.2908090231984923,
          -1.2908090231984923,
          -1.3157009145733891,
          -1.3804198321481216,
          -1.3953549669730598,
          -1.4152684800729776,
          -1.4053117235230188,
          -1.3804198321481216,
          -1.400333345248039,
          -1.3953549669730598,
          -1.3754414538731423,
          -1.3903765886980806,
          -1.3953549669730598,
          -1.3754414538731423,
          -0.7531441695007166,
          -0.7431874129507579,
          -0.7431874129507579,
          -0.7830144391505931,
          -0.7182955215758607,
          -0.7232738998508401,
          -0.708338765025902,
          -0.8128847088004696,
          -0.6087711995263139,
          -0.4295495816270552,
          -0.2752198551026936,
          -0.3449171509524053,
          -0.3399387726774259,
          -0.4643982295519111,
          -1.5098576672975863,
          -1.5098576672975863,
          -1.5098576672975863,
          -1.5098576672975863,
          -0.3100685030275494,
          -0.2553063420027762,
          -0.2602847202777556,
          -0.4245712033520759,
          -0.4295495816270552,
          -0.439506338177014,
          -0.4345279599020347,
          -0.4096360685271376,
          -0.4743549861018699,
          -0.4942684992017876,
          -0.4843117426518288,
          -0.4594198512769317,
          -0.4245712033520759,
          -0.439506338177014,
          -1.4750090193727303,
          -1.4750090193727303,
          -1.4799873976477098,
          -1.470030641097751,
          -1.3953549669730598,
          -1.3555279407732246,
          -0.2254360723528997,
          -0.1208901285783321,
          -0.1208901285783321,
          -0.2752198551026936,
          -0.30509012475257,
          -0.3200252595775082,
          -0.3996793119771788,
          -0.573922551601458,
          -0.6386414691761904,
          -0.6386414691761904,
          -0.6535766040011286,
          -0.6685117388260666,
          -1.4849657759226893,
          -1.400333345248039,
          -1.400333345248039,
          -1.400333345248039,
          -1.3953549669730598,
          -1.3903765886980806,
          -1.400333345248039,
          -1.410290101797998,
          -1.4152684800729776,
          -1.420246858347957,
          -1.410290101797998,
          -1.4152684800729776,
          -1.4252252366229363,
          -1.420246858347957,
          -1.1115874052992338,
          -0.6983820084759431,
          -0.6834468736510049,
          -0.6535766040011286,
          -0.6734901171010461,
          -0.7531441695007166,
          -0.6884252519259842,
          -0.6485982257261491,
          -0.5988144429763551,
          -0.071106345828538,
          -0.1208901285783321,
          -0.1706739113281262,
          -0.155738776503188,
          -0.1756522896031056,
          -0.2105009375279615,
          -0.4942684992017876,
          -0.5092036340267256,
          -0.5092036340267256,
          -0.5141820123017051,
          -0.5042252557517463,
          -0.499246877476767,
          -0.5042252557517463,
          -0.5440522819515815,
          -0.2901549899276318,
          -0.1856090461530644,
          -0.3150468813025288,
          -0.3200252595775082,
          -0.30509012475257,
          -0.1358252634032703,
          0.0085477065711325,
          0.003569328296153,
          0.003569328296153,
          -0.0810631023784968,
          -0.1109333720283733,
          -0.1159117503033527,
          -0.1308468851282909,
          -0.1358252634032703,
          -0.1507603982282086,
          -0.1656955330531468,
          -0.1109333720283733,
          -0.1856090461530644,
          -0.2453495854528173,
          -0.2851766116526524,
          -0.4195928250770964,
          -0.4843117426518288,
          -0.4494630947269729,
          -0.4892901209268082,
          -0.5241387688516639,
          -0.4544414730019523,
          -0.4544414730019523,
          -0.7631009260506755,
          -0.758122547775696,
          -0.7680793043256549,
          -0.6983820084759431,
          -0.6784684953760255,
          -1.166349566324007,
          -1.151414431499069,
          -1.1115874052992338,
          -1.1315009183991516,
          -1.1315009183991516,
          -1.1315009183991516,
          -1.116565783574213,
          -1.076738757374378,
          -1.091673892199316,
          -1.0866955139243368,
          -1.1713279445989866,
          -1.1066090270242543,
          -1.1115874052992338,
          -1.1315009183991516,
          -0.0362576979036821,
          -0.0810631023784968,
          -0.1009766154784145,
          -0.155738776503188,
          -0.1706739113281262,
          -0.2353928289028585,
          -0.5988144429763551,
          -0.573922551601458,
          -0.5639657950514992,
          -0.5390739036766021,
          -0.5589874167765198,
          -0.6535766040011286,
          -0.758122547775696,
          -0.7730576826006342,
          -0.758122547775696,
          -0.7830144391505931,
          -0.8128847088004696,
          -0.7879928174255725,
          -0.7780360608756137,
          -0.758122547775696
         ]
        }
       ],
       "layout": {
        "legend": {
         "title": {
          "text": "regime"
         },
         "tracegroupgap": 0
        },
        "scene": {
         "domain": {
          "x": [
           0,
           1
          ],
          "y": [
           0,
           1
          ]
         },
         "xaxis": {
          "title": {
           "text": "Polyarchy"
          }
         },
         "yaxis": {
          "title": {
           "text": "Liberal"
          }
         },
         "zaxis": {
          "title": {
           "text": "Participation"
          }
         }
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "fillpattern": {
             "fillmode": "overlay",
             "size": 10,
             "solidity": 0.2
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "title": {
         "text": "3D Scatter Plot of Democracy Variables"
        }
       }
      }
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig = px.scatter_3d(\n",
    "    vdem, \n",
    "    x=\"v2x_polyarchy\", \n",
    "    y=\"v2x_libdem\", \n",
    "    z=\"v2x_partipdem\", \n",
    "    color=\"regime\",\n",
    "    title=\"3D Scatter Plot of Democracy Variables\"\n",
    ")\n",
    "\n",
    "fig.update_layout(\n",
    "    scene=dict(\n",
    "        xaxis_title=\"Polyarchy\",\n",
    "        yaxis_title=\"Liberal\",\n",
    "        zaxis_title=\"Participation\"\n",
    "    )\n",
    ")\n",
    "\n",
    "fig.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This is all good and well, but how can we represent this data as a 2-dimensional space? One increasingly popular method is UMAP. While we need to do some hand-waving as the mathematics are too complicated to be dealt with here, UMAP has a few key hyperparameters that can be experimented with.\n",
    "\n",
    "-   Number of nearest neighbours used to construct the initial high-dimensional graph (`n_neighbors`).\n",
    "-   Minimum distance between points in low dimensional space (`min_dist`).\n",
    "\n",
    "We will instantiate a UMAP, setting `n_neighbors` to 100, and fit it using our continuous features."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Set a random seed\n",
    "np.random.seed(123)\n",
    "\n",
    "# Instantiate a UMAP with the relevant hyperparameter choice\n",
    "reducer = UMAP(n_neighbors=100)\n",
    "\n",
    "# Create a subset of the data using only variables beginning with \"v2x\"\n",
    "vdem_subset = vdem[vdem.columns[vdem.columns.str.contains(\"v2x\")]].to_numpy()\n",
    "\n",
    "# Fit / transform the model to the subset of data to obtain the embeddings\n",
    "embedding = reducer.fit_transform(vdem_subset)\n",
    "\n",
    "# Convert the embeddings to a data frame\n",
    "embedding = pd.DataFrame(embedding, columns = [\"first_dim\", \"second_dim\"])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "After this, we can extract the 2-d space created by UMAP and plot it."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 251,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"yyPCHr\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"yyPCHr\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"first_dim\":[6.51674222946167,6.512907028198242,6.449214935302734,4.866077423095703,4.962682247161865,5.710876941680908,5.7226243019104,6.072944164276123,6.590290546417236,6.362383842468262,5.763228416442871,4.303800582885742,3.8984360694885254,2.586031198501587,11.887409210205078,11.693941116333008,11.6430025100708,11.644271850585938,11.630430221557617,11.734424591064453,11.761123657226563,11.653114318847656,11.47243595123291,9.945507049560547,11.609359741210938,11.6473388671875,12.308818817138672,11.656645774841309,15.61210823059082,15.685789108276367,15.712860107421875,15.757234573364258,15.839219093322754,15.869376182556152,15.884811401367188,15.929427146911621,15.895536422729492,16.010448455810547,16.04749870300293,16.054462432861328,16.100812911987305,16.232418060302734,14.25604248046875,14.253641128540039,14.25402545928955,14.262155532836914,14.244158744812012,14.204154014587402,14.199509620666504,14.207005500793457,14.22874927520752,14.193474769592285,14.260049819946289,14.255759239196777,14.25346565246582,14.280628204345703,10.203845024108887,10.183808326721191,10.191618919372559,10.151081085205078,10.101852416992188,10.114703178405762,10.090592384338379,10.111259460449219,10.156342506408691,10.046765327453613,10.038183212280273,5.961064338684082,5.965362548828125,5.899856090545654,12.656173706054688,12.58960247039795,12.667911529541016,12.104652404785156,11.830795288085938,11.928750038146973,11.840916633605957,11.555316925048828,11.594130516052246,10.424455642700195,10.326248168945313,10.497682571411133,10.212702751159668,8.816280364990234,14.771771430969238,14.767433166503906,14.698492050170898,14.011496543884277,13.955848693847656,13.944390296936035,13.959773063659668,13.947105407714844,14.089268684387207,14.03465461730957,14.050101280212402,13.882128715515137,13.824498176574707,13.821842193603516,-6.093944072723389,-5.042766571044922,-4.064688682556152,-2.6556944847106934,-2.5216288566589355,-2.2692935466766357,-1.207958459854126,-1.1597779989242554,-1.178887128829956,-0.5230798125267029,-0.5267851948738098,-6.025513172149658,-6.068131923675537,-6.054253101348877,-3.8397865295410156,-3.9191153049468994,-4.121507167816162,-4.188201904296875,-4.689674377441406,-4.812140464782715,-4.792911529541016,-4.7605881690979,-4.752864837646484,-4.772537708282471,-4.166197299957275,-4.852243900299072,-5.45890474319458,-5.529874324798584,3.4800753593444824,3.4568569660186768,3.3631083965301514,2.750288248062134,2.8722262382507324,2.822615146636963,2.840111494064331,2.9032418727874756,2.743917942047119,2.5584347248077393,2.9886271953582764,2.8653879165649414,2.669992685317993,2.016315460205078,-6.362481594085693,-6.348680019378662,-4.847926616668701,-6.419131755828857,-6.642902374267578,-6.5936279296875,-6.40840482711792,-6.421561241149902,-6.350702285766602,-6.194694995880127,-6.21330451965332,-6.238655090332031,-6.222610950469971,-6.250555992126465,-4.486271858215332,-3.81577730178833,-3.7147412300109863,-4.0626091957092285,-4.971084117889404,-6.578689098358154,-6.333059787750244,-6.313868045806885,-6.300793647766113,-6.3307785987854,-6.284937858581543,-6.320981979370117,-6.375458240509033,-6.405003547668457,6.890196323394775,8.131352424621582,7.96156644821167,8.059510231018066,8.290729522705078,8.44384765625,8.61742115020752,8.598342895507813,8.40433406829834,7.55789041519165,7.238461971282959,7.441043853759766,8.69754409790039,9.120549201965332,15.526775360107422,15.556120872497559,15.806559562683105,15.831743240356445,15.757855415344238,14.8651762008667,10.600833892822266,8.384941101074219,8.028512954711914,8.029333114624023,5.691040515899658,4.351313591003418,4.241412162780762,4.590737819671631,14.501818656921387,14.548267364501953,14.534784317016602,14.738197326660156,14.753960609436035,14.82823371887207,12.754087448120117,12.380599021911621,11.495330810546875,8.130702018737793,8.360248565673828,7.9481706619262695,8.312461853027344,13.363484382629395,15.881414413452148,15.859484672546387,15.851035118103027,15.863271713256836,15.870537757873535,15.888046264648438,15.808366775512695,14.39151668548584,14.186710357666016,14.123793601989746,14.06501579284668,14.470032691955566,14.610572814941406,14.711371421813965,15.754441261291504,15.694819450378418,15.720390319824219,15.955230712890625,15.988818168640137,15.888519287109375,15.928000450134277,16.093751907348633,16.13886070251465,15.6911039352417,15.503827095031738,15.649887084960938,14.53787899017334,14.495404243469238,5.2204108238220215,5.3798933029174805,5.504737377166748,5.638980865478516,6.585391521453857,6.503007888793945,6.517589569091797,6.593598365783691,6.088544845581055,4.283719539642334,1.8211872577667236,-2.1082305908203125,-2.468088150024414,-2.4742462635040283,-2.5337257385253906,-2.58038330078125,-2.7099897861480713,-3.6000843048095703,-5.200406074523926,-5.149923324584961,-5.153614044189453,-5.188244819641113,-5.466547012329102,-5.556281566619873,-5.504647731781006,-5.513294696807861,-5.515305995941162,-5.5404767990112305,7.698947906494141,7.694160461425781,7.6474223136901855,7.551459789276123,7.507559299468994,5.090299129486084,5.2278056144714355,4.980968475341797,4.183027744293213,1.0152335166931152,-1.543424129486084,4.163680553436279,4.062504768371582,4.064060211181641,-0.7682276368141174,-1.1704210042953491,-1.036355972290039,-1.1222883462905884,-1.1103036403656006,-1.3397183418273926,-1.5155984163284302,-1.3667078018188477,-1.2436033487319946,-1.744876742362976,-3.429152250289917,-3.282454013824463,-6.290686130523682,-6.5646185874938965,-0.6468724608421326,-0.43316224217414856,-0.484098345041275,-0.4188743233680725,0.08150214701890945,-0.3032848536968231,-0.17413389682769775,-0.4888727366924286,-1.4177249670028687,-1.2743899822235107,-1.2616177797317505,-0.9575060606002808,2.986863613128662,2.565624952316284,4.655426502227783,4.662185192108154,-1.27298104763031,-2.079810380935669,2.433668851852417,2.706073045730591,2.720803737640381,2.0612151622772217,1.8246667385101318,1.7979660034179688,-1.509804368019104,-3.677873373031616,-3.7933075428009033,-3.927243232727051,0.6151596903800964,0.5723696351051331,0.5900735259056091,0.6187120676040649,0.6523020267486572,0.07053223997354507,-0.46436285972595215,-0.5558697581291199,-0.8882259130477905,-1.4332168102264404,-1.1146929264068604,-1.0129661560058594,-1.185640573501587,-1.9899413585662842,13.226655960083008,13.574710845947266,13.676809310913086,13.656743049621582,13.66174602508545,13.649357795715332,13.185100555419922,13.299201965332031,13.714539527893066,13.68763542175293,13.82286262512207,12.80673885345459,12.070096969604492,9.206222534179688,7.819652557373047,7.84763765335083,8.148138046264648,9.910187721252441,9.912837982177734,9.933710098266602,9.895259857177734,8.565150260925293,8.496469497680664,9.804353713989258,9.782465934753418,9.775044441223145,8.197000503540039,5.79489278793335,-6.431983947753906,-6.467578887939453,-6.613893985748291,-6.63974666595459,-6.446869373321533,-6.805196762084961,-6.950775146484375,-6.960641384124756,-6.716355800628662,-6.419440269470215,-6.589916229248047,-6.613532066345215,-6.453449249267578,-6.19706916809082,-6.344419479370117,-6.2751336097717285,-6.852272033691406,-6.885893821716309,-6.7405104637146,-6.678650856018066,-6.6522603034973145,-6.709303855895996,-5.647770881652832,-6.141156196594238,-6.506992816925049,-6.049398899078369,-6.135055065155029,-4.3692097663879395,-4.372969627380371,-4.365756988525391,-4.364859580993652,-4.40869140625,-4.378291606903076,-4.349024772644043,-4.3499436378479,-4.372320652008057,-4.0062360763549805,-4.051811218261719,-4.457956790924072,-4.3796162605285645,-4.360194683074951,-3.4147114753723145,-3.3914742469787598,-3.3758649826049805,-3.381535768508911,-3.361518383026123,-3.3486170768737793,-3.591688394546509,-3.57981276512146,-3.4852161407470703,-4.005870342254639,-3.7359092235565186,-7.087481498718262,-5.291670799255371,-5.29047966003418,12.042625427246094,12.149401664733887,12.272415161132813,12.369403839111328,12.457515716552734,12.259232521057129,12.062175750732422,11.88002872467041,12.741592407226563,12.656846046447754,13.184957504272461,13.153898239135742,13.300772666931152,13.715279579162598,-6.598630428314209,-6.583128929138184,-6.559255599975586,-6.566476345062256,-6.586362838745117,-6.556069850921631,-6.69612979888916,-6.576771259307861,-5.073877811431885,-3.7881906032562256,-3.7536795139312744,-3.9893157482147217,-3.9289283752441406,-4.3453168869018555,8.263452529907227,8.223790168762207,8.210977554321289,7.8806538581848145,6.275859832763672,3.3951516151428223,2.6468493938446045,1.4015076160430908,1.2465803623199463,0.14138217270374298,-1.0098718404769897,-0.9721744656562805,-1.0088253021240234,-1.4536173343658447,0.3054923713207245,0.5084661245346069,0.5739806294441223,3.33667254447937,3.5713984966278076,3.5295822620391846,3.5844314098358154,3.140918016433716,2.182115316390991,2.1468584537506104,2.210881471633911,2.708800792694092,3.739976644515991,4.387593746185303,-5.489602088928223,-5.4736809730529785,-5.4981584548950195,-5.498847961425781,-5.472405433654785,-5.480865001678467,-5.480534553527832,-5.474118709564209,-5.450477600097656,-5.4807000160217285,-5.4805684089660645,-5.470217227935791,-5.461436748504639,-5.494268417358398,12.714764595031738,12.746962547302246,12.253271102905273,10.674078941345215,10.590784072875977,10.511002540588379,11.210845947265625,15.279522895812988,15.312840461730957,14.985920906066895,15.054328918457031,15.05984115600586,13.97819709777832,10.460963249206543,2.0195040702819824,1.3931277990341187,1.5904474258422852,1.7453941106796265,3.970538377761841,5.296305179595947,5.3947954177856445,3.7095632553100586,6.293392658233643,6.879469871520996,6.626247882843018,6.697808265686035,6.939793109893799,6.823117733001709,0.32700902223587036,0.44319596886634827,0.41459396481513977,0.5786740183830261,0.5651258230209351,0.5111609101295471,0.45967772603034973,0.4044528603553772,-0.1165093183517456,-1.0661332607269287,-1.048986792564392,-1.0712733268737793,-1.4479551315307617,-1.8313745260238647,0.18368247151374817,2.187196731567383,2.6711578369140625,3.0921950340270996,3.2978408336639404,3.9229815006256104,3.893174171447754,3.8347561359405518,3.7715656757354736,2.7998056411743164,2.820711612701416,1.2566877603530884,1.7181254625320435,1.834283471107483,3.328780174255371,3.721025228500366,3.700990915298462,3.730746030807495,3.7544610500335693,3.6674468517303467,2.7847678661346436,2.319514513015747,1.543029546737671,0.6004531979560852,0.04098048806190491,0.09582268446683884,-0.018682735040783882,0.005920327268540859,1.5726090669631958,1.700692892074585,1.7088414430618286,1.6241936683654785,1.5403730869293213,1.3395885229110718,0.15625213086605072,0.06048325076699257,-0.07910893857479095,-0.12558963894844055,-0.10884642601013184,-0.17710646986961365,0.04634247347712517,0.38637444376945496,13.750274658203125,13.729439735412598,13.665021896362305,13.675493240356445,13.65349006652832,13.684008598327637,13.97004222869873,14.056634902954102,13.906586647033691,13.920147895812988,13.863645553588867,13.749756813049316,13.896403312683105,13.914508819580078,-0.1279810220003128,0.40171340107917786,1.5057884454727173,0.09335210919380188,-6.020391941070557,-5.955470561981201,-5.89484977722168,-5.56445837020874,-5.697688579559326,-5.087013244628906,-5.123170375823975,-5.0806779861450195,-5.063830375671387,-2.4589316844940186,-1.6735621690750122,-1.68321692943573,-1.6808115243911743,-1.75831937789917,-1.8047887086868286,-1.8015005588531494,-2.208738088607788,-2.275961399078369,-2.253218412399292,-2.3388254642486572,-2.3944451808929443,-2.612201452255249,-2.537043809890747,-2.5271353721618652,-1.1043280363082886,-1.1531749963760376,-1.2798596620559692,-3.4300637245178223,-3.481600522994995,-3.534510850906372,-3.6561458110809326,-4.249247074127197,-5.245206356048584,-5.320188045501709,-5.305042743682861,-5.271523475646973,-5.386298179626465,-5.2911601066589355,7.368697166442871,6.170516490936279,6.125935077667236,6.161976337432861,6.175076007843018,8.016300201416016,10.211472511291504,10.414032936096191,6.342071533203125,0.6370497941970825,-1.0466917753219604,-1.1448299884796143,-0.07356102764606476,0.9650185704231262,6.206320285797119,6.256260871887207,6.125968933105469,4.872255802154541,4.814455986022949,4.850800514221191,4.599616050720215,4.774780750274658,4.94196081161499,6.298104763031006,6.203383445739746,4.740171432495117,3.5756051540374756,2.9124133586883545,2.886958599090576,3.1439571380615234,3.2207188606262207,4.359938621520996,3.982081651687622,-1.1970744132995605,7.683626651763916,7.8050312995910645,6.866990089416504,6.615764141082764,6.603562355041504,5.218043327331543,-2.4187605381011963,-5.045735836029053,-3.8550708293914795,-3.8290863037109375,-3.8359503746032715,-3.9545862674713135,-3.9140236377716064,-4.011987209320068,-4.295806884765625,-5.033329010009766,-5.509575843811035,-5.494620323181152,-5.471476078033447,-5.5003509521484375,-5.532820701599121,-5.532281875610352,8.505525588989258,8.512009620666504,8.457204818725586,8.232966423034668,8.0134916305542,7.746510028839111,7.27938175201416,6.89749002456665,6.018161773681641,5.948559761047363,4.249368667602539,3.711130380630493,3.8313558101654053,2.984527111053467,-0.04602733999490738,-0.04481854662299156,-0.04571472108364105,-0.005543462000787258,-0.045406922698020935,0.11288610100746155,-0.04027858376502991,-0.7320361733436584,-0.9809321761131287,-1.2742223739624023,-1.671522617340088,-1.3492310047149658,-1.6514308452606201,-1.8596919775009155,2.7639496326446533,2.782562732696533,-1.9900540113449097,-2.8020732402801514,5.2457709312438965,6.378641128540039,6.632143974304199,8.36391544342041,7.156657695770264,6.069284915924072,6.0214948654174805,6.1768317222595215,7.029170036315918,8.079351425170898,-1.1121091842651367,-1.1650382280349731,-2.317925453186035,-3.606187343597412,-3.6724395751953125,-3.7684707641601563,-3.884528875350952,-4.154872417449951,-5.518985748291016,-5.576791763305664,-5.6438093185424805,-5.858826637268066,-6.391669273376465,-6.470017433166504,-2.4623968601226807,4.124296188354492,7.199384689331055,7.403500556945801,7.364932060241699,7.212648391723633,4.642639636993408,3.38810396194458,2.5648956298828125,2.8859896659851074,3.4828836917877197,2.497082233428955,2.0819201469421387,-0.8197339773178101,2.1496307849884033,2.1133346557617188,2.0693247318267822,1.37564218044281,1.273437738418579,0.6945734620094299,-0.9761211276054382,-1.7311078310012817,-1.568996787071228,-1.6096798181533813,-1.7400184869766235,-0.06081465259194374,3.442638397216797,3.5222339630126953,-2.5092344284057617,-2.5317764282226563,-2.5390594005584717,-2.3020262718200684,-2.2757458686828613,-2.279151678085327,-2.3025052547454834,-2.2488882541656494,-2.23047137260437,-2.296323776245117,-2.410579204559326,-2.3677546977996826,-2.4648520946502686,-2.616443395614624,-4.0965704917907715,-3.4923086166381836,-3.465343952178955,-3.458212375640869,-2.232015371322632,-2.2544031143188477,-2.185863494873047,-2.37392520904541,-2.3675787448883057,-2.5469110012054443,-3.5872116088867188,-3.996774435043335,-4.851059913635254,-5.339518070220947,0.18788838386535645,-5.057538510300219E-4,1.1196928024291992,0.9297529458999634,1.0144010782241821,1.1366313695907593,2.912379264831543,3.1385385990142822,3.094743013381958,2.7969796657562256,2.1983273029327393,0.20668113231658936,0.2918868064880371,0.2804822623729706,-2.015613555908203,-2.0628738403320313,-2.047933578491211,-2.7139577865600586,-2.723419666290283,-2.6743123531341553,-2.6760928630828857,-3.3547518253326416,-2.2538726329803467,-1.3644969463348389,-1.452168345451355,-1.478585124015808,-1.4294623136520386,-2.1685235500335693,14.697542190551758,14.09742546081543,14.074118614196777,14.17750358581543,14.102134704589844,14.119221687316895,14.782633781433105,14.91177749633789,14.741776466369629,14.885427474975586,14.618348121643066,14.668814659118652,14.569750785827637,14.519755363464355,16.128734588623047,16.07628631591797,16.09634017944336,15.525395393371582,15.430459976196289,15.734453201293945,15.814008712768555,15.894729614257813,15.31019115447998,14.718056678771973,14.934465408325195,14.756379127502441,15.091540336608887,14.792234420776367,10.619596481323242,10.582480430603027,10.473611831665039,10.444842338562012,10.453633308410645,9.058772087097168,8.915057182312012,8.343361854553223,8.5535306930542,7.9271931648254395,4.971551895141602,6.110926628112793,4.611898899078369,2.9337093830108643,-3.4023380279541016,-3.631612539291382,-3.623345375061035,-3.7529213428497314,-3.8563477993011475,-5.176241874694824,-5.4571852684021,-5.4711384773254395,-5.437498092651367,-5.371260166168213,-6.5080461502075195,-6.690862655639648,-6.878861904144287,-7.060263156890869,12.412643432617188,12.593692779541016,12.603336334228516,12.672822952270508,12.686779975891113,12.719391822814941,12.670673370361328,12.6450834274292,12.539456367492676,12.65980052947998,12.728350639343262,12.28816032409668,11.731605529785156,11.574246406555176,-3.7520880699157715,-4.063833236694336,-4.056633472442627,-5.0664238929748535,-4.84321403503418,-4.548129081726074,-2.1519131660461426,-2.265936851501465,-2.1347365379333496,-3.340938091278076,-3.4936420917510986,-4.098788261413574,-4.415696144104004,-5.227919578552246,15.897960662841797,15.893533706665039,15.923674583435059,15.953235626220703,15.943018913269043,15.954236030578613,15.911359786987305,15.96265983581543,15.431356430053711,14.619508743286133,14.528141975402832,14.904679298400879,14.835824966430664,14.824843406677246,15.22396183013916,15.227538108825684,15.234511375427246,15.28027629852295,15.296910285949707,15.353658676147461,15.475789070129395,15.689810752868652,15.562897682189941,15.818790435791016,15.851926803588867,15.919112205505371,15.358319282531738,15.515495300292969,5.309061050415039,5.385720252990723,5.721157550811768,5.551122188568115,5.262086868286133,5.281063079833984,5.12566614151001,6.48711633682251,6.926985740661621,7.521279811859131,6.679737567901611,6.761554718017578,7.818958282470703,7.874112606048584,4.0054612159729,3.9781384468078613,4.033321380615234,2.5594429969787598,2.4972968101501465,2.515674591064453,2.544747829437256,3.531771659851074,7.441413879394531,6.812885761260986,7.104460716247559,6.890148639678955,7.908069133758545,7.670787811279297,15.368037223815918,15.385457038879395,15.488080024719238,15.569991111755371,15.543137550354004,15.709814071655273,15.823076248168945,15.747998237609863,15.425816535949707,15.328091621398926,15.253832817077637,15.117280006408691,15.493570327758789,15.498784065246582,15.983673095703125,15.962603569030762,15.986102104187012,16.0011043548584,15.998340606689453,16.100234985351563,16.040828704833984,15.901993751525879,16.031024932861328,15.975639343261719,15.969839096069336,15.405289649963379,15.249914169311523,15.414488792419434,4.162537097930908,4.085496425628662,3.870056629180908,4.084659099578857,4.034736633300781,4.6951422691345215,5.423713684082031,5.304870128631592,4.464651107788086,4.60221004486084,4.327099323272705,2.987809658050537,1.2450231313705444,1.0368211269378662,-6.587002754211426,-6.574900150299072,-6.529087543487549,-6.46444034576416,-6.499732494354248,-6.486513137817383,-6.480480670928955,-6.474065780639648,-6.4636311531066895,-6.4867095947265625,-6.564435005187988,-6.814513683319092,-6.865374565124512,-6.89517068862915,-0.4788016676902771,-0.5069308280944824,-0.5257764458656311,-0.5491321682929993,-0.9738865494728088,-1.158921241760254,-1.1446051597595215,-1.4198106527328491,-1.0815569162368774,-1.1616681814193726,-1.8361924886703491,-2.0642552375793457,-2.1226541996002197,-2.142300605773926,15.689993858337402,15.67281436920166,15.66203498840332,15.672008514404297,15.735621452331543,15.685361862182617,15.7219877243042,15.765843391418457,15.760923385620117,15.793530464172363,15.717289924621582,15.929365158081055,15.810726165771484,15.909978866577148,14.011493682861328,14.084016799926758,14.18199634552002,14.083724975585938,14.112502098083496,14.125879287719727,14.187830924987793,14.148516654968262,14.115554809570313,14.10263729095459,14.072856903076172,14.077666282653809,14.02428913116455,14.015066146850586,-2.5510928630828857,-2.554447650909424,-2.5327095985412598,-2.510390281677246,-2.4949324131011963,-2.505335807800293,-2.555372714996338,-2.4884862899780273,-2.472188949584961,-2.4773547649383545,-2.4691834449768066,-2.459613800048828,-2.462491512298584,-2.4526069164276123,13.736685752868652,13.907326698303223,13.90589714050293,13.955459594726563,13.953024864196777,13.976240158081055,14.042616844177246,14.071915626525879,14.24205207824707,14.309030532836914,14.17269229888916,14.326506614685059,14.247464179992676,14.63271713256836,4.065624713897705,4.198957920074463,4.653256416320801,6.052423000335693,6.085794925689697,4.8294901847839355,4.181572437286377,1.8900775909423828,4.686581134796143,6.277678489685059,6.5086188316345215,6.382391452789307,6.708106517791748,6.4862494468688965,5.679741859436035,5.808029651641846,5.5797624588012695,5.153314590454102,5.08839750289917,5.028120517730713,5.1078290939331055,5.2486419677734375,4.869095325469971,4.71861457824707,5.009658336639404,4.936079025268555,4.946687698364258,5.059293270111084,1.5393717288970947,1.5420145988464355,1.7385592460632324,2.7966511249542236,3.3451406955718994,3.132631540298462,3.137467384338379,3.4604790210723877,2.959336519241333,1.661401391029358,3.891578197479248,6.501082897186279,6.237937927246094,4.866115093231201,3.9516890048980713,4.679882049560547,2.8943474292755127,0.0931420624256134,-1.1350129842758179,-1.8453608751296997,-2.2000110149383545,-2.334510564804077,-1.672485589981079,3.872979164123535,3.949094295501709,3.900043487548828,4.139542579650879,4.92603063583374,8.028840065002441,8.17524528503418,8.19697093963623,8.16295337677002,8.139050483703613,6.787386417388916,6.6496500968933105,6.60814094543457,6.461974620819092,6.4669036865234375,5.673115253448486,5.199553489685059,3.0493273735046387,1.5285106897354126,-2.450166940689087,-2.418785333633423,-2.4406943321228027,-2.4612817764282227,-2.4177207946777344,-2.4570963382720947,-2.4242095947265625,-2.4135642051696777,-2.3860743045806885,-2.380307674407959,-2.3882806301116943,-2.366644859313965,-2.3820135593414307,-2.363027334213257,15.838637351989746,15.84763240814209,15.839029312133789,15.866671562194824,15.858322143554688,15.868437767028809,15.965509414672852,16.069963455200195,16.03368377685547,15.54383659362793,15.442977905273438,15.452714920043945,15.359389305114746,15.314780235290527,9.761676788330078,9.789791107177734,9.775288581848145,9.814517974853516,9.772563934326172,9.754751205444336,9.771219253540039,9.725080490112305,9.637660026550293,9.61226749420166,9.695441246032715,9.701654434204102,9.728682518005371,9.81194019317627,0.8105032444000244,0.7727199792861938,0.4355159103870392,0.3207278549671173,0.32212162017822266,0.2879209816455841,0.33591341972351074,0.2793499529361725,0.3733339309692383,0.4040122628211975,0.45569753646850586,0.4831573963165283,0.8839110732078552,1.18699312210083,-6.329812526702881,-6.369716644287109,-6.336507320404053,-6.330756664276123,-6.341742992401123,-6.336086273193359,-6.331351280212402,-6.328379154205322,-6.329845905303955,-6.337794303894043,-6.32984733581543,-6.46939754486084,-6.473894119262695,-6.4074811935424805,2.127051591873169,2.1274476051330566,2.0227837562561035,2.0803604125976563,2.0959255695343018,2.061436653137207,2.0673365592956543,2.0775845050811768,3.189241647720337,3.317422389984131,3.7167768478393555,3.6579718589782715,3.8233282566070557,1.916786551475525,15.540533065795898,15.49478816986084,14.744614601135254,14.771819114685059,14.784709930419922,14.625290870666504,14.669623374938965,14.614584922790527,14.828262329101563,15.243996620178223,14.923810958862305,14.747336387634277,15.025354385375977,14.521806716918945,-6.787575721740723,-6.72943639755249,-6.750426292419434,-6.728320598602295,-6.724507808685303,-6.717369079589844,-6.72785758972168,-6.733593940734863,-6.645568370819092,-6.67471170425415,-6.679977893829346,-6.718161582946777,-6.714389324188232,-6.778326034545898,-5.126931190490723,-1.8545429706573486,11.576876640319824,11.342653274536133,10.55848503112793,10.232754707336426,10.223714828491211,10.248067855834961,11.860812187194824,11.419415473937988,10.685089111328125,3.5107359886169434,-2.4102485179901123,0.6475476026535034,3.029215097427368,2.9091598987579346,2.6809043884277344,0.7316107153892517,-0.24668090045452118,-1.061008334159851,-3.455303192138672,-3.761507272720337,-3.799809217453003,-3.8243372440338135,-3.8843371868133545,-4.040531635284424,-4.0495805740356445,-4.0799431800842285,0.4965199828147888,0.2998836934566498,0.2834933400154114,0.1508760005235672,-0.7372048497200012,-0.4025971293449402,-0.3263714611530304,-0.3980748653411865,-0.4299543797969818,2.0377964973449707,2.5584232807159424,2.1865217685699463,-0.5404611825942993,-0.39369428157806396,15.320239067077637,14.8117094039917,14.799456596374512,14.792546272277832,14.74090576171875,14.649998664855957,14.657076835632324,14.807764053344727,14.813597679138184,14.690940856933594,14.690503120422363,14.639290809631348,14.647530555725098,14.721755981445313,14.39574146270752,14.445283889770508,14.44449234008789,14.44748306274414,14.425421714782715,14.62906265258789,14.601664543151855,14.711454391479492,14.720794677734375,14.758429527282715,14.32904052734375,14.093616485595703,13.969597816467285,14.014570236206055,-4.267824649810791,-4.251466274261475,-4.267617225646973,-4.463545322418213,-4.591026782989502,-4.56330680847168,-4.8033447265625,-4.843693733215332,-4.751870155334473,-5.000556468963623,-4.953670501708984,-5.0340352058410645,-5.247922897338867,-5.217762470245361,-6.768399238586426,-4.997760772705078,-5.043931484222412,-5.0714569091796875,-5.065675735473633,-5.0962066650390625,-5.0728840827941895,-4.998960494995117,-4.541830062866211,-4.560801982879639,-4.6239333152771,-4.681437015533447,-4.607024669647217,-4.604776859283447,-3.0987801551818848,-3.033690929412842,-2.663776397705078,-2.7791669368743896,-2.3389453887939453,-2.747300148010254,-2.083198308944702,-1.2307389974594116,3.1490955352783203,12.920573234558105,12.253283500671387,9.606937408447266,6.3220906257629395,4.880630016326904,-6.982677936553955,-6.976781845092773,-7.00313138961792,-6.9957122802734375,-7.1548895835876465,-7.192883014678955,-7.098374366760254,-7.004222393035889,-7.213970184326172,-7.192531585693359,-7.190402984619141,-7.207022190093994,-7.3028435707092285,-7.3096842765808105,-6.620382308959961,-6.744324207305908,-6.687629222869873,-6.654718399047852,-6.676787376403809,-6.561944961547852,-6.512551307678223,-6.472498893737793,-6.504095077514648,-6.481363773345947,-6.882065296173096,-7.155392646789551,-7.128034591674805,-6.980520248413086,-3.780503034591675,-3.781195640563965,-3.7609970569610596,-3.8110413551330566,-3.728339195251465,-3.766716957092285,-4.851334571838379,-4.969633102416992,-4.993423938751221,-5.06406307220459,-5.047109127044678,-4.998310089111328,-4.915404319763184,-4.995266437530518,-5.221050262451172,-5.258059024810791,-5.277129650115967,-5.314844608306885,-5.36792516708374,-5.355240821838379,-5.331817150115967,-5.434885501861572,-5.435742378234863,-5.380441665649414,-5.3614020347595215,-6.09790563583374,-6.260396480560303,-5.987279891967773,-6.086495876312256,-6.071810722351074,-6.09976863861084,-6.050413608551025,-6.0543622970581055,-6.011066436767578,-6.042059421539307,-6.018021106719971,-6.009495258331299,-6.015638828277588,-5.948302268981934,-5.9999213218688965,-6.019935131072998,-5.9374165534973145,-2.348534345626831,-2.408848285675049,-3.3068087100982666,-3.4039859771728516,-3.3925929069519043,-3.5088021755218506,-3.483593702316284,-3.5050249099731445,-3.488731622695923,-2.6458287239074707,-2.5801661014556885,-3.2190346717834473,-3.6712355613708496,-3.8886609077453613,-5.424086093902588,-5.464224815368652,-5.50819730758667,-5.5031280517578125,-5.498414516448975,-5.431490898132324,-5.427121639251709,-4.143956661224365,-4.045942783355713,-4.1168532371521,-4.004621505737305,-4.036453723907471,-4.03101110458374,-3.9934604167938232,-4.985024452209473,-4.96079683303833,-4.965082168579102,-4.969204902648926,-4.981346607208252,-4.990457057952881,-4.949439525604248,-4.964572429656982,-4.930231094360352,-4.921751499176025,-4.970376968383789,-4.930578708648682,-4.801130294799805,-4.772680759429932,4.102637767791748,4.059807300567627,3.961397409439087,3.817763328552246,3.8280725479125977,3.130659580230713,2.530548572540283,2.3756117820739746,2.494657039642334,2.562195062637329,6.012039661407471,7.5653886795043945,7.431539058685303,7.031297206878662,-5.18272066116333,-5.1956706047058105,-5.169795513153076,-5.209287643432617,-5.197542667388916,-5.185284614562988,-5.160193920135498,-5.152003288269043,-5.165696144104004,-5.195936679840088,-5.151909351348877,-5.201365947723389,-5.196692943572998,-5.204714775085449,-1.3131369352340698,-1.2931832075119019,-1.230302333831787,-1.1568926572799683,-1.1950587034225464,-1.152014970779419,-1.1104391813278198,-0.723440408706665,-1.0640932321548462,-1.1991608142852783,-1.2378844022750854,-1.3374347686767578,-1.4784350395202637,-2.5253612995147705,-4.936790943145752,-4.886198997497559,-4.838040828704834,-4.9822096824646,-4.972898483276367,-4.97694206237793,-4.873573303222656,1.8194165229797363,3.2779009342193604,2.7152211666107178,2.0112497806549072,2.2448205947875977,6.493810653686523,7.061846733093262,1.9579837322235107,1.9333616495132446,2.313746213912964,6.009169101715088,7.824394226074219,7.956515789031982,8.24918270111084,8.135723114013672,8.128504753112793,6.708907604217529,6.405314922332764,6.3266825675964355,6.325317859649658,5.257739543914795,-1.8484746217727661,-1.9083495140075684,-3.9266719818115234,-2.6972978115081787,-1.9100816249847412,0.3864785432815552,0.41668975353240967,0.40104472637176514,0.48053038120269775,0.6176865100860596,0.6521654725074768,0.7338239550590515,-3.3441739082336426,-2.1296942234039307,12.634220123291016,12.610614776611328,12.92391586303711,13.389983177185059,13.368892669677734,13.349583625793457,13.468866348266602,13.621759414672852,13.584600448608398,13.713500022888184,13.654353141784668,13.54358196258545,13.485457420349121,13.071910858154297,-6.731809139251709,-6.759384632110596,-6.777331829071045,-6.763888835906982,-6.761543273925781,-6.804637908935547,-6.727742671966553,-6.834887981414795,-6.752458095550537,-6.775341510772705,-6.737644195556641,-6.581742286682129,-5.070720195770264,-4.919574737548828,-1.413554072380066,0.8580338954925537,0.8839700222015381,0.16463293135166168,0.08825581520795822,0.18411420285701752,0.12040848284959793,0.09830192476511002,0.4909278154373169,0.11569789797067642,-1.6163556575775146,-1.234993815422058,-1.9918675422668457,-2.903149127960205,-5.53862190246582,-5.560989856719971,-5.541922569274902,-5.524153232574463,-5.5480427742004395,-5.512906551361084,-5.546691417694092,-5.51990270614624,-5.442663192749023,-5.496433734893799,-5.472667217254639,-5.34009313583374,-5.31339693069458,-5.369527816772461,-6.028924942016602,-6.377921104431152,-2.0711638927459717,2.0353546142578125,-3.254293203353882,-3.2128872871398926,-3.228355646133423,-3.4332988262176514,-3.6969940662384033,-3.811028480529785,-3.806035280227661,-4.656887531280518,-4.89840030670166,-5.033349990844727,-5.047102928161621,-4.926907062530518,-4.92521858215332,-3.948962450027466,0.03613956272602081,0.44999054074287415,0.47881948947906494,0.4658748209476471,0.7699084281921387,0.5049037933349609,0.5224560499191284,0.476021409034729,0.49211615324020386,0.2582051455974579,6.311737537384033,8.509772300720215,8.327455520629883,7.1117963790893555,6.754592418670654,4.587578773498535,3.204420804977417,2.0934925079345703,1.9600067138671875,4.613533973693848,7.861444473266602,12.545653343200684,12.729918479919434,11.324885368347168,7.19051456451416,7.250730037689209,7.2803955078125,7.851572513580322,8.007347106933594,10.223807334899902,10.018296241760254,9.793991088867188,8.409509658813477,6.711997985839844,6.691405773162842,6.531256198883057,6.625380516052246,6.366235733032227,-3.7102813720703125,-3.7186992168426514,-3.67923641204834,-3.362048387527466,-3.2984871864318848,-3.3827741146087646,-3.38283371925354,-3.2902517318725586,-3.1040687561035156,-2.612083911895752,-3.5112221240997314,-3.7276949882507324,-3.8342490196228027,-3.918381452560425,-3.9989068508148193,-4.0030412673950195,-3.9742937088012695,-3.982508659362793,-4.003104209899902,-3.9609568119049072,-3.964921712875366,-4.015931129455566,-4.026318550109863,-4.025062084197998,-4.126623153686523,-4.4634480476379395,-4.471454620361328,-5.012289047241211,-6.367954730987549,-6.448171138763428,-6.135648727416992,-6.072615146636963,-6.078064918518066,-6.089817047119141,-6.044857978820801,-6.068305015563965,-5.982119083404541,-5.964515686035156,-5.986304759979248,-6.006318092346191,-5.992976188659668,-6.095758438110352,-1.6912800073623657,-1.7212932109832764,-1.6844531297683716,-1.083070158958435,-1.1167041063308716,3.62949275970459,5.123484134674072,4.748922348022461,6.068819522857666,3.7846264839172363,3.293386220932007,3.8257663249969482,4.880908966064453,4.257372856140137,-5.3761115074157715,-5.3851118087768555,-5.358573913574219,-5.390020370483398,-5.3572096824646,-5.308926582336426,-5.336643695831299,-5.31265926361084,-5.352761268615723,-5.335284233093262,-5.381870269775391,-5.431971073150635,-5.82565450668335,-5.841372966766357,-6.912420749664307,-6.907778739929199,-6.96973991394043,-7.213078022003174,-7.260746955871582,-7.346990585327148,-7.219901084899902,-7.11570405960083,-7.098415374755859,-7.110302448272705,-7.12285041809082,-7.181497573852539,-7.08335018157959,-7.078951358795166,-2.087297201156616,-2.028599739074707,-2.0842621326446533,-2.0344765186309814,-1.9299503564834595,-1.8867334127426147,-1.8987128734588623,-2.008744955062866,-1.9279426336288452,-1.246658205986023,0.12648905813694,-0.5780211091041565,-0.5143536329269409,-1.243323564529419,12.188944816589355,12.281289100646973,12.335935592651367,11.5735445022583,11.548578262329102,12.096848487854004,12.018861770629883,11.673894882202148,11.56513786315918,11.648265838623047,11.748254776000977,12.054556846618652,11.796298027038574,11.735113143920898,-6.89536714553833,-6.94333553314209,-6.931373596191406,-6.991498947143555,-6.987618923187256,-6.932015419006348,-6.955882549285889,-6.973082065582275,-6.9810004234313965,-7.004889488220215,-6.981087684631348,-7.018087863922119,-7.027026176452637,-7.016550540924072,-5.340170860290527,-5.3618340492248535,-5.324463844299316,-5.596944332122803,-5.6061320304870605,-5.651021957397461,-5.659907341003418,-5.651897430419922,-6.0332207679748535,-5.603250503540039,-5.781381607055664,-5.678779602050781,-5.65985107421875,-5.621301651000977,-0.431512713432312,0.1281423568725586,0.11246678233146667,-1.1083714962005615,-1.099137783050537,-1.1507681608200073,-1.1420999765396118,-1.0432651042938232,-1.4007658958435059,-1.3967323303222656,-1.3536776304244995,-1.146541953086853,-1.1436846256256104,-1.1906235218048096,-7.111681938171387,-7.10623836517334,-7.0952959060668945,-7.162799835205078,-7.114315032958984,-7.146265029907227,-7.140781402587891,-7.317835330963135,-7.202087879180908,-7.114156723022461,-7.052475452423096,-7.079197406768799,-7.053823947906494,-6.963377952575684,14.963981628417969,15.078128814697266,15.09696102142334,14.591474533081055,14.63608455657959,14.546372413635254,14.534890174865723,14.555292129516602,14.483229637145996,14.689957618713379,14.664216041564941,14.821575164794922,14.45028305053711,14.786303520202637,-6.503939628601074,-7.027166366577148,-7.138845920562744,-7.106588840484619,-7.075862884521484,-6.829762935638428,-6.772193431854248,-6.770997047424316,-6.6891255378723145,-6.704897880554199,-6.6755757331848145,-6.7015252113342285,-6.67310905456543,-6.649890422821045,9.969108581542969,9.962525367736816,9.966401100158691,9.961557388305664,9.970050811767578,9.935249328613281,9.967818260192871,9.963934898376465,9.96965217590332,9.961353302001953,9.983110427856445,9.990734100341797,9.964274406433105,9.959087371826172,15.802862167358398,15.847734451293945,15.77974796295166,15.857463836669922,15.901933670043945,15.89289665222168,15.887481689453125,15.879654884338379,15.866942405700684,15.896011352539063,15.7700777053833,15.799676895141602,15.866479873657227,15.64475154876709,3.4994776248931885,3.5371153354644775,3.495609760284424,3.105104446411133,3.102435827255249,2.8127453327178955,2.8510682582855225,2.688473701477051,1.810564637184143,1.9039969444274902,1.952426791191101,1.8227685689926147,1.8791333436965942,1.8268626928329468,8.700580596923828,8.630455017089844,8.535778045654297,8.447826385498047,8.673860549926758,8.613057136535645,8.647948265075684,7.689252853393555,7.414636611938477,7.3423614501953125,7.290661811828613,8.612969398498535,10.725366592407227,8.558579444885254,0.12253808975219727,0.6242090463638306,0.5958845615386963,2.0038275718688965,1.9960377216339111,-0.40429508686065674,-0.5964682698249817,-1.2181411981582642,-2.0369176864624023,-3.4302191734313965,-3.702153444290161,-3.679612874984741,-3.7179646492004395,-3.7905194759368896,14.378571510314941,14.492719650268555,14.50130844116211,13.868236541748047,13.883661270141602,13.733635902404785,12.76954460144043,12.076244354248047,12.113689422607422,12.137179374694824,12.785393714904785,12.424805641174316,11.963142395019531,11.808371543884277,-6.716190338134766,-6.664401054382324,-6.657448768615723,-6.71442174911499,-6.727630138397217,-6.704219341278076,-6.738394737243652,-6.715744972229004,-6.6499857902526855,-6.57301664352417,-6.585914611816406,-6.542165279388428,-6.552123546600342,-6.576761722564697,14.45451545715332,14.465051651000977,14.4047269821167,14.48070240020752,14.446260452270508,14.48126220703125,14.409429550170898,14.249691009521484,14.158190727233887,14.094779014587402,13.46533489227295,12.775357246398926,12.409101486206055,12.238717079162598,15.576396942138672,15.698225975036621,15.704841613769531,15.275885581970215,15.01606559753418,15.012222290039063,14.967669486999512,14.302968978881836,13.848492622375488,13.694293022155762,13.86545181274414,13.588464736938477,15.02458381652832,15.408825874328613,15.123666763305664,15.164170265197754,15.167149543762207,15.147866249084473,15.150400161743164,15.15379524230957,15.168850898742676,15.18288803100586,15.145709991455078,15.177929878234863,15.189321517944336,15.214753150939941,15.185325622558594,15.157848358154297,-7.341972827911377,-7.3149094581604,-7.3579816818237305,-7.315357208251953,-7.330005168914795,-7.328421115875244,-7.369065761566162,-7.368858337402344,-7.380053520202637,-7.350998878479004,-7.341800689697266,-7.337003231048584,-7.33686637878418,-7.367099761962891,15.964041709899902,15.982754707336426,16.00419044494629,16.01335334777832,16.1097354888916,16.121295928955078,15.99134635925293,16.053070068359375,15.98133659362793,16.087003707885742,16.121702194213867,16.1549129486084,16.16233253479004,16.159305572509766,-5.864733695983887,-5.784502983093262,-5.9127702713012695,-5.919260025024414,-5.141327381134033,-1.9955641031265259,-1.9762870073318481,-1.9589673280715942,-1.964792013168335,-2.0316953659057617,-1.9963380098342896,-1.9045826196670532,-1.830021858215332,1.5108214616775513,16.202281951904297,16.24178123474121,16.190717697143555,16.202280044555664,16.20738410949707,15.7258939743042,15.665873527526855,15.774577140808105,15.982975006103516,15.976617813110352,15.976455688476563,15.888435363769531,15.837811470031738,15.640596389770508,15.772380828857422,15.79023265838623,15.724995613098145,15.488821029663086,15.521479606628418,14.660701751708984,14.618027687072754,14.576737403869629,14.652730941772461,14.564160346984863,13.657279968261719,12.748924255371094,12.438141822814941,12.10817813873291,3.6556639671325684,3.6420705318450928,3.730922222137451,4.570677757263184,4.564765930175781,6.2471466064453125,6.530510425567627,6.579002857208252,6.524097442626953,5.967146873474121,3.7008376121520996,2.4272124767303467,1.8499025106430054,1.7539418935775757,-0.182831808924675,-0.19635456800460815,-0.16251933574676514,-0.12146054953336716,-0.13141348958015442,-0.05681696906685829,-0.029153428971767426,0.015385287813842297,0.01726529188454151,0.007903046905994415,-2.550300359725952,-6.398587226867676,-6.434453964233398,-6.462839126586914,14.6196870803833,14.63070011138916,14.61967658996582,14.508377075195313,14.551288604736328,14.491418838500977,14.552331924438477,14.507095336914063,14.632922172546387,14.544356346130371,14.608231544494629,14.200216293334961,14.157722473144531,14.34675121307373,12.069329261779785,12.100855827331543,12.049235343933105,11.862353324890137,11.888063430786133,11.851048469543457,11.63969898223877,10.910688400268555,10.51968765258789,10.644229888916016,11.45478343963623,11.935770034790039,11.722612380981445,11.315763473510742,0.020030496641993523,-0.003388208569958806,0.012539585120975971,0.012380760163068771,0.019504159688949585,0.017232459038496017,0.01996210217475891,-0.03895673155784607,0.05582081526517868,0.025882773101329803,0.04294711723923683,0.04230142757296562,0.03252413868904114,0.0035558089148253202,14.950309753417969,14.85740852355957,14.83087158203125,14.741860389709473,14.43778133392334,14.537304878234863,14.311192512512207,14.211453437805176,14.202384948730469,14.18676471710205,14.19034194946289,14.104917526245117,14.124616622924805,14.091976165771484,14.709359169006348,14.725569725036621,14.714618682861328,14.75244426727295,14.779654502868652,14.686820983886719,14.686371803283691,14.684429168701172,14.832513809204102,14.709219932556152,14.894255638122559,14.861784934997559,15.317638397216797,15.376365661621094,2.907942771911621,1.2989529371261597,0.839287519454956,0.23764973878860474,0.28767284750938416,0.1463269740343094,0.1684345006942749,3.488159656524658,4.326313495635986,4.792316436767578,4.632476329803467,4.389673709869385,3.450591564178467,3.518782377243042,-1.9685708284378052,-2.0008440017700195,-2.024972915649414,-2.051503896713257,-2.0019969940185547,-2.0149824619293213,-1.989119052886963,-2.023864269256592,0.1324668973684311,0.9871688485145569,-0.07814499735832214,-0.0791965126991272,0.21705414354801178,1.770558476448059,13.112075805664063,13.16821002960205,13.138388633728027,12.640249252319336,12.44033145904541,12.567895889282227,12.536283493041992,12.475736618041992,12.414680480957031,12.508401870727539,12.632226943969727,12.753851890563965,12.796245574951172,12.739068984985352,12.0018310546875,11.936267852783203,11.982380867004395,11.715271949768066,10.668220520019531,11.499520301818848,11.460821151733398,11.509615898132324,11.519521713256836,9.245840072631836,3.405524730682373,2.7516844272613525,1.9415818452835083,1.2457681894302368,2.158200740814209,2.17863130569458,2.1586532592773438,1.4017502069473267,1.269936442375183,1.262938141822815,1.2009974718093872,1.1202095746994019,1.1678510904312134,0.9700085520744324,1.3308990001678467,2.0272297859191895,1.8778880834579468,4.748766899108887,15.328893661499023,15.152088165283203,15.231963157653809,15.174674034118652,15.147010803222656,15.167092323303223,15.193522453308105,15.116861343383789,15.164681434631348,15.20091724395752,15.20997142791748,15.208133697509766,15.39093017578125,15.487689018249512,15.98737621307373,16.05033302307129,16.04758644104004,16.17833137512207,16.148529052734375,16.129179000854492,16.132667541503906,16.181970596313477,16.1345272064209,16.188920974731445,15.964485168457031,15.998345375061035,15.998001098632813,15.995794296264648,-6.097485542297363,-5.136034965515137,-5.072509288787842,-5.065978050231934,-5.0777482986450195,-5.073619842529297,-5.088473320007324,-5.073403358459473,-5.0629119873046875,-5.075857162475586,-5.079188823699951,-5.062787055969238,-5.088901519775391,-5.078052997589111,6.805514812469482,6.931569576263428,6.041346549987793,4.307290077209473,4.449863433837891,4.404728889465332,4.383316993713379,4.4002909660339355,4.393424034118652,4.404141426086426,4.269609451293945,4.37037467956543,4.289398193359375,4.138801574707031,8.580155372619629,8.597107887268066,8.3525390625,8.553281784057617,8.59603500366211,10.806797981262207,11.867398262023926,8.294646263122559,7.833921432495117,12.378045082092285,13.639208793640137,12.656383514404297,8.711469650268555,7.9216766357421875,8.333491325378418,8.332679748535156,8.287225723266602,8.339424133300781,8.388177871704102,8.70511245727539,8.378819465637207,8.217655181884766,8.184332847595215,9.421951293945313,8.90633773803711,8.766136169433594,8.410914421081543,8.338644981384277,-6.240470886230469,-6.241642475128174,-6.244183540344238,-6.227850437164307,-6.239161014556885,-6.230904579162598,-6.238260746002197,-6.234978199005127,-6.231835842132568,-6.239360809326172,-6.227789402008057,-6.242758274078369,-6.238036632537842,-6.224106311798096,6.72617244720459,6.779256343841553,6.155978679656982,2.1728272438049316,0.82786625623703,0.28722402453422546,0.05913903936743736,-1.1361253261566162,-1.3724534511566162,-1.2299890518188477,-1.6182094812393188,-1.8230993747711182,-1.515299677848816,-1.4579848051071167,0.5064374804496765,0.5413359999656677,0.5494627356529236,0.564379096031189,0.5856820940971375,0.784572958946228,4.512526512145996,4.744156837463379,4.871070384979248,5.025162696838379,5.828237056732178,9.883402824401855,9.92921257019043,9.967571258544922,-3.2269670963287354,-3.2293827533721924,-3.229729175567627,-3.226977825164795,-3.242020606994629,-3.232992172241211,-3.234253406524658,-3.230581760406494,-3.217639207839966,-3.2292590141296387,-3.230276107788086,-3.212650775909424,-3.216313600540161,-3.2185444831848145,13.984323501586914,13.998564720153809,13.947300910949707,13.912470817565918,13.943912506103516,13.966004371643066,13.979029655456543,14.036648750305176,13.775461196899414,14.125944137573242,14.494950294494629,14.568302154541016,14.636107444763184,14.190987586975098,14.554347038269043,14.549592971801758,14.380106925964355,14.156084060668945,14.19827651977539,14.257166862487793,14.184253692626953,14.462383270263672,14.285562515258789,14.099475860595703,12.9139986038208,11.790255546569824,14.076238632202148,12.765487670898438,2.8714146614074707,3.044956684112549,3.026444435119629,2.929399251937866,3.1019818782806396,3.3115758895874023,3.821242570877075,4.780052661895752,4.79233980178833,5.4163384437561035,5.192018032073975,5.2190117835998535,5.290478706359863,5.422401428222656,10.103861808776855,10.11899185180664,10.15460205078125,10.212926864624023,10.225719451904297,10.26926326751709,11.777910232543945,12.071220397949219,11.93193531036377,11.58919906616211,11.349998474121094,11.995144844055176,12.149778366088867,12.64456844329834,-6.419689655303955,-6.456295013427734,-6.466224670410156,-6.480062484741211,-6.500096321105957,-6.483839988708496,-6.493753433227539,-6.484095096588135,-6.480983257293701,-6.492065906524658,-6.483508110046387,-6.498222827911377,-6.489719390869141,-6.481450080871582,13.548943519592285,12.760993957519531,12.632413864135742,9.899267196655273,8.009255409240723,6.5400309562683105,6.59993314743042,3.908900499343872,1.5342384576797485,1.2956628799438477,1.1843392848968506,0.9957886338233948,0.7835195660591125,0.18275848031044006,-1.9384920597076416,-1.7694257497787476,-1.7506859302520752,-1.7583664655685425,-1.7769696712493896,-2.1134259700775146,-2.5278003215789795,-2.532616376876831,-2.5082900524139404,-2.5015950202941895,-2.507349729537964,-2.442174196243286,-2.4479763507843018,-2.4612417221069336],\n",
       "\"second_dim\":[12.239229202270508,12.19738483428955,12.205506324768066,12.486579895019531,12.543935775756836,12.303491592407227,12.302408218383789,12.233152389526367,12.120522499084473,12.143555641174316,12.22417163848877,12.002351760864258,11.77415657043457,11.409618377685547,10.539080619812012,10.646450996398926,10.672619819641113,10.715608596801758,10.7188138961792,10.650867462158203,10.568246841430664,10.685794830322266,10.80347728729248,11.63020133972168,10.721901893615723,10.674397468566895,10.34620189666748,10.706266403198242,3.2613189220428467,3.324535608291626,3.3412089347839355,3.3319966793060303,3.3686234951019287,3.383913040161133,3.4273993968963623,3.4058547019958496,3.3834095001220703,3.4697158336639404,3.5205636024475098,3.5011045932769775,3.540433883666992,4.842382907867432,2.6954593658447266,2.688415765762329,2.688646078109741,2.7025885581970215,2.6804771423339844,2.6390373706817627,2.6385302543640137,2.644833564758301,2.6644043922424316,2.6291263103485107,2.6990504264831543,2.6983768939971924,2.6976404190063477,2.717902660369873,10.897307395935059,10.883930206298828,10.89858341217041,10.944842338562012,10.914365768432617,10.92410659790039,10.926554679870605,10.944134712219238,11.05286693572998,10.900697708129883,10.9080171585083,13.142121315002441,13.134966850280762,13.151617050170898,9.953371047973633,10.011451721191406,9.940591812133789,10.286866188049316,10.461904525756836,10.447131156921387,10.428471565246582,10.745149612426758,10.735970497131348,11.577363014221191,11.628600120544434,11.586548805236816,11.705406188964844,12.352238655090332,7.576970100402832,7.602458953857422,7.658135414123535,8.643349647521973,8.64657211303711,8.658365249633789,8.667988777160645,8.672257423400879,8.522689819335938,8.574679374694824,8.554909706115723,8.771864891052246,8.837613105773926,8.79123592376709,0.15915928781032562,3.8824145793914795,5.624993324279785,7.063607215881348,7.214493751525879,7.371467590332031,8.465448379516602,8.551470756530762,8.4673433303833,9.229093551635742,9.23790454864502,0.17608295381069183,0.01319568045437336,-0.2309040129184723,5.6930999755859375,5.593808174133301,5.1533331871032715,4.992671012878418,4.444626331329346,4.414290428161621,4.352471828460693,4.382176399230957,4.392239570617676,4.385006427764893,4.660684108734131,4.10032320022583,2.9984536170959473,2.8927252292633057,13.016292572021484,13.053802490234375,13.098612785339355,12.916016578674316,12.957945823669434,12.940469741821289,12.939098358154297,12.990826606750488,12.89660358428955,12.786322593688965,13.041023254394531,12.96817398071289,12.853323936462402,12.434331893920898,2.1759562492370605,2.0727715492248535,5.639089584350586,1.5569548606872559,0.43440917134284973,1.1136244535446167,1.4498494863510132,1.483269214630127,1.4663008451461792,1.6116365194320679,1.5999881029129028,1.579692006111145,1.6234753131866455,1.7475508451461792,5.64959716796875,6.203574180603027,6.597209453582764,6.283158302307129,5.48418664932251,0.9190343022346497,-0.31570562720298767,-0.31550154089927673,-0.28850701451301575,-0.287863165140152,-0.3385125398635864,-0.2858288288116455,-0.2927773594856262,-0.18512123823165894,12.516258239746094,12.124238014221191,12.261591911315918,12.181356430053711,12.08103084564209,12.00306224822998,11.86291217803955,11.880105018615723,11.968351364135742,12.173480987548828,12.250555992126465,12.178070068359375,11.819259643554688,11.763940811157227,4.327601909637451,4.395301342010498,4.722525596618652,4.806029796600342,5.260066509246826,6.191152572631836,11.336666107177734,11.947783470153809,12.02833366394043,12.066985130310059,12.467109680175781,12.573744773864746,12.697479248046875,12.732365608215332,5.731529235839844,5.672969341278076,5.6972174644470215,5.593683242797852,5.766610622406006,6.165571212768555,9.796130180358887,10.172895431518555,10.74988079071045,12.182562828063965,11.965877532958984,12.286513328552246,12.086979866027832,9.122550010681152,3.744283437728882,3.8556320667266846,3.829606533050537,3.7244410514831543,3.7604429721832275,3.7018468379974365,4.248239994049072,7.355908393859863,7.625125408172607,7.7679033279418945,7.944545745849609,7.429574489593506,7.246430397033691,6.978190898895264,3.8497581481933594,4.280918121337891,4.326165199279785,4.937716960906982,4.888950347900391,4.764831066131592,4.8572211265563965,4.272110462188721,4.565094470977783,5.67344856262207,5.887895107269287,5.628171443939209,7.691071033477783,7.842894077301025,12.415616989135742,12.374735832214355,12.360419273376465,12.420680046081543,12.17766284942627,12.17131233215332,12.132756233215332,12.163849830627441,12.211173057556152,12.609405517578125,11.317748069763184,7.5655341148376465,7.313594818115234,7.290412902832031,7.671963691711426,7.578856468200684,7.5713043212890625,6.665128707885742,4.774744987487793,4.6665143966674805,4.706911087036133,4.62660551071167,4.380463123321533,4.267551422119141,4.388260364532471,4.290510654449463,4.345427989959717,4.348435878753662,11.981904983520508,11.96693229675293,11.949590682983398,12.018133163452148,11.963262557983398,11.988380432128906,11.978775024414063,11.997316360473633,11.83431625366211,10.447221755981445,7.4868574142456055,11.870616912841797,11.7781400680542,11.797879219055176,9.271429061889648,8.85010051727295,8.978976249694824,8.866915702819824,8.847865104675293,8.479973793029785,8.388627052307129,8.487953186035156,8.642707824707031,8.317838668823242,7.084024906158447,6.494972229003906,2.2104101181030273,2.2533655166625977,8.925140380859375,9.232721328735352,9.103927612304688,9.255972862243652,10.027711868286133,9.346951484680176,9.556065559387207,9.111268997192383,7.922583103179932,8.011515617370605,8.137118339538574,8.67839241027832,12.19975471496582,12.401598930358887,12.203834533691406,12.230725288391113,7.855175495147705,6.915899753570557,11.458980560302734,11.86681842803955,11.838303565979004,11.415903091430664,11.253942489624023,11.33652400970459,7.912098407745361,4.918413162231445,4.703334331512451,4.519041061401367,10.322532653808594,10.335111618041992,10.323989868164063,10.384442329406738,10.380036354064941,9.93341064453125,9.331345558166504,9.223432540893555,8.754659652709961,8.054559707641602,8.595736503601074,8.737091064453125,8.329440116882324,7.1254801750183105,8.76684856414795,8.087362289428711,7.8292236328125,8.057857513427734,8.058125495910645,8.148697853088379,9.230229377746582,9.129128456115723,7.760463237762451,8.054677963256836,7.71456241607666,9.514068603515625,10.108752250671387,11.772961616516113,12.51668643951416,12.416765213012695,12.376677513122559,11.772056579589844,11.780936241149902,11.781455039978027,11.712206840515137,11.993205070495605,11.966044425964355,11.66323184967041,11.65053653717041,11.691011428833008,12.085504531860352,12.518353462219238,2.014610767364502,1.9000048637390137,0.8774996995925903,0.6659963726997375,0.8243122696876526,0.37437376379966736,0.2390720397233963,0.15397058427333832,0.5318935513496399,0.8553022146224976,-0.36053988337516785,-0.38061192631721497,0.45459291338920593,2.597890853881836,2.491091251373291,2.501169443130493,1.8880667686462402,1.8644112348556519,2.1838910579681396,2.276750087738037,2.421837091445923,2.350400447845459,2.8652470111846924,0.729118824005127,0.5700590014457703,0.7231132984161377,0.4038727283477783,2.7349531650543213,2.7251834869384766,2.7281477451324463,2.741365671157837,2.6857049465179443,2.7204692363739014,2.7356889247894287,2.7069339752197266,2.7417590618133545,4.389512538909912,4.354379653930664,2.8088014125823975,2.7325363159179688,2.728619337081909,7.097487926483154,7.110280990600586,7.130366802215576,7.140054702758789,7.148940563201904,7.170021057128906,6.878543853759766,6.908076763153076,6.87589168548584,6.541549205780029,6.718249320983887,-0.26267579197883606,-2.526918411254883,-2.5394339561462402,9.961653709411621,9.898808479309082,9.773015975952148,9.693431854248047,9.672051429748535,9.776719093322754,10.226938247680664,10.29094123840332,9.675220489501953,9.774900436401367,9.085739135742188,9.16335391998291,8.69680118560791,8.294862747192383,2.4124324321746826,2.406808614730835,2.4168238639831543,2.3845136165618896,2.402170419692993,2.4184916019439697,2.4021804332733154,2.398590564727783,5.347474098205566,6.324189186096191,6.299178600311279,5.504289627075195,5.614634037017822,4.955044746398926,12.024032592773438,12.103202819824219,12.074597358703613,12.329787254333496,12.767881393432617,12.98112678527832,12.65648365020752,11.86719036102295,11.733503341674805,10.884580612182617,9.195942878723145,9.458122253417969,9.136683464050293,8.588857650756836,11.266448020935059,11.321666717529297,11.349377632141113,12.584644317626953,12.624696731567383,12.626614570617676,12.637103080749512,12.57903003692627,12.362434387207031,12.378023147583008,12.415510177612305,12.746769905090332,12.812192916870117,13.032094955444336,-1.6499074697494507,-1.6354373693466187,-1.663206696510315,-1.6647509336471558,-1.647972822189331,-1.649718999862671,-1.6578621864318848,-1.6443212032318115,-1.6809226274490356,-1.655787706375122,-1.662676215171814,-1.6497783660888672,-1.6423943042755127,-1.6466559171676636,9.901421546936035,9.853530883789063,10.221128463745117,11.405529975891113,11.499287605285645,11.538752555847168,11.047470092773438,6.461877346038818,6.334039211273193,7.191958427429199,6.921319007873535,7.043134689331055,8.577387809753418,11.575124740600586,12.240299224853516,11.86126708984375,11.968144416809082,11.695576667785645,12.781670570373535,12.783289909362793,12.549260139465332,12.408462524414063,12.3427734375,12.307312965393066,12.352887153625488,12.35078239440918,12.419239044189453,12.333803176879883,10.514328956604004,10.66649055480957,10.660294532775879,10.793546676635742,10.775766372680664,10.735614776611328,10.726993560791016,10.71407413482666,10.214499473571777,9.115721702575684,9.102088928222656,9.055875778198242,8.541951179504395,7.68233585357666,10.740935325622559,11.780682563781738,11.822742462158203,12.105737686157227,12.25460147857666,12.423720359802246,12.280194282531738,12.247597694396973,12.303539276123047,11.832853317260742,11.783034324645996,11.139129638671875,11.23909854888916,11.282297134399414,12.523300170898438,12.656298637390137,12.693371772766113,12.646484375,12.589211463928223,12.613245964050293,11.820531845092773,11.650473594665527,11.175162315368652,10.348552703857422,10.254386901855469,10.142585754394531,10.221973419189453,10.285776138305664,12.193639755249023,12.272634506225586,12.28111743927002,12.250541687011719,12.177010536193848,12.017398834228516,11.145042419433594,11.031096458435059,10.896321296691895,10.790433883666992,10.873620986938477,10.825475692749023,11.069621086120605,11.316031455993652,7.718632698059082,7.715031147003174,7.743693828582764,7.767632961273193,7.793424129486084,7.84623908996582,6.690586090087891,6.716658115386963,5.961568832397461,6.518684387207031,7.412006855010986,7.565176010131836,6.502771377563477,6.543853759765625,10.824431419372559,11.318965911865234,12.106498718261719,11.009134292602539,1.4557393789291382,1.3497101068496704,1.362298846244812,1.1441346406936646,1.4731262922286987,2.1749672889709473,2.109649658203125,2.13580060005188,2.1785566806793213,5.183347702026367,7.200799465179443,7.179186820983887,7.148934364318848,7.017189979553223,6.951542854309082,6.90859842300415,6.278071403503418,6.222721099853516,6.224914073944092,6.1067962646484375,5.8830885887146,5.287836074829102,5.260323524475098,5.222057819366455,8.169966697692871,8.18274974822998,7.972496509552002,5.932605743408203,5.873403072357178,5.809662342071533,5.663538932800293,4.373676300048828,3.2430641651153564,3.1800034046173096,3.198060989379883,3.237257242202759,3.0986828804016113,3.1813809871673584,12.563385963439941,12.771883010864258,12.702792167663574,12.729193687438965,12.740774154663086,12.286401748657227,11.586836814880371,11.526817321777344,12.681927680969238,11.246573448181152,9.10143756866455,8.928459167480469,10.400623321533203,11.01889419555664,12.908523559570313,12.881767272949219,12.922163009643555,13.209497451782227,13.215147018432617,13.22145938873291,13.187026023864746,13.209120750427246,13.253665924072266,12.900983810424805,12.906371116638184,13.228804588317871,13.084636688232422,13.006708145141602,11.9462890625,12.048676490783691,11.987823486328125,12.625005722045898,12.893609046936035,9.056830406188965,12.363065719604492,12.308204650878906,12.334674835205078,12.363536834716797,12.345666885375977,12.926974296569824,5.508957386016846,2.2256345748901367,5.660626411437988,5.657184600830078,5.628805160522461,5.448876857757568,5.488924503326416,5.411311626434326,4.989630222320557,3.7084641456604004,2.9902963638305664,2.955275297164917,2.9544007778167725,2.9438529014587402,2.9340784549713135,2.9174013137817383,11.952256202697754,11.977105140686035,12.040226936340332,11.99802303314209,12.053764343261719,12.124261856079102,12.291499137878418,12.465895652770996,12.581808090209961,12.573162078857422,12.441734313964844,12.389826774597168,12.303147315979004,11.835165023803711,10.476521492004395,10.450263977050781,10.494449615478516,10.508077621459961,10.497133255004883,10.700438499450684,10.429963111877441,9.177850723266602,8.9376802444458,8.578729629516602,7.647871494293213,7.899991512298584,7.663668632507324,7.285606384277344,12.825641632080078,12.902061462402344,8.566926002502441,5.213491439819336,13.108746528625488,13.075267791748047,13.053675651550293,12.235020637512207,12.535106658935547,12.660005569458008,12.667532920837402,12.718589782714844,12.501975059509277,12.010934829711914,8.407463073730469,8.285661697387695,7.404653549194336,5.891716003417969,5.872267723083496,5.823588848114014,5.664468288421631,5.192133903503418,2.964897871017456,2.937384843826294,2.870457172393799,2.5367209911346436,0.7713019251823425,0.6783817410469055,5.975598335266113,12.162452697753906,12.273487091064453,12.19262409210205,12.223297119140625,12.271662712097168,12.972600936889648,12.903074264526367,12.671430587768555,12.485875129699707,12.41818618774414,12.45654296875,12.249713897705078,9.247359275817871,12.50393009185791,12.52553939819336,12.520535469055176,11.914101600646973,11.849123001098633,11.426289558410645,9.356032371520996,7.021580696105957,7.465975284576416,7.3259782791137695,7.041502952575684,10.598166465759277,12.752519607543945,12.63628101348877,5.82182502746582,5.760375499725342,5.716759204864502,6.192439556121826,6.245770454406738,6.252871036529541,6.204929351806641,6.2827558517456055,6.323474884033203,6.229991912841797,6.074219703674316,6.103527545928955,5.991683006286621,5.916755199432373,4.467896938323975,5.879565715789795,5.898497104644775,5.9075703620910645,7.450562000274658,7.485675811767578,7.4432196617126465,7.315741539001465,7.347232341766357,7.167921543121338,5.766025543212891,4.77036714553833,3.210181951522827,2.9141652584075928,10.537039756774902,10.467427253723145,11.144590377807617,11.013932228088379,11.061249732971191,11.161284446716309,11.78589153289795,11.80610466003418,11.813305854797363,11.609241485595703,11.201916694641113,9.906594276428223,9.993546485900879,9.991130828857422,8.62533950805664,8.5372896194458,8.575247764587402,7.557434558868408,7.576653480529785,7.65458869934082,7.659132957458496,6.876837730407715,7.462850093841553,8.065033912658691,7.978377342224121,7.975402355194092,7.967896461486816,7.450780868530273,7.558945178985596,8.336633682250977,8.44234848022461,8.285408973693848,8.376518249511719,8.298105239868164,7.201113224029541,7.014742851257324,7.0735087394714355,6.570930480957031,6.8692216873168945,6.957902908325195,7.000521659851074,6.969208717346191,3.6431612968444824,3.5363800525665283,3.526689052581787,6.299369812011719,6.588967323303223,6.153318405151367,5.939208984375,5.1305928230285645,5.827560901641846,7.24395227432251,6.812386512756348,7.1814069747924805,6.481306552886963,5.702393054962158,11.482749938964844,11.501220703125,11.555963516235352,11.56265640258789,11.600253105163574,12.19044303894043,12.264739990234375,12.6853609085083,12.522497177124023,12.75574779510498,13.188179016113281,12.711457252502441,13.035299301147461,12.87270450592041,6.03278112411499,5.693965435028076,5.690892696380615,5.487307548522949,5.315159320831299,3.28416109085083,2.596656560897827,2.553264617919922,2.5352373123168945,2.6656486988067627,0.7134543061256409,0.9976726770401001,1.4299356937408447,1.0955722332000732,10.570757865905762,10.544281959533691,10.535296440124512,10.51501750946045,10.49118423461914,10.552188873291016,10.54041576385498,10.532797813415527,10.547505378723145,10.522878646850586,10.488053321838379,10.563010215759277,10.807022094726563,10.831032752990723,6.627541542053223,6.289409160614014,6.278353214263916,5.427724838256836,5.638422012329102,5.715115070343018,8.302778244018555,8.25828742980957,8.423974990844727,7.178578853607178,7.011017799377441,6.386850357055664,6.11169958114624,4.76369571685791,5.963082313537598,5.935111045837402,5.933691501617432,5.907546520233154,5.8978471755981445,5.861067771911621,5.869086742401123,5.881047248840332,6.6014723777771,7.824532508850098,7.268683910369873,7.041204929351807,7.076167106628418,7.0601935386657715,3.262535810470581,3.3018009662628174,3.2997360229492188,3.3644535541534424,3.4016025066375732,3.387035608291626,3.464144468307495,3.7006075382232666,4.150657653808594,3.951535940170288,3.901237726211548,4.0256667137146,6.056760787963867,5.993673324584961,13.036825180053711,13.08674144744873,13.079834938049316,13.04820442199707,13.071915626525879,13.013675689697266,12.924434661865234,12.49976921081543,12.348052978515625,12.46841812133789,12.368138313293457,12.32227611541748,12.214897155761719,12.180887222290039,11.757497787475586,11.779946327209473,11.794479370117188,11.401815414428711,11.345382690429688,11.364994049072266,11.390531539916992,11.82979679107666,12.114039421081543,12.303220748901367,12.283079147338867,12.3092622756958,12.030187606811523,12.003847122192383,4.392868995666504,4.404915809631348,4.387154579162598,4.444644451141357,4.512765884399414,4.821871757507324,4.979279041290283,5.1940693855285645,5.92468786239624,6.119954586029053,6.205636024475098,5.97559928894043,5.9915032386779785,5.982123851776123,3.507275104522705,3.5265326499938965,3.488830089569092,3.633289098739624,3.9554412364959717,4.079036712646484,4.102935314178467,4.03151273727417,4.93650484085083,4.878251552581787,5.1877121925354,5.860762119293213,6.138811111450195,6.076761245727539,12.679756164550781,12.641119003295898,12.432207107543945,12.8092679977417,12.872325897216797,12.81713581085205,12.78581428527832,12.851150512695313,12.753373146057129,12.74973201751709,12.65467643737793,11.987637519836426,11.053969383239746,10.976373672485352,1.0807218551635742,1.098974347114563,1.205228567123413,1.3806023597717285,1.4003037214279175,1.425362467765808,1.4297579526901245,1.4225953817367554,1.4388684034347534,1.4001502990722656,1.3016482591629028,0.82671719789505,0.3895224928855896,0.5147850513458252,9.242408752441406,9.223626136779785,9.236037254333496,8.984529495239258,8.683859825134277,8.484824180603027,8.61280632019043,8.047638893127441,8.530600547790527,8.352107048034668,7.639159679412842,7.644407272338867,7.552497863769531,7.471868515014648,4.4866228103637695,4.552282810211182,4.560788154602051,4.436064720153809,4.52612829208374,4.472971439361572,4.798121452331543,4.81483268737793,4.705276012420654,4.997006893157959,4.659501552581787,4.751919269561768,5.127669334411621,4.97450065612793,5.470801830291748,5.140397071838379,4.918339252471924,5.114270210266113,5.203011989593506,5.220508098602295,4.898182392120361,4.94768762588501,5.088325023651123,5.213826656341553,5.232792854309082,5.265117645263672,5.493927955627441,6.051176071166992,4.413975238800049,4.406452655792236,4.401584625244141,4.438063621520996,4.417722225189209,4.45270299911499,4.394540309906006,4.443772315979004,4.449190139770508,4.475286960601807,4.458907127380371,4.473671913146973,4.445457935333252,4.466397762298584,7.733494281768799,6.382258415222168,6.339922904968262,5.809417724609375,5.764009475708008,5.640322208404541,6.063322067260742,6.712316036224365,7.073904037475586,7.310608863830566,7.281204700469971,7.262650966644287,7.412582874298096,6.726451396942139,12.884702682495117,12.911818504333496,12.961539268493652,12.786946296691895,12.799734115600586,12.937358856201172,12.859739303588867,11.9782075881958,12.582427978515625,12.732706069946289,12.788360595703125,12.823309898376465,12.66606330871582,12.808183670043945,13.097671508789063,13.028999328613281,13.060235023498535,12.989455223083496,12.996695518493652,12.954451560974121,12.983856201171875,12.990336418151855,12.77258014678955,12.727035522460938,12.770191192626953,12.814802169799805,12.768583297729492,12.787190437316895,12.105278968811035,12.101531982421875,12.2291841506958,12.831274032592773,13.007144927978516,13.025445938110352,12.991074562072754,13.065221786499023,12.977936744689941,12.279997825622559,13.120794296264648,12.77888011932373,12.814855575561523,13.233938217163086,12.69898796081543,12.19688606262207,11.633941650390625,9.76925277709961,8.313724517822266,7.667862415313721,7.391735553741455,7.352514266967773,7.804929256439209,12.83676528930664,12.919270515441895,12.871906280517578,12.902676582336426,12.969731330871582,12.689420700073242,12.694265365600586,12.699440956115723,12.670244216918945,12.672408103942871,13.038504600524902,13.084749221801758,13.08504581451416,13.059245109558105,13.163531303405762,13.134591102600098,13.109956741333008,12.928923606872559,12.111701965332031,4.589547157287598,5.145299911499023,5.177181243896484,5.174872875213623,5.157116889953613,5.239598274230957,5.203310489654541,5.134352684020996,5.12043571472168,5.061565399169922,5.107562065124512,5.097071647644043,5.101945400238037,5.06699275970459,5.836242198944092,5.874494552612305,5.810838222503662,5.817889213562012,5.74055290222168,5.7632155418396,4.8997416496276855,5.040857791900635,5.048489570617676,6.436381816864014,6.546261310577393,6.546219348907471,6.727739334106445,6.720848083496094,11.588926315307617,11.609548568725586,11.58924674987793,11.570958137512207,11.616328239440918,11.57284164428711,11.577537536621094,11.66851806640625,11.75410270690918,11.780287742614746,11.728593826293945,11.73115348815918,11.772870063781738,11.758511543273926,11.550271987915039,11.495469093322754,11.271483421325684,11.254125595092773,11.270188331604004,11.192389488220215,11.212690353393555,11.195046424865723,11.332823753356934,11.333468437194824,11.313682556152344,11.357380867004395,11.609274864196777,11.836443901062012,-3.0226123332977295,-2.983720064163208,-3.0287892818450928,-3.0411829948425293,-3.0299527645111084,-3.056941032409668,-3.0513339042663574,-3.06548810005188,-3.046978712081909,-3.0465753078460693,-3.0253665447235107,-2.441598653793335,-2.4583616256713867,-2.4024930000305176,11.253631591796875,11.293314933776855,11.248126983642578,11.220479965209961,11.238125801086426,11.234672546386719,11.235093116760254,11.357706069946289,12.043092727661133,12.079445838928223,12.567583084106445,12.660544395446777,12.768895149230957,12.215906143188477,4.424138069152832,4.375175952911377,5.420914649963379,5.936280727386475,5.967523574829102,6.803763389587402,6.871549129486084,7.335832595825195,6.8649163246154785,5.869416236877441,5.815738677978516,6.958384990692139,6.519833087921143,7.327555179595947,-0.2204914093017578,-0.3301777243614197,-0.4078657925128937,-0.4357620179653168,-0.49085357785224915,-0.5164533257484436,-0.4949183464050293,-0.44597649574279785,-0.45605164766311646,-0.46669086813926697,-0.46546491980552673,-0.4659282863140106,-0.45957621932029724,-0.19300077855587006,3.099912643432617,6.8445024490356445,10.8218355178833,10.879298210144043,11.097602844238281,11.189801216125488,11.217655181884766,11.144071578979492,10.52383804321289,10.906533241271973,11.41999340057373,13.10258960723877,6.011316299438477,10.530789375305176,11.915096282958984,11.800597190856934,11.740743637084961,10.521413803100586,9.447179794311523,8.361140251159668,5.862420558929443,5.545842170715332,5.576181888580322,5.5481462478637695,5.508938789367676,5.366485595703125,5.280446529388428,5.255548477172852,10.207275390625,10.124658584594727,10.09708023071289,9.885276794433594,8.641921043395996,9.160721778869629,9.294679641723633,9.173352241516113,9.126968383789063,11.34316349029541,11.454670906066895,11.352704048156738,9.038357734680176,9.193819999694824,6.156999111175537,5.689602851867676,5.613529205322266,5.619696617126465,5.628312110900879,5.995279312133789,6.000556468963623,5.68010139465332,5.363913536071777,6.003364086151123,5.493937969207764,5.933557987213135,7.110906600952148,6.886473178863525,2.8353493213653564,2.872652530670166,2.884136438369751,2.876312255859375,2.871060609817505,3.0378365516662598,3.0473556518554688,3.1227638721466064,3.09071683883667,3.100341796875,4.625692367553711,5.075606822967529,6.065466403961182,5.52211332321167,6.203705787658691,6.184508323669434,6.190623760223389,6.0818257331848145,6.001764297485352,6.043710708618164,5.737612247467041,5.729119300842285,5.759460926055908,5.512518882751465,5.544214248657227,5.448335647583008,5.093019962310791,5.199552536010742,2.4750006198883057,5.609435558319092,5.614348888397217,5.642405986785889,5.663118362426758,5.669971466064453,5.657529830932617,5.719971179962158,6.128560543060303,6.113064765930176,6.045810699462891,6.009363651275635,6.065903663635254,6.063251495361328,6.713086128234863,6.755407333374023,7.1565022468566895,7.088954448699951,7.17215633392334,7.049877166748047,7.339910984039307,8.130208969116211,12.60416316986084,9.260969161987305,9.811777114868164,11.737565040588379,12.149797439575195,12.790483474731445,1.6535857915878296,1.587869644165039,1.5474599599838257,1.5462563037872314,1.1744056940078735,1.1283283233642578,1.3047385215759277,1.49175226688385,1.0926977396011353,1.1148169040679932,1.074109435081482,1.0970065593719482,0.7898048758506775,0.8177889585494995,2.385502576828003,2.2504773139953613,2.332767963409424,2.511434555053711,2.5233969688415527,2.7341721057891846,2.8819568157196045,2.8779306411743164,2.9164695739746094,2.9536995887756348,1.75236976146698,0.26539912819862366,0.30477601289749146,0.06653976440429688,6.290111064910889,6.313647747039795,6.352205276489258,6.297887802124023,6.33289909362793,6.3136982917785645,5.637515068054199,5.529947757720947,5.477843284606934,5.432582378387451,5.4456682205200195,5.47402286529541,5.589790344238281,5.517057418823242,4.716100215911865,4.627337455749512,4.633801460266113,4.646780967712402,4.527414321899414,4.579541206359863,4.640670299530029,4.471088886260986,4.472527503967285,4.507468223571777,4.510066509246826,0.7500976920127869,0.46441471576690674,0.6257563233375549,-1.7826857566833496,-1.7325063943862915,-1.7536956071853638,-1.8352819681167603,-1.8794384002685547,-1.8665108680725098,-1.8694919347763062,-1.8718585968017578,-1.846156120300293,-1.8727113008499146,-1.861944317817688,-1.8743082284927368,-1.8921104669570923,-1.8387094736099243,7.365223407745361,7.321146488189697,6.113134384155273,5.986874103546143,6.043429851531982,5.94689416885376,5.918703556060791,5.8858842849731445,5.969644069671631,7.0526862144470215,7.132383346557617,6.560969829559326,6.321574687957764,5.699217796325684,4.349002361297607,4.333930015563965,4.315732002258301,4.301960468292236,4.339919567108154,4.292880535125732,4.314889430999756,4.54503059387207,4.649451732635498,4.518913269042969,4.622092247009277,4.643551349639893,4.46291446685791,4.587428569793701,4.087100982666016,4.148116111755371,4.1335930824279785,4.114864826202393,4.101716041564941,4.103360652923584,4.102878093719482,4.1302971839904785,4.252216815948486,4.233145713806152,4.1612396240234375,4.1980695724487305,4.319833755493164,4.318064212799072,11.87130069732666,11.802587509155273,11.783522605895996,11.773599624633789,11.783121109008789,11.584141731262207,11.396150588989258,11.336496353149414,11.388651847839355,11.411405563354492,12.148077011108398,12.027240753173828,12.037652969360352,12.080146789550781,-2.6051883697509766,-2.592097282409668,-2.61771821975708,-2.5794734954833984,-2.5927093029022217,-2.605299234390259,-2.6027753353118896,-2.6372921466827393,-2.614748477935791,-2.5968220233917236,-2.6410505771636963,-2.611205816268921,-2.613137722015381,-2.615046262741089,7.912919044494629,7.947088241577148,8.001167297363281,8.07713508605957,8.04159164428711,8.000826835632324,8.143948554992676,8.695836067199707,8.138976097106934,8.07544231414795,8.03903865814209,7.908440113067627,7.833863735198975,6.0592145919799805,4.147266864776611,4.122514724731445,4.201124668121338,4.058514595031738,4.063046455383301,4.106771469116211,4.182417869567871,12.30579948425293,12.86548900604248,12.776398658752441,12.464737892150879,12.5737943649292,12.722097396850586,12.617321014404297,11.638906478881836,11.589021682739258,11.738590240478516,12.4243803024292,12.14073657989502,12.209847450256348,11.968198776245117,11.990324974060059,12.184925079345703,12.626465797424316,12.695916175842285,12.633384704589844,12.635029792785645,13.00851058959961,8.709922790527344,8.725509643554688,6.405631065368652,5.1517462730407715,8.69677734375,10.786787986755371,10.866551399230957,10.810187339782715,10.871495246887207,11.001749992370605,11.121504783630371,11.061264991760254,6.81053352355957,8.43667984008789,10.05955982208252,10.094141006469727,9.677377700805664,9.093375205993652,9.087372779846191,9.106322288513184,8.996420860290527,8.741076469421387,8.863205909729004,8.78526782989502,8.812231063842773,9.000747680664063,9.038487434387207,9.506685256958008,2.5584654808044434,2.5574777126312256,2.540311574935913,2.5222744941711426,2.5332682132720947,2.5802230834960938,2.561326742172241,2.60402512550354,2.555586099624634,2.58205246925354,2.5534145832061768,2.8212943077087402,5.402308464050293,5.501102447509766,8.304621696472168,11.1170654296875,11.0503511428833,10.768062591552734,10.78100299835205,10.786111831665039,10.701407432556152,10.695545196533203,11.208385467529297,10.801526069641113,8.401321411132813,8.927345275878906,8.275899887084961,7.073760509490967,0.5873392224311829,0.5838537812232971,0.5281967520713806,0.5070645809173584,0.49350592494010925,0.45511776208877563,0.5011411309242249,0.8635557889938354,0.8745989799499512,0.9777082800865173,0.8972880840301514,0.9994150400161743,1.0569676160812378,1.0193302631378174,-1.8706618547439575,0.8783784508705139,6.9399638175964355,11.287474632263184,5.231047630310059,5.290027618408203,5.284231662750244,5.118831634521484,4.999443054199219,5.026832580566406,4.951321601867676,4.003406524658203,3.642580986022949,3.3866989612579346,3.700697422027588,3.914072036743164,3.9138782024383545,4.746154308319092,9.687423706054688,10.101216316223145,10.117427825927734,10.099265098571777,10.35537052154541,10.166465759277344,10.17464542388916,10.11545467376709,10.141093254089355,9.979432106018066,12.818205833435059,12.290729522705078,12.356557846069336,12.599299430847168,12.68204116821289,13.183550834655762,12.922870635986328,12.419200897216797,12.282559394836426,12.591402053833008,12.142316818237305,9.60726547241211,9.550339698791504,10.790783882141113,12.714550971984863,12.693799018859863,12.684460639953613,12.565306663513184,12.530006408691406,11.654513359069824,11.702412605285645,11.809486389160156,12.567556381225586,12.793522834777832,12.84543228149414,12.866608619689941,12.813335418701172,13.069751739501953,4.957476615905762,4.923978805541992,4.973343372344971,5.131840229034424,5.174142360687256,5.076069355010986,5.0644330978393555,5.129640102386475,5.233729362487793,5.533318996429443,5.0536885261535645,4.963153839111328,4.837427139282227,4.846362590789795,4.441410541534424,4.443401336669922,4.41442346572876,4.4320783615112305,4.446834564208984,4.443362712860107,4.41636848449707,4.452415466308594,4.428314208984375,4.4327545166015625,4.389511585235596,4.189129829406738,4.132192134857178,3.7028450965881348,1.8975886106491089,2.048125982284546,1.6848516464233398,1.5868427753448486,1.610376000404358,1.6180475950241089,1.5615040063858032,1.6617168188095093,1.4530291557312012,1.400570034980774,1.4695038795471191,1.556214451789856,1.5246856212615967,1.6699368953704834,8.332176208496094,8.274884223937988,8.394207000732422,9.027170181274414,8.989831924438477,12.407228469848633,12.599246978759766,12.663209915161133,12.757621765136719,12.967543601989746,12.091078758239746,12.455817222595215,12.869998931884766,12.779800415039063,0.9746586084365845,0.949379563331604,0.9636249542236328,0.9502428770065308,0.9648832082748413,0.9996919631958008,1.0175020694732666,0.9542116522789001,1.0139435529708862,1.0761067867279053,1.035106897354126,0.9021778106689453,1.030898928642273,1.1102473735809326,1.8471932411193848,1.84000563621521,1.721474528312683,1.0471924543380737,0.9959229826927185,0.499187171459198,0.24867279827594757,0.23847264051437378,0.19162443280220032,0.13319708406925201,0.2848580777645111,0.2866221070289612,0.15502506494522095,0.21278037130832672,8.476105690002441,8.543471336364746,8.508100509643555,8.624910354614258,8.715421676635742,8.70862865447998,8.710811614990234,8.632918357849121,8.662090301513672,8.36023235321045,9.892180442810059,8.986007690429688,9.031042098999023,8.419673919677734,10.528254508972168,10.456554412841797,10.481337547302246,10.785680770874023,10.819765090942383,10.492775917053223,10.602313995361328,10.681720733642578,10.761479377746582,10.765108108520508,10.649347305297852,10.525704383850098,10.574235916137695,10.51101016998291,-0.5072211623191833,-0.46600279211997986,-0.5264986157417297,-0.5885517597198486,-0.563853919506073,-0.595884382724762,-0.5588045120239258,-0.5673309564590454,-0.5645955204963684,-0.5688127279281616,-0.5497863292694092,-0.5558781623840332,-0.5179674625396729,-0.5700694918632507,1.2347710132598877,1.165845513343811,1.2479965686798096,0.7763915657997131,0.780833899974823,0.6866717338562012,0.7247900366783142,0.7182651162147522,0.29060864448547363,0.7003521919250488,0.5957707762718201,0.7102307081222534,0.7123076319694519,0.7179614305496216,9.243766784667969,9.882445335388184,9.900766372680664,8.625873565673828,8.640843391418457,8.642436981201172,8.580339431762695,8.824699401855469,8.289412498474121,8.311596870422363,8.297563552856445,8.666007041931152,8.69810962677002,8.628095626831055,-0.23592443764209747,-0.2636304199695587,-0.2735910713672638,-0.19056211411952972,-0.25282078981399536,-0.20319043099880219,-0.20271417498588562,0.6408596038818359,1.040497064590454,1.3129024505615234,1.3724100589752197,1.4268337488174438,1.478911280632019,1.767829418182373,5.661562442779541,5.706593036651611,5.692317962646484,5.092794895172119,5.160162925720215,5.121052265167236,5.950400352478027,5.863365173339844,5.994359493255615,5.902225494384766,5.952700138092041,6.835150718688965,7.380838871002197,7.165684223175049,2.441417694091797,0.29288792610168457,0.06979899853467941,-0.14029739797115326,-0.11200496554374695,-0.5497424006462097,-0.5416492223739624,-0.5819443464279175,-0.6164088249206543,-0.619195282459259,-0.6210419535636902,-0.597133994102478,-0.5706228613853455,-0.473480224609375,10.557408332824707,10.557010650634766,10.560467720031738,10.562360763549805,10.5651216506958,10.515823364257813,10.53996753692627,10.560372352600098,10.563210487365723,10.541485786437988,10.595495223999023,10.597344398498535,10.568241119384766,10.561426162719727,4.26345157623291,4.253957748413086,4.275042533874512,4.0662336349487305,4.069199562072754,4.059363842010498,4.189897060394287,4.1978068351745605,4.194678783416748,4.288123607635498,4.843953609466553,4.796063423156738,4.738846302032471,4.852777481079102,12.262395858764648,12.272455215454102,12.230095863342285,12.050313949584961,12.012758255004883,11.957942008972168,11.962736129760742,11.945039749145508,11.607990264892578,11.593180656433105,11.51569652557373,11.53313159942627,11.658985137939453,11.573407173156738,12.359253883361816,12.320684432983398,12.316492080688477,11.982514381408691,11.866776466369629,11.965226173400879,11.870200157165527,12.146697044372559,12.237967491149902,12.28479290008545,12.242486000061035,11.875253677368164,11.360807418823242,11.987195014953613,9.845505714416504,10.26409912109375,10.201115608215332,11.207762718200684,11.168584823608398,9.200897216796875,8.973565101623535,8.084466934204102,7.585961818695068,5.914219379425049,5.620429515838623,5.631411075592041,5.565446376800537,5.415102958679199,7.968921184539795,7.794825077056885,7.3114728927612305,7.527315139770508,7.470608234405518,7.7818427085876465,9.519392967224121,10.1135892868042,10.065210342407227,10.046080589294434,9.622424125671387,9.987466812133789,10.344230651855469,10.439717292785645,0.6006855964660645,0.5417110323905945,0.6024624705314636,0.5922982096672058,0.560081958770752,0.5574542880058289,0.6087870597839355,0.5945106148719788,0.7633677124977112,0.8677753210067749,0.8048630356788635,0.794958233833313,0.7719210982322693,0.7841918468475342,7.8948822021484375,7.875206470489502,7.919572830200195,7.824675559997559,7.895592212677002,7.854724884033203,7.885963439941406,8.157333374023438,8.263134002685547,8.229982376098633,9.092391014099121,9.734087944030762,10.224072456359863,10.324467658996582,5.7575788497924805,5.53632116317749,5.510714530944824,6.519116401672363,7.151663780212402,7.13131856918335,7.228849411010742,8.071767807006836,8.71053409576416,8.893869400024414,8.692002296447754,9.005270957946777,7.245809078216553,6.633028507232666,2.8442862033843994,2.8512356281280518,2.872248888015747,2.8572146892547607,2.854912757873535,2.838801383972168,2.842573881149292,2.879714250564575,2.835730791091919,2.8977296352386475,2.9135684967041016,2.9863383769989014,2.882352590560913,2.893491268157959,0.4496113955974579,0.51482093334198,0.5214147567749023,0.550048828125,0.5849468111991882,0.5960384011268616,0.5708197355270386,0.5161342620849609,0.4993404448032379,0.5311822295188904,0.4828249216079712,0.4569092094898224,0.4561450481414795,0.5654358863830566,4.930020809173584,4.960129261016846,4.9633402824401855,4.974587917327881,5.024920463562012,4.690653324127197,3.596858501434326,3.542919158935547,3.585801839828491,4.537856578826904,4.603048801422119,4.612092971801758,4.642550945281982,4.5894670486450195,1.2517777681350708,1.2133311033248901,1.3434711694717407,1.390731692314148,1.9671255350112915,8.570755958557129,8.550415992736816,8.610111236572266,8.577982902526855,8.5044527053833,8.559610366821289,8.550684928894043,8.523743629455566,12.101712226867676,5.058311462402344,5.003815174102783,5.096611022949219,5.051756858825684,5.0887932777404785,6.018514156341553,6.118476390838623,5.989525318145752,5.530518054962158,5.4479660987854,5.530257225036621,5.735958099365234,5.757945537567139,6.160816192626953,5.254319667816162,5.2057414054870605,5.451596260070801,5.872532367706299,5.804239273071289,5.56489896774292,5.650364398956299,5.708667755126953,5.956111907958984,5.870550632476807,8.174437522888184,9.55601978302002,9.646902084350586,9.865818977355957,12.2542724609375,12.21078872680664,12.293487548828125,12.340513229370117,12.380319595336914,12.230875015258789,12.115889549255371,12.153788566589355,12.151046752929688,12.221596717834473,12.452224731445313,11.895644187927246,11.631041526794434,11.480611801147461,5.9802045822143555,5.991522312164307,5.949828624725342,5.898242950439453,5.914735317230225,5.833059310913086,5.79379415512085,5.752116680145264,5.743169784545898,5.7385406494140625,4.435550212860107,2.0681333541870117,1.40786612033844,1.319898247718811,5.131031513214111,5.158287525177002,5.24631929397583,5.760684013366699,5.7967963218688965,5.660287857055664,5.709193706512451,5.805142879486084,5.269933700561523,5.980352401733398,5.998476505279541,7.107836723327637,7.532980918884277,7.4209675788879395,10.75076961517334,10.688899993896484,10.716727256774902,10.734145164489746,10.709403038024902,10.808619499206543,10.825896263122559,11.291531562805176,11.56346607208252,11.471073150634766,10.913799285888672,10.668087005615234,10.775752067565918,10.978126525878906,5.7483110427856445,5.773187637329102,5.756031036376953,5.753472328186035,5.753457069396973,5.749106407165527,5.747199535369873,5.810186386108398,5.714100360870361,5.740237712860107,5.743907451629639,5.767138957977295,5.73850154876709,5.768527030944824,6.637653350830078,6.78083610534668,6.931149005889893,7.272408485412598,6.671077728271484,6.380310535430908,7.010714530944824,7.440126419067383,7.2316131591796875,6.84130334854126,7.293252944946289,7.650195598602295,7.633732795715332,7.732667446136475,5.494494438171387,5.498662948608398,5.5289387702941895,5.594450950622559,5.676120281219482,5.508115291595459,5.440342903137207,5.434116363525391,5.579968452453613,5.514937877655029,5.8039350509643555,5.789678573608398,6.651288986206055,6.682636737823486,11.837142944335938,11.397797584533691,10.938192367553711,10.230640411376953,10.102625846862793,10.037803649902344,10.085010528564453,12.174558639526367,12.180255889892578,12.190818786621094,12.162097930908203,12.15556526184082,12.009726524353027,11.92456340789795,7.011662483215332,6.977819919586182,6.9588398933410645,6.9788126945495605,6.991257667541504,6.986359119415283,6.963517189025879,6.992759704589844,10.767010688781738,11.221304893493652,10.541577339172363,10.444231033325195,10.770381927490234,11.682355880737305,8.942212104797363,8.906623840332031,8.97714614868164,9.493916511535645,9.63933277130127,9.52310848236084,9.52981185913086,9.573697090148926,9.63313102722168,9.563562393188477,9.499658584594727,9.429657936096191,9.37768840789795,9.467673301696777,10.720687866210938,10.702630043029785,10.669118881225586,10.727986335754395,11.446830749511719,10.857083320617676,10.86620807647705,10.82799243927002,10.796333312988281,12.12331485748291,13.043838500976563,12.73025894165039,12.096863746643066,11.754536628723145,12.392163276672363,12.372220993041992,12.395059585571289,11.925606727600098,11.832850456237793,11.801640510559082,11.79555892944336,11.696197509765625,11.735219955444336,11.602160453796387,11.904202461242676,12.49305534362793,12.352229118347168,13.153264045715332,3.4588143825531006,3.3662805557250977,3.4104669094085693,3.477633237838745,3.48785138130188,3.4432976245880127,3.4392154216766357,3.4805450439453125,3.417438507080078,3.4182138442993164,3.496917963027954,3.8417344093322754,4.131119728088379,4.1566057205200195,3.483295440673828,3.516148805618286,3.5212652683258057,4.542723655700684,4.2762932777404785,3.570338487625122,3.5695321559906006,3.8479301929473877,4.587036609649658,4.518354892730713,4.985626697540283,4.947232723236084,4.888864040374756,4.898451328277588,1.5165973901748657,1.867505431175232,1.900510549545288,1.925020694732666,1.925879716873169,1.9083470106124878,1.931366205215454,1.915597677230835,1.9467366933822632,1.9303563833236694,1.9176061153411865,1.9315611124038696,1.9117902517318726,1.9271434545516968,12.617776870727539,12.53827953338623,12.600380897521973,12.498820304870605,12.478193283081055,12.529573440551758,12.471306800842285,12.543678283691406,12.563891410827637,12.568807601928711,12.662954330444336,12.76138973236084,12.760289192199707,12.803984642028809,11.865174293518066,11.875709533691406,11.959451675415039,11.931275367736816,11.925310134887695,11.23720932006836,10.296392440795898,11.994315147399902,12.000479698181152,9.678976058959961,7.864816665649414,9.477338790893555,11.793313026428223,12.020951271057129,12.610562324523926,12.614493370056152,12.6439790725708,12.64948558807373,12.625391960144043,12.453805923461914,12.625171661376953,12.622220039367676,12.582602500915527,12.055488586425781,12.328767776489258,12.376258850097656,12.615738868713379,12.615306854248047,-4.451929569244385,-4.440378189086914,-4.4242682456970215,-4.440176963806152,-4.449960708618164,-4.463521480560303,-4.454869747161865,-4.461118698120117,-4.463808059692383,-4.450041770935059,-4.447628974914551,-4.443197727203369,-4.454333305358887,-4.4617462158203125,12.679548263549805,12.651040077209473,12.724471092224121,12.415937423706055,11.5230712890625,11.246156692504883,10.912713050842285,9.106106758117676,8.536296844482422,8.898346900939941,7.590155601501465,7.119779109954834,7.77498722076416,7.8846755027771,11.129965782165527,11.130414009094238,11.110608100891113,11.130455017089844,11.2160005569458,11.393707275390625,13.165994644165039,13.215231895446777,13.190897941589355,13.231250762939453,13.172587394714355,10.650230407714844,10.5255765914917,10.568534851074219,9.583684921264648,9.586838722229004,9.590957641601563,9.586360931396484,9.600028991699219,9.591399192810059,9.592248916625977,9.592107772827148,9.575663566589355,9.587641716003418,9.587053298950195,9.569475173950195,9.572803497314453,9.574943542480469,5.783498764038086,5.714905261993408,5.855266094207764,6.557137489318848,6.491754531860352,6.471921443939209,6.60490608215332,6.827159881591797,7.722352027893066,6.771894931793213,6.591197967529297,6.753129482269287,7.061078071594238,7.410531520843506,3.3282785415649414,3.504817485809326,4.332244873046875,4.900585174560547,4.871041297912598,4.764863014221191,5.150513172149658,6.193980693817139,6.836068630218506,7.4220871925354,9.425055503845215,10.380842208862305,7.729782581329346,9.455979347229004,12.83767318725586,12.938433647155762,12.943675994873047,12.879247665405273,12.96290397644043,12.958305358886719,13.026090621948242,13.014490127563477,13.034951210021973,12.940606117248535,12.958163261413574,13.009858131408691,13.024212837219238,13.03219223022461,11.752349853515625,11.757370948791504,11.769074440002441,11.74514102935791,11.700421333312988,11.67479419708252,10.801884651184082,10.70274543762207,10.75341796875,10.82629108428955,10.954739570617676,10.621594429016113,10.587234497070313,10.43273639678955,-2.561831474304199,-2.4845757484436035,-2.46577525138855,-2.4567012786865234,-2.4804131984710693,-2.46785044670105,-2.45565128326416,-2.4562814235687256,-2.4465832710266113,-2.4613661766052246,-2.4370853900909424,-2.441757917404175,-2.4432907104492188,-2.3890981674194336,8.327818870544434,9.396172523498535,9.505387306213379,11.593731880187988,12.148358345031738,12.624560356140137,12.528190612792969,12.730938911437988,11.998021125793457,11.859437942504883,11.693438529968262,11.533717155456543,11.297142028808594,10.948665618896484,6.715590476989746,7.023248672485352,7.063223361968994,7.049510955810547,7.025804042816162,6.3392486572265625,5.329850196838379,5.321874618530273,5.285109043121338,5.281141757965088,5.254089832305908,5.278305530548096,5.329370021820068,5.383507251739502]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"first_dim\",\n",
       "\"y\":\"second_dim\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"first_dim\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"second_dim\"\n",
       "}]\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"42\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x1ed3aab40e0>"
      ]
     },
     "execution_count": 251,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(embedding, aes(\"first_dim\", \"second_dim\")) +\n",
    "    geom_point() +\n",
    "    labs(x = \"First dimension\", y = \"Second dimension\")\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "To see how this pertains to value labels, we can add the regime classifications to this plot."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"fZ29gz\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"fZ29gz\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"first_dim\":[6.335777282714844,6.325832843780518,6.262874126434326,4.721985340118408,4.821208953857422,5.540600299835205,5.555131912231445,5.8931450843811035,6.396718978881836,6.173861980438232,5.586993217468262,4.132484436035156,3.7110135555267334,2.327237606048584,11.625908851623535,11.423194885253906,11.365225791931152,11.373534202575684,11.356762886047363,11.463846206665039,11.498111724853516,11.379169464111328,11.1845064163208,9.766401290893555,11.343649864196777,11.370582580566406,12.08283519744873,11.382192611694336,17.491453170776367,17.54007911682129,17.56104278564453,17.60508155822754,17.66956329345703,17.70122528076172,17.714609146118164,17.766925811767578,17.72886848449707,17.80843162536621,17.8309326171875,17.841222763061523,17.870899200439453,17.492115020751953,16.34906005859375,16.351024627685547,16.35053825378418,16.36249542236328,16.340492248535156,16.30388069152832,16.298439025878906,16.307180404663086,16.328369140625,16.294984817504883,16.351957321166992,16.348495483398438,16.34653091430664,16.3652400970459,10.269993782043457,10.258707046508789,10.255318641662598,10.220832824707031,10.198328971862793,10.204879760742188,10.170321464538574,10.175129890441895,10.161712646484375,10.145553588867188,10.130054473876953,5.8685784339904785,5.868607044219971,5.805727005004883,12.514986038208008,12.4337739944458,12.520366668701172,11.898889541625977,11.592329025268555,11.678842544555664,11.597396850585938,11.265121459960938,11.316866874694824,10.139017105102539,10.034993171691895,10.195584297180176,9.923530578613281,8.645054817199707,15.184690475463867,15.16788387298584,15.080987930297852,14.120551109313965,14.080201148986816,14.070406913757324,14.080219268798828,14.064909934997559,14.238754272460938,14.174566268920898,14.189411163330078,13.978645324707031,13.887907981872559,13.921222686767578,-4.106196880340576,-4.07405424118042,-3.3040213584899902,-2.543126344680786,-2.483558177947998,-2.4846720695495605,-1.7134993076324463,-1.6249734163284302,-1.7323920726776123,-0.9459550976753235,-0.951522171497345,-4.04624605178833,-4.040908336639404,-3.977121353149414,-3.069275140762329,-3.1395764350891113,-3.2671890258789063,-3.395888328552246,-3.866335391998291,-3.9771010875701904,-3.9406206607818604,-3.917367935180664,-3.9141104221343994,-3.930208206176758,-3.332979917526245,-3.9428505897521973,-4.278425693511963,-4.312544822692871,3.4077939987182617,3.384695529937744,3.290621519088745,2.6583831310272217,2.784893751144409,2.7320146560668945,2.750683069229126,2.8209035396575928,2.648871421813965,2.4553022384643555,2.9078657627105713,2.7779996395111084,2.5754942893981934,1.8879778385162354,-4.904812335968018,-4.851648807525635,-4.399499893188477,-4.812508583068848,-4.710866451263428,-4.844475269317627,-4.780795097351074,-4.8028082847595215,-4.718479156494141,-4.604381561279297,-4.618411540985107,-4.640583515167236,-4.636274337768555,-4.681270122528076,-4.052164077758789,-3.2366244792938232,-3.1407485008239746,-3.480884313583374,-4.43628454208374,-4.784270286560059,-4.2062764167785645,-4.185151100158691,-4.176516056060791,-4.208487510681152,-4.150872707366943,-4.1967549324035645,-4.247424125671387,-4.306807518005371,6.720937728881836,7.925909996032715,7.759377479553223,7.858264446258545,8.089264869689941,8.244882583618164,8.420331001281738,8.396635055541992,8.202247619628906,7.372272491455078,7.048954486846924,7.2491679191589355,8.500149726867676,8.93337345123291,17.016063690185547,17.01701545715332,17.13909339904785,17.129226684570313,16.872068405151367,15.734917640686035,10.2733736038208,8.185333251953125,7.8343400955200195,7.839865207672119,5.53249454498291,4.225035190582275,4.116119384765625,4.463286399841309,15.587946891784668,15.636380195617676,15.617433547973633,15.840526580810547,15.765907287597656,15.707609176635742,12.647787094116211,12.196310997009277,11.203190803527832,7.935887336730957,8.161469459533691,7.756502151489258,8.115584373474121,13.413678169250488,17.587032318115234,17.51966094970703,17.535083770751953,17.575891494750977,17.5708065032959,17.607892990112305,17.31608772277832,14.895394325256348,14.619552612304688,14.508798599243164,14.391998291015625,14.949477195739746,15.136672973632813,15.323368072509766,17.434432983398438,17.20214080810547,17.20558738708496,17.16874122619629,17.22028923034668,17.189260482788086,17.185514450073242,17.576570510864258,17.502979278564453,16.67852783203125,16.425716400146484,16.650314331054688,14.924140930175781,14.81874942779541,5.062445640563965,5.220770835876465,5.340258598327637,5.478041172027588,6.396275043487549,6.313835144042969,6.327366352081299,6.402136325836182,5.906599521636963,4.156573295593262,1.5559409856796265,-2.3020823001861572,-2.4024407863616943,-2.4086878299713135,-2.1847896575927734,-2.2568681240081787,-2.252859354019165,-2.9875147342681885,-4.456457614898682,-4.385465145111084,-4.393944263458252,-4.411712169647217,-4.60008430480957,-4.653753280639648,-4.628408908843994,-4.620177268981934,-4.639314651489258,-4.666227340698242,7.495901107788086,7.490168571472168,7.447296619415283,7.3478684425354,7.306474685668945,4.920256614685059,5.056870937347412,4.808974266052246,4.001622676849365,0.6912034153938293,-2.635632276535034,3.9836976528167725,3.8754303455352783,3.876796007156372,-1.0070552825927734,-1.4178061485290527,-1.2811899185180664,-1.3665317296981812,-1.3748267889022827,-1.6824673414230347,-1.7670303583145142,-1.6779694557189941,-1.541658639907837,-1.781669020652771,-2.809302806854248,-3.3007073402404785,-4.834402084350586,-5.117171287536621,-1.1362626552581787,-0.9008327126502991,-1.020742654800415,-0.8917868137359619,-0.3023262619972229,-0.7748749852180481,-0.5998005270957947,-1.0036574602127075,-2.2584598064422607,-2.151301622390747,-2.069404363632202,-1.5344282388687134,2.8208088874816895,2.427380323410034,4.497029781341553,4.504326343536377,-2.31001615524292,-3.005833148956299,2.188201665878296,2.5149998664855957,2.5235025882720947,1.8124195337295532,1.5485724210739136,1.5315817594528198,-2.253671407699585,-3.5154054164886475,-3.498220443725586,-3.2831499576568604,0.26910173892974854,0.23452149331569672,0.256085604429245,0.2927039861679077,0.3203720450401306,-0.32203665375709534,-0.8374962210655212,-0.9550471901893616,-1.4387378692626953,-2.1096339225769043,-1.6455048322677612,-1.5067360401153564,-1.8366138935089111,-2.8453707695007324,13.363816261291504,13.910087585449219,14.07967472076416,13.991787910461426,13.988409996032715,13.954902648925781,13.218220710754395,13.349007606506348,14.136249542236328,14.019550323486328,14.245086669921875,12.781105041503906,11.913467407226563,9.039987564086914,7.639209270477295,7.6628828048706055,7.962284564971924,9.662166595458984,9.65536880493164,9.669291496276855,9.66774845123291,8.366602897644043,8.299198150634766,9.611176490783691,9.653454780578613,9.567341804504395,7.9981536865234375,5.639077186584473,-4.924788951873779,-4.930057048797607,-4.804053783416748,-4.773772239685059,-4.631120204925537,-4.860122203826904,-4.94982385635376,-4.9441423416137695,-4.816357135772705,-4.620463848114014,-4.435207843780518,-4.460920810699463,-4.542044639587402,-4.8438520431518555,-4.965733051300049,-4.896627902984619,-5.310862064361572,-5.329981327056885,-5.272288799285889,-5.2330322265625,-5.239755630493164,-5.280002117156982,-4.423831462860107,-4.311062335968018,-4.620009422302246,-4.2177815437316895,-4.215103626251221,-3.1254756450653076,-3.1251447200775146,-3.1186139583587646,-3.1141326427459717,-3.1515583992004395,-3.1269686222076416,-3.101508855819702,-3.10174560546875,-3.130638599395752,-3.274256706237793,-3.291635274887085,-3.2254157066345215,-3.13390851020813,-3.1152868270874023,-2.7906863689422607,-2.780778169631958,-2.750889539718628,-2.74141263961792,-2.7357096672058105,-2.72292423248291,-3.0232291221618652,-2.999520778656006,-2.9816062450408936,-3.4379355907440186,-3.1685845851898193,-4.928334712982178,-2.7385947704315186,-2.7370476722717285,11.952067375183105,12.056416511535645,12.209803581237793,12.311223983764648,12.410614967346191,12.190251350402832,11.87031078338623,11.680630683898926,12.669883728027344,12.562275886535645,13.241711616516113,13.190095901489258,13.456154823303223,13.972081184387207,-5.186057090759277,-5.1660380363464355,-5.184101581573486,-5.148936748504639,-5.171936511993408,-5.12375545501709,-5.281173229217529,-5.159396171569824,-4.493780136108398,-3.245858669281006,-3.213212728500366,-3.2620110511779785,-3.1776270866394043,-3.4688000679016113,8.063862800598145,8.023015975952148,8.012420654296875,7.685262680053711,6.136167049407959,3.321248769760132,2.532320737838745,1.2085957527160645,1.0387816429138184,-0.1128489077091217,-1.4052352905273438,-1.3632910251617432,-1.5033177137374878,-1.890366554260254,0.08254687488079071,0.27545854449272156,0.3504319190979004,3.2070391178131104,3.450908899307251,3.407684326171875,3.463409185409546,3.0122575759887695,2.042539596557617,2.0128376483917236,2.0815701484680176,2.5995514392852783,3.6361260414123535,4.292072772979736,-3.0689032077789307,-3.053319215774536,-3.0776803493499756,-3.0777645111083984,-3.05142879486084,-3.0599350929260254,-3.0592265129089355,-3.05318021774292,-3.029233932495117,-3.059436321258545,-3.059211015701294,-3.050426483154297,-3.0396504402160645,-3.072848081588745,12.581365585327148,12.62393569946289,12.059755325317383,10.387112617492676,10.28371810913086,10.218876838684082,10.909560203552246,16.019195556640625,16.095369338989258,15.506949424743652,15.656530380249023,15.633540153503418,14.120591163635254,10.168865203857422,1.873190999031067,1.1957180500030518,1.3834619522094727,1.5269341468811035,3.8640947341918945,5.163597583770752,5.247261047363281,3.5651819705963135,6.113380432128906,6.702654838562012,6.443638324737549,6.5207085609436035,6.772260665893555,6.651848316192627,0.02833014912903309,0.16415178775787354,0.13654427230358124,0.3115345239639282,0.3019673526287079,0.24446852505207062,0.1886613667011261,0.13157954812049866,-0.42678433656692505,-1.1553045511245728,-1.1972094774246216,-1.238196611404419,-1.6333178281784058,-2.389160633087158,-0.0971900224685669,1.9812557697296143,2.4604945182800293,2.9125635623931885,3.1349096298217773,3.787032127380371,3.7326064109802246,3.67113995552063,3.621603012084961,2.58835506439209,2.602426052093506,0.9887188076972961,1.4477012157440186,1.5729271173477173,3.1942050457000732,3.59781813621521,3.580859661102295,3.608299493789673,3.626905918121338,3.544990301132202,2.572448968887329,2.0986082553863525,1.2724229097366333,0.26245129108428955,-0.310916006565094,-0.2704901397228241,-0.38092565536499023,-0.34122908115386963,1.4181338548660278,1.5506752729415894,1.5630557537078857,1.4756817817687988,1.3900363445281982,1.165895938873291,-0.06891462206840515,-0.1750805377960205,-0.3281741440296173,-0.38825345039367676,-0.3622549772262573,-0.4344891309738159,-0.18912442028522491,0.16642096638679504,14.185481071472168,14.167010307312012,14.11861515045166,14.100664138793945,14.070746421813965,14.083441734313965,14.745015144348145,14.799063682556152,14.936697959899902,14.754941940307617,14.395658493041992,14.243553161621094,14.72725772857666,14.738465309143066,-0.3547438383102417,0.1888132095336914,1.3431413173675537,-0.13223057985305786,-4.385293960571289,-4.301000118255615,-4.251615047454834,-3.8607139587402344,-4.096493721008301,-3.900956392288208,-3.8841147422790527,-3.8555636405944824,-3.885849952697754,-4.294734477996826,-2.8989858627319336,-2.918123483657837,-2.940255641937256,-3.049949884414673,-3.0916309356689453,-3.1179616451263428,-3.493833065032959,-3.5189950466156006,-3.51839017868042,-3.592459201812744,-3.7494521141052246,-4.121160984039307,-4.196244239807129,-4.237215995788574,-1.9579399824142456,-1.9543547630310059,-2.0904204845428467,-2.6921656131744385,-2.6875152587890625,-2.7129886150360107,-2.8055920600891113,-3.4227960109710693,-4.125668048858643,-4.184829235076904,-4.171970367431641,-4.149882793426514,-4.226860523223877,-4.156488418579102,7.207466125488281,6.029110431671143,5.978832721710205,6.011137962341309,6.0254130363464355,7.823253154754639,9.932453155517578,10.110320091247559,6.190929412841797,0.39987727999687195,-1.302701711654663,-1.5132807493209839,-0.3839868903160095,0.7034282088279724,6.06715202331543,6.117183685302734,5.9941911697387695,4.778822422027588,4.72507905960083,4.7591118812561035,4.520218849182129,4.682497978210449,4.848994731903076,6.16147518157959,6.06710958480835,4.652585983276367,3.508105516433716,2.8292741775512695,2.7167813777923584,2.9672772884368896,3.007530927658081,4.237844944000244,3.8836233615875244,-1.5740622282028198,7.50221061706543,7.624068737030029,6.694726467132568,6.4381537437438965,6.399824619293213,5.09192419052124,-4.0386738777160645,-3.88077449798584,-3.044747829437256,-3.0324785709381104,-3.0359413623809814,-3.1253435611724854,-3.078418254852295,-3.1798505783081055,-3.3955464363098145,-4.02664852142334,-4.325929641723633,-4.2976250648498535,-4.274474143981934,-4.303866386413574,-4.328083515167236,-4.323506832122803,8.305928230285645,8.315653800964355,8.258523941040039,8.0338773727417,7.819676399230957,7.551856517791748,7.093543529510498,6.730239391326904,5.869124412536621,5.79548454284668,4.108382701873779,3.562201738357544,3.6780216693878174,2.7801473140716553,-0.35574448108673096,-0.3597775101661682,-0.35411036014556885,-0.3124808669090271,-0.36151573061943054,-0.16654668748378754,-0.3622537851333618,-1.1605321168899536,-1.431936264038086,-1.6578601598739624,-2.481003999710083,-2.2645962238311768,-2.463435411453247,-2.7396624088287354,2.660842180252075,2.6928133964538574,-1.4957358837127686,-4.103586196899414,5.1609907150268555,6.234416484832764,6.511703968048096,8.166555404663086,6.999824523925781,5.922643184661865,5.872547626495361,6.028975009918213,6.862401008605957,7.881516456604004,-1.71507728099823,-1.8571181297302246,-2.3923239707946777,-2.861654043197632,-2.9417262077331543,-3.002526044845581,-3.1065332889556885,-3.223459482192993,-4.327481269836426,-4.370853424072266,-4.416375637054443,-4.5304436683654785,-4.564953804016113,-4.6183953285217285,-3.6567113399505615,3.9684104919433594,7.013701438903809,7.2113728523254395,7.177972793579102,7.0249552726745605,4.538802146911621,3.298630714416504,2.449434995651245,2.7559804916381836,3.327751398086548,2.35629940032959,1.9309757947921753,-1.295196294784546,2.0237183570861816,1.9939650297164917,1.951183795928955,1.1931993961334229,1.0942107439041138,0.47474348545074463,-1.4037632942199707,-3.04013991355896,-2.6738359928131104,-2.8069169521331787,-3.029048204421997,-0.352702796459198,3.335418701171875,3.401031255722046,-3.7362048625946045,-3.7801036834716797,-3.8067753314971924,-3.5391640663146973,-3.4894602298736572,-3.4959373474121094,-3.5289955139160156,-3.490509033203125,-3.456188201904297,-3.5083484649658203,-3.595543622970581,-3.5777132511138916,-3.643432855606079,-3.5940845012664795,-3.3014633655548096,-2.7059738636016846,-2.678920269012451,-2.662806272506714,-2.3579111099243164,-2.3134260177612305,-2.3655924797058105,-2.4301700592041016,-2.4118902683258057,-2.477905511856079,-2.759100914001465,-3.0952162742614746,-3.734469175338745,-4.125162124633789,-0.1167602390050888,-0.31871703267097473,0.8691574335098267,0.6671147346496582,0.7576022148132324,0.8774330615997314,2.6971383094787598,2.9295132160186768,2.8837106227874756,2.566749095916748,1.9175834655761719,-0.196639284491539,-0.10385783761739731,-0.11277954280376434,-1.404554009437561,-1.4091778993606567,-1.445845365524292,-2.2784366607666016,-2.25793194770813,-2.182384967803955,-2.1771044731140137,-2.802196979522705,-2.3902716636657715,-2.0297319889068604,-2.1147408485412598,-2.0978024005889893,-2.107764959335327,-2.418574810028076,15.118107795715332,14.310794830322266,14.250282287597656,14.40511703491211,14.2979736328125,14.336285591125488,15.313399314880371,15.48857307434082,15.319611549377441,15.621261596679688,15.266800880432129,15.297109603881836,15.185342788696289,15.15365219116211,17.85594367980957,17.84864044189453,17.869033813476563,16.299272537231445,16.11823081970215,16.555660247802734,16.697246551513672,17.056612014770508,16.273775100708008,15.248274803161621,15.566276550292969,15.298796653747559,15.839702606201172,15.850567817687988,10.357169151306152,10.296412467956543,10.184538841247559,10.179448127746582,10.158295631408691,8.8899507522583,8.736069679260254,8.1635103225708,8.380248069763184,7.756565570831299,4.871676921844482,5.96634578704834,4.519309043884277,2.8510289192199707,-2.736063003540039,-2.9155030250549316,-2.863295793533325,-2.874704599380493,-2.9869449138641357,-4.071346759796143,-4.158629417419434,-4.159825801849365,-4.1191887855529785,-4.0938801765441895,-4.657833099365234,-4.912082672119141,-5.222369194030762,-5.295357704162598,12.150093078613281,12.324838638305664,12.328202247619629,12.402215957641602,12.419929504394531,12.417762756347656,12.391434669494629,12.368501663208008,12.266447067260742,12.387840270996094,12.467708587646484,12.015288352966309,11.45165729522705,11.321537971496582,-3.257636547088623,-3.5605974197387695,-3.6187286376953125,-4.530032157897949,-4.3916730880737305,-4.274674892425537,-1.7259199619293213,-1.7514762878417969,-1.6014541387557983,-2.7106761932373047,-2.8857622146606445,-3.5535202026367188,-3.9315030574798584,-4.478161334991455,16.745983123779297,16.75600814819336,16.7722225189209,16.806921005249023,16.813034057617188,16.829919815063477,16.801359176635742,16.835643768310547,16.109834671020508,14.956025123596191,15.052797317504883,15.46161937713623,15.390832901000977,15.390185356140137,17.11967658996582,17.111074447631836,17.126733779907227,17.14340591430664,17.13405418395996,17.20197868347168,17.290327072143555,17.42230796813965,17.13338279724121,17.461170196533203,17.496360778808594,17.530153274536133,16.238693237304688,16.416091918945313,5.196106910705566,5.265683174133301,5.6159515380859375,5.439492702484131,5.149824142456055,5.163764476776123,5.007953643798828,6.326180458068848,6.7554402351379395,7.351245880126953,6.503433704376221,6.585371494293213,7.6310715675354,7.693363666534424,3.8206593990325928,3.79308819770813,3.8484489917755127,2.2994117736816406,2.2292063236236572,2.248595952987671,2.2822494506835938,3.3252832889556885,7.219058513641357,6.620384216308594,6.9185404777526855,6.702757835388184,7.71347188949585,7.468055725097656,16.8476505279541,16.8521728515625,16.956369400024414,17.009370803833008,16.961217880249023,17.0118350982666,17.036907196044922,16.899967193603516,16.348295211791992,16.18416404724121,16.08624839782715,16.040138244628906,16.387353897094727,16.394285202026367,17.769691467285156,17.704071044921875,17.779216766357422,17.73268699645996,17.60872459411621,17.645580291748047,17.589462280273438,17.489980697631836,17.231170654296875,17.221830368041992,17.097993850708008,16.357831954956055,16.115001678466797,16.28439712524414,4.038396835327148,3.962470531463623,3.7232441902160645,3.9773366451263428,3.9292125701904297,4.573512554168701,5.293483257293701,5.17780065536499,4.347276210784912,4.473128318786621,4.203792095184326,2.8067147731781006,0.9859090447425842,0.7640876770019531,-4.841648578643799,-4.8350629806518555,-4.819580554962158,-4.823791980743408,-4.859591960906982,-4.852309703826904,-4.8467936515808105,-4.837278842926025,-4.843503475189209,-4.847537517547607,-4.885353088378906,-4.9856648445129395,-4.9060587882995605,-4.986607074737549,-0.9254333972930908,-0.9541646242141724,-0.9454542994499207,-1.0720152854919434,-1.4937412738800049,-1.7076009511947632,-1.5959386825561523,-2.128211498260498,-1.6336969137191772,-1.8190704584121704,-2.38604998588562,-2.3424575328826904,-2.4293105602264404,-2.4972732067108154,17.11367416381836,17.059764862060547,17.061386108398438,17.113489151000977,17.115306854248047,17.123249053955078,17.017345428466797,17.058061599731445,17.094682693481445,17.01427459716797,17.070514678955078,17.24941062927246,16.987348556518555,17.136493682861328,15.210197448730469,15.400619506835938,15.570783615112305,15.418317794799805,15.395553588867188,15.407126426696777,15.58331298828125,15.535026550292969,15.448269844055176,15.384204864501953,15.358759880065918,15.34238338470459,15.207940101623535,14.99630355834961,-4.900837421417236,-4.897998809814453,-4.913875579833984,-4.916184902191162,-4.924331188201904,-4.879919052124023,-4.907472133636475,-4.891208648681641,-4.947673797607422,-4.921813011169434,-4.942074775695801,-4.957152843475342,-4.962728500366211,-4.9582014083862305,14.169255256652832,14.790122032165527,14.813718795776367,15.0321683883667,15.044856071472168,15.117132186889648,15.029088973999023,14.818937301635742,14.854999542236328,14.832435607910156,14.712403297424316,14.86074161529541,14.73891544342041,15.334270477294922,3.9679527282714844,4.098587989807129,4.548480033874512,5.919110298156738,5.951615810394287,4.716399669647217,4.080458164215088,1.706032395362854,4.550456523895264,6.131973743438721,6.364958763122559,6.243603706359863,6.5565032958984375,6.3488850593566895,5.570200443267822,5.69269323348999,5.466706275939941,5.03685998916626,4.9708428382873535,4.91395902633667,4.9934611320495605,5.131163597106934,4.746213912963867,4.590758800506592,4.883819103240967,4.808938503265381,4.8173346519470215,4.926596641540527,1.375120997428894,1.3791494369506836,1.5892921686172485,2.706637382507324,3.2713563442230225,3.0582056045532227,3.062960386276245,3.3899385929107666,2.8768439292907715,1.5105100870132446,3.8079893589019775,6.359683513641357,6.10037899017334,4.776664733886719,3.8504703044891357,4.519599914550781,2.66884446144104,-0.33599379658699036,-1.8060767650604248,-2.3119826316833496,-2.4884719848632813,-2.4542932510375977,-2.2208690643310547,3.773735761642456,3.861656665802002,3.801818370819092,4.046047210693359,4.812679767608643,7.860820770263672,8.001845359802246,8.024377822875977,7.990542888641357,7.968934059143066,6.668525695800781,6.534583568572998,6.487701416015625,6.338592052459717,6.349641799926758,5.564079284667969,5.092474460601807,2.971559762954712,1.370230793952942,-4.820520401000977,-4.339075088500977,-4.312391757965088,-4.310784339904785,-4.329984188079834,-4.254816055297852,-4.291700839996338,-4.351097106933594,-4.372018814086914,-4.39959192276001,-4.378406524658203,-4.391897678375244,-4.383274078369141,-4.415005207061768,16.747955322265625,16.757722854614258,16.77445411682129,16.7812442779541,16.80556297302246,16.816295623779297,17.19344139099121,17.189617156982422,17.207258224487305,16.265533447265625,16.14042854309082,16.149669647216797,16.000402450561523,15.97275161743164,9.640061378479004,9.636885643005371,9.624567031860352,9.6677827835083,9.619246482849121,9.651845932006836,9.632847785949707,9.556660652160645,9.422346115112305,9.393792152404785,9.475174903869629,9.485526084899902,9.503003120422363,9.579092025756836,0.6102966070175171,0.5572020411491394,0.1655248999595642,0.0952814444899559,0.09369602054357529,0.05602702125906944,0.10097123682498932,0.04973091930150986,0.148443803191185,0.20870555937290192,0.23284302651882172,0.2653709053993225,0.6770604848861694,0.9961850643157959,-3.759551763534546,-3.8008675575256348,-3.7661373615264893,-3.7583467960357666,-3.7695298194885254,-3.7446658611297607,-3.7565484046936035,-3.7471659183502197,-3.7555184364318848,-3.76847505569458,-3.759671449661255,-3.9710874557495117,-3.9743800163269043,-3.915468692779541,1.8578708171844482,1.8566913604736328,1.7511974573135376,1.8055362701416016,1.8220852613449097,1.7874714136123657,1.7940809726715088,1.8211456537246704,3.0044448375701904,3.1364552974700928,3.587477684020996,3.540036678314209,3.7116799354553223,1.7576091289520264,17.000829696655273,16.965087890625,15.931886672973633,15.737245559692383,15.737820625305176,15.312739372253418,15.311346054077148,15.114986419677734,15.467195510864258,16.198583602905273,15.923565864562988,15.352102279663086,15.763279914855957,15.022674560546875,-4.651963233947754,-4.560216903686523,-4.549956798553467,-4.491254806518555,-4.476836204528809,-4.479395866394043,-4.49135684967041,-4.491053581237793,-4.435422897338867,-4.450960636138916,-4.461317539215088,-4.496396064758301,-4.489926338195801,-4.655456066131592,-3.97762393951416,-3.169281005859375,11.315573692321777,11.122785568237305,10.423432350158691,10.108171463012695,10.105744361877441,10.14549446105957,11.613410949707031,11.11867618560791,10.39052963256836,3.442673444747925,-3.6368415355682373,0.3358343541622162,2.8286292552948,2.690288782119751,2.4608147144317627,0.4159191846847534,-0.6939379572868347,-1.8212659358978271,-2.7723937034606934,-2.9044947624206543,-2.9494869709014893,-2.97845721244812,-3.0438365936279297,-3.1872270107269287,-3.234006881713867,-3.227309465408325,0.14013442397117615,-0.058530185371637344,-0.08591493219137192,-0.2569420635700226,-1.4187790155410767,-0.9044548869132996,-0.8060380220413208,-0.9558952450752258,-0.9657070636749268,1.7698156833648682,2.306396961212158,1.921802282333374,-1.0690569877624512,-0.8979696035385132,16.167015075683594,15.87038803100586,15.89515209197998,15.886771202087402,15.832924842834473,15.600330352783203,15.603546142578125,15.873641967773438,15.999115943908691,15.64050579071045,15.84013843536377,15.613658905029297,15.22067642211914,15.357080459594727,16.45188331604004,16.487194061279297,16.486129760742188,16.496280670166016,16.469017028808594,16.611412048339844,16.583026885986328,16.667726516723633,16.680740356445313,16.7225284576416,15.80978012084961,15.434832572937012,14.955940246582031,15.190793991088867,-3.7808852195739746,-3.7575998306274414,-3.7775936126708984,-4.017134666442871,-4.151980400085449,-4.126276969909668,-4.348642826080322,-4.373351097106934,-4.317727088928223,-4.478064060211182,-4.475924491882324,-4.494833469390869,-4.618535995483398,-4.610152721405029,-5.352516174316406,-4.498393535614014,-4.544398784637451,-4.570876598358154,-4.56527042388916,-4.595442295074463,-4.5708160400390625,-4.5133748054504395,-4.0987701416015625,-4.105501174926758,-4.202467441558838,-4.2549967765808105,-4.16433048248291,-4.158222675323486,-3.0862534046173096,-3.0485734939575195,-2.709486246109009,-2.7856996059417725,-2.7579333782196045,-2.827549695968628,-2.6261532306671143,-2.0279335975646973,3.021132707595825,12.950530052185059,12.171822547912598,9.399456024169922,6.13682222366333,4.755542278289795,-5.370429515838623,-5.345620632171631,-5.359799385070801,-5.35442590713501,-5.410455226898193,-5.437078475952148,-5.392641067504883,-5.351131439208984,-5.445217132568359,-5.43383264541626,-5.416184425354004,-5.437841892242432,-5.446351528167725,-5.466951847076416,-5.199099540710449,-5.2750749588012695,-5.2434186935424805,-5.26525354385376,-5.289116859436035,-5.222116947174072,-5.213848114013672,-5.179900169372559,-5.212876319885254,-5.2010579109191895,-5.283717155456543,-5.167665958404541,-5.149011611938477,-4.935689926147461,-3.2493741512298584,-3.239159345626831,-3.223914861679077,-3.2442526817321777,-3.218433380126953,-3.1889426708221436,-4.3714919090271,-4.4554829597473145,-4.468407154083252,-4.513120651245117,-4.498720169067383,-4.4737701416015625,-4.421360969543457,-4.473404884338379,-4.457131862640381,-4.460262775421143,-4.492314338684082,-4.530791759490967,-4.534247398376465,-4.5524797439575195,-4.54608678817749,-4.595174312591553,-4.596954822540283,-4.552212238311768,-4.531294822692871,-4.276279926300049,-4.353560924530029,-4.140632629394531,-3.6726951599121094,-3.6664977073669434,-3.6903960704803467,-3.623979330062866,-3.620657444000244,-3.5777156352996826,-3.6089141368865967,-3.5834834575653076,-3.5770821571350098,-3.581615447998047,-3.5147931575775146,-3.5637223720550537,-3.5828161239624023,-3.50519061088562,-2.3936140537261963,-2.3872013092041016,-2.7012646198272705,-2.6798176765441895,-2.702273368835449,-2.749910831451416,-2.7272000312805176,-2.730241298675537,-2.7092649936676025,-2.5051119327545166,-2.492232322692871,-2.7438971996307373,-3.125363349914551,-3.085379123687744,-4.551748752593994,-4.582557201385498,-4.614888668060303,-4.6048173904418945,-4.615492343902588,-4.542333602905273,-4.541354656219482,-3.307471752166748,-3.2206003665924072,-3.2947514057159424,-3.215691089630127,-3.2446563243865967,-3.227870225906372,-3.2237637042999268,-4.086757659912109,-4.072237014770508,-4.0742878913879395,-4.073115825653076,-4.083841800689697,-4.097451686859131,-4.051928520202637,-4.072177410125732,-4.081997394561768,-4.074151515960693,-4.096427917480469,-4.080289363861084,-3.9576518535614014,-3.9299662113189697,3.9250845909118652,3.8762385845184326,3.7766239643096924,3.628169059753418,3.635488748550415,2.890758752822876,2.2723333835601807,2.109996795654297,2.233949899673462,2.3040664196014404,5.825033187866211,7.368112087249756,7.240514278411865,6.836180686950684,-2.6291892528533936,-2.6421852111816406,-2.6161506175994873,-2.6558022499084473,-2.643749237060547,-2.631655216217041,-2.608180046081543,-2.5985641479492188,-2.6122348308563232,-2.642232656478882,-2.5984623432159424,-2.6475980281829834,-2.642632007598877,-2.651040554046631,-2.214583396911621,-2.189128875732422,-2.1539952754974365,-2.0963335037231445,-2.1274802684783936,-2.1661810874938965,-2.043023109436035,-1.3788511753082275,-2.030486822128296,-2.06648850440979,-2.0912678241729736,-2.2149200439453125,-2.2654685974121094,-3.532087564468384,-4.058141231536865,-3.994192600250244,-3.9503703117370605,-4.071077346801758,-4.040732383728027,-4.0746989250183105,-3.9910435676574707,1.6734564304351807,3.1843461990356445,2.613802194595337,1.8781554698944092,2.1228318214416504,6.347663879394531,6.899463653564453,1.730472207069397,1.702466368675232,2.104311227798462,5.841752529144287,7.632299423217773,7.760509014129639,8.04709529876709,7.948737621307373,7.931277751922607,6.555735111236572,6.25785493850708,6.180028915405273,6.176904201507568,5.142265796661377,-1.397919774055481,-1.3810465335845947,-3.3989601135253906,-4.223400115966797,-1.3873133659362793,0.16986434161663055,0.19900164008140564,0.18702539801597595,0.24173636734485626,0.3907688558101654,0.43151143193244934,0.5082080364227295,-2.7974343299865723,-1.599013328552246,12.463919639587402,12.438329696655273,12.840198516845703,13.444045066833496,13.423567771911621,13.404556274414063,13.541553497314453,13.773558616638184,13.692307472229004,13.83321762084961,13.77284049987793,13.615165710449219,13.546958923339844,13.01873779296875,-5.344049453735352,-5.366376876831055,-5.378859043121338,-5.364537715911865,-5.365604877471924,-5.410491943359375,-5.335915565490723,-5.439133167266846,-5.362090110778809,-5.391259670257568,-5.348320484161377,-5.2649078369140625,-4.5201735496521,-4.421260833740234,-1.8888030052185059,0.6107032895088196,0.6313769221305847,-0.1046837791800499,-0.1625453233718872,-0.09472030401229858,-0.15835067629814148,-0.17585133016109467,0.26320216059684753,-0.14828722178936005,-1.7491583824157715,-1.3465561866760254,-1.768980860710144,-2.7945423126220703,-3.696079730987549,-3.7156074047088623,-3.687906503677368,-3.668093204498291,-3.6687726974487305,-3.642612934112549,-3.6860039234161377,-3.747210741043091,-3.668097734451294,-3.7563436031341553,-3.699190616607666,-3.5921902656555176,-3.6070573329925537,-3.627721071243286,-3.5944690704345703,-4.571650981903076,-3.0086143016815186,1.7588452100753784,-3.622380018234253,-3.6546778678894043,-3.6588027477264404,-3.634965658187866,-3.549914836883545,-3.6030354499816895,-3.5555965900421143,-3.7578790187835693,-3.885344982147217,-3.953885078430176,-4.0413384437561035,-3.9801173210144043,-3.9667415618896484,-3.3102283477783203,-0.41224977374076843,0.07389053702354431,0.10903246700763702,0.09058399498462677,0.43596598505973816,0.14136120676994324,0.16054099798202515,0.10628370195627213,0.1269281506538391,-0.13448509573936462,6.169259071350098,8.315327644348145,8.135650634765625,6.952653884887695,6.617900848388672,4.504161834716797,3.1179873943328857,1.960994005203247,1.814713954925537,4.47515344619751,7.665740966796875,12.5194673538208,12.702625274658203,11.033437728881836,7.035167694091797,7.093273639678955,7.124924659729004,7.670691967010498,7.823821067810059,9.943778038024902,9.752908706665039,9.55439281463623,8.244812965393066,6.572338581085205,6.553948402404785,6.3929362297058105,6.481563568115234,6.241549491882324,-3.453331708908081,-3.4803624153137207,-3.467202663421631,-3.6011147499084473,-3.6146881580352783,-3.6330132484436035,-3.618577241897583,-3.638625383377075,-3.7130253314971924,-3.8953773975372314,-3.5340945720672607,-3.55785870552063,-3.518111228942871,-3.552586793899536,-3.2847070693969727,-3.288942813873291,-3.298983573913574,-3.266519069671631,-3.291019916534424,-3.2470297813415527,-3.2609734535217285,-3.269047975540161,-3.2772676944732666,-3.2676703929901123,-3.354353666305542,-3.6074624061584473,-3.6186630725860596,-4.0064239501953125,-4.823909759521484,-4.940402507781982,-4.55012321472168,-4.477367401123047,-4.487117290496826,-4.499174118041992,-4.442258834838867,-4.494404315948486,-4.356328010559082,-4.327417373657227,-4.365631103515625,-4.408113956451416,-4.387147903442383,-4.522220611572266,-1.7900383472442627,-1.8152594566345215,-1.7152615785598755,-1.2708120346069336,-1.307147741317749,3.47721529006958,4.978703022003174,4.620548248291016,5.926766872406006,3.7036361694335938,3.1196377277374268,3.6808629035949707,4.760977745056152,4.1447649002075195,-3.6211745738983154,-3.592414379119873,-3.601163625717163,-3.6283252239227295,-3.594146490097046,-3.5552420616149902,-3.599656343460083,-3.562258005142212,-3.626164674758911,-3.6550023555755615,-3.682835102081299,-3.6667075157165527,-4.091251373291016,-4.141876697540283,-5.35283899307251,-5.34669828414917,-5.374230861663818,-5.435292720794678,-5.46240234375,-5.4077863693237305,-5.223628044128418,-5.1202826499938965,-5.093023777008057,-5.069462776184082,-5.146510601043701,-5.1971354484558105,-5.068114280700684,-5.0826945304870605,-1.5261563062667847,-1.4927895069122314,-1.5228620767593384,-1.4034392833709717,-1.3556660413742065,-1.3405306339263916,-1.3682146072387695,-1.384198546409607,-1.4307847023010254,-1.7945963144302368,-0.27945074439048767,-1.0960400104522705,-1.0270395278930664,-1.7385144233703613,11.920560836791992,12.022598266601563,12.069499969482422,11.293987274169922,11.266340255737305,11.843794822692871,11.749177932739258,11.39522647857666,11.284157752990723,11.365163803100586,11.481335639953613,11.797419548034668,11.53425407409668,11.485915184020996,-4.669283390045166,-4.718575477600098,-4.701084613800049,-4.748222351074219,-4.751332759857178,-4.696480751037598,-4.717934608459473,-4.732078552246094,-4.743668079376221,-4.766435146331787,-4.747140884399414,-4.781032562255859,-4.79214334487915,-4.779788017272949,-3.6842682361602783,-3.69612717628479,-3.6838741302490234,-3.78672194480896,-3.7713489532470703,-3.8243727684020996,-3.833899736404419,-3.8250327110290527,-4.081364631652832,-3.781766176223755,-3.927769184112549,-3.845773458480835,-3.8187758922576904,-3.793834686279297,-0.9108004570007324,-0.2749197483062744,-0.29116177558898926,-1.5539231300354004,-1.486814022064209,-1.5706679821014404,-1.5850028991699219,-1.4019653797149658,-1.8511236906051636,-1.8450610637664795,-1.8686774969100952,-1.5480707883834839,-1.506711483001709,-1.5686464309692383,-4.964466094970703,-4.951038360595703,-4.938290596008301,-5.025393486022949,-4.980912685394287,-5.005498886108398,-5.002171516418457,-5.42004919052124,-5.424545764923096,-5.4093828201293945,-5.348871231079102,-5.407066345214844,-5.39377498626709,-5.384848117828369,16.019351959228516,16.110076904296875,16.120887756347656,15.896385192871094,15.913833618164063,15.844038963317871,15.516840934753418,15.566030502319336,15.430574417114258,15.666508674621582,15.6328706741333,15.46263313293457,14.942910194396973,15.321812629699707,-5.102269172668457,-5.070345878601074,-5.091007709503174,-5.006686210632324,-4.964414119720459,-4.598812103271484,-4.543208599090576,-4.540226459503174,-4.456357002258301,-4.457878589630127,-4.445187568664551,-4.488121032714844,-4.461461544036865,-4.451315879821777,10.298710823059082,10.294830322265625,10.290288925170898,10.293492317199707,10.285198211669922,10.322430610656738,10.290525436401367,10.297221183776855,10.295161247253418,10.30048656463623,10.288985252380371,10.270933151245117,10.298248291015625,10.262211799621582,17.30567169189453,17.33883285522461,17.267335891723633,17.425512313842773,17.458738327026367,17.45292854309082,17.403017044067383,17.392955780029297,17.383987426757813,17.36914825439453,17.05915069580078,17.11014747619629,17.191781997680664,16.935731887817383,3.345125913619995,3.3822152614593506,3.34317684173584,2.9368417263031006,2.931762218475342,2.630863666534424,2.6702380180358887,2.5083353519439697,1.581732153892517,1.6751528978347778,1.712821364402771,1.5861825942993164,1.661212682723999,1.5974977016448975,8.507633209228516,8.436666488647461,8.33967399597168,8.247503280639648,8.473708152770996,8.40491008758545,8.449853897094727,7.493515491485596,7.226278305053711,7.152074813842773,7.100857734680176,8.412696838378906,10.411783218383789,8.354429244995117,-0.29209867119789124,0.26806575059890747,0.23189876973628998,1.7224409580230713,1.717819094657898,-0.9309254288673401,-1.1489322185516357,-1.9901657104492188,-2.3007519245147705,-2.653381824493408,-2.8442063331604004,-2.805466413497925,-2.837797164916992,-2.9058029651641846,14.685535430908203,14.849259376525879,15.015864372253418,14.35042667388916,14.39040756225586,14.150520324707031,12.750506401062012,11.911459922790527,11.954004287719727,11.986429214477539,12.734382629394531,12.277508735656738,11.739001274108887,11.568449020385742,-4.828917980194092,-4.763044834136963,-4.773419380187988,-4.82550573348999,-4.819384574890137,-4.799156188964844,-4.850278377532959,-4.825575828552246,-4.797346115112305,-4.758005619049072,-4.760985374450684,-4.7110114097595215,-4.718094348907471,-4.739912509918213,14.778072357177734,14.79758358001709,14.725789070129395,14.825221061706543,14.771573066711426,14.814313888549805,14.736869812011719,14.500889778137207,14.38878345489502,14.344097137451172,13.518364906311035,12.684664726257324,12.198286056518555,12.019566535949707,16.5353946685791,16.736698150634766,16.74249839782715,15.99466323852539,15.553576469421387,15.556018829345703,15.478001594543457,14.586751937866211,13.98144245147705,13.779022216796875,13.985726356506348,13.645203590393066,15.528085708618164,16.087982177734375,17.158052444458008,17.197256088256836,17.197994232177734,17.180709838867188,17.18329429626465,17.190929412841797,17.199987411499023,17.202543258666992,17.179019927978516,17.193586349487305,17.198566436767578,17.19040298461914,17.207530975341797,17.173053741455078,-5.388876914978027,-5.397112846374512,-5.4266743659973145,-5.399006366729736,-5.450992584228516,-5.43195104598999,-5.450982093811035,-5.427475452423096,-5.449512958526611,-5.4307966232299805,-5.398726940155029,-5.375189304351807,-5.385317325592041,-5.451344966888428,17.19291114807129,17.187286376953125,17.187028884887695,17.202116012573242,17.321393966674805,17.443979263305664,17.751062393188477,17.821672439575195,17.745744705200195,17.46588134765625,17.477378845214844,17.508014678955078,17.50052833557129,17.516021728515625,-4.19122838973999,-4.114877223968506,-4.260403156280518,-4.275878429412842,-3.7847537994384766,-1.4914370775222778,-1.5219995975494385,-1.4622890949249268,-1.4938398599624634,-1.5461124181747437,-1.5069358348846436,-1.5288050174713135,-1.5801349878311157,1.3452006578445435,17.39493179321289,17.438859939575195,17.377155303955078,17.393098831176758,17.38628387451172,16.588668823242188,16.4783935546875,16.6446475982666,16.998884201049805,17.02528190612793,16.989255905151367,16.8339786529541,16.78656578063965,16.453413009643555,16.900047302246094,16.931612014770508,16.784446716308594,16.417621612548828,16.466344833374023,15.776055335998535,15.710826873779297,15.654657363891602,15.61750602722168,15.555435180664063,13.95394229888916,12.701680183410645,12.40085506439209,12.016767501831055,3.495544195175171,3.477142572402954,3.579648494720459,4.4201130867004395,4.415021896362305,6.0624871253967285,6.340439796447754,6.387824535369873,6.33429479598999,5.784729957580566,3.558464288711548,2.23984956741333,1.6230686902999878,1.5108017921447754,-6.968023300170898,-6.946704387664795,-6.954693794250488,-6.903980731964111,-6.934377670288086,-6.866136074066162,-6.831350326538086,-6.8015336990356445,-6.789951324462891,-6.7897868156433105,-4.88776159286499,-4.916398525238037,-4.800813674926758,-4.804367542266846,15.911581993103027,15.908672332763672,15.865793228149414,15.570806503295898,15.591108322143555,15.591279029846191,15.627326965332031,15.549397468566895,15.866130828857422,15.491643905639648,15.548654556274414,14.803075790405273,14.623496055603027,14.831992149353027,11.755827903747559,11.815868377685547,11.768314361572266,11.580425262451172,11.606645584106445,11.557855606079102,11.346383094787598,10.629400253295898,10.231470108032227,10.369473457336426,11.1630220413208,11.656944274902344,11.434904098510742,11.003411293029785,-6.809978008270264,-6.8234477043151855,-6.807952880859375,-6.7993597984313965,-6.80871057510376,-6.804408073425293,-6.799026966094971,-6.8563127517700195,-6.771984577178955,-6.802191257476807,-6.767210006713867,-6.827266693115234,-6.807548522949219,-6.845489025115967,15.65977954864502,15.509413719177246,15.44911003112793,15.253259658813477,15.172523498535156,15.366963386535645,14.941283226013184,14.693832397460938,14.75592041015625,14.876672744750977,14.727901458740234,14.534082412719727,14.554426193237305,14.491455078125,15.852800369262695,15.867094039916992,15.845560073852539,15.854193687438965,15.860657691955566,15.82973861694336,15.849666595458984,15.847539901733398,15.940510749816895,15.84861946105957,15.8901948928833,15.84814453125,15.988046646118164,16.027416229248047,2.6930243968963623,1.0631535053253174,0.5687528252601624,-0.11729957908391953,-0.08558441698551178,-0.24010345339775085,-0.20524314045906067,3.292072296142578,4.171375274658203,4.634222984313965,4.4742021560668945,4.230732440948486,3.254819869995117,3.3275341987609863,-2.9655816555023193,-2.9847018718719482,-2.985727310180664,-2.969217538833618,-2.9719526767730713,-2.966160535812378,-2.9817583560943604,-2.960261821746826,-0.1374519169330597,0.7510392665863037,-0.3780921399593353,-0.4071803092956543,-0.05292755365371704,1.552261471748352,13.212924003601074,13.271164894104004,13.210501670837402,12.622308731079102,12.401670455932617,12.55656909942627,12.526244163513184,12.447885513305664,12.381353378295898,12.484450340270996,12.628582000732422,12.75832462310791,12.805031776428223,12.730408668518066,11.716136932373047,11.646910667419434,11.70510196685791,11.439728736877441,10.391846656799316,11.210458755493164,11.169384956359863,11.220014572143555,11.233235359191895,9.067138671875,3.331211566925049,2.6420178413391113,1.7554535865783691,1.0500786304473877,2.022691011428833,2.0497050285339355,2.024712085723877,1.2237541675567627,1.0828838348388672,1.0723235607147217,1.0187206268310547,0.924698531627655,0.9788346886634827,0.7676055431365967,1.1509933471679688,1.8986824750900269,1.7362972497940063,4.65543794631958,17.150049209594727,17.025718688964844,17.063283920288086,17.00111961364746,16.968564987182617,16.999399185180664,17.026443481445313,16.94141960144043,17.01317596435547,17.04290008544922,17.03262710571289,16.900348663330078,16.958024978637695,17.050487518310547,17.781587600708008,17.836467742919922,17.83010482788086,17.550554275512695,17.62431526184082,17.8880672454834,17.89130401611328,17.799789428710938,17.49220848083496,17.5632266998291,17.155275344848633,17.215587615966797,17.229644775390625,17.228660583496094,-4.486637115478516,-3.7396130561828613,-3.6917567253112793,-3.7115962505340576,-3.7085208892822266,-3.694547653198242,-3.7147767543792725,-3.6949126720428467,-3.6960721015930176,-3.7022128105163574,-3.7024176120758057,-3.6911847591400146,-3.7102575302124023,-3.712189197540283,6.649873733520508,6.768346786499023,5.891682147979736,4.172707557678223,4.310142517089844,4.269793510437012,4.245067119598389,4.2655415534973145,4.260921001434326,4.27714729309082,4.150297164916992,4.254733562469482,4.177392959594727,4.029829502105713,8.382100105285645,8.408404350280762,8.151676177978516,8.354016304016113,8.394444465637207,10.453651428222656,11.653265953063965,8.069191932678223,7.6388325691223145,12.336520195007324,14.042011260986328,12.646293640136719,8.511626243591309,7.725996971130371,8.161421775817871,8.157702445983887,8.114179611206055,8.168374061584473,8.208024024963379,8.530184745788574,8.202435493469238,8.034830093383789,8.006855010986328,9.20658016204834,8.730073928833008,8.590568542480469,8.233793258666992,8.164698600769043,-3.5664098262786865,-3.5705785751342773,-3.566908836364746,-3.5539391040802,-3.56526255607605,-3.5563125610351563,-3.5638656616210938,-3.5591278076171875,-3.557292938232422,-3.5652759075164795,-3.554957628250122,-3.5705976486206055,-3.5639004707336426,-3.5502371788024902,6.58014440536499,6.626280307769775,6.00895881652832,2.0467913150787354,0.6142103672027588,0.06439460068941116,-0.19162419438362122,-1.5559662580490112,-1.9514098167419434,-1.7353084087371826,-2.5543112754821777,-2.9257147312164307,-2.4318203926086426,-2.3027355670928955,0.31797417998313904,0.34810569882392883,0.357683926820755,0.3668091595172882,0.4010801911354065,0.6116551756858826,4.40134859085083,4.62992525100708,4.76501989364624,4.928797245025635,5.738441467285156,10.196614265441895,10.305590629577637,10.29528522491455,-7.12086296081543,-7.130126953125,-7.127159595489502,-7.151412010192871,-7.116970539093018,-7.130949020385742,-7.127867698669434,-7.125903129577637,-7.12841272354126,-7.13460111618042,-7.1275858879089355,-7.106491565704346,-7.1266913414001465,-7.143115043640137,15.070089340209961,15.108465194702148,15.00794506072998,14.741490364074707,14.784724235534668,14.799129486083984,14.774348258972168,14.74947738647461,14.199422836303711,14.845135688781738,15.255009651184082,15.271224021911621,15.222824096679688,14.692456245422363,16.431589126586914,16.361980438232422,15.936236381530762,15.553977012634277,15.603816032409668,15.694458961486816,15.490143775939941,15.357672691345215,14.983783721923828,14.615159034729004,12.898884773254395,11.553595542907715,14.477127075195313,12.762922286987305,2.781482696533203,2.9627091884613037,2.9432172775268555,2.847674608230591,3.0231282711029053,3.2358782291412354,3.760159969329834,4.672813415527344,4.685790538787842,5.298152446746826,5.075916767120361,5.100409984588623,5.178705215454102,5.309341907501221,9.811144828796387,9.815163612365723,9.853387832641602,9.914249420166016,9.930007934570313,9.971855163574219,11.496192932128906,11.793320655822754,11.622313499450684,11.327043533325195,11.06121826171875,11.722688674926758,11.877860069274902,12.395986557006836,-3.90918231010437,-3.954775810241699,-3.967942953109741,-3.9852025508880615,-4.000343322753906,-3.984001636505127,-3.9943485260009766,-3.985503911972046,-3.9835424423217773,-3.9920833110809326,-3.986342668533325,-3.9994266033172607,-3.992096424102783,-3.999614715576172,13.803269386291504,12.77947998046875,12.623617172241211,9.754392623901367,7.809276580810547,6.384941577911377,6.44196081161499,3.793168306350708,1.349913477897644,1.109053134918213,0.9886923432350159,0.7848007082939148,0.5485295653343201,-0.07028032094240189,-3.236027240753174,-3.044557571411133,-3.0289697647094727,-3.0297560691833496,-3.033177614212036,-3.4636545181274414,-4.170083999633789,-4.161989212036133,-4.212457180023193,-4.205860137939453,-4.216881275177002,-4.22905969619751,-4.189916133880615,-4.126001358032227],\n",
       "\"second_dim\":[10.711585998535156,10.669339179992676,10.682129859924316,11.072197914123535,11.124144554138184,10.831026077270508,10.830588340759277,10.736449241638184,10.588831901550293,10.627104759216309,10.750516891479492,10.637908935546875,10.441974639892578,10.232260704040527,9.569136619567871,9.645713806152344,9.66476058959961,9.72350788116455,9.715276718139648,9.654850006103516,9.575318336486816,9.68581485748291,9.769811630249023,10.117268562316895,9.71314525604248,9.66036605834961,9.46774673461914,9.69821834564209,3.890148162841797,3.9686710834503174,4.003072738647461,4.012448787689209,4.081360816955566,4.102148056030273,4.145326137542725,4.147933483123779,4.110610008239746,4.231780529022217,4.283101558685303,4.27023458480835,4.324368000030518,5.567681789398193,2.9006965160369873,2.891946315765381,2.8927574157714844,2.902186393737793,2.884110927581787,2.840585470199585,2.8390583992004395,2.8453176021575928,2.8657026290893555,2.829127311706543,2.9052088260650635,2.9031920433044434,2.901978015899658,2.9293134212493896,11.112566947937012,11.133844375610352,11.123470306396484,11.122835159301758,11.178033828735352,11.157491683959961,11.175283432006836,11.136406898498535,11.03684139251709,11.219870567321777,11.214710235595703,11.670974731445313,11.667852401733398,11.688297271728516,9.169976234436035,9.199989318847656,9.157320976257324,9.35810661315918,9.476104736328125,9.471129417419434,9.446309089660645,9.69652271270752,9.688739776611328,10.272233963012695,10.301955223083496,10.253684043884277,10.387924194335938,10.806875228881836,7.556023120880127,7.569490432739258,7.594123363494873,8.280073165893555,8.272021293640137,8.282967567443848,8.298360824584961,8.294432640075684,8.203899383544922,8.231393814086914,8.21481990814209,8.38628101348877,8.413546562194824,8.379087448120117,-1.472933053970337,2.3772385120391846,4.348503589630127,6.212404727935791,6.388468265533447,6.659778594970703,7.853370189666748,7.916254043579102,7.914436340332031,8.620162010192871,8.60739517211914,-1.438593864440918,-1.5970405340194702,-1.8320811986923218,4.3956522941589355,4.294864177703857,3.883364677429199,3.7397782802581787,2.9697487354278564,2.903813600540161,2.8547894954681396,2.890395164489746,2.903193473815918,2.8883986473083496,3.4368462562561035,2.615964889526367,1.3980621099472046,1.2821260690689087,11.730501174926758,11.769179344177246,11.825517654418945,11.706639289855957,11.733477592468262,11.718594551086426,11.71619701385498,11.762655258178711,11.691937446594238,11.598073959350586,11.80557918548584,11.748863220214844,11.651878356933594,11.333917617797852,0.39413610100746155,0.28458356857299805,4.0455546379089355,-0.24067553877830505,-1.362585425376892,-0.6942930817604065,-0.3341714143753052,-0.31217220425605774,-0.2867913544178009,-0.1254633218050003,-0.14302822947502136,-0.1695258915424347,-0.11928777396678925,-0.010808728635311127,4.212225437164307,4.844414234161377,5.258190631866455,4.910919189453125,3.8128488063812256,-0.8945421576499939,-1.9801825284957886,-1.9822229146957397,-1.9586596488952637,-1.9620448350906372,-1.9966450929641724,-1.9554656744003296,-1.9818415641784668,-1.8828994035720825,10.956552505493164,10.52812671661377,10.659440040588379,10.56950569152832,10.483120918273926,10.40017318725586,10.25774097442627,10.27305793762207,10.363323211669922,10.560648918151855,10.665914535522461,10.58249282836914,10.218729019165039,10.17802906036377,4.819838047027588,4.894895553588867,5.295316696166992,5.384034633636475,5.780157566070557,6.268266201019287,9.972790718078613,10.350879669189453,10.433073997497559,10.468670845031738,10.996813774108887,11.193770408630371,11.328296661376953,11.34016227722168,5.714585304260254,5.667943000793457,5.690032958984375,5.6867356300354,5.845244407653809,6.22789192199707,9.037943840026855,9.314658164978027,9.702527046203613,10.585537910461426,10.36721420288086,10.69145679473877,10.493919372558594,8.547264099121094,4.420915126800537,4.5167388916015625,4.479981422424316,4.392666816711426,4.4321088790893555,4.383913993835449,4.847375392913818,7.195772171020508,7.378889083862305,7.488580703735352,7.632819175720215,7.291025161743164,7.183522701263428,6.9686994552612305,4.4807515144348145,4.836552143096924,4.88994026184082,5.560135841369629,5.519214630126953,5.362513065338135,5.468692779541016,4.998290061950684,5.2807936668396,6.131833553314209,6.237697601318359,6.074573040008545,7.5554518699646,7.682115077972412,10.978018760681152,10.924766540527344,10.901912689208984,10.952277183532715,10.644309043884277,10.644862174987793,10.603397369384766,10.63218879699707,10.714202880859375,11.237348556518555,10.241279602050781,6.836938858032227,6.433203220367432,6.418103218078613,6.483735084533691,6.425821304321289,6.2909135818481445,5.320408821105957,3.1152522563934326,3.0301883220672607,3.064398765563965,2.990377426147461,2.681135654449463,2.5583174228668213,2.6753876209259033,2.577967643737793,2.6360437870025635,2.628113031387329,10.386924743652344,10.37266731262207,10.355117797851563,10.428824424743652,10.377095222473145,10.561023712158203,10.54145336151123,10.578523635864258,10.477117538452148,9.532256126403809,7.365713119506836,10.51457691192627,10.430387496948242,10.448341369628906,8.392508506774902,8.006831169128418,8.129660606384277,8.049732208251953,8.031312942504883,7.7367048263549805,7.58535099029541,7.723194122314453,7.8805460929870605,7.3533830642700195,5.705564022064209,5.438440322875977,0.44394975900650024,0.419383704662323,8.394003868103027,8.647775650024414,8.53521728515625,8.662540435791016,9.259913444519043,8.74209213256836,8.899897575378418,8.547272682189941,7.619266986846924,7.711778163909912,7.750522613525391,8.126017570495605,10.970255851745605,11.212038040161133,10.804543495178223,10.834580421447754,7.673670768737793,6.7264485359191895,10.30502700805664,10.66443920135498,10.631576538085938,10.307093620300293,10.18022632598877,10.26333999633789,7.5132880210876465,3.9411020278930664,3.6593005657196045,3.3989384174346924,9.461871147155762,9.501229286193848,9.475247383117676,9.525157928466797,9.512261390686035,9.171882629394531,8.695228576660156,8.556159019470215,8.225634574890137,7.600454807281494,8.040409088134766,8.13686466217041,7.8190388679504395,6.865623950958252,8.178438186645508,7.603334903717041,7.407918453216553,7.6145100593566895,7.625192165374756,7.701460361480713,8.602351188659668,8.543787002563477,7.351352691650391,7.625497817993164,7.3621649742126465,8.776116371154785,9.173221588134766,10.192843437194824,10.937651634216309,10.843069076538086,10.789069175720215,10.372530937194824,10.407407760620117,10.383590698242188,10.26710033416748,10.397639274597168,10.366907119750977,10.105198860168457,10.03740119934082,10.151762008666992,10.486390113830566,11.04278564453125,0.20198550820350647,0.08605940639972687,-0.9407206773757935,-1.1527825593948364,-0.9478469491004944,-1.4751579761505127,-1.6443144083023071,-1.7268527746200562,-1.3083760738372803,-0.9204304218292236,-2.1250529289245605,-2.157783269882202,-1.3036139011383057,0.8436668515205383,0.6971858143806458,0.7216988205909729,-0.02195739559829235,-0.053034231066703796,0.29972803592681885,0.39723557233810425,0.5635221600532532,0.46888479590415955,1.2184293270111084,-0.9466410279273987,-1.2134042978286743,-0.9386687874794006,-1.251611351966858,1.356000542640686,1.345694661140442,1.349893569946289,1.360270380973816,1.3066130876541138,1.3409675359725952,1.3585238456726074,1.328229308128357,1.362030267715454,3.247603416442871,3.186701536178589,1.4117631912231445,1.3518294095993042,1.3520368337631226,5.720180988311768,5.75377893447876,5.7326436042785645,5.753345489501953,5.764362335205078,5.789052963256836,5.509426116943359,5.53494119644165,5.562588214874268,5.139019012451172,5.350262641906738,-2.162635326385498,-4.143927097320557,-4.153299808502197,9.012527465820313,8.973054885864258,8.881601333618164,8.821757316589355,8.830777168273926,8.883577346801758,9.295044898986816,9.32672119140625,8.916173934936523,8.987282752990723,8.467034339904785,8.538131713867188,8.13381290435791,7.864161491394043,0.5553640127182007,0.5526771545410156,0.5694049596786499,0.536195695400238,0.5483723282814026,0.5811672806739807,0.5388039946556091,0.5446354746818542,3.664513349533081,4.975910186767578,4.964607238769531,4.244365692138672,4.309198379516602,3.669846296310425,10.424453735351563,10.500658988952637,10.475022315979004,10.727561950683594,11.260108947753906,11.697587966918945,11.455618858337402,10.843809127807617,10.741732597351074,10.083797454833984,8.522900581359863,8.792622566223145,8.454163551330566,7.973622798919678,10.424294471740723,10.457905769348145,10.478781700134277,11.313411712646484,11.333459854125977,11.341975212097168,11.344931602478027,11.32780933380127,11.22539234161377,11.248284339904785,11.275768280029297,11.540070533752441,11.511908531188965,11.656217575073242,-3.243248701095581,-3.2285878658294678,-3.2559590339660645,-3.256493091583252,-3.2398581504821777,-3.2425055503845215,-3.249584436416626,-3.236861228942871,-3.2722058296203613,-3.2478272914886475,-3.254406213760376,-3.2420854568481445,-3.2349014282226563,-3.2388217449188232,9.13414192199707,9.092935562133789,9.328484535217285,10.081605911254883,10.148704528808594,10.213123321533203,9.918503761291504,6.695074558258057,6.5857086181640625,7.2665605545043945,7.041441917419434,7.146498680114746,8.214510917663574,10.238729476928711,11.133030891418457,10.840137481689453,10.919046401977539,10.629080772399902,11.424233436584473,11.342596054077148,11.098297119140625,11.089215278625488,10.834510803222656,10.758599281311035,10.829803466796875,10.818068504333496,10.875765800476074,10.793608665466309,9.659876823425293,9.8004150390625,9.798086166381836,9.916373252868652,9.907533645629883,9.860933303833008,9.859013557434082,9.855037689208984,9.401557922363281,8.178369522094727,8.091338157653809,8.119604110717773,7.668276309967041,7.146867752075195,9.937491416931152,10.653753280639648,10.642251968383789,10.870840072631836,10.99298095703125,11.088801383972168,10.949877738952637,10.921440124511719,10.986006736755371,10.631462097167969,10.580109596252441,10.157822608947754,10.187657356262207,10.217286109924316,11.2526273727417,11.357195854187012,11.394304275512695,11.3475923538208,11.290051460266113,11.316307067871094,10.622326850891113,10.510119438171387,10.14670181274414,9.494318008422852,9.485129356384277,9.374979019165039,9.457174301147461,9.521970748901367,11.153070449829102,11.196512222290039,11.22141170501709,11.199467658996582,11.136377334594727,10.999654769897461,10.34263801574707,10.232163429260254,10.11909008026123,10.014984130859375,10.100181579589844,10.057547569274902,10.27149772644043,10.473298072814941,7.323301792144775,7.3078436851501465,7.330101013183594,7.350125789642334,7.366092681884766,7.424105167388916,6.429973602294922,6.472049713134766,5.730808258056641,6.254959583282471,7.069186210632324,7.16874361038208,6.233596324920654,6.275448322296143,10.036249160766602,10.4739408493042,11.054662704467773,10.197725296020508,-0.23082014918327332,-0.32273778319358826,-0.296926885843277,-0.3899793326854706,-0.11463287472724915,0.6930339932441711,0.6330435872077942,0.6704826354980469,0.7092622518539429,5.56100606918335,7.206421852111816,7.204376220703125,7.179383277893066,7.07633638381958,7.005861759185791,7.000707149505615,6.37888765335083,6.29983377456665,6.306453227996826,6.181396484375,5.994055271148682,5.471960067749023,5.521902561187744,5.474081993103027,7.7048258781433105,7.718585014343262,7.467582702636719,4.676033973693848,4.608257293701172,4.527527809143066,4.374815464019775,3.1387062072753906,1.6802996397018433,1.6054729223251343,1.6188231706619263,1.6767170429229736,1.5115841627120972,1.6124502420425415,10.983885765075684,11.272062301635742,11.206934928894043,11.229754447937012,11.246251106262207,10.692728042602539,10.122651100158691,10.137369155883789,11.167060852050781,10.36453628540039,8.321198463439941,8.194808006286621,9.617566108703613,10.07862377166748,11.410792350769043,11.388986587524414,11.430083274841309,11.798306465148926,11.808707237243652,11.807979583740234,11.806583404541016,11.805964469909668,11.838850021362305,11.396072387695313,11.406822204589844,11.826691627502441,11.791280746459961,11.775638580322266,10.71786117553711,10.790961265563965,10.71975040435791,11.244921684265137,11.54752254486084,8.429076194763184,10.786613464355469,10.727083206176758,10.792316436767578,10.837260246276855,10.842588424682617,11.490242958068848,5.7662577629089355,0.7572008967399597,4.350083351135254,4.349488258361816,4.325419902801514,4.15783166885376,4.193470478057861,4.1070942878723145,3.696578025817871,2.194477081298828,1.375599980354309,1.3522047996520996,1.3604964017868042,1.340325117111206,1.3187402486801147,1.305595874786377,10.348791122436523,10.378377914428711,10.43679428100586,10.398462295532227,10.451268196105957,10.520569801330566,10.707365989685059,10.90261173248291,11.088293075561523,11.084905624389648,11.072999954223633,11.076881408691406,10.964340209960938,10.609731674194336,9.704960823059082,9.67828369140625,9.721664428710938,9.73350715637207,9.715421676635742,9.90831470489502,9.661823272705078,8.516738891601563,8.2946138381958,7.900079727172852,7.2952165603637695,7.642848014831543,7.3268656730651855,7.035141944885254,11.598512649536133,11.676039695739746,7.1511101722717285,5.2031025886535645,11.680784225463867,11.57148265838623,11.53479290008545,10.640609741210938,10.958559036254883,11.1611967086792,11.172674179077148,11.215544700622559,10.931618690490723,10.409128189086914,7.871585369110107,7.757556915283203,6.613193035125732,4.60378885269165,4.580202102661133,4.48568058013916,4.355765342712402,3.88259220123291,1.3507401943206787,1.3094406127929688,1.2295225858688354,0.8663371801376343,-0.9842110872268677,-1.0967366695404053,6.050915718078613,10.808952331542969,10.688343048095703,10.599047660827637,10.628637313842773,10.686416625976563,11.580109596252441,11.620828628540039,11.479552268981934,11.257987976074219,11.134809494018555,11.283780097961426,11.136947631835938,8.589527130126953,11.380413055419922,11.4107084274292,11.411626815795898,10.904051780700684,10.849061012268066,10.531403541564941,8.675207138061523,7.093214511871338,7.390585422515869,7.322723388671875,7.098674774169922,9.826761245727539,11.473219871520996,11.351065635681152,5.921265125274658,5.865864276885986,5.841553688049316,6.274727821350098,6.323462009429932,6.317956924438477,6.278561592102051,6.362401485443115,6.3896684646606445,6.293072700500488,6.141216278076172,6.173363208770752,6.050761699676514,5.903008460998535,3.296971321105957,4.608026504516602,4.632678031921387,4.640366077423096,6.704969882965088,6.69572114944458,6.745856285095215,6.536929130554199,6.5679450035095215,6.327332019805908,4.465911865234375,3.617636203765869,1.7422372102737427,1.3576278686523438,9.735468864440918,9.700339317321777,10.187546730041504,10.089154243469238,10.122735977172852,10.200262069702148,10.568305015563965,10.556541442871094,10.566856384277344,10.402519226074219,10.080438613891602,9.12597370147705,9.197677612304688,9.203965187072754,7.144068717956543,7.0786967277526855,7.098791122436523,6.294972896575928,6.278591156005859,6.3423590660095215,6.347041130065918,5.609101295471191,6.682531833648682,7.532352447509766,7.4654340744018555,7.430347919464111,7.4568963050842285,6.760825157165527,7.4925384521484375,8.015846252441406,8.094691276550293,7.990213394165039,8.051129341125488,7.990128040313721,7.198091506958008,7.069889545440674,7.065487384796143,6.64115571975708,6.836697101593018,6.931643962860107,6.937525272369385,6.8823018074035645,4.422707557678223,4.308971405029297,4.326143741607666,6.641602516174316,6.872820854187012,6.570549488067627,6.428488254547119,5.709353446960449,6.113505840301514,7.216436386108398,6.887476444244385,7.180124282836914,6.639552116394043,5.7888078689575195,10.187224388122559,10.22317123413086,10.229336738586426,10.243118286132813,10.279559135437012,10.672699928283691,10.723109245300293,11.110807418823242,10.961649894714355,11.189165115356445,11.761524200439453,11.214786529541016,11.645200729370117,11.636221885681152,4.776162147521973,4.462756633758545,4.438321590423584,4.193322658538818,4.023646354675293,1.741392731666565,1.023323655128479,0.9979850053787231,0.9767364859580994,1.1151461601257324,-1.0805548429489136,-0.8396053910255432,-0.4899556636810303,-0.8550353050231934,9.718074798583984,9.733409881591797,9.725327491760254,9.718337059020996,9.70634937286377,9.764810562133789,9.748337745666504,9.731191635131836,9.719996452331543,9.722460746765137,9.69942855834961,9.673023223876953,9.828006744384766,9.846566200256348,5.3190016746521,4.930098533630371,4.928864479064941,3.7980034351348877,4.158920764923096,4.391729831695557,6.955138206481934,6.840256690979004,6.994187355041504,5.785046100616455,5.642500400543213,4.969557285308838,4.59122896194458,3.102060317993164,6.512679100036621,6.464648246765137,6.475903511047363,6.48853874206543,6.447718143463135,6.422237396240234,6.421186923980713,6.455896854400635,6.879085063934326,7.728213787078857,7.165212631225586,7.088332653045654,7.112737655639648,7.08611536026001,3.7195932865142822,3.7622745037078857,3.7626984119415283,3.8326144218444824,3.8889596462249756,3.899644136428833,4.015657424926758,4.296349048614502,4.664896488189697,4.595386505126953,4.555699348449707,4.6930251121521,6.336247444152832,6.345426559448242,11.594311714172363,11.639581680297852,11.612499237060547,11.619817733764648,11.631875038146973,11.569222450256348,11.494218826293945,10.991260528564453,10.799957275390625,10.895559310913086,10.83079719543457,10.783288955688477,10.631758689880371,10.597359657287598,10.414346694946289,10.439628601074219,10.451513290405273,10.22831916809082,10.178603172302246,10.194348335266113,10.21805191040039,10.546197891235352,10.522082328796387,10.739642143249512,10.705717086791992,10.744038581848145,10.431507110595703,10.412209510803223,4.818734169006348,4.828618049621582,4.856924057006836,4.942906379699707,5.006046295166016,5.3432512283325195,5.5310773849487305,5.711170196533203,6.229060649871826,6.393820762634277,6.429704189300537,6.166497230529785,6.32981014251709,6.322540760040283,4.240326404571533,4.241989612579346,4.217100143432617,4.358229160308838,4.660523891448975,4.812814712524414,4.813248634338379,4.693925380706787,5.569064617156982,5.499852657318115,5.7821197509765625,6.172586917877197,6.387448787689209,6.383066177368164,11.313010215759277,11.283062934875488,11.099682807922363,11.441542625427246,11.50576400756836,11.415834426879883,11.33990478515625,11.409956932067871,11.366625785827637,11.352012634277344,11.273090362548828,10.754541397094727,10.064525604248047,10.028777122497559,-0.7390076518058777,-0.7188136577606201,-0.6058386564254761,-0.41623640060424805,-0.40476667881011963,-0.36881473660469055,-0.37024787068367004,-0.37667006254196167,-0.35563138127326965,-0.4006628394126892,-0.5118539333343506,-1.037057638168335,-1.4860128164291382,-1.361696720123291,8.623141288757324,8.603851318359375,8.604555130004883,8.493634223937988,8.08691120147705,7.905994892120361,7.967815399169922,7.638726234436035,7.9141035079956055,7.876916408538818,7.113124370574951,6.904797554016113,6.832399845123291,6.804060459136963,5.0387864112854,5.093127727508545,5.096921920776367,4.994379997253418,5.09384298324585,5.038567543029785,5.327444553375244,5.3552632331848145,5.261084079742432,5.538576126098633,5.197706699371338,5.375542640686035,5.665014266967773,5.5434370040893555,5.292306900024414,5.009424686431885,4.82915735244751,4.980851650238037,5.075204372406006,5.09602165222168,4.810480117797852,4.8422369956970215,4.970874309539795,5.06359338760376,5.086469650268555,5.124920845031738,5.316905498504639,5.846322536468506,4.919826984405518,4.920114040374756,4.950286865234375,4.986847877502441,4.980019569396973,4.986659049987793,4.9157938957214355,5.023682117462158,5.017397403717041,5.0360612869262695,5.027148723602295,5.0451483726501465,5.02789831161499,5.040866374969482,7.3328537940979,6.121623992919922,6.082657337188721,5.601258754730225,5.554145336151123,5.4422101974487305,5.859708309173584,6.477302074432373,6.877957344055176,7.121106147766113,7.053776264190674,7.080846309661865,7.197797775268555,6.688049793243408,11.525062561035156,11.539824485778809,11.563831329345703,11.300679206848145,11.312092781066895,11.526761054992676,11.484890937805176,10.895423889160156,11.178948402404785,11.224569320678711,11.264623641967773,11.306317329406738,11.122807502746582,11.28665542602539,11.633445739746094,11.557188987731934,11.60388469696045,11.55711841583252,11.573092460632324,11.528266906738281,11.54708194732666,11.549246788024902,11.357152938842773,11.318511009216309,11.346749305725098,11.393836975097656,11.348052024841309,11.359138488769531,11.046696662902832,11.042295455932617,11.135769844055176,11.607705116271973,11.729655265808105,11.773710250854492,11.739115715026855,11.778820037841797,11.741843223571777,11.224197387695313,11.792708396911621,11.251834869384766,11.309837341308594,11.818587303161621,11.338160514831543,10.797049522399902,10.41944694519043,9.016411781311035,7.809918403625488,7.078792095184326,6.711690425872803,6.593343734741211,7.221261501312256,11.49169635772705,11.570321083068848,11.527121543884277,11.53414249420166,11.55481243133545,11.127522468566895,11.123430252075195,11.129971504211426,11.111285209655762,11.104345321655273,11.508395195007324,11.563103675842285,11.562043190002441,11.547173500061035,11.649249076843262,11.675054550170898,11.683676719665527,11.640115737915039,11.056007385253906,5.130229473114014,5.581509113311768,5.588290691375732,5.5905842781066895,5.599753379821777,5.5940423011779785,5.601898193359375,5.567968368530273,5.572248935699463,5.5419921875,5.563019275665283,5.588675022125244,5.558037281036377,5.535925388336182,6.335326194763184,6.367101192474365,6.31591796875,6.334883213043213,6.26210880279541,6.295660018920898,5.520418643951416,5.682163238525391,5.676873207092285,6.774847984313965,6.838743209838867,6.842121601104736,6.978734970092773,6.96337890625,9.96605110168457,10.011836051940918,9.98047924041748,9.954187393188477,10.009780883789063,9.950529098510742,9.977195739746094,10.072840690612793,10.204949378967285,10.229569435119629,10.18797779083252,10.205667495727539,10.325366973876953,10.336618423461914,10.642205238342285,10.611769676208496,10.441237449645996,10.418391227722168,10.433127403259277,10.356285095214844,10.352270126342773,10.36114501953125,10.487587928771973,10.487396240234375,10.459895133972168,10.500371932983398,10.682926177978516,10.8519926071167,-4.683096408843994,-4.642366886138916,-4.689113616943359,-4.700806617736816,-4.6884870529174805,-4.717523097991943,-4.71198844909668,-4.724626541137695,-4.707200050354004,-4.7065911293029785,-4.684561252593994,-4.1115546226501465,-4.129091262817383,-4.070100784301758,10.138986587524414,10.179868698120117,10.150731086730957,10.115656852722168,10.12997817993164,10.132203102111816,10.131725311279297,10.258938789367676,10.791516304016113,10.814811706542969,11.260807991027832,11.359264373779297,11.455517768859863,11.11773681640625,4.908994674682617,4.8480095863342285,5.515900135040283,6.026547908782959,6.03011417388916,6.759940147399902,6.850930690765381,7.266087532043457,6.907071113586426,6.111025333404541,5.946588516235352,6.962222099304199,6.648393630981445,7.2244791984558105,-2.0391294956207275,-2.134812116622925,-2.2082297801971436,-2.2332756519317627,-2.2662227153778076,-2.3038151264190674,-2.286127805709839,-2.2385666370391846,-2.2168896198272705,-2.2433066368103027,-2.2421011924743652,-2.2575571537017822,-2.2578418254852295,-2.011916399002075,1.5780012607574463,6.9216814041137695,9.888040542602539,9.984760284423828,10.564509391784668,10.813164710998535,10.777180671691895,10.821510314941406,9.535900115966797,9.753718376159668,10.120929718017578,11.812605857849121,6.095309257507324,9.661115646362305,10.685880661010742,10.589458465576172,10.55388355255127,9.645833969116211,8.818193435668945,7.9593658447265625,4.649352073669434,4.242201805114746,4.268263339996338,4.246793270111084,4.210719108581543,4.09108304977417,4.019172668457031,3.9823102951049805,9.369141578674316,9.315546989440918,9.291961669921875,9.116669654846191,8.258410453796387,8.6331205368042,8.714704513549805,8.617148399353027,8.587591171264648,10.236886024475098,10.282590866088867,10.229620933532715,8.510339736938477,8.660781860351563,6.416276454925537,5.781604290008545,5.71309232711792,5.712673187255859,5.706681728363037,5.997751712799072,6.002592086791992,5.762876510620117,5.48691463470459,6.024261951446533,5.5673394203186035,5.942711353302002,7.059621810913086,6.880589962005615,3.0636508464813232,3.1129701137542725,3.120083808898926,3.110687017440796,3.105982780456543,3.323664903640747,3.3189070224761963,3.4220283031463623,3.394120693206787,3.4147746562957764,4.60101318359375,4.956226825714111,5.843770980834961,5.344339847564697,4.750020980834961,4.742623805999756,4.722923278808594,4.529565811157227,4.408324241638184,4.43203067779541,4.1324076652526855,4.081486701965332,4.128147125244141,3.838654041290283,3.8864524364471436,3.7725608348846436,3.3776350021362305,3.4791877269744873,0.5914524793624878,3.9132494926452637,3.9094974994659424,3.918668746948242,3.9436395168304443,3.9122962951660156,3.932234048843384,4.002462863922119,4.5008769035339355,4.493009090423584,4.402589797973633,4.354463577270508,4.443207263946533,4.431478977203369,5.722714424133301,5.804318428039551,6.304871082305908,6.2043657302856445,6.550690650939941,6.23036527633667,6.830244064331055,7.7398786544799805,11.350529670715332,8.564046859741211,8.913803100585938,10.170042037963867,10.634308815002441,11.372175216674805,-0.2836557924747467,-0.35406550765037537,-0.3956194519996643,-0.3945411443710327,-0.8088910579681396,-0.8604772090911865,-0.6613179445266724,-0.45410600304603577,-0.902247428894043,-0.874009907245636,-0.9122235774993896,-0.8971763253211975,-1.2149103879928589,-1.188187599182129,0.5171247720718384,0.373506635427475,0.459129273891449,0.6467705368995667,0.6569714546203613,0.8876022696495056,1.0531014204025269,1.0603680610656738,1.0913058519363403,1.1323679685592651,-0.16229763627052307,-1.6745538711547852,-1.6164264678955078,-1.8292287588119507,4.924452781677246,4.956860065460205,5.013908863067627,4.935074806213379,4.984228134155273,4.95669412612915,4.013236999511719,3.859480381011963,3.8093597888946533,3.751924753189087,3.7676470279693604,3.8077685832977295,3.9448635578155518,3.84405779838562,3.0554826259613037,2.963117837905884,2.9613230228424072,2.9514667987823486,2.841488838195801,2.887582540512085,2.949951171875,2.768184185028076,2.770083427429199,2.8208396434783936,2.824093818664551,-0.9195181727409363,-1.2248214483261108,-1.013596773147583,-3.4250619411468506,-3.375575304031372,-3.3972151279449463,-3.4740726947784424,-3.5180671215057373,-3.5016355514526367,-3.507412910461426,-3.5068230628967285,-3.4810638427734375,-3.5065102577209473,-3.491776943206787,-3.5076663494110107,-3.5249361991882324,-3.46657657623291,6.580636024475098,6.52240514755249,4.885214328765869,4.730257034301758,4.789502143859863,4.678447246551514,4.663509368896484,4.621474266052246,4.701218128204346,6.201676845550537,6.283622741699219,5.340299606323242,4.990912914276123,4.375077247619629,2.665006637573242,2.6310205459594727,2.6086699962615967,2.601116895675659,2.6321988105773926,2.6123569011688232,2.6335678100585938,3.328253746032715,3.4791183471679688,3.334733247756958,3.4603769779205322,3.4766077995300293,3.313209295272827,3.432346820831299,2.5735390186309814,2.6378467082977295,2.6185405254364014,2.600867509841919,2.5872538089752197,2.585972785949707,2.5946547985076904,2.6157114505767822,2.7354040145874023,2.7255947589874268,2.641021490097046,2.690248489379883,2.835857629776001,2.84501314163208,10.52052116394043,10.45514965057373,10.445319175720215,10.448509216308594,10.461698532104492,10.33633804321289,10.22728157043457,10.1913423538208,10.223849296569824,10.237005233764648,10.657565116882324,10.439424514770508,10.453203201293945,10.520252227783203,-4.208694934844971,-4.195528507232666,-4.220811367034912,-4.182883262634277,-4.195300579071045,-4.208470344543457,-4.205544471740723,-4.240062236785889,-4.217257976531982,-4.198598861694336,-4.242758274078369,-4.208666801452637,-4.214649200439453,-4.217524528503418,7.593484401702881,7.545976638793945,7.706315517425537,7.797245502471924,7.749517917633057,7.787816047668457,7.842193126678467,8.285840034484863,7.822185039520264,7.704049110412598,7.643370151519775,7.563340663909912,7.428537845611572,6.050389766693115,2.6414027214050293,2.641284704208374,2.711291790008545,2.548804998397827,2.546196699142456,2.5944201946258545,2.682404041290283,11.229781150817871,11.598936080932617,11.575011253356934,11.363147735595703,11.432323455810547,11.198380470275879,11.048269271850586,10.54024600982666,10.497293472290039,10.596524238586426,10.933066368103027,10.547502517700195,10.612948417663574,10.36851978302002,10.393969535827637,10.583775520324707,11.077726364135742,11.175762176513672,11.125173568725586,11.12719440460205,11.567435264587402,7.305401802062988,7.2564802169799805,5.049165725708008,5.237386703491211,7.246236801147461,9.90410327911377,9.986743927001953,9.926785469055176,9.991310119628906,10.112960815429688,10.22244930267334,10.149003028869629,5.575377941131592,7.003884792327881,9.267011642456055,9.296525955200195,8.970088005065918,8.528425216674805,8.517509460449219,8.532684326171875,8.447668075561523,8.248098373413086,8.34949016571045,8.319734573364258,8.309995651245117,8.476791381835938,8.503687858581543,8.853334426879883,0.6853628158569336,0.6785715818405151,0.6517889499664307,0.6505544185638428,0.6561660170555115,0.6921234726905823,0.6965399384498596,0.7094531059265137,0.6772270202636719,0.6790428161621094,0.6791935563087463,0.984338104724884,3.7238101959228516,3.8608055114746094,7.732239723205566,10.203364372253418,10.135416984558105,9.963907241821289,9.98728084564209,9.98464584350586,9.902950286865234,9.910662651062012,10.346311569213867,9.991227149963379,7.504022121429443,7.993561267852783,7.095268726348877,6.082073211669922,-0.9141013026237488,-0.921611487865448,-0.9768655300140381,-0.997477114200592,-1.0068460702896118,-1.0467020273208618,-1.0033448934555054,-0.6371169686317444,-0.6158213019371033,-0.522630512714386,-0.6031065583229065,-0.46965283155441284,-0.4158633351325989,-0.4642457365989685,-3.506065845489502,-0.8806654810905457,6.740983486175537,10.18344783782959,4.559426307678223,4.622636795043945,4.617586612701416,4.356962203979492,4.011587142944336,3.9797184467315674,3.9080395698547363,2.626415252685547,2.1753437519073486,1.8851897716522217,2.187803268432617,2.426556348800659,2.4167582988739014,3.6187658309936523,8.965478897094727,9.271086692810059,9.282341003417969,9.2698974609375,9.4764986038208,9.326873779296875,9.329663276672363,9.280004501342773,9.303001403808594,9.187444686889648,11.30654239654541,10.703744888305664,10.761933326721191,11.028155326843262,11.12775993347168,11.794559478759766,11.663748741149902,11.30355453491211,11.185285568237305,11.193452835083008,10.541101455688477,8.806044578552246,8.790732383728027,9.622509002685547,11.146744728088379,11.12697982788086,11.115606307983398,10.983654022216797,10.947901725769043,10.32336711883545,10.321263313293457,10.396523475646973,10.999826431274414,11.259161949157715,11.313275337219238,11.341572761535645,11.279047012329102,11.562317848205566,3.981611490249634,3.9233803749084473,3.9779844284057617,4.412283420562744,4.478823184967041,4.318641185760498,4.307979106903076,4.443578720092773,4.700939178466797,5.670840740203857,4.179499626159668,3.9379794597625732,3.7810535430908203,3.7568626403808594,3.3042733669281006,3.3065922260284424,3.2822980880737305,3.3156116008758545,3.3114500045776367,3.345060348510742,3.2809340953826904,3.3070123195648193,3.282489061355591,3.2873079776763916,3.2097525596618652,2.8729758262634277,2.8185644149780273,2.213339328765869,0.10744742304086685,0.23618991672992706,-0.03427647054195404,-0.11835005134344101,-0.09345326572656631,-0.08628363907337189,-0.13450080156326294,-0.04074105620384216,-0.22964057326316833,-0.2731034755706787,-0.21103212237358093,-0.13034626841545105,-0.16018231213092804,-0.03695603832602501,7.406432628631592,7.366506576538086,7.421381950378418,8.142305374145508,8.096619606018066,11.107741355895996,11.169896125793457,11.25704574584961,11.262094497680664,11.64007568359375,10.817909240722656,11.129980087280273,11.454378128051758,11.405233383178711,-0.5019323825836182,-0.5230749845504761,-0.5061882138252258,-0.5266324877738953,-0.5061051845550537,-0.46465960144996643,-0.44856441020965576,-0.5126320719718933,-0.4575793743133545,-0.3984459936618805,-0.44961872696876526,-0.5864098072052002,-0.581173837184906,-0.5104697942733765,-0.08021724969148636,-0.08798779547214508,-0.21513618528842926,-0.9355441331863403,-1.0030348300933838,-1.4988073110580444,-1.7136101722717285,-1.6906111240386963,-1.7310813665390015,-1.7956682443618774,-1.6490591764450073,-1.6608307361602783,-1.769101858139038,-1.715106725692749,7.048044681549072,7.110944747924805,7.055549144744873,7.114124298095703,7.243028163909912,7.283170700073242,7.285729885101318,7.146535873413086,7.229655742645264,7.755113124847412,9.123600006103516,8.459997177124023,8.514191627502441,7.778850078582764,9.614999771118164,9.57430648803711,9.603361129760742,9.770339965820313,9.800682067871094,9.553205490112305,9.647780418395996,9.66987133026123,9.745753288269043,9.767108917236328,9.66211223602295,9.573677062988281,9.579244613647461,9.505471229553223,-2.3413631916046143,-2.319343328475952,-2.380545139312744,-2.4524972438812256,-2.4270544052124023,-2.4014906883239746,-2.4098658561706543,-2.4255197048187256,-2.4251785278320313,-2.4303581714630127,-2.4104111194610596,-2.4253811836242676,-2.3875677585601807,-2.4362549781799316,-0.232153981924057,-0.31223469972610474,-0.21958115696907043,-0.7389122843742371,-0.7375187873840332,-0.8412407636642456,-0.7982170581817627,-0.8027244210243225,-1.334420084953308,-0.8140977621078491,-0.9523364305496216,-0.8170613050460815,-0.8014298677444458,-0.8067044019699097,8.642410278320313,9.118310928344727,9.134241104125977,7.973268508911133,7.94368839263916,7.976707935333252,7.944949626922607,8.09032154083252,7.643249988555908,7.679279804229736,7.693776607513428,7.984017848968506,8.02730655670166,7.932512283325195,-2.1453394889831543,-2.169757127761841,-2.1784772872924805,-2.112513780593872,-2.1557397842407227,-2.1240711212158203,-2.1195974349975586,-1.3671624660491943,-0.9549309015274048,-0.6589084267616272,-0.5841580629348755,-0.5354807376861572,-0.48561641573905945,-0.16775619983673096,5.81535005569458,5.903055191040039,5.894747734069824,5.154096603393555,5.235518455505371,5.148983955383301,5.922921180725098,5.8510823249816895,5.95168399810791,5.937606334686279,5.9637980461120605,6.876658916473389,7.243834972381592,7.178570747375488,0.6061810255050659,-1.6196296215057373,-1.8624714612960815,-2.0533719062805176,-2.023733377456665,-2.3742711544036865,-2.346967935562134,-2.391495704650879,-2.399797201156616,-2.4072482585906982,-2.403813600540161,-2.3809144496917725,-2.3607850074768066,-2.2490382194519043,11.564081192016602,11.56374740600586,11.56201171875,11.55578327178955,11.55491828918457,11.602097511291504,11.56673526763916,11.560356140136719,11.557144165039063,11.573690414428711,11.521546363830566,11.517400741577148,11.548648834228516,11.560794830322266,4.867428779602051,4.891769886016846,4.86782693862915,4.705552101135254,4.7182159423828125,4.7075514793396,4.818459987640381,4.821555137634277,4.810374736785889,4.913201332092285,5.38414192199707,5.352808952331543,5.337046146392822,5.347259521484375,10.975275039672852,10.972017288208008,10.940792083740234,10.796181678771973,10.763752937316895,10.741791725158691,10.741412162780762,10.743191719055176,10.52723217010498,10.504557609558105,10.423089027404785,10.452981948852539,10.56961441040039,10.493098258972168,10.800518035888672,10.742826461791992,10.735299110412598,10.374078750610352,10.262612342834473,10.359800338745117,10.268932342529297,10.543784141540527,10.642483711242676,10.692073822021484,10.652588844299316,10.269330024719238,10.035418510437012,10.384184837341309,9.08620548248291,9.409675598144531,9.348326683044434,10.112924575805664,10.080099105834961,8.633424758911133,8.439393997192383,7.64752721786499,6.904173374176025,4.6821489334106445,4.322521209716797,4.3371262550354,4.252709865570068,4.117480278015137,7.762065410614014,7.635255336761475,7.1957621574401855,7.18750524520874,7.133875846862793,7.384002208709717,8.77463436126709,9.176711082458496,9.133456230163574,9.12629508972168,8.871235847473145,9.14159870147705,9.379377365112305,9.451281547546387,-1.2572351694107056,-1.2892245054244995,-1.2338720560073853,-1.2498046159744263,-1.2826142311096191,-1.2764426469802856,-1.244720458984375,-1.2461498975753784,-1.0724101066589355,-0.9470597505569458,-1.011349081993103,-1.0059736967086792,-1.0302376747131348,-1.0347405672073364,7.713896751403809,7.701608180999756,7.724490165710449,7.64776611328125,7.7166056632995605,7.680488586425781,7.6716413497924805,7.896093845367432,7.9684624671936035,7.917308330535889,8.540517807006836,8.98622989654541,9.37052059173584,9.428323745727539,6.1673583984375,6.008610725402832,5.986048698425293,6.7572760581970215,7.2348737716674805,7.2111053466796875,7.290185928344727,7.842461109161377,8.295451164245605,8.435287475585938,8.282814979553223,8.52653980255127,7.329608917236328,6.911202907562256,3.3097314834594727,3.3279666900634766,3.3405537605285645,3.3279831409454346,3.327258825302124,3.3116517066955566,3.317676305770874,3.3562893867492676,3.3115649223327637,3.369051694869995,3.388836622238159,3.4585273265838623,3.359720230102539,3.361863613128662,-1.5522336959838867,-1.4856131076812744,-1.482596755027771,-1.45545494556427,-1.419832706451416,-1.4070020914077759,-1.4370124340057373,-1.4850928783416748,-1.5062521696090698,-1.473440170288086,-1.5154271125793457,-1.543723225593567,-1.5414878129959106,-1.446520209312439,5.538898468017578,5.593029975891113,5.598587989807129,5.61851692199707,5.687356948852539,5.38893461227417,4.323390960693359,4.297850131988525,4.235830307006836,5.237819671630859,5.304293632507324,5.3213300704956055,5.359333038330078,5.309196949005127,-0.3830905854701996,-0.40807244181632996,-0.31198132038116455,-0.26730814576148987,0.48985064029693604,7.143841743469238,7.141297817230225,7.180390357971191,7.1741943359375,7.103638648986816,7.1433796882629395,7.19162130355835,7.288501262664795,11.051033973693848,5.754725933074951,5.718924522399902,5.770202159881592,5.754879474639893,5.779617786407471,6.46176290512085,6.518881797790527,6.462344646453857,6.107590675354004,6.028564453125,6.09339714050293,6.264530181884766,6.2691240310668945,6.5415778160095215,5.783688068389893,5.726205348968506,5.940698146820068,6.215394020080566,6.166827201843262,5.619961738586426,5.679413318634033,5.719667434692383,5.962587356567383,5.870491981506348,7.729706764221191,8.803157806396484,8.802467346191406,8.934677124023438,10.945963859558105,10.900687217712402,10.978442192077637,10.947890281677246,10.98685359954834,10.722079277038574,10.585710525512695,10.622283935546875,10.622547149658203,10.730579376220703,11.131993293762207,10.733283042907715,10.548517227172852,10.408259391784668,7.3092265129089355,7.287774085998535,7.2610697746276855,7.195849418640137,7.233201026916504,7.127503871917725,7.078012466430664,7.0368523597717285,7.018257141113281,7.021107196807861,4.898928165435791,0.27722659707069397,-0.38656917214393616,-0.48019036650657654,5.205017566680908,5.231743812561035,5.30745267868042,5.744231224060059,5.791388988494873,5.649155139923096,5.704184532165527,5.7895188331604,5.332771301269531,5.949397563934326,5.996328830718994,6.899664878845215,7.271779537200928,7.243911266326904,9.80096435546875,9.707972526550293,9.764204025268555,9.75576114654541,9.726710319519043,9.833883285522461,9.813504219055176,10.084814071655273,10.266206741333008,10.195406913757324,9.881033897399902,9.694073677062988,9.774580955505371,9.854538917541504,7.0414719581604,7.055877208709717,7.035454273223877,7.024281024932861,7.036534786224365,7.032586574554443,7.026435375213623,7.098608493804932,6.99498176574707,7.030168533325195,6.994837284088135,7.053191661834717,7.033372402191162,7.059123516082764,6.716259479522705,6.83772087097168,6.953611373901367,7.243605136871338,6.578035831451416,6.333528995513916,6.846861839294434,7.2130303382873535,7.018864154815674,6.646391868591309,7.070312976837158,7.377779960632324,7.364494800567627,7.444703102111816,5.570768356323242,5.583852767944336,5.606152534484863,5.681330680847168,5.771531581878662,5.577441692352295,5.5185418128967285,5.511669635772705,5.687801361083984,5.595058441162109,5.907856464385986,5.8935160636901855,6.8923444747924805,6.950409889221191,10.641927719116211,10.411116600036621,10.031218528747559,9.43030071258545,9.310407638549805,9.259056091308594,9.31049919128418,10.880416870117188,10.810606002807617,10.781248092651367,10.766990661621094,10.780349731445313,10.722536087036133,10.640950202941895,6.844435214996338,6.813677787780762,6.789178848266602,6.770442008972168,6.812073707580566,6.799659252166748,6.822874546051025,6.792963981628418,9.969528198242188,10.290383338928223,9.779437065124512,9.673643112182617,9.956805229187012,10.607552528381348,8.321293830871582,8.30293083190918,8.366456985473633,8.700053215026855,8.792448043823242,8.71651840209961,8.704222679138184,8.744060516357422,8.777548789978027,8.734299659729004,8.719222068786621,8.685588836669922,8.626364707946777,8.692242622375488,9.759613037109375,9.728100776672363,9.709297180175781,9.742788314819336,10.161675453186035,9.83742904663086,9.840513229370117,9.80630111694336,9.786816596984863,10.630727767944336,11.762697219848633,11.514862060546875,10.999164581298828,10.758240699768066,11.263736724853516,11.242403030395508,11.267236709594727,10.90829849243164,10.838746070861816,10.83895206451416,10.815836906433105,10.733281135559082,10.764551162719727,10.668317794799805,10.89906120300293,11.390520095825195,11.265755653381348,11.748043060302734,3.9636733531951904,3.8058812618255615,3.8785512447357178,3.9065988063812256,3.909390926361084,3.8741655349731445,3.8752949237823486,3.881044864654541,3.8442349433898926,3.8643205165863037,3.9318740367889404,4.2628631591796875,4.594155311584473,4.642719268798828,4.22641658782959,4.281520366668701,4.28490686416626,5.271116256713867,5.018606662750244,4.361611843109131,4.363058567047119,4.624078273773193,5.2954182624816895,5.2517170906066895,5.611593246459961,5.574742794036865,5.529741287231445,5.539073944091797,-0.192657932639122,0.3952234089374542,0.4446026682853699,0.468441903591156,0.46372556686401367,0.45114976167678833,0.47026893496513367,0.44835129380226135,0.48334360122680664,0.467107892036438,0.45414018630981445,0.47314828634262085,0.45070767402648926,0.47076067328453064,11.067392349243164,10.975049018859863,11.103569030761719,11.122349739074707,11.089643478393555,11.1436185836792,11.088285446166992,11.157617568969727,11.17851448059082,11.185649871826172,11.28870964050293,11.379636764526367,11.386565208435059,11.438050270080566,10.257608413696289,10.270275115966797,10.354695320129395,10.323680877685547,10.32072639465332,9.90906810760498,9.31862735748291,10.392327308654785,10.405258178710938,8.823257446289063,7.424073219299316,8.6893310546875,10.189815521240234,10.420677185058594,11.040213584899902,11.04001235961914,11.06824016571045,11.07923698425293,11.055773735046387,10.90226936340332,11.054337501525879,11.047564506530762,11.004218101501465,10.588312149047852,10.787480354309082,10.82917308807373,11.043510437011719,11.040386199951172,-6.0861077308654785,-6.074038505554199,-6.058431148529053,-6.074543476104736,-6.084092140197754,-6.097679615020752,-6.088987827301025,-6.0954084396362305,-6.097996711730957,-6.084158897399902,-6.081751346588135,-6.077144145965576,-6.0884575843811035,-6.0958781242370605,11.12891674041748,11.098604202270508,11.22653865814209,11.289251327514648,10.609047889709473,10.41884708404541,10.122224807739258,8.461019515991211,8.046445846557617,8.27026081085205,7.3609418869018555,7.036215782165527,7.547691345214844,7.613012790679932,10.249161720275879,10.244909286499023,10.225846290588379,10.24438190460205,10.33009147644043,10.475653648376465,11.784961700439453,11.818267822265625,11.786008834838867,11.817584037780762,11.719369888305664,11.485051155090332,11.602654457092285,11.55687427520752,7.498001575469971,7.513347148895264,7.513449668884277,7.536283493041992,7.500420570373535,7.514780521392822,7.512588977813721,7.51409387588501,7.529664039611816,7.524192810058594,7.51027250289917,7.488511085510254,7.514518737792969,7.527573585510254,5.57945442199707,5.520449638366699,5.637399196624756,6.293097972869873,6.236682891845703,6.22346830368042,6.350114345550537,6.570675849914551,7.33068323135376,6.559481620788574,6.518612861633301,6.702265739440918,7.009204864501953,7.174210071563721,3.555718183517456,3.7310712337493896,4.397241115570068,4.804754734039307,4.79096794128418,4.716116428375244,5.054734230041504,6.127772331237793,6.673961639404297,7.166082859039307,8.730496406555176,9.379936218261719,7.44138240814209,8.708209991455078,11.608343124389648,11.676265716552734,11.69361400604248,11.648271560668945,11.70534896850586,11.674925804138184,11.68321418762207,11.609171867370605,11.625504493713379,11.491793632507324,11.522509574890137,11.57344913482666,11.55374526977539,11.583916664123535,10.454726219177246,10.441936492919922,10.437161445617676,10.432907104492188,10.389769554138184,10.384356498718262,9.828718185424805,9.776705741882324,9.804109573364258,9.844281196594238,9.921257019042969,9.667723655700684,9.664053916931152,9.614340782165527,-4.2239089012146,-4.1535539627075195,-4.138337135314941,-4.127044200897217,-4.152595520019531,-4.141263008117676,-4.129120826721191,-4.1294941902160645,-4.119740962982178,-4.1328125,-4.114788055419922,-4.1138739585876465,-4.117575645446777,-4.06279182434082,7.851515769958496,8.644308090209961,8.719929695129395,10.00423812866211,10.541245460510254,11.090682983398438,10.988962173461914,11.411834716796875,10.95401668548584,10.864349365234375,10.721436500549316,10.591670989990234,10.396490097045898,10.140639305114746,6.80040168762207,7.061926364898682,7.083214282989502,7.087783336639404,7.056252956390381,6.453259468078613,5.578685283660889,5.559208393096924,5.57698392868042,5.587254524230957,5.5546555519104,5.61317253112793,5.62117862701416,5.672938823699951],\n",
       "\"regime\":[\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Liberal Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Closed Autocracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Democracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\",\"Electoral Autocracy\"]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"first_dim\",\n",
       "\"y\":\"second_dim\",\n",
       "\"colour\":\"regime\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"first_dim\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"second_dim\"\n",
       "},{\n",
       "\"type\":\"str\",\n",
       "\"column\":\"country_year\"\n",
       "},{\n",
       "\"type\":\"str\",\n",
       "\"column\":\"regime\"\n",
       "}]\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"1\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x2813eefa570>"
      ]
     },
     "execution_count": 13,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Add country/year and regime information to the embedding\n",
    "embedding = pd.concat([embedding, vdem.filter(items=[\"country_year\",\"regime\"])], axis= 1)\n",
    "\n",
    "# Plot the results\n",
    "(\n",
    "    ggplot(embedding, aes(\"first_dim\", \"second_dim\", colour=\"regime\")) +\n",
    "    geom_point() +\n",
    "    labs(x = \"First dimension\", y = \"Second dimension\", colour = \"\")\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Note that UMAP has created a 2-map that maintains the topography of the data. Admittedly, this can be hard initially to interpret. However, we can note the following:\n",
    "\n",
    "-   This is a semi-circle configuration of points whereby less democratic regime types become more prominent.\n",
    "-   Despite this, we see considerable overlap between different regimes, indicating that considering these countries in at a given point in time to be distinctively democratic / autocratic may not be warranted in some cases.\n",
    "-   There is an outlier cluster that is distinct to the semi-circle configuration of points that UMAP provides. We can isolate these observations simply by filtering."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "array(['Burma/Myanmar-2022', 'Burma/Myanmar-2023', 'Yemen-2016',\n",
       "       'Yemen-2017', 'Yemen-2018', 'Yemen-2019', 'Yemen-2020',\n",
       "       'Yemen-2021', 'Yemen-2022', 'Yemen-2023', 'South Sudan-2017',\n",
       "       'South Sudan-2018', 'South Sudan-2021', 'South Sudan-2022',\n",
       "       'Afghanistan-2021', 'Afghanistan-2022', 'Afghanistan-2023',\n",
       "       'North Korea-2010', 'North Korea-2011', 'North Korea-2012',\n",
       "       'North Korea-2013', 'North Korea-2014', 'North Korea-2015',\n",
       "       'North Korea-2016', 'North Korea-2017', 'North Korea-2018',\n",
       "       'North Korea-2019', 'North Korea-2020', 'North Korea-2021',\n",
       "       'North Korea-2022', 'North Korea-2023', 'Qatar-2010', 'Qatar-2011',\n",
       "       'Qatar-2012', 'Qatar-2013', 'Qatar-2014', 'Qatar-2015',\n",
       "       'Qatar-2016', 'Qatar-2017', 'Qatar-2018', 'Qatar-2019',\n",
       "       'Qatar-2020', 'Qatar-2021', 'Qatar-2022', 'Qatar-2023',\n",
       "       'Syria-2010', 'Syria-2011', 'Syria-2012', 'Syria-2013',\n",
       "       'Syria-2014', 'Syria-2015', 'Syria-2016', 'Syria-2017',\n",
       "       'Syria-2018', 'Syria-2019', 'Syria-2020', 'Syria-2021',\n",
       "       'Syria-2022', 'Syria-2023', 'Belarus-2021', 'Belarus-2022',\n",
       "       'Belarus-2023', 'China-2010', 'China-2011', 'China-2012',\n",
       "       'China-2013', 'China-2014', 'China-2015', 'China-2016',\n",
       "       'China-2017', 'China-2018', 'China-2019', 'China-2020',\n",
       "       'China-2021', 'China-2022', 'China-2023', 'Eritrea-2010',\n",
       "       'Eritrea-2011', 'Eritrea-2012', 'Eritrea-2013', 'Eritrea-2014',\n",
       "       'Eritrea-2015', 'Eritrea-2016', 'Eritrea-2017', 'Eritrea-2018',\n",
       "       'Eritrea-2019', 'Eritrea-2020', 'Eritrea-2021', 'Eritrea-2022',\n",
       "       'Eritrea-2023', 'Libya-2010', 'Tajikistan-2016', 'Tajikistan-2017',\n",
       "       'Tajikistan-2018', 'Tajikistan-2019', 'Tajikistan-2020',\n",
       "       'Tajikistan-2021', 'Tajikistan-2022', 'Tajikistan-2023',\n",
       "       'Turkmenistan-2010', 'Turkmenistan-2011', 'Turkmenistan-2012',\n",
       "       'Turkmenistan-2013', 'Turkmenistan-2014', 'Turkmenistan-2015',\n",
       "       'Turkmenistan-2016', 'Turkmenistan-2017', 'Turkmenistan-2018',\n",
       "       'Turkmenistan-2019', 'Turkmenistan-2020', 'Turkmenistan-2021',\n",
       "       'Turkmenistan-2022', 'Turkmenistan-2023', 'Uzbekistan-2010',\n",
       "       'Uzbekistan-2011', 'Uzbekistan-2012', 'Uzbekistan-2013',\n",
       "       'Uzbekistan-2014', 'Uzbekistan-2015', 'Uzbekistan-2016',\n",
       "       'Bahrain-2011', 'Bahrain-2012', 'Bahrain-2013', 'Bahrain-2014',\n",
       "       'Bahrain-2015', 'Bahrain-2016', 'Bahrain-2017', 'Bahrain-2018',\n",
       "       'Bahrain-2019', 'Bahrain-2020', 'Bahrain-2021', 'Bahrain-2022',\n",
       "       'Bahrain-2023', 'Equatorial Guinea-2010', 'Equatorial Guinea-2018',\n",
       "       'Equatorial Guinea-2020', 'Equatorial Guinea-2021',\n",
       "       'Equatorial Guinea-2022', 'Saudi Arabia-2010', 'Saudi Arabia-2011',\n",
       "       'Saudi Arabia-2012', 'Saudi Arabia-2013', 'Saudi Arabia-2014',\n",
       "       'Saudi Arabia-2015', 'Saudi Arabia-2016', 'Saudi Arabia-2017',\n",
       "       'Saudi Arabia-2018', 'Saudi Arabia-2019', 'Saudi Arabia-2020',\n",
       "       'Saudi Arabia-2021', 'Saudi Arabia-2022', 'Saudi Arabia-2023',\n",
       "       'United Arab Emirates-2010', 'United Arab Emirates-2011',\n",
       "       'United Arab Emirates-2012', 'United Arab Emirates-2013',\n",
       "       'United Arab Emirates-2014', 'United Arab Emirates-2015',\n",
       "       'United Arab Emirates-2016', 'United Arab Emirates-2017',\n",
       "       'United Arab Emirates-2018', 'United Arab Emirates-2019',\n",
       "       'United Arab Emirates-2020', 'United Arab Emirates-2021',\n",
       "       'United Arab Emirates-2022', 'United Arab Emirates-2023'],\n",
       "      dtype=object)"
      ]
     },
     "execution_count": 14,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "embedding.query(\"second_dim < -1.5\")[\"country_year\"].to_numpy()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This approach yields a very interesting finding: the most notoriously undemocratic regimes in the world such as Afghanistan under the Taliban, North Korea, and Eritrea all form a part of this cluster."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.13.1"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
